/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qdatetime_wrapper.h"

// Extra includes
#include <qdatetime.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDateTime_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDateTime >()))
        return -1;

    QDateTime* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "spec" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDateTime(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDateTime(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QDateTime", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QDateTime()
    // 1: QDateTime(QDate)
    // 2: QDateTime(QDate,QTime,Qt::TimeSpec)
    // 3: QDateTime(QDateTime)
    if (numArgs == 0) {
        overloadId = 0; // QDateTime()
    } else if (numArgs == 1 && Shiboken::Converter<const QDateTime & >::isConvertible(pyargs[0])) {
        overloadId = 3; // QDateTime(QDateTime)
    } else if (Shiboken::Converter<const QDate & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QDateTime(QDate)
        } else if (Shiboken::Converter<const QTime & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QDateTime(QDate,QTime,Qt::TimeSpec)
            } else if (Shiboken::Converter<Qt::TimeSpec >::isConvertible(pyargs[2])) {
                overloadId = 2; // QDateTime(QDate,QTime,Qt::TimeSpec)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTime_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDateTime()
            {

                if(!PyErr_Occurred()) {
                // QDateTime()
                cptr = new QDateTime();
                }
                break;
            }
            case 1: // QDateTime(QDate)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QDate* cpp_arg0 = Shiboken::Converter<QDate* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QDateTime(QDate)
                cptr = new QDateTime(*cpp_arg0);
                }
                break;
            }
            case 2: // QDateTime(QDate,QTime,Qt::TimeSpec)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "spec");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "spec";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDateTime(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QDate* cpp_arg0 = Shiboken::Converter<QDate* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QTime* cpp_arg1 = Shiboken::Converter<QTime* >::toCpp(pyargs[1]);
                Qt::TimeSpec cpp_arg2 = pyargs[2] ? Shiboken::Converter<Qt::TimeSpec >::toCpp(pyargs[2]) : Qt::LocalTime;

                if(!PyErr_Occurred()) {
                // QDateTime(QDate,QTime,Qt::TimeSpec)
                cptr = new QDateTime(*cpp_arg0, *cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 3: // QDateTime(QDateTime)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QDateTime* cpp_arg0 = Shiboken::Converter<QDateTime* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QDateTime(QDateTime)
                cptr = new QDateTime(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDateTime >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDateTime_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDateTime_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QDate", "PySide.QtCore.QDate, PySide.QtCore.QTime, PySide.QtCore.Qt.TimeSpec = Qt.LocalTime", "PySide.QtCore.QDateTime", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDateTime", overloads);
        return -1;
}

static PyObject* SbkQDateTimeFunc_addDays(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addDays(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // addDays(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_addDays_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addDays(int)const
            QDateTime cppResult = cppSelf->QDateTime::addDays(cpp_arg0);
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateTimeFunc_addDays_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.addDays", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_addMSecs(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addMSecs(qint64)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // addMSecs(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_addMSecs_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addMSecs(qint64)const
            QDateTime cppResult = cppSelf->QDateTime::addMSecs(cpp_arg0);
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateTimeFunc_addMSecs_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.addMSecs", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_addMonths(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addMonths(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // addMonths(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_addMonths_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addMonths(int)const
            QDateTime cppResult = cppSelf->QDateTime::addMonths(cpp_arg0);
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateTimeFunc_addMonths_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.addMonths", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_addSecs(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addSecs(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // addSecs(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_addSecs_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addSecs(int)const
            QDateTime cppResult = cppSelf->QDateTime::addSecs(cpp_arg0);
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateTimeFunc_addSecs_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.addSecs", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_addYears(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addYears(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // addYears(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_addYears_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addYears(int)const
            QDateTime cppResult = cppSelf->QDateTime::addYears(cpp_arg0);
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateTimeFunc_addYears_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.addYears", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_currentDateTime(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentDateTime()
            QDateTime cppResult = QDateTime::currentDateTime();
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateTimeFunc_currentDateTimeUtc(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentDateTimeUtc()
            QDateTime cppResult = QDateTime::currentDateTimeUtc();
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateTimeFunc_currentMSecsSinceEpoch(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentMSecsSinceEpoch()
            qint64 cppResult = QDateTime::currentMSecsSinceEpoch();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateTimeFunc_date(PyObject* self)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // date()const
            QDate cppResult = cppSelf->QDateTime::date();
            pyResult = Shiboken::Converter<QDate >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateTimeFunc_daysTo(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: daysTo(QDateTime)const
    if (Shiboken::Converter<const QDateTime & >::isConvertible(arg)) {
        overloadId = 0; // daysTo(QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_daysTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDateTime* cpp_arg0 = Shiboken::Converter<QDateTime* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // daysTo(QDateTime)const
            int cppResult = cppSelf->QDateTime::daysTo(*cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateTimeFunc_daysTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDateTime", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.daysTo", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_fromMSecsSinceEpoch(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromMSecsSinceEpoch(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // fromMSecsSinceEpoch(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_fromMSecsSinceEpoch_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // fromMSecsSinceEpoch(qint64)
            QDateTime cppResult = QDateTime::fromMSecsSinceEpoch(cpp_arg0);
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateTimeFunc_fromMSecsSinceEpoch_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.fromMSecsSinceEpoch", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_fromString(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "f" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDateTime.fromString(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDateTime.fromString(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDateTime.fromString(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromString", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromString(QString,Qt::DateFormat)
    // 1: fromString(QString,QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromString(QString,Qt::DateFormat)
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // fromString(QString,QString)
        } else if (Shiboken::Converter<Qt::DateFormat >::isConvertible(pyargs[1])) {
            overloadId = 0; // fromString(QString,Qt::DateFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_fromString_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fromString(QString,Qt::DateFormat)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "f");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "f";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDateTime.fromString(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                Qt::DateFormat cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::DateFormat >::toCpp(pyargs[1]) : Qt::TextDate;

                if(!PyErr_Occurred()) {
                // fromString(QString,Qt::DateFormat)
                QDateTime cppResult = QDateTime::fromString(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
                }
                break;
            }
            case 1: // fromString(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // fromString(QString,QString)
                QDateTime cppResult = QDateTime::fromString(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateTimeFunc_fromString_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.Qt.DateFormat = Qt.TextDate", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDateTime.fromString", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_fromTime_t(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromTime_t(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // fromTime_t(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_fromTime_t_TypeError;

    // Call function/method
    {
        {
            uint cpp_arg0 = Shiboken::Converter<uint >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // fromTime_t(uint)
            QDateTime cppResult = QDateTime::fromTime_t(cpp_arg0);
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateTimeFunc_fromTime_t_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.fromTime_t", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_isNull(PyObject* self)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QDateTime::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateTimeFunc_isValid(PyObject* self)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QDateTime::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateTimeFunc_msecsTo(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: msecsTo(QDateTime)const
    if (Shiboken::Converter<const QDateTime & >::isConvertible(arg)) {
        overloadId = 0; // msecsTo(QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_msecsTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDateTime* cpp_arg0 = Shiboken::Converter<QDateTime* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // msecsTo(QDateTime)const
            qint64 cppResult = cppSelf->QDateTime::msecsTo(*cpp_arg0);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateTimeFunc_msecsTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDateTime", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.msecsTo", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_secsTo(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: secsTo(QDateTime)const
    if (Shiboken::Converter<const QDateTime & >::isConvertible(arg)) {
        overloadId = 0; // secsTo(QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_secsTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDateTime* cpp_arg0 = Shiboken::Converter<QDateTime* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // secsTo(QDateTime)const
            int cppResult = cppSelf->QDateTime::secsTo(*cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateTimeFunc_secsTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDateTime", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.secsTo", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_setDate(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDate(QDate)
    if (Shiboken::Converter<const QDate & >::isConvertible(arg)) {
        overloadId = 0; // setDate(QDate)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_setDate_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDate* cpp_arg0 = Shiboken::Converter<QDate* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDate(QDate)
            cppSelf->QDateTime::setDate(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDateTimeFunc_setDate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDate", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.setDate", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_setMSecsSinceEpoch(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMSecsSinceEpoch(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMSecsSinceEpoch(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_setMSecsSinceEpoch_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMSecsSinceEpoch(qint64)
            cppSelf->QDateTime::setMSecsSinceEpoch(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDateTimeFunc_setMSecsSinceEpoch_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.setMSecsSinceEpoch", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_setTime(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTime(QTime)
    if (Shiboken::Converter<const QTime & >::isConvertible(arg)) {
        overloadId = 0; // setTime(QTime)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_setTime_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTime* cpp_arg0 = Shiboken::Converter<QTime* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTime(QTime)
            cppSelf->QDateTime::setTime(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDateTimeFunc_setTime_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTime", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.setTime", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_setTimeSpec(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTimeSpec(Qt::TimeSpec)
    if (Shiboken::Converter<Qt::TimeSpec >::isConvertible(arg)) {
        overloadId = 0; // setTimeSpec(Qt::TimeSpec)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_setTimeSpec_TypeError;

    // Call function/method
    {
        {
            Qt::TimeSpec cpp_arg0 = Shiboken::Converter<Qt::TimeSpec >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTimeSpec(Qt::TimeSpec)
            cppSelf->QDateTime::setTimeSpec(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDateTimeFunc_setTimeSpec_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.TimeSpec", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.setTimeSpec", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_setTime_t(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTime_t(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTime_t(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_setTime_t_TypeError;

    // Call function/method
    {
        {
            uint cpp_arg0 = Shiboken::Converter<uint >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTime_t(uint)
            cppSelf->QDateTime::setTime_t(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDateTimeFunc_setTime_t_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.setTime_t", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_setUtcOffset(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUtcOffset(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUtcOffset(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_setUtcOffset_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUtcOffset(int)
            cppSelf->QDateTime::setUtcOffset(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDateTimeFunc_setUtcOffset_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.setUtcOffset", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_time(PyObject* self)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // time()const
            QTime cppResult = cppSelf->QDateTime::time();
            pyResult = Shiboken::Converter<QTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateTimeFunc_timeSpec(PyObject* self)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // timeSpec()const
            Qt::TimeSpec cppResult = cppSelf->QDateTime::timeSpec();
            pyResult = Shiboken::Converter<Qt::TimeSpec >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateTimeFunc_toLocalTime(PyObject* self)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toLocalTime()const
            QDateTime cppResult = cppSelf->QDateTime::toLocalTime();
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateTimeFunc_toMSecsSinceEpoch(PyObject* self)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toMSecsSinceEpoch()const
            qint64 cppResult = cppSelf->QDateTime::toMSecsSinceEpoch();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateTimeFunc_toString(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "f" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDateTime.toString(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDateTime.toString(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toString", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toString(Qt::DateFormat)const
    // 1: toString(QString)const
    if (numArgs == 0) {
        overloadId = 0; // toString(Qt::DateFormat)const
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // toString(QString)const
    } else if (Shiboken::Converter<Qt::DateFormat >::isConvertible(arg)) {
        overloadId = 0; // toString(Qt::DateFormat)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_toString_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toString(Qt::DateFormat)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "f");
                    if (value) {
                        if (arg)
                            errorArgName = "f";
                        else
                            arg = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDateTime.toString(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                Qt::DateFormat cpp_arg0 = arg ? Shiboken::Converter<Qt::DateFormat >::toCpp(arg) : Qt::TextDate;

                if(!PyErr_Occurred()) {
                // toString(Qt::DateFormat)const
                QString cppResult = cppSelf->QDateTime::toString(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // toString(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // toString(QString)const
                QString cppResult = cppSelf->QDateTime::toString(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateTimeFunc_toString_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DateFormat = Qt.TextDate", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.toString", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_toTimeSpec(PyObject* self, PyObject* arg)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toTimeSpec(Qt::TimeSpec)const
    if (Shiboken::Converter<Qt::TimeSpec >::isConvertible(arg)) {
        overloadId = 0; // toTimeSpec(Qt::TimeSpec)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateTimeFunc_toTimeSpec_TypeError;

    // Call function/method
    {
        {
            Qt::TimeSpec cpp_arg0 = Shiboken::Converter<Qt::TimeSpec >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // toTimeSpec(Qt::TimeSpec)const
            QDateTime cppResult = cppSelf->QDateTime::toTimeSpec(cpp_arg0);
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateTimeFunc_toTimeSpec_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.TimeSpec", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDateTime.toTimeSpec", overloads);
        return 0;
}

static PyObject* SbkQDateTimeFunc_toTime_t(PyObject* self)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toTime_t()const
            uint cppResult = cppSelf->QDateTime::toTime_t();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateTimeFunc_toUTC(PyObject* self)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toUTC()const
            QDateTime cppResult = cppSelf->QDateTime::toUTC();
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateTimeFunc_utcOffset(PyObject* self)
{
    QDateTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDateTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // utcOffset()const
            int cppResult = cppSelf->QDateTime::utcOffset();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQDateTime_methods[] = {
    {"addDays", (PyCFunction)SbkQDateTimeFunc_addDays, METH_O},
    {"addMSecs", (PyCFunction)SbkQDateTimeFunc_addMSecs, METH_O},
    {"addMonths", (PyCFunction)SbkQDateTimeFunc_addMonths, METH_O},
    {"addSecs", (PyCFunction)SbkQDateTimeFunc_addSecs, METH_O},
    {"addYears", (PyCFunction)SbkQDateTimeFunc_addYears, METH_O},
    {"currentDateTime", (PyCFunction)SbkQDateTimeFunc_currentDateTime, METH_NOARGS|METH_STATIC},
    {"currentDateTimeUtc", (PyCFunction)SbkQDateTimeFunc_currentDateTimeUtc, METH_NOARGS|METH_STATIC},
    {"currentMSecsSinceEpoch", (PyCFunction)SbkQDateTimeFunc_currentMSecsSinceEpoch, METH_NOARGS|METH_STATIC},
    {"date", (PyCFunction)SbkQDateTimeFunc_date, METH_NOARGS},
    {"daysTo", (PyCFunction)SbkQDateTimeFunc_daysTo, METH_O},
    {"fromMSecsSinceEpoch", (PyCFunction)SbkQDateTimeFunc_fromMSecsSinceEpoch, METH_O|METH_STATIC},
    {"fromString", (PyCFunction)SbkQDateTimeFunc_fromString, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromTime_t", (PyCFunction)SbkQDateTimeFunc_fromTime_t, METH_O|METH_STATIC},
    {"isNull", (PyCFunction)SbkQDateTimeFunc_isNull, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQDateTimeFunc_isValid, METH_NOARGS},
    {"msecsTo", (PyCFunction)SbkQDateTimeFunc_msecsTo, METH_O},
    {"secsTo", (PyCFunction)SbkQDateTimeFunc_secsTo, METH_O},
    {"setDate", (PyCFunction)SbkQDateTimeFunc_setDate, METH_O},
    {"setMSecsSinceEpoch", (PyCFunction)SbkQDateTimeFunc_setMSecsSinceEpoch, METH_O},
    {"setTime", (PyCFunction)SbkQDateTimeFunc_setTime, METH_O},
    {"setTimeSpec", (PyCFunction)SbkQDateTimeFunc_setTimeSpec, METH_O},
    {"setTime_t", (PyCFunction)SbkQDateTimeFunc_setTime_t, METH_O},
    {"setUtcOffset", (PyCFunction)SbkQDateTimeFunc_setUtcOffset, METH_O},
    {"time", (PyCFunction)SbkQDateTimeFunc_time, METH_NOARGS},
    {"timeSpec", (PyCFunction)SbkQDateTimeFunc_timeSpec, METH_NOARGS},
    {"toLocalTime", (PyCFunction)SbkQDateTimeFunc_toLocalTime, METH_NOARGS},
    {"toMSecsSinceEpoch", (PyCFunction)SbkQDateTimeFunc_toMSecsSinceEpoch, METH_NOARGS},
    {"toString", (PyCFunction)SbkQDateTimeFunc_toString, METH_VARARGS|METH_KEYWORDS},
    {"toTimeSpec", (PyCFunction)SbkQDateTimeFunc_toTimeSpec, METH_O},
    {"toTime_t", (PyCFunction)SbkQDateTimeFunc_toTime_t, METH_NOARGS},
    {"toUTC", (PyCFunction)SbkQDateTimeFunc_toUTC, METH_NOARGS},
    {"utcOffset", (PyCFunction)SbkQDateTimeFunc_utcOffset, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQDateTime_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QDateTime& cpp_self = *Shiboken::Converter<QDateTime* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QDateTime & >::isConvertible(other)) {
                // operator!=(const QDateTime & other) const
                QDateTime* cpp_other = Shiboken::Converter<QDateTime* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDateTime  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQDateTime_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter<const QDateTime & >::isConvertible(other)) {
                // operator<(const QDateTime & other) const
                QDateTime* cpp_other = Shiboken::Converter<QDateTime* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDateTime  >::toCpp(other) : (cpp_self < (*cpp_other));
            } else goto SbkQDateTime_RichComparison_TypeError;

            break;
        case Py_LE:
            if (Shiboken::Converter<const QDateTime & >::isConvertible(other)) {
                // operator<=(const QDateTime & other) const
                QDateTime* cpp_other = Shiboken::Converter<QDateTime* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDateTime  >::toCpp(other) : (cpp_self <= (*cpp_other));
            } else goto SbkQDateTime_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QDateTime & >::isConvertible(other)) {
                // operator==(const QDateTime & other) const
                QDateTime* cpp_other = Shiboken::Converter<QDateTime* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDateTime  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQDateTime_RichComparison_TypeError;

            break;
        case Py_GT:
            if (Shiboken::Converter<const QDateTime & >::isConvertible(other)) {
                // operator>(const QDateTime & other) const
                QDateTime* cpp_other = Shiboken::Converter<QDateTime* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDateTime  >::toCpp(other) : (cpp_self > (*cpp_other));
            } else goto SbkQDateTime_RichComparison_TypeError;

            break;
        case Py_GE:
            if (Shiboken::Converter<const QDateTime & >::isConvertible(other)) {
                // operator>=(const QDateTime & other) const
                QDateTime* cpp_other = Shiboken::Converter<QDateTime* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDateTime  >::toCpp(other) : (cpp_self >= (*cpp_other));
            } else goto SbkQDateTime_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQDateTime_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

static long SbkQDateTime_HashFunc(PyObject* obj){
    return PySide::hash(Shiboken::Converter<QDateTime >::toCpp(obj));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDateTime_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QDateTime",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &SbkQDateTime_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQDateTime_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDateTime_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDateTime_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDateTime >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDateTime",
    /*user_data*/           0
};
} //extern


void init_QDateTime(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QDATETIME_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDateTime_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDateTime_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDateTime_Type));
    PyModule_AddObject(module, "QDateTime",
        ((PyObject*)&SbkQDateTime_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDateTime >("QDateTime");
    Shiboken::TypeResolver::createObjectTypeResolver<QDateTime >("QDateTime*");
    Shiboken::TypeResolver::createValueTypeResolver<QDateTime >(typeid(QDateTime).name());
    PySide::initQtMetaType<QDateTime >();
}

