/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qgenericargument_wrapper.h"

// Extra includes

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGenericArgument_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGenericArgument >()))
        return -1;

    QGenericArgument* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "aData", "aName" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QGenericArgument(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QGenericArgument(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QGenericArgument", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QGenericArgument(QGenericArgument)
    // 1: QGenericArgument(const char*,const void*)
    if (numArgs == 0) {
        overloadId = 1; // QGenericArgument(const char*,const void*)
    } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QGenericArgument(const char*,const void*)
        } else if (Shiboken::Converter<const void * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QGenericArgument(const char*,const void*)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QGenericArgument & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QGenericArgument(QGenericArgument)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGenericArgument_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGenericArgument(QGenericArgument)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QGenericArgument* cpp_arg0 = Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QGenericArgument(QGenericArgument)
                cptr = new QGenericArgument(*cpp_arg0);
                }
                break;
            }
            case 1: // QGenericArgument(const char*,const void*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aName");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "aName";
                        else
                            pyargs[0] = value;
                    }
                    value = PyDict_GetItemString(kwds, "aData");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "aData";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QGenericArgument(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                const char * cpp_arg0 = pyargs[0] ? Shiboken::Converter<const char * >::toCpp(pyargs[0]) : 0;
                const void * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const void * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QGenericArgument(const char*,const void*)
                cptr = new QGenericArgument(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGenericArgument >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGenericArgument_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQGenericArgument_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QGenericArgument", "str = None, void = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QGenericArgument", overloads);
        return -1;
}

static PyObject* SbkQGenericArgumentFunc_data(PyObject* self)
{
    QGenericArgument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGenericArgument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // data()const
            void * cppResult = cppSelf->QGenericArgument::data();
            pyResult = Shiboken::Converter<void * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGenericArgumentFunc_name(PyObject* self)
{
    QGenericArgument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGenericArgument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            const char * cppResult = cppSelf->QGenericArgument::name();
            pyResult = Shiboken::Converter<const char * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQGenericArgument_methods[] = {
    {"data", (PyCFunction)SbkQGenericArgumentFunc_data, METH_NOARGS},
    {"name", (PyCFunction)SbkQGenericArgumentFunc_name, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGenericArgument_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QGenericArgument",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGenericArgument_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGenericArgument_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGenericArgument >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGenericArgument",
    /*user_data*/           0
};
} //extern


void init_QGenericArgument(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QGENERICARGUMENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGenericArgument_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGenericArgument_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGenericArgument_Type));
    PyModule_AddObject(module, "QGenericArgument",
        ((PyObject*)&SbkQGenericArgument_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QGenericArgument >("QGenericArgument");
    Shiboken::TypeResolver::createObjectTypeResolver<QGenericArgument >("QGenericArgument*");
    Shiboken::TypeResolver::createValueTypeResolver<QGenericArgument >(typeid(QGenericArgument).name());
    PySide::initQtMetaType<QGenericArgument >();
}

