/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtcore_python.h"

#include "qobject_wrapper.h"

// Extra includes
#include <QCoreApplication>
#include <QList>
#include <QThread>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include "signalmanager.h"

using namespace Shiboken;

// Begin code injection
// ========================================================================
// START of custom code block [file: glue/qobject_connect.cpp]
static bool getReceiver(PyObject *callback, QObject **receiver, PyObject **self)
{
    if (PyMethod_Check(callback)) {
        *self = PyMethod_GET_SELF(callback);
        if (Shiboken::Converter<QObject*>::checkType(*self))
            *receiver = Converter<QObject*>::toCpp(*self);
    } else if (PyCFunction_Check(callback)) {
        *self = PyCFunction_GET_SELF(callback);
        if (*self && Shiboken::Converter<QObject*>::checkType(*self))
            *receiver = Converter<QObject*>::toCpp(*self);
    } else if (PyCallable_Check(callback)) {
        // Ok, just a callable object
        *receiver = 0;
        *self = 0;
    }

    bool usingGlobalReceiver = !*receiver;
    if (usingGlobalReceiver) {
        PySide::SignalManager& signalManager = PySide::SignalManager::instance();
        *receiver = signalManager.globalReceiver();
    }

    return usingGlobalReceiver;
}

static bool qobjectConnect(QObject* source, const char* signal, QObject* receiver, const char* slot, Qt::ConnectionType type)
{
    if (!signal || !slot)
        return false;

    if (!PySide::checkSignal(signal))
        return false;
    signal++;

    PySide::SignalManager::registerMetaMethod(source, signal, QMetaMethod::Signal);

    bool isSignal = PySide::isSignal(slot);
    slot++;
    PySide::SignalManager::registerMetaMethod(receiver, slot, isSignal ? QMetaMethod::Signal : QMetaMethod::Slot);
    return QObject::connect(source, signal - 1, receiver, slot - 1, type);
}

static bool qobjectConnectCallback(QObject* source, const char* signal, PyObject* callback, Qt::ConnectionType type)
{
    if (!signal || !PySide::checkSignal(signal))
        return false;
    signal++;

    PySide::SignalManager::registerMetaMethod(source, signal, QMetaMethod::Signal);
    int signalIndex = source->metaObject()->indexOfMethod(signal);

    PySide::SignalManager& signalManager = PySide::SignalManager::instance();

    // Extract receiver from callback
    QObject* receiver = 0;
    PyObject* self = 0;
    bool usingGlobalReceiver = getReceiver(callback, &receiver, &self);
    if (receiver == 0 && self == 0)
        return false;

    const QMetaObject* metaObject = receiver->metaObject();
    const QByteArray callbackSig = PySide::getCallbackSignature(signal, receiver, callback, usingGlobalReceiver).toAscii();
    const char* slot = callbackSig.constData();
    int slotIndex = metaObject->indexOfSlot(slot);
    if (slotIndex == -1) {
        if (!usingGlobalReceiver && self && !((SbkBaseWrapper*)self)->containsCppWrapper) {
            qWarning() << "You can't add dynamic slots on an object originated from C++.";
            return false;
        }
        if (usingGlobalReceiver) {
            signalManager.addGlobalSlot(slot, callback);
        } else {
            PySide::SignalManager::registerMetaMethod(receiver, slot, QMetaMethod::Slot);
        }
        slotIndex = metaObject->indexOfSlot(slot);
    }
    if (QMetaObject::connect(source, signalIndex, receiver, slotIndex, type)) {
        #ifndef AVOID_PROTECTED_HACK
            source->connectNotify(signal - 1);
        #else
            // Need to cast to QObjectWrapper* and call the public version of
            // connectNotify when avoiding the protected hack.
            reinterpret_cast<QObjectWrapper*>(source)->connectNotify(signal - 1);
        #endif
        if (usingGlobalReceiver)
            signalManager.globalReceiverConnectNotify(source, slotIndex);

        return true;
    }
    return false;
}


static bool qobjectDisconnectCallback(QObject* source, const char* signal, PyObject* callback)
{
    if (!PySide::checkSignal(signal))
        return false;

    PySide::SignalManager& signalManager = PySide::SignalManager::instance();

    // Extract receiver from callback
    QObject* receiver = 0;
    PyObject* self = 0;
    bool usingGlobalReceiver = getReceiver(callback, &receiver, &self);
    if (receiver == 0 && self == 0)
        return false;

    const QMetaObject* metaObject = receiver->metaObject();
    const QByteArray callbackSig = PySide::getCallbackSignature(signal, receiver, callback, usingGlobalReceiver).toAscii();
    QByteArray qtSlotName(callbackSig);
    qtSlotName = qtSlotName.prepend('1');

    if (QObject::disconnect(source, signal, receiver, qtSlotName.constData())) {
        if (usingGlobalReceiver) {
            int slotIndex = metaObject->indexOfSlot(callbackSig.constData());
            signalManager.globalReceiverDisconnectNotify(source, slotIndex);
        }
        return true;
    }
    return false;
}

// END of custom code block [file: glue/qobject_connect.cpp]
// ========================================================================

// End of code injection
// Begin code injection

static bool
qobjectInheritsInternal(PyTypeObject *objType, const char *class_name)
{
    if (strcmp(objType->tp_name, class_name) == 0)
        return true;

    PyTypeObject* base = (objType)->tp_base;
    if (base == 0)
        return false;
    return qobjectInheritsInternal(base, class_name);
}

// End of code injection
// Begin code injection
// ========================================================================
// START of custom code block [file: glue/qobject_findchild.cpp]
static QObject* _findChildHelper(const QObject* parent, const QString& name, PyTypeObject* desiredType)
{
    foreach(QObject* child, parent->children()) {
        Shiboken::AutoDecRef pyChild(Shiboken::Converter<QObject* >::toPython(child));
        if (PyType_IsSubtype(pyChild->ob_type, desiredType)
            && (name.isNull() || name == child->objectName())) {
            return child;
        }
    }

    QObject* obj;
    foreach(QObject* child, parent->children()) {
        obj = _findChildHelper(child, name, desiredType);
        if (obj)
            return obj;
    }
    return 0;
}

static void _findChildrenHelper(const QObject* parent, const QString& name, PyTypeObject* desiredType, PyObject* result)
{
    foreach(QObject* child, parent->children()) {
        Shiboken::AutoDecRef pyChild(Shiboken::Converter<QObject* >::toPython(child));
        if (PyType_IsSubtype(pyChild->ob_type, desiredType)
            && (name.isNull() || name == child->objectName())) {
            PyList_Append(result, pyChild);
        }
        _findChildrenHelper(child, name, desiredType, result);
    }
}
// END of custom code block [file: glue/qobject_findchild.cpp]
// ========================================================================

// End of code injection

// Native ---------------------------------------------------------

QObjectWrapper::QObjectWrapper(QObject * parent) : QObject(parent), m_metaObject(0) {
    // ... middle
}

void QObjectWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QObjectWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QObjectWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QObjectWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QObjectWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QObject.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QObjectWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QObject.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QObjectWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QObjectWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QObject::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QObjectWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QObject::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QObjectWrapper::~QObjectWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQObject_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QObject >()))
        return -1;

    QObjectWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QObject", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QObject(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QObject(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QObject(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObject_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QObject(QObject*)
            cptr = new QObjectWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQObject_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQObject_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QObject", overloads);
        return -1;
}

static PyObject* SbkQObjectFunc_blockSignals(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: blockSignals(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // blockSignals(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_blockSignals_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // blockSignals(bool)
            bool cppResult = cppSelf->QObject::blockSignals(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_blockSignals_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.blockSignals", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_childEvent(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: childEvent(QChildEvent*)
    if (Shiboken::Converter<QChildEvent * >::isConvertible(arg)) {
        overloadId = 0; // childEvent(QChildEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_childEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QChildEvent* cpp_arg0 = Shiboken::Converter<QChildEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // childEvent(QChildEvent*)
            cppSelf->QObject::childEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQObjectFunc_childEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QChildEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.childEvent", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_children(PyObject* self)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // children()const
            const QList<QObject * > & cppResult = cppSelf->QObject::children();
            pyResult = Shiboken::Converter< QList<QObject * >  >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQObjectFunc_connect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QObject* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QObject* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "type" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject.connect(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QObject.connect(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QObject.connect(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:connect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: connect(const QObject*,const char*,PyCallable*,Qt::ConnectionType)
    // 1: connect(const QObject*,const char*,const QObject*,const char*,Qt::ConnectionType)
    // 2: connect(const QObject*,const char*,const char*,Qt::ConnectionType)const
    // 3: connect(const char*,PyCallable*,Qt::ConnectionType)
    // 4: connect(const char*,const QObject*,const char*,Qt::ConnectionType)
    if (Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        if (numArgs >= 3 && Shiboken::Converter<const QObject * >::isConvertible(pyargs[1]) && Shiboken::Converter<const char * >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 4; // connect(const char*,const QObject*,const char*,Qt::ConnectionType)
            } else if (Shiboken::Converter<Qt::ConnectionType >::isConvertible(pyargs[3])) {
                overloadId = 4; // connect(const char*,const QObject*,const char*,Qt::ConnectionType)
            }
        } else if (PyCallable_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 3; // connect(const char*,PyCallable*,Qt::ConnectionType)
            } else if (Shiboken::Converter<Qt::ConnectionType >::isConvertible(pyargs[2])) {
                overloadId = 3; // connect(const char*,PyCallable*,Qt::ConnectionType)
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
        if (Shiboken::Converter<const char * >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 2; // connect(const QObject*,const char*,const char*,Qt::ConnectionType)const
            } else if (Shiboken::Converter<Qt::ConnectionType >::isConvertible(pyargs[3])) {
                overloadId = 2; // connect(const QObject*,const char*,const char*,Qt::ConnectionType)const
            }
        } else if (numArgs >= 4 && Shiboken::Converter<const QObject * >::isConvertible(pyargs[2]) && Shiboken::Converter<const char * >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 1; // connect(const QObject*,const char*,const QObject*,const char*,Qt::ConnectionType)
            } else if (Shiboken::Converter<Qt::ConnectionType >::isConvertible(pyargs[4])) {
                overloadId = 1; // connect(const QObject*,const char*,const QObject*,const char*,Qt::ConnectionType)
            }
        } else if (PyCallable_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // connect(const QObject*,const char*,PyCallable*,Qt::ConnectionType)
            } else if (Shiboken::Converter<Qt::ConnectionType >::isConvertible(pyargs[3])) {
                overloadId = 0; // connect(const QObject*,const char*,PyCallable*,Qt::ConnectionType)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_connect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // connect(const QObject*,const char*,PyCallable*,Qt::ConnectionType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "type";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject.connect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                Qt::ConnectionType cpp_arg3 = pyargs[3] ? Shiboken::Converter<Qt::ConnectionType >::toCpp(pyargs[3]) : Qt::AutoConnection;

                if(!PyErr_Occurred()) {
                // connect(const QObject*,const char*,PyCallable*,Qt::ConnectionType)
                // Begin code injection
                
                // connect() - disable generation of function call.
                pyResult = Shiboken::Converter<bool >::toPython(qobjectConnectCallback(cpp_arg0, cpp_arg1, pyargs[3-1], cpp_arg3));
                
                // End of code injection


                }
                break;
            }
            case 1: // connect(const QObject*,const char*,const QObject*,const char*,Qt::ConnectionType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "type";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject.connect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QObject* cpp_arg2 = Shiboken::Converter<QObject* >::toCpp(pyargs[2]);
                const char * cpp_arg3 = Shiboken::Converter<const char * >::toCpp(pyargs[3]);
                Qt::ConnectionType cpp_arg4 = pyargs[4] ? Shiboken::Converter<Qt::ConnectionType >::toCpp(pyargs[4]) : Qt::AutoConnection;

                if(!PyErr_Occurred()) {
                // connect(const QObject*,const char*,const QObject*,const char*,Qt::ConnectionType)
                // Begin code injection
                
                // connect() - disable generation of function call.
                pyResult = Shiboken::Converter<bool >::toPython(qobjectConnect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4));
                
                // End of code injection


                }
                break;
            }
            case 2: // connect(const QObject*,const char*,const char*,Qt::ConnectionType)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "type";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject.connect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                const char * cpp_arg2 = Shiboken::Converter<const char * >::toCpp(pyargs[2]);
                Qt::ConnectionType cpp_arg3 = pyargs[3] ? Shiboken::Converter<Qt::ConnectionType >::toCpp(pyargs[3]) : Qt::AutoConnection;

                if(!PyErr_Occurred()) {
                // connect(const QObject*,const char*,const char*,Qt::ConnectionType)const
                // Begin code injection
                
                // connect() - disable generation of function call.
                pyResult = Shiboken::Converter<bool >::toPython(qobjectConnect(cpp_arg0, cpp_arg1, cppSelf, cpp_arg2, cpp_arg3));
                
                // End of code injection


                }
                break;
            }
            case 3: // connect(const char*,PyCallable*,Qt::ConnectionType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "type";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject.connect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                Qt::ConnectionType cpp_arg2 = pyargs[2] ? Shiboken::Converter<Qt::ConnectionType >::toCpp(pyargs[2]) : Qt::AutoConnection;

                if(!PyErr_Occurred()) {
                // connect(const char*,PyCallable*,Qt::ConnectionType)
                // Begin code injection
                
                // connect() - disable generation of function call.
                pyResult = Shiboken::Converter<bool >::toPython(qobjectConnectCallback(cppSelf, cpp_arg0, pyargs[2-1], cpp_arg2));
                
                // End of code injection


                }
                break;
            }
            case 4: // connect(const char*,const QObject*,const char*,Qt::ConnectionType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "type";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject.connect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QObject* cpp_arg1 = Shiboken::Converter<QObject* >::toCpp(pyargs[1]);
                const char * cpp_arg2 = Shiboken::Converter<const char * >::toCpp(pyargs[2]);
                Qt::ConnectionType cpp_arg3 = pyargs[3] ? Shiboken::Converter<Qt::ConnectionType >::toCpp(pyargs[3]) : Qt::AutoConnection;

                if(!PyErr_Occurred()) {
                // connect(const char*,const QObject*,const char*,Qt::ConnectionType)
                // Begin code injection
                
                // connect() - disable generation of function call.
                pyResult = Shiboken::Converter<bool >::toPython(qobjectConnect(cppSelf, cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3));
                
                // End of code injection


                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_connect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, str, PyCallable, PySide.QtCore.Qt.ConnectionType = Qt.AutoConnection", "PySide.QtCore.QObject, str, PySide.QtCore.QObject, str, PySide.QtCore.Qt.ConnectionType = Qt.AutoConnection", "PySide.QtCore.QObject, str, str, PySide.QtCore.Qt.ConnectionType = Qt.AutoConnection", "str, PyCallable, PySide.QtCore.Qt.ConnectionType = Qt.AutoConnection", "str, PySide.QtCore.QObject, str, PySide.QtCore.Qt.ConnectionType = Qt.AutoConnection", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QObject.connect", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_connectNotify(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: connectNotify(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // connectNotify(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_connectNotify_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // connectNotify(const char*)
            cppSelf->QObject::connectNotify(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQObjectFunc_connectNotify_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.connectNotify", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_customEvent(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: customEvent(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // customEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_customEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // customEvent(QEvent*)
            cppSelf->QObject::customEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQObjectFunc_customEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.customEvent", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_deleteLater(PyObject* self)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // deleteLater()
            cppSelf->QObject::deleteLater();

            // Ownership transferences.
            BindingManager::instance().transferOwnershipToCpp(self);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQObjectFunc_disconnect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QObject* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QObject* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "member", "receiver", "signal" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject.disconnect(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QObject.disconnect(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:disconnect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: disconnect(const QObject*,const char*,PyCallable*)
    // 1: disconnect(const QObject*,const char*)
    // 2: disconnect(const QObject*,const char*,const QObject*,const char*)
    // 3: disconnect(const char*,PyCallable*)
    // 4: disconnect(const char*,const QObject*,const char*)
    if (numArgs == 0) {
        overloadId = 4; // disconnect(const char*,const QObject*,const char*)
    } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 4; // disconnect(const char*,const QObject*,const char*)
        } else if (Shiboken::Converter<const QObject * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 4; // disconnect(const char*,const QObject*,const char*)
            } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[2])) {
                overloadId = 4; // disconnect(const char*,const QObject*,const char*)
            }
        } else if (numArgs == 2 && PyCallable_Check(pyargs[1])) {
            overloadId = 3; // disconnect(const char*,PyCallable*)
        }
    } else if (Shiboken::Converter<const QObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // disconnect(const QObject*,const char*)
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // disconnect(const QObject*,const char*)
            } else if (numArgs == 4 && Shiboken::Converter<const QObject * >::isConvertible(pyargs[2]) && Shiboken::Converter<const char * >::isConvertible(pyargs[3])) {
                overloadId = 2; // disconnect(const QObject*,const char*,const QObject*,const char*)
            } else if (numArgs == 3 && PyCallable_Check(pyargs[2])) {
                overloadId = 0; // disconnect(const QObject*,const char*,PyCallable*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_disconnect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // disconnect(const QObject*,const char*,PyCallable*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // disconnect(const QObject*,const char*,PyCallable*)
                // Begin code injection
                
                // disconnect() - disable generation of function call.
                pyResult = Shiboken::Converter<bool >::toPython(qobjectDisconnectCallback(cpp_arg0, cpp_arg1, pyargs[2]));
                
                // End of code injection


                }
                break;
            }
            case 1: // disconnect(const QObject*,const char*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "member");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "member";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject.disconnect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // disconnect(const QObject*,const char*)
                bool cppResult = cppSelf->QObject::disconnect(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // disconnect(const QObject*,const char*,const QObject*,const char*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QObject* cpp_arg2 = Shiboken::Converter<QObject* >::toCpp(pyargs[2]);
                const char * cpp_arg3 = Shiboken::Converter<const char * >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // disconnect(const QObject*,const char*,const QObject*,const char*)
                bool cppResult = QObject::disconnect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 3: // disconnect(const char*,PyCallable*)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // disconnect(const char*,PyCallable*)
                // Begin code injection
                
                // disconnect() - disable generation of function call.
                pyResult = Shiboken::Converter<bool >::toPython(qobjectDisconnectCallback(cppSelf, cpp_arg0, pyargs[1]));
                
                // End of code injection


                }
                break;
            }
            case 4: // disconnect(const char*,const QObject*,const char*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "signal");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "signal";
                        else
                            pyargs[0] = value;
                    }
                    value = PyDict_GetItemString(kwds, "receiver");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "receiver";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "member");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "member";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject.disconnect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cpp_arg0 = pyargs[0] ? Shiboken::Converter<const char * >::toCpp(pyargs[0]) : 0;
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;
                const char * cpp_arg2 = pyargs[2] ? Shiboken::Converter<const char * >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // disconnect(const char*,const QObject*,const char*)
                bool cppResult = cppSelf->QObject::disconnect(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_disconnect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, str, PyCallable", "PySide.QtCore.QObject, str = None", "PySide.QtCore.QObject, str, PySide.QtCore.QObject, str", "str, PyCallable", "str = None, PySide.QtCore.QObject = None, str = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QObject.disconnect", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_disconnectNotify(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: disconnectNotify(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // disconnectNotify(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_disconnectNotify_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // disconnectNotify(const char*)
            cppSelf->QObject::disconnectNotify(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQObjectFunc_disconnectNotify_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.disconnectNotify", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_dumpObjectInfo(PyObject* self)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dumpObjectInfo()
            cppSelf->QObject::dumpObjectInfo();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQObjectFunc_dumpObjectTree(PyObject* self)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dumpObjectTree()
            cppSelf->QObject::dumpObjectTree();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQObjectFunc_dynamicPropertyNames(PyObject* self)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dynamicPropertyNames()const
            QList<QByteArray > cppResult = cppSelf->QObject::dynamicPropertyNames();
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQObjectFunc_emit(PyObject* self, PyObject* args)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    PyObject* nonvarargs = PyTuple_GetSlice(args, 0, 1);
    Shiboken::AutoDecRef auto_nonvarargs(nonvarargs);
    pyargs[1] = PyTuple_GetSlice(args, 1, numArgs);
    Shiboken::AutoDecRef auto_varargs(pyargs[1]);

    // invalid argument lengths


    if (!PyArg_UnpackTuple(nonvarargs, "emit", 1, 1, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: emit(const char*,...)
    if (numArgs >= 1 && Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        overloadId = 0; // emit(const char*,...)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_emit_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
            // emit(const char*,...)
            // Begin code injection
            
            pyResult = Shiboken::Converter<bool >::toPython(PySide::SignalManager::instance().emitSignal(cppSelf, cpp_arg0, pyargs[2-1]));
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_emit_TypeError:
        const char* overloads[] = {"str, ...", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QObject.emit", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_event(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QObject::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.event", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_eventFilter(PyObject* self, PyObject* args)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: eventFilter(QObject*,QEvent*)
    if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_eventFilter_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QEvent* cpp_arg1 = Shiboken::Converter<QEvent* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // eventFilter(QObject*,QEvent*)
            bool cppResult = cppSelf->QObject::eventFilter(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_eventFilter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QObject.eventFilter", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_findChild(PyObject* self, PyObject* args)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "findChild", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: findChild(PyTypeObject*,QString)
    if (numArgs == 2 && PyType_Check(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // findChild(PyTypeObject*,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_findChild_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // findChild(PyTypeObject*,QString)
            // Begin code injection
            
            pyResult = Shiboken::Converter<QObject* >::toPython(_findChildHelper(cppSelf, cpp_arg1, (PyTypeObject*)pyargs[1-1]));
            
            // End of code injection


            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_findChild_TypeError:
        const char* overloads[] = {"PyTypeObject, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QObject.findChild", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_findChildren(PyObject* self, PyObject* args)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "findChildren", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: findChildren(PyTypeObject*,QString)
    if (numArgs == 2 && PyType_Check(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // findChildren(PyTypeObject*,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_findChildren_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // findChildren(PyTypeObject*,QString)
            // Begin code injection
            
            pyResult = PyList_New(0);
            _findChildrenHelper(cppSelf, cpp_arg1, (PyTypeObject*)pyargs[1-1], pyResult);
            
            // End of code injection


            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_findChildren_TypeError:
        const char* overloads[] = {"PyTypeObject, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QObject.findChildren", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_inherits(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inherits(const char*)const
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // inherits(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_inherits_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inherits(const char*)const
            // Begin code injection
            
            bool retval =  qobjectInheritsInternal(self->ob_type, cpp_arg0) ? true : cppSelf->inherits(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(retval);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_inherits_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.inherits", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_installEventFilter(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: installEventFilter(QObject*)
    if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // installEventFilter(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_installEventFilter_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // installEventFilter(QObject*)
            cppSelf->QObject::installEventFilter(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQObjectFunc_installEventFilter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.installEventFilter", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_isWidgetType(PyObject* self)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isWidgetType()const
            bool cppResult = cppSelf->QObject::isWidgetType();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQObjectFunc_killTimer(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: killTimer(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // killTimer(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_killTimer_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // killTimer(int)
            cppSelf->QObject::killTimer(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQObjectFunc_killTimer_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.killTimer", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_metaObject(PyObject* self)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // metaObject()const
            // Begin code injection
            
            pyResult = Shiboken::Converter<const QMetaObject * >::toPython(cppSelf->metaObject());
            
            // End of code injection


            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQObjectFunc_moveToThread(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveToThread(QThread*)
    if (Shiboken::Converter<QThread * >::isConvertible(arg)) {
        overloadId = 0; // moveToThread(QThread*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_moveToThread_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QThread* cpp_arg0 = Shiboken::Converter<QThread* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveToThread(QThread*)
            cppSelf->QObject::moveToThread(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQObjectFunc_moveToThread_TypeError:
        const char* overloads[] = {"PySide.QtCore.QThread", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.moveToThread", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_objectName(PyObject* self)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // objectName()const
            QString cppResult = cppSelf->QObject::objectName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQObjectFunc_parent(PyObject* self)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parent()const
            QObject * cppResult = cppSelf->QObject::parent();
            pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);

            // Ownership transferences.
            Shiboken::setParent(pyResult, self);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQObjectFunc_property(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: property(const char*)const
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // property(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_property_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // property(const char*)const
            QVariant cppResult = cppSelf->QObject::property(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_property_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.property", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_receivers(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: receivers(const char*)const
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // receivers(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_receivers_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // receivers(const char*)const
            // Begin code injection
            
            // Avoid return +1 because SignalManager connect to "destroyed()" signal to control object timelife
            int ret = cppSelf->receivers(cpp_arg0);
            if (ret > 0 && strcmp(cpp_arg0, SIGNAL(destroyed())) == 0 && PySide::SignalManager::instance().hasConnectionWith(cppSelf))
                ret--;
            pyResult = Shiboken::Converter<int >::toPython(ret);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_receivers_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.receivers", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_registerUserData(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // registerUserData()
            uint cppResult = QObject::registerUserData();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQObjectFunc_removeEventFilter(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeEventFilter(QObject*)
    if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // removeEventFilter(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_removeEventFilter_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeEventFilter(QObject*)
            cppSelf->QObject::removeEventFilter(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQObjectFunc_removeEventFilter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.removeEventFilter", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_sender(PyObject* self)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sender()const
            QObject * cppResult = cppSelf->QObject::sender();
            pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);

            // Ownership transferences.
            SbkBaseWrapper_setOwnership(pyResult, true);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQObjectFunc_setObjectName(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setObjectName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setObjectName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_setObjectName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setObjectName(QString)
            cppSelf->QObject::setObjectName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQObjectFunc_setObjectName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.setObjectName", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_setParent(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setParent(QObject*)
    if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // setParent(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_setParent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setParent(QObject*)
            cppSelf->QObject::setParent(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQObjectFunc_setParent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.setParent", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_setProperty(PyObject* self, PyObject* args)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setProperty", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setProperty(const char*,QVariant)
    if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setProperty(const char*,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_setProperty_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setProperty(const char*,QVariant)
            bool cppResult = cppSelf->QObject::setProperty(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_setProperty_TypeError:
        const char* overloads[] = {"str, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QObject.setProperty", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_signalsBlocked(PyObject* self)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // signalsBlocked()const
            bool cppResult = cppSelf->QObject::signalsBlocked();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQObjectFunc_startTimer(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: startTimer(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // startTimer(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_startTimer_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // startTimer(int)
            int cppResult = cppSelf->QObject::startTimer(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_startTimer_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.startTimer", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_timerEvent(PyObject* self, PyObject* arg)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: timerEvent(QTimerEvent*)
    if (Shiboken::Converter<QTimerEvent * >::isConvertible(arg)) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_timerEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTimerEvent* cpp_arg0 = Shiboken::Converter<QTimerEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // timerEvent(QTimerEvent*)
            cppSelf->QObject::timerEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQObjectFunc_timerEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTimerEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QObject.timerEvent", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_tr(PyObject* self, PyObject* args, PyObject* kwds)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "arg__2", "arg__3" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject.tr(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QObject.tr(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QObject.tr(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:tr", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: tr(const char*,const char*,int)
    if (Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // tr(const char*,const char*,int)
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // tr(const char*,const char*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // tr(const char*,const char*,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_tr_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "arg__2");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "arg__2";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "arg__3");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "arg__3";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject.tr(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;
            int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;

            if(!PyErr_Occurred()) {
            // tr(const char*,const char*,int)
            // Begin code injection
            
            QString result;
            if (QCoreApplication::instance()) {
                PyObject *klass = PyObject_GetAttrString(self, "__class__");
                PyObject *cname = PyObject_GetAttrString(klass, "__name__");
                result = QString(QCoreApplication::instance()->translate(PyString_AsString(cname), cpp_arg0, cpp_arg1, QCoreApplication::CodecForTr, cpp_arg2));
            
                Py_DECREF(klass);
                Py_DECREF(cname);
            } else {
                result = QString(QString::fromLatin1(cpp_arg0));
            }
            pyResult = Shiboken::Converter<QString >::toPython(result);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_tr_TypeError:
        const char* overloads[] = {"str, str = None, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QObject.tr", overloads);
        return 0;
}

static PyObject* SbkQObjectFunc_trUtf8(PyObject* self, PyObject* args, PyObject* kwds)
{
    QObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "arg__2", "arg__3" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject.trUtf8(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QObject.trUtf8(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QObject.trUtf8(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:trUtf8", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: trUtf8(const char*,const char*,int)
    if (Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // trUtf8(const char*,const char*,int)
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // trUtf8(const char*,const char*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // trUtf8(const char*,const char*,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQObjectFunc_trUtf8_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "arg__2");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "arg__2";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "arg__3");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "arg__3";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QObject.trUtf8(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;
            int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;

            if(!PyErr_Occurred()) {
            // trUtf8(const char*,const char*,int)
            // Begin code injection
            
            QString result;
            if (QCoreApplication::instance()) {
                PyObject *klass = PyObject_GetAttrString(self, "__class__");
                PyObject *cname = PyObject_GetAttrString(klass, "__name__");
                result = QString(QCoreApplication::instance()->translate(PyString_AsString(cname), cpp_arg0, cpp_arg1, QCoreApplication::UnicodeUTF8, cpp_arg2));
            
                Py_DECREF(klass);
                Py_DECREF(cname);
            } else {
                result = QString(QString::fromLatin1(cpp_arg0));
            }
            pyResult = Shiboken::Converter<QString >::toPython(result);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQObjectFunc_trUtf8_TypeError:
        const char* overloads[] = {"str, str = None, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QObject.trUtf8", overloads);
        return 0;
}

static PyMethodDef SbkQObjectMethod_connect = {
    "connect", (PyCFunction)SbkQObjectFunc_connect, METH_VARARGS|METH_KEYWORDS|METH_STATIC
};

static PyMethodDef SbkQObjectMethod_disconnect = {
    "disconnect", (PyCFunction)SbkQObjectFunc_disconnect, METH_VARARGS|METH_KEYWORDS|METH_STATIC
};

static PyMethodDef SbkQObject_methods[] = {
    {"blockSignals", (PyCFunction)SbkQObjectFunc_blockSignals, METH_O},
    {"childEvent", (PyCFunction)SbkQObjectFunc_childEvent, METH_O},
    {"children", (PyCFunction)SbkQObjectFunc_children, METH_NOARGS},
    SbkQObjectMethod_connect,
    {"connectNotify", (PyCFunction)SbkQObjectFunc_connectNotify, METH_O},
    {"customEvent", (PyCFunction)SbkQObjectFunc_customEvent, METH_O},
    {"deleteLater", (PyCFunction)SbkQObjectFunc_deleteLater, METH_NOARGS},
    SbkQObjectMethod_disconnect,
    {"disconnectNotify", (PyCFunction)SbkQObjectFunc_disconnectNotify, METH_O},
    {"dumpObjectInfo", (PyCFunction)SbkQObjectFunc_dumpObjectInfo, METH_NOARGS},
    {"dumpObjectTree", (PyCFunction)SbkQObjectFunc_dumpObjectTree, METH_NOARGS},
    {"dynamicPropertyNames", (PyCFunction)SbkQObjectFunc_dynamicPropertyNames, METH_NOARGS},
    {"emit", (PyCFunction)SbkQObjectFunc_emit, METH_VARARGS},
    {"event", (PyCFunction)SbkQObjectFunc_event, METH_O},
    {"eventFilter", (PyCFunction)SbkQObjectFunc_eventFilter, METH_VARARGS},
    {"findChild", (PyCFunction)SbkQObjectFunc_findChild, METH_VARARGS},
    {"findChildren", (PyCFunction)SbkQObjectFunc_findChildren, METH_VARARGS},
    {"inherits", (PyCFunction)SbkQObjectFunc_inherits, METH_O},
    {"installEventFilter", (PyCFunction)SbkQObjectFunc_installEventFilter, METH_O},
    {"isWidgetType", (PyCFunction)SbkQObjectFunc_isWidgetType, METH_NOARGS},
    {"killTimer", (PyCFunction)SbkQObjectFunc_killTimer, METH_O},
    {"metaObject", (PyCFunction)SbkQObjectFunc_metaObject, METH_NOARGS},
    {"moveToThread", (PyCFunction)SbkQObjectFunc_moveToThread, METH_O},
    {"objectName", (PyCFunction)SbkQObjectFunc_objectName, METH_NOARGS},
    {"parent", (PyCFunction)SbkQObjectFunc_parent, METH_NOARGS},
    {"property", (PyCFunction)SbkQObjectFunc_property, METH_O},
    {"receivers", (PyCFunction)SbkQObjectFunc_receivers, METH_O},
    {"registerUserData", (PyCFunction)SbkQObjectFunc_registerUserData, METH_NOARGS|METH_STATIC},
    {"removeEventFilter", (PyCFunction)SbkQObjectFunc_removeEventFilter, METH_O},
    {"sender", (PyCFunction)SbkQObjectFunc_sender, METH_NOARGS},
    {"setObjectName", (PyCFunction)SbkQObjectFunc_setObjectName, METH_O},
    {"setParent", (PyCFunction)SbkQObjectFunc_setParent, METH_O},
    {"setProperty", (PyCFunction)SbkQObjectFunc_setProperty, METH_VARARGS},
    {"signalsBlocked", (PyCFunction)SbkQObjectFunc_signalsBlocked, METH_NOARGS},
    {"startTimer", (PyCFunction)SbkQObjectFunc_startTimer, METH_O},
    {"timerEvent", (PyCFunction)SbkQObjectFunc_timerEvent, METH_O},
    {"tr", (PyCFunction)SbkQObjectFunc_tr, METH_VARARGS|METH_KEYWORDS},
    {"trUtf8", (PyCFunction)SbkQObjectFunc_trUtf8, METH_VARARGS|METH_KEYWORDS},
    {0} // Sentinel
};

static PyObject* SbkQObject_getattro(PyObject* self, PyObject* name)
{
    if (self) {
        if (SbkBaseWrapper_instanceDict(self)) {
            PyObject* meth = PyDict_GetItem(SbkBaseWrapper_instanceDict(self), name);
            if (meth) {
                Py_INCREF(meth);
                return meth;
            }
        }
        const char* cname = PyString_AS_STRING(name);
        if (strcmp(cname, "connect") == 0)
            return PyCFunction_NewEx(&SbkQObjectMethod_connect, self, 0);
        if (strcmp(cname, "disconnect") == 0)
            return PyCFunction_NewEx(&SbkQObjectMethod_disconnect, self, 0);
    }
    PyObject* attr = PyObject_GenericGetAttr(self, name);
    if (attr && PySide::isQPropertyType(attr)) {
        PyObject *value = PySide::qproperty_get(attr, self);
        Py_DECREF(attr);
        Py_INCREF(value);
        attr = value;
    }
    return attr;
}

static int SbkQObject_setattro(PyObject* self, PyObject* name, PyObject* value)
{
    Shiboken::AutoDecRef pp(PySide::qproperty_get_object(self, name));
    if (!pp.isNull())
                return PySide::qproperty_set(pp, self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQObject_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QObject",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         SbkQObject_getattro,
    /*tp_setattro*/         SbkQObject_setattro,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQObject_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQObject_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QObject >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QObject*",
    /*user_data*/           0
};
} //extern


void init_QObject(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQObject_Type);


    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQObject_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQObject_Type));
    PyModule_AddObject(module, "QObject",
        ((PyObject*)&SbkQObject_Type));

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("destroyed", "QObject*", NULL);
    PyDict_SetItemString(SbkQObject_Type.super.ht_type.tp_dict, "destroyed", signal_item);
    Py_DECREF(signal_item);



    Shiboken::TypeResolver::createObjectTypeResolver<QObject >("QObject*");
    Shiboken::TypeResolver::createObjectTypeResolver<QObject >(typeid(QObject).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QObject >(typeid(QObjectWrapper).name());
    PySide::initQtMetaType<QObject* >();
}


