/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qtextcodec_wrapper.h"
#include "qtextcodec_converterstate_wrapper.h"

// Extra includes
#include <QList>
#include <QTextCodec>
#include <qbytearray.h>
#include <qtextcodec.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QTextCodecWrapper::QTextCodecWrapper() : QTextCodec() {
    // ... middle
}

QList<QByteArray > QTextCodecWrapper::aliases() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "aliases"));
    if (py_override.isNull()) {
        return this->QTextCodec::aliases();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<QByteArray >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QList<QByteArray > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextCodec.aliases", "list", pyResult->ob_type->tp_name);
        return QList<QByteArray >();
    }
    QList<QByteArray > cppResult(Shiboken::Converter<QList<QByteArray > >::toCpp(pyResult));
    return cppResult;
}

QByteArray QTextCodecWrapper::convertFromUnicode(const QChar * in, int length, QTextCodec::ConverterState * state) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "convertFromUnicode"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QTextCodec.convertFromUnicode()' not implemented.");
        return QByteArray();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NiN)",
        Shiboken::Converter<const QChar * >::toPython(in),
        length,
        Shiboken::Converter<QTextCodec::ConverterState * >::toPython(state)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QByteArray();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QByteArray >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextCodec.convertFromUnicode", SbkType<QByteArray >()->tp_name, pyResult->ob_type->tp_name);
        return QByteArray();
    }
    QByteArray cppResult(Shiboken::Converter<QByteArray >::toCpp(pyResult));
    return cppResult;
}

QString QTextCodecWrapper::convertToUnicode(const char * in, int length, QTextCodec::ConverterState * state) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "convertToUnicode"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QTextCodec.convertToUnicode()' not implemented.");
        return QString();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NiN)",
        Shiboken::Converter<const char * >::toPython(in),
        length,
        Shiboken::Converter<QTextCodec::ConverterState * >::toPython(state)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextCodec.convertToUnicode", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter<QString >::toCpp(pyResult));
    return cppResult;
}

int QTextCodecWrapper::mibEnum() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mibEnum"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QTextCodec.mibEnum()' not implemented.");
        return int(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextCodec.mibEnum", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QByteArray QTextCodecWrapper::name() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "name"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QTextCodec.name()' not implemented.");
        return QByteArray();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QByteArray();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QByteArray >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextCodec.name", SbkType<QByteArray >()->tp_name, pyResult->ob_type->tp_name);
        return QByteArray();
    }
    QByteArray cppResult(Shiboken::Converter<QByteArray >::toCpp(pyResult));
    return cppResult;
}

QTextCodecWrapper::~QTextCodecWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextCodec_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextCodec >()))
        return -1;

    QTextCodecWrapper* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QTEXTCODEC_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QTextCodec' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // QTextCodec()
            cptr = new QTextCodecWrapper();
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextCodec >(), cptr)) {
        delete cptr;
        return -1;
    }
    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* SbkQTextCodecFunc_aliases(PyObject* self)
{
    QTextCodec* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCodec* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // aliases()const
            QList<QByteArray > cppResult = cppSelf->QTextCodec::aliases();
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCodecFunc_availableCodecs(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // availableCodecs()
            QList<QByteArray > cppResult = QTextCodec::availableCodecs();
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCodecFunc_availableMibs(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // availableMibs()
            QList<int > cppResult = QTextCodec::availableMibs();
            pyResult = Shiboken::Converter<QList<int > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCodecFunc_canEncode(PyObject* self, PyObject* arg)
{
    QTextCodec* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCodec* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: canEncode(QChar)const
    // 1: canEncode(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // canEncode(QString)const
    } else if (Shiboken::Converter<QChar >::isConvertible(arg)) {
        overloadId = 0; // canEncode(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_canEncode_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // canEncode(QChar)const
            {
                QChar cpp_arg0 = Shiboken::Converter<QChar >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // canEncode(QChar)const
                bool cppResult = cppSelf->QTextCodec::canEncode(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // canEncode(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // canEncode(QString)const
                bool cppResult = cppSelf->QTextCodec::canEncode(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCodecFunc_canEncode_TypeError:
        const char* overloads[] = {"QChar", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextCodec.canEncode", overloads);
        return 0;
}

static PyObject* SbkQTextCodecFunc_codecForCStrings(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // codecForCStrings()
            QTextCodec * cppResult = QTextCodec::codecForCStrings();
            pyResult = Shiboken::Converter<QTextCodec * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCodecFunc_codecForHtml(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "codecForHtml", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: codecForHtml(QByteArray)
    // 1: codecForHtml(QByteArray,QTextCodec*)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // codecForHtml(QByteArray)
        } else if (numArgs == 2 && Shiboken::Converter<QTextCodec * >::isConvertible(pyargs[1])) {
            overloadId = 1; // codecForHtml(QByteArray,QTextCodec*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_codecForHtml_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // codecForHtml(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // codecForHtml(QByteArray)
                QTextCodec * cppResult = QTextCodec::codecForHtml(*cpp_arg0);
                pyResult = Shiboken::Converter<QTextCodec * >::toPython(cppResult);
                }
                break;
            }
            case 1: // codecForHtml(QByteArray,QTextCodec*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QTextCodec* cpp_arg1 = Shiboken::Converter<QTextCodec* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // codecForHtml(QByteArray,QTextCodec*)
                QTextCodec * cppResult = QTextCodec::codecForHtml(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QTextCodec * >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCodecFunc_codecForHtml_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "PySide.QtCore.QByteArray, PySide.QtCore.QTextCodec", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTextCodec.codecForHtml", overloads);
        return 0;
}

static PyObject* SbkQTextCodecFunc_codecForLocale(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // codecForLocale()
            QTextCodec * cppResult = QTextCodec::codecForLocale();
            pyResult = Shiboken::Converter<QTextCodec * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCodecFunc_codecForMib(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: codecForMib(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // codecForMib(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_codecForMib_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // codecForMib(int)
            QTextCodec * cppResult = QTextCodec::codecForMib(cpp_arg0);
            pyResult = Shiboken::Converter<QTextCodec * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCodecFunc_codecForMib_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextCodec.codecForMib", overloads);
        return 0;
}

static PyObject* SbkQTextCodecFunc_codecForName(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: codecForName(QByteArray)
    // 1: codecForName(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 1; // codecForName(const char*)
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // codecForName(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_codecForName_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // codecForName(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // codecForName(QByteArray)
                QTextCodec * cppResult = QTextCodec::codecForName(*cpp_arg0);
                pyResult = Shiboken::Converter<QTextCodec * >::toPython(cppResult);
                }
                break;
            }
            case 1: // codecForName(const char*)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // codecForName(const char*)
                QTextCodec * cppResult = QTextCodec::codecForName(cpp_arg0);
                pyResult = Shiboken::Converter<QTextCodec * >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCodecFunc_codecForName_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextCodec.codecForName", overloads);
        return 0;
}

static PyObject* SbkQTextCodecFunc_codecForTr(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // codecForTr()
            QTextCodec * cppResult = QTextCodec::codecForTr();
            pyResult = Shiboken::Converter<QTextCodec * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCodecFunc_codecForUtfText(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "codecForUtfText", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: codecForUtfText(QByteArray)
    // 1: codecForUtfText(QByteArray,QTextCodec*)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // codecForUtfText(QByteArray)
        } else if (numArgs == 2 && Shiboken::Converter<QTextCodec * >::isConvertible(pyargs[1])) {
            overloadId = 1; // codecForUtfText(QByteArray,QTextCodec*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_codecForUtfText_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // codecForUtfText(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // codecForUtfText(QByteArray)
                QTextCodec * cppResult = QTextCodec::codecForUtfText(*cpp_arg0);
                pyResult = Shiboken::Converter<QTextCodec * >::toPython(cppResult);
                }
                break;
            }
            case 1: // codecForUtfText(QByteArray,QTextCodec*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QTextCodec* cpp_arg1 = Shiboken::Converter<QTextCodec* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // codecForUtfText(QByteArray,QTextCodec*)
                QTextCodec * cppResult = QTextCodec::codecForUtfText(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QTextCodec * >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCodecFunc_codecForUtfText_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "PySide.QtCore.QByteArray, PySide.QtCore.QTextCodec", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTextCodec.codecForUtfText", overloads);
        return 0;
}

static PyObject* SbkQTextCodecFunc_convertFromUnicode(PyObject* self, PyObject* args)
{
    QTextCodec* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCodec* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "convertFromUnicode", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: convertFromUnicode(const QChar*,int,QTextCodec::ConverterState*)const
    if (numArgs == 3 && Shiboken::Converter<const QChar * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QTextCodec::ConverterState * >::isConvertible(pyargs[2])) {
        overloadId = 0; // convertFromUnicode(const QChar*,int,QTextCodec::ConverterState*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_convertFromUnicode_TypeError;

    // Call function/method
    {
        {
            QChar * cpp_arg0 = Shiboken::Converter<QChar * >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QTextCodec::ConverterState* cpp_arg2 = Shiboken::Converter<QTextCodec::ConverterState* >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // convertFromUnicode(const QChar*,int,QTextCodec::ConverterState*)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QTextCodec.convertFromUnicode()' not implemented.");
                return 0;
            }
            QByteArray cppResult = cppSelf->convertFromUnicode(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCodecFunc_convertFromUnicode_TypeError:
        const char* overloads[] = {"QChar, int, PySide.QtCore.QTextCodec::ConverterState", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTextCodec.convertFromUnicode", overloads);
        return 0;
}

static PyObject* SbkQTextCodecFunc_convertToUnicode(PyObject* self, PyObject* args)
{
    QTextCodec* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCodec* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "convertToUnicode", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: convertToUnicode(const char*,int,QTextCodec::ConverterState*)const
    if (numArgs == 3 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QTextCodec::ConverterState * >::isConvertible(pyargs[2])) {
        overloadId = 0; // convertToUnicode(const char*,int,QTextCodec::ConverterState*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_convertToUnicode_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QTextCodec::ConverterState* cpp_arg2 = Shiboken::Converter<QTextCodec::ConverterState* >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // convertToUnicode(const char*,int,QTextCodec::ConverterState*)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QTextCodec.convertToUnicode()' not implemented.");
                return 0;
            }
            QString cppResult = cppSelf->convertToUnicode(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCodecFunc_convertToUnicode_TypeError:
        const char* overloads[] = {"str, int, PySide.QtCore.QTextCodec::ConverterState", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTextCodec.convertToUnicode", overloads);
        return 0;
}

static PyObject* SbkQTextCodecFunc_fromUnicode(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextCodec* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCodec* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "state" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTextCodec.fromUnicode(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTextCodec.fromUnicode(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTextCodec.fromUnicode(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:fromUnicode", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: fromUnicode(const QChar*,int,QTextCodec::ConverterState*)const
    // 1: fromUnicode(QString)const
    if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        overloadId = 1; // fromUnicode(QString)const
    } else if (numArgs >= 2 && Shiboken::Converter<const QChar * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // fromUnicode(const QChar*,int,QTextCodec::ConverterState*)const
        } else if (Shiboken::Converter<QTextCodec::ConverterState * >::isConvertible(pyargs[2])) {
            overloadId = 0; // fromUnicode(const QChar*,int,QTextCodec::ConverterState*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_fromUnicode_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fromUnicode(const QChar*,int,QTextCodec::ConverterState*)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "state");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "state";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTextCodec.fromUnicode(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QChar * cpp_arg0 = Shiboken::Converter<QChar * >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QTextCodec::ConverterState* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QTextCodec::ConverterState* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // fromUnicode(const QChar*,int,QTextCodec::ConverterState*)const
                QByteArray cppResult = cppSelf->QTextCodec::fromUnicode(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
                }
                break;
            }
            case 1: // fromUnicode(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // fromUnicode(QString)const
                QByteArray cppResult = cppSelf->QTextCodec::fromUnicode(cpp_arg0);
                pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCodecFunc_fromUnicode_TypeError:
        const char* overloads[] = {"QChar, int, PySide.QtCore.QTextCodec::ConverterState = None", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTextCodec.fromUnicode", overloads);
        return 0;
}

static PyObject* SbkQTextCodecFunc_makeDecoder(PyObject* self, PyObject* arg)
{
    QTextCodec* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCodec* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: makeDecoder()const
    // 1: makeDecoder(QFlags<QTextCodec::ConversionFlag>)const
    if (numArgs == 0) {
        overloadId = 0; // makeDecoder()const
    } else if (Shiboken::Converter<QFlags<QTextCodec::ConversionFlag> >::isConvertible(arg)) {
        overloadId = 1; // makeDecoder(QFlags<QTextCodec::ConversionFlag>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_makeDecoder_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // makeDecoder()const
            {

                if(!PyErr_Occurred()) {
                // makeDecoder()const
                QTextDecoder * cppResult = cppSelf->QTextCodec::makeDecoder();
                pyResult = Shiboken::Converter<QTextDecoder * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // makeDecoder(QFlags<QTextCodec::ConversionFlag>)const
            {
                QFlags<QTextCodec::ConversionFlag> cpp_arg0 = Shiboken::Converter<QFlags<QTextCodec::ConversionFlag> >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // makeDecoder(QFlags<QTextCodec::ConversionFlag>)const
                QTextDecoder * cppResult = cppSelf->QTextCodec::makeDecoder(cpp_arg0);
                pyResult = Shiboken::Converter<QTextDecoder * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCodecFunc_makeDecoder_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QTextCodec.ConversionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextCodec.makeDecoder", overloads);
        return 0;
}

static PyObject* SbkQTextCodecFunc_makeEncoder(PyObject* self, PyObject* arg)
{
    QTextCodec* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCodec* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: makeEncoder()const
    // 1: makeEncoder(QFlags<QTextCodec::ConversionFlag>)const
    if (numArgs == 0) {
        overloadId = 0; // makeEncoder()const
    } else if (Shiboken::Converter<QFlags<QTextCodec::ConversionFlag> >::isConvertible(arg)) {
        overloadId = 1; // makeEncoder(QFlags<QTextCodec::ConversionFlag>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_makeEncoder_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // makeEncoder()const
            {

                if(!PyErr_Occurred()) {
                // makeEncoder()const
                QTextEncoder * cppResult = cppSelf->QTextCodec::makeEncoder();
                pyResult = Shiboken::Converter<QTextEncoder * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // makeEncoder(QFlags<QTextCodec::ConversionFlag>)const
            {
                QFlags<QTextCodec::ConversionFlag> cpp_arg0 = Shiboken::Converter<QFlags<QTextCodec::ConversionFlag> >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // makeEncoder(QFlags<QTextCodec::ConversionFlag>)const
                QTextEncoder * cppResult = cppSelf->QTextCodec::makeEncoder(cpp_arg0);
                pyResult = Shiboken::Converter<QTextEncoder * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCodecFunc_makeEncoder_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QTextCodec.ConversionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextCodec.makeEncoder", overloads);
        return 0;
}

static PyObject* SbkQTextCodecFunc_mibEnum(PyObject* self)
{
    QTextCodec* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCodec* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // mibEnum()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QTextCodec.mibEnum()' not implemented.");
                return 0;
            }
            int cppResult = cppSelf->mibEnum();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCodecFunc_name(PyObject* self)
{
    QTextCodec* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCodec* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QTextCodec.name()' not implemented.");
                return 0;
            }
            QByteArray cppResult = cppSelf->name();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCodecFunc_setCodecForCStrings(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCodecForCStrings(QTextCodec*)
    if (Shiboken::Converter<QTextCodec * >::isConvertible(arg)) {
        overloadId = 0; // setCodecForCStrings(QTextCodec*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_setCodecForCStrings_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextCodec* cpp_arg0 = Shiboken::Converter<QTextCodec* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCodecForCStrings(QTextCodec*)
            QTextCodec::setCodecForCStrings(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCodecFunc_setCodecForCStrings_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextCodec", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextCodec.setCodecForCStrings", overloads);
        return 0;
}

static PyObject* SbkQTextCodecFunc_setCodecForLocale(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCodecForLocale(QTextCodec*)
    if (Shiboken::Converter<QTextCodec * >::isConvertible(arg)) {
        overloadId = 0; // setCodecForLocale(QTextCodec*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_setCodecForLocale_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextCodec* cpp_arg0 = Shiboken::Converter<QTextCodec* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCodecForLocale(QTextCodec*)
            QTextCodec::setCodecForLocale(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCodecFunc_setCodecForLocale_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextCodec", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextCodec.setCodecForLocale", overloads);
        return 0;
}

static PyObject* SbkQTextCodecFunc_setCodecForTr(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCodecForTr(QTextCodec*)
    if (Shiboken::Converter<QTextCodec * >::isConvertible(arg)) {
        overloadId = 0; // setCodecForTr(QTextCodec*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_setCodecForTr_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextCodec* cpp_arg0 = Shiboken::Converter<QTextCodec* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCodecForTr(QTextCodec*)
            QTextCodec::setCodecForTr(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCodecFunc_setCodecForTr_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextCodec", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextCodec.setCodecForTr", overloads);
        return 0;
}

static PyObject* SbkQTextCodecFunc_toUnicode(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextCodec* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCodec* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "state" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTextCodec.toUnicode(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTextCodec.toUnicode(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTextCodec.toUnicode(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:toUnicode", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: toUnicode(QByteArray)const
    // 1: toUnicode(const char*)const
    // 2: toUnicode(const char*,int,QTextCodec::ConverterState*)const
    if (Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // toUnicode(const char*)const
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // toUnicode(const char*,int,QTextCodec::ConverterState*)const
            } else if (Shiboken::Converter<QTextCodec::ConverterState * >::isConvertible(pyargs[2])) {
                overloadId = 2; // toUnicode(const char*,int,QTextCodec::ConverterState*)const
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        overloadId = 0; // toUnicode(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodecFunc_toUnicode_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toUnicode(QByteArray)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // toUnicode(QByteArray)const
                QString cppResult = cppSelf->QTextCodec::toUnicode(*cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // toUnicode(const char*)const
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // toUnicode(const char*)const
                QString cppResult = cppSelf->QTextCodec::toUnicode(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 2: // toUnicode(const char*,int,QTextCodec::ConverterState*)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "state");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "state";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTextCodec.toUnicode(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QTextCodec::ConverterState* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QTextCodec::ConverterState* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // toUnicode(const char*,int,QTextCodec::ConverterState*)const
                QString cppResult = cppSelf->QTextCodec::toUnicode(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCodecFunc_toUnicode_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "str", "str, int, PySide.QtCore.QTextCodec::ConverterState = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTextCodec.toUnicode", overloads);
        return 0;
}

static PyMethodDef SbkQTextCodec_methods[] = {
    {"aliases", (PyCFunction)SbkQTextCodecFunc_aliases, METH_NOARGS},
    {"availableCodecs", (PyCFunction)SbkQTextCodecFunc_availableCodecs, METH_NOARGS|METH_STATIC},
    {"availableMibs", (PyCFunction)SbkQTextCodecFunc_availableMibs, METH_NOARGS|METH_STATIC},
    {"canEncode", (PyCFunction)SbkQTextCodecFunc_canEncode, METH_O},
    {"codecForCStrings", (PyCFunction)SbkQTextCodecFunc_codecForCStrings, METH_NOARGS|METH_STATIC},
    {"codecForHtml", (PyCFunction)SbkQTextCodecFunc_codecForHtml, METH_VARARGS|METH_STATIC},
    {"codecForLocale", (PyCFunction)SbkQTextCodecFunc_codecForLocale, METH_NOARGS|METH_STATIC},
    {"codecForMib", (PyCFunction)SbkQTextCodecFunc_codecForMib, METH_O|METH_STATIC},
    {"codecForName", (PyCFunction)SbkQTextCodecFunc_codecForName, METH_O|METH_STATIC},
    {"codecForTr", (PyCFunction)SbkQTextCodecFunc_codecForTr, METH_NOARGS|METH_STATIC},
    {"codecForUtfText", (PyCFunction)SbkQTextCodecFunc_codecForUtfText, METH_VARARGS|METH_STATIC},
    {"convertFromUnicode", (PyCFunction)SbkQTextCodecFunc_convertFromUnicode, METH_VARARGS},
    {"convertToUnicode", (PyCFunction)SbkQTextCodecFunc_convertToUnicode, METH_VARARGS},
    {"fromUnicode", (PyCFunction)SbkQTextCodecFunc_fromUnicode, METH_VARARGS|METH_KEYWORDS},
    {"makeDecoder", (PyCFunction)SbkQTextCodecFunc_makeDecoder, METH_NOARGS|METH_O},
    {"makeEncoder", (PyCFunction)SbkQTextCodecFunc_makeEncoder, METH_NOARGS|METH_O},
    {"mibEnum", (PyCFunction)SbkQTextCodecFunc_mibEnum, METH_NOARGS},
    {"name", (PyCFunction)SbkQTextCodecFunc_name, METH_NOARGS},
    {"setCodecForCStrings", (PyCFunction)SbkQTextCodecFunc_setCodecForCStrings, METH_O|METH_STATIC},
    {"setCodecForLocale", (PyCFunction)SbkQTextCodecFunc_setCodecForLocale, METH_O|METH_STATIC},
    {"setCodecForTr", (PyCFunction)SbkQTextCodecFunc_setCodecForTr, METH_O|METH_STATIC},
    {"toUnicode", (PyCFunction)SbkQTextCodecFunc_toUnicode, METH_VARARGS|METH_KEYWORDS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextCodec_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QTextCodec",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextCodec_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextCodec_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextCodec >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextCodec*",
    /*user_data*/           0
};
} //extern

PyObject* SbkPySide_QtCore_QTextCodec_ConversionFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextCodec::ConversionFlags >::checkType(self) && Shiboken::Converter<QTextCodec::ConversionFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextCodec::ConversionFlags >::toPython(
        Shiboken::Converter<QTextCodec::ConversionFlags>::toCpp(self)
        & Shiboken::Converter< QTextCodec::ConversionFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QTextCodec_ConversionFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextCodec::ConversionFlags >::checkType(self) && Shiboken::Converter<QTextCodec::ConversionFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextCodec::ConversionFlags >::toPython(
        Shiboken::Converter<QTextCodec::ConversionFlags>::toCpp(self)
        | Shiboken::Converter< QTextCodec::ConversionFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QTextCodec_ConversionFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextCodec::ConversionFlags >::checkType(self) && Shiboken::Converter<QTextCodec::ConversionFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextCodec::ConversionFlags >::toPython(
        Shiboken::Converter<QTextCodec::ConversionFlags>::toCpp(self)
        ^ Shiboken::Converter< QTextCodec::ConversionFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QTextCodec_ConversionFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextCodec::ConversionFlags >::toPython(
        ~Shiboken::Converter<QTextCodec::ConversionFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QTextCodec_ConversionFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QTextCodec_ConversionFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QTextCodec_ConversionFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QTextCodec_ConversionFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QTextCodec_ConversionFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtCore_QTextCodec_ConversionFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QTextCodec_ConversionFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QTextCodec_ConversionFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ConversionFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtCore_QTextCodec_ConversionFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QTextCodec_ConversionFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QTextCodec_ConversionFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QTextCodec_ConversionFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtCore_QTextCodec_ConversionFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ConversionFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtCore_QTextCodec_ConversionFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QTextCodec(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QTEXTCODEC_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextCodec_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQTextCodec_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTextCodec_Type));
    PyModule_AddObject(module, "QTextCodec",
        ((PyObject*)&SbkQTextCodec_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ConversionFlag
    SbkPySide_QtCoreTypes[SBK_QTEXTCODEC_CONVERSIONFLAG_IDX] = &SbkPySide_QtCore_QTextCodec_ConversionFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QTextCodec_ConversionFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QTextCodec_ConversionFlag_Type);
    PyDict_SetItemString(SbkQTextCodec_Type.super.ht_type.tp_dict,
            "ConversionFlag",((PyObject*)&SbkPySide_QtCore_QTextCodec_ConversionFlag_Type));

    // init flags class: QFlags<QTextCodec::ConversionFlag>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QTEXTCODEC_CONVERSIONFLAG__IDX] = &SbkPySide_QtCore_QTextCodec_ConversionFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QTextCodec_ConversionFlags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QTextCodec_ConversionFlags_Type);
    PyDict_SetItemString(SbkQTextCodec_Type.super.ht_type.tp_dict,
            "ConversionFlags",((PyObject*)&SbkPySide_QtCore_QTextCodec_ConversionFlags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextCodec_ConversionFlag_Type,
        (long) QTextCodec::DefaultConversion, "DefaultConversion");
    PyDict_SetItemString(SbkQTextCodec_Type.super.ht_type.tp_dict,
        "DefaultConversion", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextCodec_ConversionFlag_Type.tp_dict,
        "DefaultConversion", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextCodec_ConversionFlag_Type,
        (long) QTextCodec::ConvertInvalidToNull, "ConvertInvalidToNull");
    PyDict_SetItemString(SbkQTextCodec_Type.super.ht_type.tp_dict,
        "ConvertInvalidToNull", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextCodec_ConversionFlag_Type.tp_dict,
        "ConvertInvalidToNull", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextCodec_ConversionFlag_Type,
        (long) QTextCodec::IgnoreHeader, "IgnoreHeader");
    PyDict_SetItemString(SbkQTextCodec_Type.super.ht_type.tp_dict,
        "IgnoreHeader", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextCodec_ConversionFlag_Type.tp_dict,
        "IgnoreHeader", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextCodec_ConversionFlag_Type,
        (long) QTextCodec::FreeFunction, "FreeFunction");
    PyDict_SetItemString(SbkQTextCodec_Type.super.ht_type.tp_dict,
        "FreeFunction", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextCodec_ConversionFlag_Type.tp_dict,
        "FreeFunction", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextCodec::ConversionFlag");


    Shiboken::TypeResolver::createObjectTypeResolver<QTextCodec >("QTextCodec*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextCodec >(typeid(QTextCodec).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QTextCodec >(typeid(QTextCodecWrapper).name());
    PySide::initQtMetaType<QTextCodec* >();
}

