/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qapplication_wrapper.h"

// Extra includes
#include <QBasicTimer>
#include <QFont>
#include <QFontMetrics>
#include <QIcon>
#include <QList>
#include <QLocale>
#include <QPalette>
#include <QStringList>
#include <QStyle>
#include <qapplication.h>
#include <qbytearray.h>
#include <qclipboard.h>
#include <qcoreapplication.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qdesktopwidget.h>
#include <qfont.h>
#include <qfontmetrics.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qlocale.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qsessionmanager.h>
#include <qsize.h>
#include <qstyle.h>
#include <qthread.h>
#include <qtranslator.h>
#include <qwidget.h>

using namespace Shiboken;

// Begin code injection
// ========================================================================
// START of custom code block [file: glue/qapplication_init.cpp]
// Borrowed reference to QtGui module
extern PyObject* moduleQtGui;

static int QApplicationArgCount;
static char** QApplicationArgValues;
static const char QAPP_MACRO[] = "qApp";
static bool leavingPython = false;

void DeleteQApplicationAtExit()
{
    leavingPython = true;    
    PySide::SignalManager::instance().clear();
    QCoreApplication* cpp = QApplication::instance();
    if (cpp) {
        Shiboken::BindingManager &bmngr = Shiboken::BindingManager::instance();
        PyObject* pySelf = bmngr.retrieveWrapper(cpp);
        if (pySelf)
            bmngr.invalidateWrapper(pySelf);
        cpp->deleteLater();
    }
}

int SbkQApplication_Init(PyObject* self, PyObject* args, PyObject*)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QApplication >()))
        return -1;

    if (QApplication::instance()) {
        PyErr_SetString(PyExc_RuntimeError, "A QApplication instance already exists.");
        return -1;
    }

    int numArgs = PyTuple_GET_SIZE(args);
    if (numArgs != 1) {
        PyErr_BadArgument();
        return -1;
    }

    if (!PySequenceToArgcArgv(PyTuple_GET_ITEM(args, 0), &QApplicationArgCount, &QApplicationArgValues, "PySideApp")) {
        PyErr_BadArgument();
        return -1;
    }

    QApplicationWrapper* cptr = new QApplicationWrapper(QApplicationArgCount, QApplicationArgValues);
    Shiboken::setCppPointer(reinterpret_cast<SbkBaseWrapper*>(self),
                            Shiboken::SbkType<QApplication>(),
                            cptr);
    SbkBaseWrapper_setValidCppObject(self, 1);
    SbkBaseWrapper *sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    sbkSelf->containsCppWrapper = 1;
    sbkSelf->hasOwnership = 0;
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();

    // Verify if qApp is in main module
    PyObject* globalsDict = PyEval_GetGlobals();
    if (globalsDict) {
        PyObject* qAppObj = PyDict_GetItemString(globalsDict, QAPP_MACRO);
        if (qAppObj)
            PyDict_SetItemString(globalsDict, QAPP_MACRO, self);
    }

    PyObject_SetAttrString(moduleQtGui, QAPP_MACRO, self);
    Py_AtExit(DeleteQApplicationAtExit);
    Py_INCREF(self);
    return 1;
}

// END of custom code block [file: glue/qapplication_init.cpp]
// ========================================================================

// End of code injection

// Native ---------------------------------------------------------

QApplicationWrapper::QApplicationWrapper(int & argc, char ** argv) : QApplication(argc, argv), m_metaObject(0) {
    // ... middle
}

void QApplicationWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QApplicationWrapper::commitData(QSessionManager & sm)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "commitData"));
    if (py_override.isNull()) {
        return this->QApplication::commitData(sm);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QSessionManager & >::toPython(sm)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QApplicationWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QApplicationWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QApplicationWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QApplicationWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QApplication::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QApplication.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QApplicationWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QApplication.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QApplicationWrapper::notify(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "notify"));
    if (py_override.isNull()) {
        // Begin code injection
        
        Shiboken::ThreadStateSaver threadStateSaver;
        if (!leavingPython)
          threadStateSaver.save();
        
        // End of code injection

        return this->QApplication::notify(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QApplication.notify", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));

    return cppResult;
}

void QApplicationWrapper::saveState(QSessionManager & sm)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "saveState"));
    if (py_override.isNull()) {
        return this->QApplication::saveState(sm);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QSessionManager & >::toPython(sm)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QApplicationWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QApplicationWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QApplication::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QApplicationWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QApplication::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QApplicationWrapper::~QApplicationWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject* SbkQApplicationFunc_aboutQt(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // aboutQt()
            QApplication::aboutQt();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQApplicationFunc_activeModalWidget(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // activeModalWidget()
            QWidget * cppResult = QApplication::activeModalWidget();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_activePopupWidget(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // activePopupWidget()
            QWidget * cppResult = QApplication::activePopupWidget();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_activeWindow(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // activeWindow()
            QWidget * cppResult = QApplication::activeWindow();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_alert(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "duration" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QApplication.alert(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QApplication.alert(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QApplication.alert(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:alert", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: alert(QWidget*,int)
    if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // alert(QWidget*,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // alert(QWidget*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_alert_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "duration");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "duration";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QApplication.alert(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // alert(QWidget*,int)
            QApplication::alert(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_alert_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.alert", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_allWidgets(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // allWidgets()
            QList<QWidget * > cppResult = QApplication::allWidgets();
            pyResult = Shiboken::Converter<QList<QWidget * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_autoSipEnabled(PyObject* self)
{
    QApplication* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QApplication* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // autoSipEnabled()const
            bool cppResult = cppSelf->QApplication::autoSipEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_beep(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // beep()
            QApplication::beep();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQApplicationFunc_changeOverrideCursor(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: changeOverrideCursor(QCursor)
    if (Shiboken::Converter<const QCursor & >::isConvertible(arg)) {
        overloadId = 0; // changeOverrideCursor(QCursor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_changeOverrideCursor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QCursor > cpp_arg0_auto_ptr;
            QCursor* cpp_arg0 = Shiboken::Converter<QCursor* >::toCpp(arg);
            if (!Shiboken::Converter<QCursor >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QCursor >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // changeOverrideCursor(QCursor)
            QApplication::changeOverrideCursor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_changeOverrideCursor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QCursor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.changeOverrideCursor", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_clipboard(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clipboard()
            QClipboard * cppResult = QApplication::clipboard();
            pyResult = Shiboken::Converter<QClipboard * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_closeAllWindows(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // closeAllWindows()
            QApplication::closeAllWindows();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQApplicationFunc_colorSpec(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // colorSpec()
            int cppResult = QApplication::colorSpec();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_commitData(PyObject* self, PyObject* arg)
{
    QApplication* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QApplication* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: commitData(QSessionManager&)
    if (Shiboken::Converter<QSessionManager & >::isConvertible(arg)) {
        overloadId = 0; // commitData(QSessionManager&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_commitData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QSessionManager* cpp_arg0 = Shiboken::Converter<QSessionManager* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // commitData(QSessionManager&)
            cppSelf->QApplication::commitData(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_commitData_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSessionManager", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.commitData", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_cursorFlashTime(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cursorFlashTime()
            int cppResult = QApplication::cursorFlashTime();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_desktop(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // desktop()
            QDesktopWidget * cppResult = QApplication::desktop();
            pyResult = Shiboken::Converter<QDesktopWidget * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_desktopSettingsAware(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // desktopSettingsAware()
            bool cppResult = QApplication::desktopSettingsAware();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_doubleClickInterval(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // doubleClickInterval()
            int cppResult = QApplication::doubleClickInterval();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_event(PyObject* self, PyObject* arg)
{
    QApplication* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QApplication* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QApplication::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQApplicationFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.event", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_exec_(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // exec()
            threadStateSaver.save();
            int cppResult = QApplication::exec();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_focusWidget(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // focusWidget()
            QWidget * cppResult = QApplication::focusWidget();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_font(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: font()
    // 1: font(const QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // font()
    } else if (Shiboken::Converter<const QWidget * >::isConvertible(arg)) {
        overloadId = 1; // font(const QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_font_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // font()
            {

                if(!PyErr_Occurred()) {
                // font()
                QFont cppResult = QApplication::font();
                pyResult = Shiboken::Converter<QFont >::toPython(cppResult);
                }
                break;
            }
            case 1: // font(const QWidget*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // font(const QWidget*)
                QFont cppResult = QApplication::font(cpp_arg0);
                pyResult = Shiboken::Converter<QFont >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQApplicationFunc_font_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.font", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_fontMetrics(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontMetrics()
            QFontMetrics cppResult = QApplication::fontMetrics();
            pyResult = Shiboken::Converter<QFontMetrics >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_globalStrut(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // globalStrut()
            QSize cppResult = QApplication::globalStrut();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_inputContext(PyObject* self)
{
    QApplication* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QApplication* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // inputContext()const
            QInputContext * cppResult = cppSelf->QApplication::inputContext();
            pyResult = Shiboken::Converter<QInputContext * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_isEffectEnabled(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isEffectEnabled(Qt::UIEffect)
    if (Shiboken::Converter<Qt::UIEffect >::isConvertible(arg)) {
        overloadId = 0; // isEffectEnabled(Qt::UIEffect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_isEffectEnabled_TypeError;

    // Call function/method
    {
        {
            Qt::UIEffect cpp_arg0 = Shiboken::Converter<Qt::UIEffect >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isEffectEnabled(Qt::UIEffect)
            bool cppResult = QApplication::isEffectEnabled(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQApplicationFunc_isEffectEnabled_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.UIEffect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.isEffectEnabled", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_isLeftToRight(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isLeftToRight()
            bool cppResult = QApplication::isLeftToRight();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_isRightToLeft(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isRightToLeft()
            bool cppResult = QApplication::isRightToLeft();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_isSessionRestored(PyObject* self)
{
    QApplication* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QApplication* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSessionRestored()const
            bool cppResult = cppSelf->QApplication::isSessionRestored();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_keyboardInputDirection(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // keyboardInputDirection()
            Qt::LayoutDirection cppResult = QApplication::keyboardInputDirection();
            pyResult = Shiboken::Converter<Qt::LayoutDirection >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_keyboardInputInterval(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // keyboardInputInterval()
            int cppResult = QApplication::keyboardInputInterval();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_keyboardInputLocale(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // keyboardInputLocale()
            QLocale cppResult = QApplication::keyboardInputLocale();
            pyResult = Shiboken::Converter<QLocale >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_keyboardModifiers(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // keyboardModifiers()
            QFlags<Qt::KeyboardModifier> cppResult = QApplication::keyboardModifiers();
            pyResult = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_layoutDirection(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // layoutDirection()
            Qt::LayoutDirection cppResult = QApplication::layoutDirection();
            pyResult = Shiboken::Converter<Qt::LayoutDirection >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_mouseButtons(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // mouseButtons()
            QFlags<Qt::MouseButton> cppResult = QApplication::mouseButtons();
            pyResult = Shiboken::Converter<QFlags<Qt::MouseButton> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_notify(PyObject* self, PyObject* args)
{
    QApplication* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QApplication* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "notify", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: notify(QObject*,QEvent*)
    if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // notify(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_notify_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QEvent* cpp_arg1 = Shiboken::Converter<QEvent* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // notify(QObject*,QEvent*)

            bool cppResult = cppSelf->QApplication::notify(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);

            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQApplicationFunc_notify_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.notify", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_overrideCursor(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // overrideCursor()
            QCursor * cppResult = QApplication::overrideCursor();
            pyResult = Shiboken::Converter<QCursor * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_palette(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: palette()
    // 1: palette(const QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // palette()
    } else if (Shiboken::Converter<const QWidget * >::isConvertible(arg)) {
        overloadId = 1; // palette(const QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_palette_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // palette()
            {

                if(!PyErr_Occurred()) {
                // palette()
                QPalette cppResult = QApplication::palette();
                pyResult = Shiboken::Converter<QPalette >::toPython(cppResult);
                }
                break;
            }
            case 1: // palette(const QWidget*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // palette(const QWidget*)
                QPalette cppResult = QApplication::palette(cpp_arg0);
                pyResult = Shiboken::Converter<QPalette >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQApplicationFunc_palette_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.palette", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_quitOnLastWindowClosed(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // quitOnLastWindowClosed()
            bool cppResult = QApplication::quitOnLastWindowClosed();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_restoreOverrideCursor(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // restoreOverrideCursor()
            QApplication::restoreOverrideCursor();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQApplicationFunc_saveState(PyObject* self, PyObject* arg)
{
    QApplication* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QApplication* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: saveState(QSessionManager&)
    if (Shiboken::Converter<QSessionManager & >::isConvertible(arg)) {
        overloadId = 0; // saveState(QSessionManager&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_saveState_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QSessionManager* cpp_arg0 = Shiboken::Converter<QSessionManager* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // saveState(QSessionManager&)
            cppSelf->QApplication::saveState(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_saveState_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSessionManager", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.saveState", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_sessionId(PyObject* self)
{
    QApplication* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QApplication* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sessionId()const
            QString cppResult = cppSelf->QApplication::sessionId();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_sessionKey(PyObject* self)
{
    QApplication* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QApplication* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sessionKey()const
            QString cppResult = cppSelf->QApplication::sessionKey();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_setActiveWindow(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setActiveWindow(QWidget*)
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setActiveWindow(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setActiveWindow_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setActiveWindow(QWidget*)
            QApplication::setActiveWindow(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setActiveWindow_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setActiveWindow", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setAutoSipEnabled(PyObject* self, PyObject* arg)
{
    QApplication* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QApplication* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoSipEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoSipEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setAutoSipEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoSipEnabled(bool)
            cppSelf->QApplication::setAutoSipEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setAutoSipEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setAutoSipEnabled", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setColorSpec(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColorSpec(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setColorSpec(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setColorSpec_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setColorSpec(int)
            QApplication::setColorSpec(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setColorSpec_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setColorSpec", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setCursorFlashTime(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCursorFlashTime(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCursorFlashTime(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setCursorFlashTime_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCursorFlashTime(int)
            QApplication::setCursorFlashTime(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setCursorFlashTime_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setCursorFlashTime", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setDesktopSettingsAware(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDesktopSettingsAware(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDesktopSettingsAware(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setDesktopSettingsAware_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDesktopSettingsAware(bool)
            QApplication::setDesktopSettingsAware(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setDesktopSettingsAware_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setDesktopSettingsAware", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setDoubleClickInterval(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDoubleClickInterval(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDoubleClickInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setDoubleClickInterval_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDoubleClickInterval(int)
            QApplication::setDoubleClickInterval(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setDoubleClickInterval_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setDoubleClickInterval", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setEffectEnabled(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "enable" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QApplication.setEffectEnabled(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QApplication.setEffectEnabled(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QApplication.setEffectEnabled(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setEffectEnabled", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setEffectEnabled(Qt::UIEffect,bool)
    if (Shiboken::Converter<Qt::UIEffect >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setEffectEnabled(Qt::UIEffect,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setEffectEnabled(Qt::UIEffect,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setEffectEnabled_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "enable");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "enable";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QApplication.setEffectEnabled(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::UIEffect cpp_arg0 = Shiboken::Converter<Qt::UIEffect >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // setEffectEnabled(Qt::UIEffect,bool)
            QApplication::setEffectEnabled(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setEffectEnabled_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.UIEffect, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.setEffectEnabled", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setGlobalStrut(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGlobalStrut(QSize)
    if (Shiboken::Converter<const QSize & >::isConvertible(arg)) {
        overloadId = 0; // setGlobalStrut(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setGlobalStrut_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGlobalStrut(QSize)
            QApplication::setGlobalStrut(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setGlobalStrut_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setGlobalStrut", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setGraphicsSystem(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGraphicsSystem(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setGraphicsSystem(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setGraphicsSystem_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGraphicsSystem(QString)
            QApplication::setGraphicsSystem(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setGraphicsSystem_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setGraphicsSystem", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setInputContext(PyObject* self, PyObject* arg)
{
    QApplication* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QApplication* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInputContext(QInputContext*)
    if (Shiboken::Converter<QInputContext * >::isConvertible(arg)) {
        overloadId = 0; // setInputContext(QInputContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setInputContext_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QInputContext* cpp_arg0 = Shiboken::Converter<QInputContext* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setInputContext(QInputContext*)
            cppSelf->QApplication::setInputContext(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setInputContext_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputContext", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setInputContext", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setKeyboardInputInterval(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setKeyboardInputInterval(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setKeyboardInputInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setKeyboardInputInterval_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setKeyboardInputInterval(int)
            QApplication::setKeyboardInputInterval(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setKeyboardInputInterval_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setKeyboardInputInterval", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setLayoutDirection(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLayoutDirection(Qt::LayoutDirection)
    if (Shiboken::Converter<Qt::LayoutDirection >::isConvertible(arg)) {
        overloadId = 0; // setLayoutDirection(Qt::LayoutDirection)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setLayoutDirection_TypeError;

    // Call function/method
    {
        {
            Qt::LayoutDirection cpp_arg0 = Shiboken::Converter<Qt::LayoutDirection >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLayoutDirection(Qt::LayoutDirection)
            QApplication::setLayoutDirection(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setLayoutDirection_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.LayoutDirection", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setLayoutDirection", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setOverrideCursor(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOverrideCursor(QCursor)
    if (Shiboken::Converter<const QCursor & >::isConvertible(arg)) {
        overloadId = 0; // setOverrideCursor(QCursor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setOverrideCursor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QCursor > cpp_arg0_auto_ptr;
            QCursor* cpp_arg0 = Shiboken::Converter<QCursor* >::toCpp(arg);
            if (!Shiboken::Converter<QCursor >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QCursor >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setOverrideCursor(QCursor)
            QApplication::setOverrideCursor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setOverrideCursor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QCursor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setOverrideCursor", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setPalette(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "className" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QApplication.setPalette(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QApplication.setPalette(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QApplication.setPalette(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setPalette", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPalette(QPalette,const char*)
    if (Shiboken::Converter<const QPalette & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setPalette(QPalette,const char*)
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            overloadId = 0; // setPalette(QPalette,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setPalette_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "className");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "className";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QApplication.setPalette(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QPalette > cpp_arg0_auto_ptr;
            QPalette* cpp_arg0 = Shiboken::Converter<QPalette* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QPalette >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QPalette >(cpp_arg0);
            const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // setPalette(QPalette,const char*)
            QApplication::setPalette(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setPalette_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette, str = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.setPalette", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setQuitOnLastWindowClosed(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setQuitOnLastWindowClosed(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setQuitOnLastWindowClosed(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setQuitOnLastWindowClosed_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setQuitOnLastWindowClosed(bool)
            QApplication::setQuitOnLastWindowClosed(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setQuitOnLastWindowClosed_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setQuitOnLastWindowClosed", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setStartDragDistance(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStartDragDistance(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStartDragDistance(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setStartDragDistance_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStartDragDistance(int)
            QApplication::setStartDragDistance(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setStartDragDistance_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setStartDragDistance", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setStartDragTime(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStartDragTime(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStartDragTime(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setStartDragTime_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStartDragTime(int)
            QApplication::setStartDragTime(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setStartDragTime_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setStartDragTime", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setStyle(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyle(QStyle*)
    // 1: setStyle(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // setStyle(QString)
    } else if (Shiboken::Converter<QStyle * >::isConvertible(arg)) {
        overloadId = 0; // setStyle(QStyle*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setStyle_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setStyle(QStyle*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QStyle* cpp_arg0 = Shiboken::Converter<QStyle* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setStyle(QStyle*)

                QApplication::setStyle(cpp_arg0);

                // Begin code injection
                
                Shiboken::setParent(Shiboken::Converter<QApplication* >::toPython(qApp), arg);
                
                // End of code injection
                pyResult = Py_None;
                Py_INCREF(Py_None);
                }
                break;
            }
            case 1: // setStyle(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setStyle(QString)
                QStyle * cppResult = QApplication::setStyle(cpp_arg0);
                pyResult = Shiboken::Converter<QStyle * >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQApplicationFunc_setStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setStyle", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setStyleSheet(PyObject* self, PyObject* arg)
{
    QApplication* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QApplication* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyleSheet(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setStyleSheet(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setStyleSheet_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStyleSheet(QString)
            cppSelf->QApplication::setStyleSheet(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setStyleSheet_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setStyleSheet", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setWheelScrollLines(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWheelScrollLines(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWheelScrollLines(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setWheelScrollLines_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWheelScrollLines(int)
            QApplication::setWheelScrollLines(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setWheelScrollLines_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setWheelScrollLines", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_setWindowIcon(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowIcon(QIcon)
    if (Shiboken::Converter<const QIcon & >::isConvertible(arg)) {
        overloadId = 0; // setWindowIcon(QIcon)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_setWindowIcon_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QIcon > cpp_arg0_auto_ptr;
            QIcon* cpp_arg0 = Shiboken::Converter<QIcon* >::toCpp(arg);
            if (!Shiboken::Converter<QIcon >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QIcon >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setWindowIcon(QIcon)
            QApplication::setWindowIcon(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQApplicationFunc_setWindowIcon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QIcon", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setWindowIcon", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_startDragDistance(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // startDragDistance()
            int cppResult = QApplication::startDragDistance();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_startDragTime(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // startDragTime()
            int cppResult = QApplication::startDragTime();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_style(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // style()

            QStyle * cppResult = QApplication::style();
            pyResult = Shiboken::Converter<QStyle * >::toPython(cppResult);

            // Begin code injection
            
            Shiboken::setParent(Shiboken::Converter<QApplication* >::toPython(qApp), pyResult);
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_styleSheet(PyObject* self)
{
    QApplication* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QApplication* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // styleSheet()const
            QString cppResult = cppSelf->QApplication::styleSheet();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_syncX(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // syncX()
            QApplication::syncX();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQApplicationFunc_topLevelAt(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "topLevelAt", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: topLevelAt(QPoint)
    // 1: topLevelAt(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // topLevelAt(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // topLevelAt(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_topLevelAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // topLevelAt(QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // topLevelAt(QPoint)
                QWidget * cppResult = QApplication::topLevelAt(*cpp_arg0);
                pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
                }
                break;
            }
            case 1: // topLevelAt(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // topLevelAt(int,int)
                QWidget * cppResult = QApplication::topLevelAt(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQApplicationFunc_topLevelAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.topLevelAt", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_topLevelWidgets(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // topLevelWidgets()
            QList<QWidget * > cppResult = QApplication::topLevelWidgets();
            pyResult = Shiboken::Converter<QList<QWidget * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_type(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // type()
            QApplication::Type cppResult = QApplication::type();
            pyResult = Shiboken::Converter<QApplication::Type >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_wheelScrollLines(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // wheelScrollLines()
            int cppResult = QApplication::wheelScrollLines();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQApplicationFunc_widgetAt(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "widgetAt", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: widgetAt(QPoint)
    // 1: widgetAt(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // widgetAt(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // widgetAt(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQApplicationFunc_widgetAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // widgetAt(QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // widgetAt(QPoint)
                QWidget * cppResult = QApplication::widgetAt(*cpp_arg0);
                pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
                }
                break;
            }
            case 1: // widgetAt(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // widgetAt(int,int)
                QWidget * cppResult = QApplication::widgetAt(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQApplicationFunc_widgetAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.widgetAt", overloads);
        return 0;
}

static PyObject* SbkQApplicationFunc_windowIcon(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // windowIcon()
            QIcon cppResult = QApplication::windowIcon();
            pyResult = Shiboken::Converter<QIcon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQApplication_methods[] = {
    {"aboutQt", (PyCFunction)SbkQApplicationFunc_aboutQt, METH_NOARGS|METH_STATIC},
    {"activeModalWidget", (PyCFunction)SbkQApplicationFunc_activeModalWidget, METH_NOARGS|METH_STATIC},
    {"activePopupWidget", (PyCFunction)SbkQApplicationFunc_activePopupWidget, METH_NOARGS|METH_STATIC},
    {"activeWindow", (PyCFunction)SbkQApplicationFunc_activeWindow, METH_NOARGS|METH_STATIC},
    {"alert", (PyCFunction)SbkQApplicationFunc_alert, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"allWidgets", (PyCFunction)SbkQApplicationFunc_allWidgets, METH_NOARGS|METH_STATIC},
    {"autoSipEnabled", (PyCFunction)SbkQApplicationFunc_autoSipEnabled, METH_NOARGS},
    {"beep", (PyCFunction)SbkQApplicationFunc_beep, METH_NOARGS|METH_STATIC},
    {"changeOverrideCursor", (PyCFunction)SbkQApplicationFunc_changeOverrideCursor, METH_O|METH_STATIC},
    {"clipboard", (PyCFunction)SbkQApplicationFunc_clipboard, METH_NOARGS|METH_STATIC},
    {"closeAllWindows", (PyCFunction)SbkQApplicationFunc_closeAllWindows, METH_NOARGS|METH_STATIC},
    {"colorSpec", (PyCFunction)SbkQApplicationFunc_colorSpec, METH_NOARGS|METH_STATIC},
    {"commitData", (PyCFunction)SbkQApplicationFunc_commitData, METH_O},
    {"cursorFlashTime", (PyCFunction)SbkQApplicationFunc_cursorFlashTime, METH_NOARGS|METH_STATIC},
    {"desktop", (PyCFunction)SbkQApplicationFunc_desktop, METH_NOARGS|METH_STATIC},
    {"desktopSettingsAware", (PyCFunction)SbkQApplicationFunc_desktopSettingsAware, METH_NOARGS|METH_STATIC},
    {"doubleClickInterval", (PyCFunction)SbkQApplicationFunc_doubleClickInterval, METH_NOARGS|METH_STATIC},
    {"event", (PyCFunction)SbkQApplicationFunc_event, METH_O},
    {"exec_", (PyCFunction)SbkQApplicationFunc_exec_, METH_NOARGS|METH_STATIC},
    {"focusWidget", (PyCFunction)SbkQApplicationFunc_focusWidget, METH_NOARGS|METH_STATIC},
    {"font", (PyCFunction)SbkQApplicationFunc_font, METH_NOARGS|METH_O|METH_STATIC},
    {"fontMetrics", (PyCFunction)SbkQApplicationFunc_fontMetrics, METH_NOARGS|METH_STATIC},
    {"globalStrut", (PyCFunction)SbkQApplicationFunc_globalStrut, METH_NOARGS|METH_STATIC},
    {"inputContext", (PyCFunction)SbkQApplicationFunc_inputContext, METH_NOARGS},
    {"isEffectEnabled", (PyCFunction)SbkQApplicationFunc_isEffectEnabled, METH_O|METH_STATIC},
    {"isLeftToRight", (PyCFunction)SbkQApplicationFunc_isLeftToRight, METH_NOARGS|METH_STATIC},
    {"isRightToLeft", (PyCFunction)SbkQApplicationFunc_isRightToLeft, METH_NOARGS|METH_STATIC},
    {"isSessionRestored", (PyCFunction)SbkQApplicationFunc_isSessionRestored, METH_NOARGS},
    {"keyboardInputDirection", (PyCFunction)SbkQApplicationFunc_keyboardInputDirection, METH_NOARGS|METH_STATIC},
    {"keyboardInputInterval", (PyCFunction)SbkQApplicationFunc_keyboardInputInterval, METH_NOARGS|METH_STATIC},
    {"keyboardInputLocale", (PyCFunction)SbkQApplicationFunc_keyboardInputLocale, METH_NOARGS|METH_STATIC},
    {"keyboardModifiers", (PyCFunction)SbkQApplicationFunc_keyboardModifiers, METH_NOARGS|METH_STATIC},
    {"layoutDirection", (PyCFunction)SbkQApplicationFunc_layoutDirection, METH_NOARGS|METH_STATIC},
    {"mouseButtons", (PyCFunction)SbkQApplicationFunc_mouseButtons, METH_NOARGS|METH_STATIC},
    {"notify", (PyCFunction)SbkQApplicationFunc_notify, METH_VARARGS},
    {"overrideCursor", (PyCFunction)SbkQApplicationFunc_overrideCursor, METH_NOARGS|METH_STATIC},
    {"palette", (PyCFunction)SbkQApplicationFunc_palette, METH_NOARGS|METH_O|METH_STATIC},
    {"quitOnLastWindowClosed", (PyCFunction)SbkQApplicationFunc_quitOnLastWindowClosed, METH_NOARGS|METH_STATIC},
    {"restoreOverrideCursor", (PyCFunction)SbkQApplicationFunc_restoreOverrideCursor, METH_NOARGS|METH_STATIC},
    {"saveState", (PyCFunction)SbkQApplicationFunc_saveState, METH_O},
    {"sessionId", (PyCFunction)SbkQApplicationFunc_sessionId, METH_NOARGS},
    {"sessionKey", (PyCFunction)SbkQApplicationFunc_sessionKey, METH_NOARGS},
    {"setActiveWindow", (PyCFunction)SbkQApplicationFunc_setActiveWindow, METH_O|METH_STATIC},
    {"setAutoSipEnabled", (PyCFunction)SbkQApplicationFunc_setAutoSipEnabled, METH_O},
    {"setColorSpec", (PyCFunction)SbkQApplicationFunc_setColorSpec, METH_O|METH_STATIC},
    {"setCursorFlashTime", (PyCFunction)SbkQApplicationFunc_setCursorFlashTime, METH_O|METH_STATIC},
    {"setDesktopSettingsAware", (PyCFunction)SbkQApplicationFunc_setDesktopSettingsAware, METH_O|METH_STATIC},
    {"setDoubleClickInterval", (PyCFunction)SbkQApplicationFunc_setDoubleClickInterval, METH_O|METH_STATIC},
    {"setEffectEnabled", (PyCFunction)SbkQApplicationFunc_setEffectEnabled, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"setGlobalStrut", (PyCFunction)SbkQApplicationFunc_setGlobalStrut, METH_O|METH_STATIC},
    {"setGraphicsSystem", (PyCFunction)SbkQApplicationFunc_setGraphicsSystem, METH_O|METH_STATIC},
    {"setInputContext", (PyCFunction)SbkQApplicationFunc_setInputContext, METH_O},
    {"setKeyboardInputInterval", (PyCFunction)SbkQApplicationFunc_setKeyboardInputInterval, METH_O|METH_STATIC},
    {"setLayoutDirection", (PyCFunction)SbkQApplicationFunc_setLayoutDirection, METH_O|METH_STATIC},
    {"setOverrideCursor", (PyCFunction)SbkQApplicationFunc_setOverrideCursor, METH_O|METH_STATIC},
    {"setPalette", (PyCFunction)SbkQApplicationFunc_setPalette, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"setQuitOnLastWindowClosed", (PyCFunction)SbkQApplicationFunc_setQuitOnLastWindowClosed, METH_O|METH_STATIC},
    {"setStartDragDistance", (PyCFunction)SbkQApplicationFunc_setStartDragDistance, METH_O|METH_STATIC},
    {"setStartDragTime", (PyCFunction)SbkQApplicationFunc_setStartDragTime, METH_O|METH_STATIC},
    {"setStyle", (PyCFunction)SbkQApplicationFunc_setStyle, METH_O|METH_STATIC},
    {"setStyleSheet", (PyCFunction)SbkQApplicationFunc_setStyleSheet, METH_O},
    {"setWheelScrollLines", (PyCFunction)SbkQApplicationFunc_setWheelScrollLines, METH_O|METH_STATIC},
    {"setWindowIcon", (PyCFunction)SbkQApplicationFunc_setWindowIcon, METH_O|METH_STATIC},
    {"startDragDistance", (PyCFunction)SbkQApplicationFunc_startDragDistance, METH_NOARGS|METH_STATIC},
    {"startDragTime", (PyCFunction)SbkQApplicationFunc_startDragTime, METH_NOARGS|METH_STATIC},
    {"style", (PyCFunction)SbkQApplicationFunc_style, METH_NOARGS|METH_STATIC},
    {"styleSheet", (PyCFunction)SbkQApplicationFunc_styleSheet, METH_NOARGS},
    {"syncX", (PyCFunction)SbkQApplicationFunc_syncX, METH_NOARGS|METH_STATIC},
    {"topLevelAt", (PyCFunction)SbkQApplicationFunc_topLevelAt, METH_VARARGS|METH_STATIC},
    {"topLevelWidgets", (PyCFunction)SbkQApplicationFunc_topLevelWidgets, METH_NOARGS|METH_STATIC},
    {"type", (PyCFunction)SbkQApplicationFunc_type, METH_NOARGS|METH_STATIC},
    {"wheelScrollLines", (PyCFunction)SbkQApplicationFunc_wheelScrollLines, METH_NOARGS|METH_STATIC},
    {"widgetAt", (PyCFunction)SbkQApplicationFunc_widgetAt, METH_VARARGS|METH_STATIC},
    {"windowIcon", (PyCFunction)SbkQApplicationFunc_windowIcon, METH_NOARGS|METH_STATIC},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQApplication_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QApplication",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQApplication_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQApplication_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QApplication >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QApplication*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQApplication_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QApplication*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQApplication_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QApplication_Type_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QApplication_Type_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QApplication_Type_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Type",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QApplication_Type_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QApplication_Type_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QApplication_Type_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QApplication_ColorSpec_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QApplication_ColorSpec_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QApplication_ColorSpec_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ColorSpec",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QApplication_ColorSpec_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QApplication_ColorSpec_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QApplication_ColorSpec_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QApplication(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QAPPLICATION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQApplication_Type);


    SbkQApplication_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QCOREAPPLICATION_IDX];
    // Fill type discovery information
    SbkQApplication_Type.type_discovery = &SbkQApplication_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QCOREAPPLICATION_IDX]), &SbkQApplication_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQApplication_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQApplication_Type));
    PyModule_AddObject(module, "QApplication",
        ((PyObject*)&SbkQApplication_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Type
    SbkPySide_QtGuiTypes[SBK_QAPPLICATION_TYPE_IDX] = &SbkPySide_QtGui_QApplication_Type_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QApplication_Type_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QApplication_Type_Type);
    PyDict_SetItemString(SbkQApplication_Type.super.ht_type.tp_dict,
            "Type",((PyObject*)&SbkPySide_QtGui_QApplication_Type_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QApplication_Type_Type,
        (long) QApplication::Tty, "Tty");
    PyDict_SetItemString(SbkQApplication_Type.super.ht_type.tp_dict,
        "Tty", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QApplication_Type_Type.tp_dict,
        "Tty", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QApplication_Type_Type,
        (long) QApplication::GuiClient, "GuiClient");
    PyDict_SetItemString(SbkQApplication_Type.super.ht_type.tp_dict,
        "GuiClient", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QApplication_Type_Type.tp_dict,
        "GuiClient", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QApplication_Type_Type,
        (long) QApplication::GuiServer, "GuiServer");
    PyDict_SetItemString(SbkQApplication_Type.super.ht_type.tp_dict,
        "GuiServer", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QApplication_Type_Type.tp_dict,
        "GuiServer", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QApplication::Type");

    // init enum class: ColorSpec
    SbkPySide_QtGuiTypes[SBK_QAPPLICATION_COLORSPEC_IDX] = &SbkPySide_QtGui_QApplication_ColorSpec_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QApplication_ColorSpec_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QApplication_ColorSpec_Type);
    PyDict_SetItemString(SbkQApplication_Type.super.ht_type.tp_dict,
            "ColorSpec",((PyObject*)&SbkPySide_QtGui_QApplication_ColorSpec_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QApplication_ColorSpec_Type,
        (long) QApplication::NormalColor, "NormalColor");
    PyDict_SetItemString(SbkQApplication_Type.super.ht_type.tp_dict,
        "NormalColor", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QApplication_ColorSpec_Type.tp_dict,
        "NormalColor", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QApplication_ColorSpec_Type,
        (long) QApplication::CustomColor, "CustomColor");
    PyDict_SetItemString(SbkQApplication_Type.super.ht_type.tp_dict,
        "CustomColor", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QApplication_ColorSpec_Type.tp_dict,
        "CustomColor", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QApplication_ColorSpec_Type,
        (long) QApplication::ManyColor, "ManyColor");
    PyDict_SetItemString(SbkQApplication_Type.super.ht_type.tp_dict,
        "ManyColor", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QApplication_ColorSpec_Type.tp_dict,
        "ManyColor", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QApplication::ColorSpec");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("focusChanged", "QWidget*,QWidget*", NULL);
    PyDict_SetItemString(SbkQApplication_Type.super.ht_type.tp_dict, "focusChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("commitDataRequest", "QSessionManager&", NULL);
    PyDict_SetItemString(SbkQApplication_Type.super.ht_type.tp_dict, "commitDataRequest", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("lastWindowClosed", "void", NULL);
    PyDict_SetItemString(SbkQApplication_Type.super.ht_type.tp_dict, "lastWindowClosed", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("fontDatabaseChanged", "void", NULL);
    PyDict_SetItemString(SbkQApplication_Type.super.ht_type.tp_dict, "fontDatabaseChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("saveStateRequest", "QSessionManager&", NULL);
    PyDict_SetItemString(SbkQApplication_Type.super.ht_type.tp_dict, "saveStateRequest", signal_item);
    Py_DECREF(signal_item);



    Shiboken::TypeResolver::createObjectTypeResolver<QApplication >("QApplication*");
    Shiboken::TypeResolver::createObjectTypeResolver<QApplication >(typeid(QApplication).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QApplication >(typeid(QApplicationWrapper).name());
    PySide::initQtMetaType<QApplication* >();
}


