/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qclipboard_wrapper.h"

// Extra includes
#include <QImage>
#include <QList>
#include <QPixmap>
#include <qbytearray.h>
#include <qclipboard.h>
#include <qcoreevent.h>
#include <qimage.h>
#include <qmimedata.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpixmap.h>
#include <qthread.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static PyObject* SbkQClipboardFunc_clear(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.clear(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.clear(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:clear", &arg))
        return 0;


    // Overloaded function decisor
    // 0: clear(QClipboard::Mode)
    if (numArgs == 0) {
        overloadId = 0; // clear(QClipboard::Mode)
    } else if (Shiboken::Converter<QClipboard::Mode >::isConvertible(arg)) {
        overloadId = 0; // clear(QClipboard::Mode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQClipboardFunc_clear_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (arg)
                        errorArgName = "mode";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.clear(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QClipboard::Mode cpp_arg0 = arg ? Shiboken::Converter<QClipboard::Mode >::toCpp(arg) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
            // clear(QClipboard::Mode)
            cppSelf->QClipboard::clear(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQClipboardFunc_clear_TypeError:
        const char* overloads[] = {"PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QClipboard.clear", overloads);
        return 0;
}

static PyObject* SbkQClipboardFunc_connectNotify(PyObject* self, PyObject* arg)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: connectNotify(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // connectNotify(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQClipboardFunc_connectNotify_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // connectNotify(const char*)
            cppSelf->QClipboard::connectNotify(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQClipboardFunc_connectNotify_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QClipboard.connectNotify", overloads);
        return 0;
}

static PyObject* SbkQClipboardFunc_event(PyObject* self, PyObject* arg)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQClipboardFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QClipboard::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQClipboardFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QClipboard.event", overloads);
        return 0;
}

static PyObject* SbkQClipboardFunc_image(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.image(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.image(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:image", &arg))
        return 0;


    // Overloaded function decisor
    // 0: image(QClipboard::Mode)const
    if (numArgs == 0) {
        overloadId = 0; // image(QClipboard::Mode)const
    } else if (Shiboken::Converter<QClipboard::Mode >::isConvertible(arg)) {
        overloadId = 0; // image(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQClipboardFunc_image_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (arg)
                        errorArgName = "mode";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.image(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QClipboard::Mode cpp_arg0 = arg ? Shiboken::Converter<QClipboard::Mode >::toCpp(arg) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
            // image(QClipboard::Mode)const
            QImage cppResult = cppSelf->QClipboard::image(cpp_arg0);
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQClipboardFunc_image_TypeError:
        const char* overloads[] = {"PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QClipboard.image", overloads);
        return 0;
}

static PyObject* SbkQClipboardFunc_mimeData(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.mimeData(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.mimeData(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:mimeData", &arg))
        return 0;


    // Overloaded function decisor
    // 0: mimeData(QClipboard::Mode)const
    if (numArgs == 0) {
        overloadId = 0; // mimeData(QClipboard::Mode)const
    } else if (Shiboken::Converter<QClipboard::Mode >::isConvertible(arg)) {
        overloadId = 0; // mimeData(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQClipboardFunc_mimeData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (arg)
                        errorArgName = "mode";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.mimeData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QClipboard::Mode cpp_arg0 = arg ? Shiboken::Converter<QClipboard::Mode >::toCpp(arg) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
            // mimeData(QClipboard::Mode)const
            const QMimeData * cppResult = cppSelf->QClipboard::mimeData(cpp_arg0);
            pyResult = Shiboken::Converter<const QMimeData * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQClipboardFunc_mimeData_TypeError:
        const char* overloads[] = {"PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QClipboard.mimeData", overloads);
        return 0;
}

static PyObject* SbkQClipboardFunc_ownsClipboard(PyObject* self)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ownsClipboard()const
            bool cppResult = cppSelf->QClipboard::ownsClipboard();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQClipboardFunc_ownsFindBuffer(PyObject* self)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ownsFindBuffer()const
            bool cppResult = cppSelf->QClipboard::ownsFindBuffer();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQClipboardFunc_ownsSelection(PyObject* self)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ownsSelection()const
            bool cppResult = cppSelf->QClipboard::ownsSelection();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQClipboardFunc_pixmap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.pixmap(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.pixmap(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:pixmap", &arg))
        return 0;


    // Overloaded function decisor
    // 0: pixmap(QClipboard::Mode)const
    if (numArgs == 0) {
        overloadId = 0; // pixmap(QClipboard::Mode)const
    } else if (Shiboken::Converter<QClipboard::Mode >::isConvertible(arg)) {
        overloadId = 0; // pixmap(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQClipboardFunc_pixmap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (arg)
                        errorArgName = "mode";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.pixmap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QClipboard::Mode cpp_arg0 = arg ? Shiboken::Converter<QClipboard::Mode >::toCpp(arg) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
            // pixmap(QClipboard::Mode)const
            QPixmap cppResult = cppSelf->QClipboard::pixmap(cpp_arg0);
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQClipboardFunc_pixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QClipboard.pixmap", overloads);
        return 0;
}

static PyObject* SbkQClipboardFunc_setImage(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.setImage(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setImage(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setImage(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setImage", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setImage(QImage,QClipboard::Mode)
    if (Shiboken::Converter<const QImage & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setImage(QImage,QClipboard::Mode)
        } else if (Shiboken::Converter<QClipboard::Mode >::isConvertible(pyargs[1])) {
            overloadId = 0; // setImage(QImage,QClipboard::Mode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQClipboardFunc_setImage_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.setImage(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QImage* cpp_arg0 = Shiboken::Converter<QImage* >::toCpp(pyargs[0]);
            QClipboard::Mode cpp_arg1 = pyargs[1] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[1]) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
            // setImage(QImage,QClipboard::Mode)
            cppSelf->QClipboard::setImage(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQClipboardFunc_setImage_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage, PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.setImage", overloads);
        return 0;
}

static PyObject* SbkQClipboardFunc_setMimeData(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.setMimeData(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setMimeData(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setMimeData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setMimeData", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setMimeData(QMimeData*,QClipboard::Mode)
    if (Shiboken::Converter<QMimeData * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setMimeData(QMimeData*,QClipboard::Mode)
        } else if (Shiboken::Converter<QClipboard::Mode >::isConvertible(pyargs[1])) {
            overloadId = 0; // setMimeData(QMimeData*,QClipboard::Mode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQClipboardFunc_setMimeData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.setMimeData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QMimeData* cpp_arg0 = Shiboken::Converter<QMimeData* >::toCpp(pyargs[0]);
            QClipboard::Mode cpp_arg1 = pyargs[1] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[1]) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
            // setMimeData(QMimeData*,QClipboard::Mode)
            cppSelf->QClipboard::setMimeData(cpp_arg0, cpp_arg1);
            Shiboken::setParent(self, pyargs[0]);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQClipboardFunc_setMimeData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMimeData, PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.setMimeData", overloads);
        return 0;
}

static PyObject* SbkQClipboardFunc_setPixmap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.setPixmap(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setPixmap(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setPixmap(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setPixmap", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPixmap(QPixmap,QClipboard::Mode)
    if (Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setPixmap(QPixmap,QClipboard::Mode)
        } else if (Shiboken::Converter<QClipboard::Mode >::isConvertible(pyargs[1])) {
            overloadId = 0; // setPixmap(QPixmap,QClipboard::Mode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQClipboardFunc_setPixmap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.setPixmap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QPixmap > cpp_arg0_auto_ptr;
            QPixmap* cpp_arg0 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QPixmap >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg0);
            QClipboard::Mode cpp_arg1 = pyargs[1] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[1]) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
            // setPixmap(QPixmap,QClipboard::Mode)
            cppSelf->QClipboard::setPixmap(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQClipboardFunc_setPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPixmap, PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.setPixmap", overloads);
        return 0;
}

static PyObject* SbkQClipboardFunc_setText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.setText(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setText(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setText", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setText(QString,QClipboard::Mode)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setText(QString,QClipboard::Mode)
        } else if (Shiboken::Converter<QClipboard::Mode >::isConvertible(pyargs[1])) {
            overloadId = 0; // setText(QString,QClipboard::Mode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQClipboardFunc_setText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.setText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QClipboard::Mode cpp_arg1 = pyargs[1] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[1]) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
            // setText(QString,QClipboard::Mode)
            cppSelf->QClipboard::setText(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQClipboardFunc_setText_TypeError:
        const char* overloads[] = {"QString, PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.setText", overloads);
        return 0;
}

static PyObject* SbkQClipboardFunc_supportsFindBuffer(PyObject* self)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportsFindBuffer()const
            bool cppResult = cppSelf->QClipboard::supportsFindBuffer();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQClipboardFunc_supportsSelection(PyObject* self)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportsSelection()const
            bool cppResult = cppSelf->QClipboard::supportsSelection();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQClipboardFunc_text(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.text(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.text(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:text", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: text(QClipboard::Mode)const
    // 1: text(QString&,QClipboard::Mode)const
    if (numArgs == 0) {
        overloadId = 0; // text(QClipboard::Mode)const
    } else if (Shiboken::Converter<QString & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // text(QString&,QClipboard::Mode)const
        } else if (Shiboken::Converter<QClipboard::Mode >::isConvertible(pyargs[1])) {
            overloadId = 1; // text(QString&,QClipboard::Mode)const
        }
    } else if (Shiboken::Converter<QClipboard::Mode >::isConvertible(pyargs[0])) {
        overloadId = 0; // text(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQClipboardFunc_text_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // text(QClipboard::Mode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "mode";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.text(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QClipboard::Mode cpp_arg0 = pyargs[0] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[0]) : QClipboard::Clipboard;

                if(!PyErr_Occurred()) {
                // text(QClipboard::Mode)const
                QString cppResult = cppSelf->QClipboard::text(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // text(QString&,QClipboard::Mode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.text(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QClipboard::Mode cpp_arg1 = pyargs[1] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[1]) : QClipboard::Clipboard;

                if(!PyErr_Occurred()) {
                // text(QString&,QClipboard::Mode)const


                // Begin code injection
                
                QString retval_ = cppSelf->text(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::makeTuple(retval_, cpp_arg0);
                
                // End of code injection
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQClipboardFunc_text_TypeError:
        const char* overloads[] = {"PySide.QtGui.QClipboard.Mode = Clipboard", "QString, PySide.QtGui.QClipboard.Mode = QClipboard.Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.text", overloads);
        return 0;
}

static PyMethodDef SbkQClipboard_methods[] = {
    {"clear", (PyCFunction)SbkQClipboardFunc_clear, METH_VARARGS|METH_KEYWORDS},
    {"connectNotify", (PyCFunction)SbkQClipboardFunc_connectNotify, METH_O},
    {"event", (PyCFunction)SbkQClipboardFunc_event, METH_O},
    {"image", (PyCFunction)SbkQClipboardFunc_image, METH_VARARGS|METH_KEYWORDS},
    {"mimeData", (PyCFunction)SbkQClipboardFunc_mimeData, METH_VARARGS|METH_KEYWORDS},
    {"ownsClipboard", (PyCFunction)SbkQClipboardFunc_ownsClipboard, METH_NOARGS},
    {"ownsFindBuffer", (PyCFunction)SbkQClipboardFunc_ownsFindBuffer, METH_NOARGS},
    {"ownsSelection", (PyCFunction)SbkQClipboardFunc_ownsSelection, METH_NOARGS},
    {"pixmap", (PyCFunction)SbkQClipboardFunc_pixmap, METH_VARARGS|METH_KEYWORDS},
    {"setImage", (PyCFunction)SbkQClipboardFunc_setImage, METH_VARARGS|METH_KEYWORDS},
    {"setMimeData", (PyCFunction)SbkQClipboardFunc_setMimeData, METH_VARARGS|METH_KEYWORDS},
    {"setPixmap", (PyCFunction)SbkQClipboardFunc_setPixmap, METH_VARARGS|METH_KEYWORDS},
    {"setText", (PyCFunction)SbkQClipboardFunc_setText, METH_VARARGS|METH_KEYWORDS},
    {"supportsFindBuffer", (PyCFunction)SbkQClipboardFunc_supportsFindBuffer, METH_NOARGS},
    {"supportsSelection", (PyCFunction)SbkQClipboardFunc_supportsSelection, METH_NOARGS},
    {"text", (PyCFunction)SbkQClipboardFunc_text, METH_VARARGS|METH_KEYWORDS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQClipboard_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QClipboard",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          Shiboken::deallocWrapperWithPrivateDtor,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQClipboard_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            0,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QClipboard*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQClipboard_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QClipboard*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQClipboard_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QClipboard_Mode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QClipboard_Mode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QClipboard_Mode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Mode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QClipboard_Mode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QClipboard_Mode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QClipboard_Mode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QClipboard(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QCLIPBOARD_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQClipboard_Type);

    SbkQClipboard_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQClipboard_Type.type_discovery = &SbkQClipboard_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQClipboard_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQClipboard_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQClipboard_Type));
    PyModule_AddObject(module, "QClipboard",
        ((PyObject*)&SbkQClipboard_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Mode
    SbkPySide_QtGuiTypes[SBK_QCLIPBOARD_MODE_IDX] = &SbkPySide_QtGui_QClipboard_Mode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QClipboard_Mode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QClipboard_Mode_Type);
    PyDict_SetItemString(SbkQClipboard_Type.super.ht_type.tp_dict,
            "Mode",((PyObject*)&SbkPySide_QtGui_QClipboard_Mode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QClipboard_Mode_Type,
        (long) QClipboard::Clipboard, "Clipboard");
    PyDict_SetItemString(SbkQClipboard_Type.super.ht_type.tp_dict,
        "Clipboard", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QClipboard_Mode_Type.tp_dict,
        "Clipboard", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QClipboard_Mode_Type,
        (long) QClipboard::Selection, "Selection");
    PyDict_SetItemString(SbkQClipboard_Type.super.ht_type.tp_dict,
        "Selection", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QClipboard_Mode_Type.tp_dict,
        "Selection", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QClipboard_Mode_Type,
        (long) QClipboard::FindBuffer, "FindBuffer");
    PyDict_SetItemString(SbkQClipboard_Type.super.ht_type.tp_dict,
        "FindBuffer", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QClipboard_Mode_Type.tp_dict,
        "FindBuffer", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QClipboard_Mode_Type,
        (long) QClipboard::LastMode, "LastMode");
    PyDict_SetItemString(SbkQClipboard_Type.super.ht_type.tp_dict,
        "LastMode", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QClipboard_Mode_Type.tp_dict,
        "LastMode", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QClipboard::Mode");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("dataChanged", "void", NULL);
    PyDict_SetItemString(SbkQClipboard_Type.super.ht_type.tp_dict, "dataChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("selectionChanged", "void", NULL);
    PyDict_SetItemString(SbkQClipboard_Type.super.ht_type.tp_dict, "selectionChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("changed", "QClipboard::Mode", NULL);
    PyDict_SetItemString(SbkQClipboard_Type.super.ht_type.tp_dict, "changed", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("findBufferChanged", "void", NULL);
    PyDict_SetItemString(SbkQClipboard_Type.super.ht_type.tp_dict, "findBufferChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QClipboard >("QClipboard*");
    Shiboken::TypeResolver::createObjectTypeResolver<QClipboard >(typeid(QClipboard).name());
    PySide::initQtMetaType<QClipboard* >();
}

