/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qgraphicslayoutitem_wrapper.h"

// Extra includes
#include <qgraphicsitem.h>
#include <qgraphicslayoutitem.h>
#include <qrect.h>
#include <qsize.h>
#include <qsizepolicy.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGraphicsLayoutItemWrapper::QGraphicsLayoutItemWrapper(QGraphicsLayoutItem * parent, bool isLayout) : QGraphicsLayoutItem(parent, isLayout) {
    // ... middle
}

void QGraphicsLayoutItemWrapper::setGeometry(const QRectF & rect)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setGeometry"));
    if (py_override.isNull()) {
        return this->QGraphicsLayoutItem::setGeometry(rect);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QRectF & >::toPython(rect)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QSizeF QGraphicsLayoutItemWrapper::sizeHint(Qt::SizeHint which, const QSizeF & constraint) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QGraphicsLayoutItem.sizeHint()' not implemented.");
        return QSizeF();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<Qt::SizeHint >::toPython(which),
        Shiboken::Converter<const QSizeF & >::toPython(constraint)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSizeF();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSizeF >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsLayoutItem.sizeHint", SbkType<QSizeF >()->tp_name, pyResult->ob_type->tp_name);
        return QSizeF();
    }
    QSizeF cppResult(Shiboken::Converter<QSizeF >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsLayoutItemWrapper::updateGeometry()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "updateGeometry"));
    if (py_override.isNull()) {
        return this->QGraphicsLayoutItem::updateGeometry();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QGraphicsLayoutItemWrapper::~QGraphicsLayoutItemWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGraphicsLayoutItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsLayoutItem >()))
        return -1;

    QGraphicsLayoutItemWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSLAYOUTITEM_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QGraphicsLayoutItem' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "isLayout", "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QGraphicsLayoutItem", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsLayoutItem(QGraphicsLayoutItem*,bool)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsLayoutItem(QGraphicsLayoutItem*,bool)
    } else if (Shiboken::Converter<QGraphicsLayoutItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QGraphicsLayoutItem(QGraphicsLayoutItem*,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // QGraphicsLayoutItem(QGraphicsLayoutItem*,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItem_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "isLayout");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "isLayout";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return -1;
            QGraphicsLayoutItem* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(pyargs[0]) : 0;
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
            // QGraphicsLayoutItem(QGraphicsLayoutItem*,bool)
            cptr = new QGraphicsLayoutItemWrapper(cpp_arg0, cpp_arg1);
            Shiboken::setParent(pyargs[0], self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsLayoutItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGraphicsLayoutItem_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQGraphicsLayoutItem_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsLayoutItem = None, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsLayoutItem", overloads);
        return -1;
}

static PyObject* SbkQGraphicsLayoutItemFunc_contentsRect(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // contentsRect()const
            QRectF cppResult = cppSelf->QGraphicsLayoutItem::contentsRect();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_effectiveSizeHint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "constraint" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem.effectiveSizeHint(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem.effectiveSizeHint(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem.effectiveSizeHint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:effectiveSizeHint", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: effectiveSizeHint(Qt::SizeHint,QSizeF)const
    if (Shiboken::Converter<Qt::SizeHint >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // effectiveSizeHint(Qt::SizeHint,QSizeF)const
        } else if (Shiboken::Converter<const QSizeF & >::isConvertible(pyargs[1])) {
            overloadId = 0; // effectiveSizeHint(Qt::SizeHint,QSizeF)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_effectiveSizeHint_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "constraint");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "constraint";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem.effectiveSizeHint(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::SizeHint cpp_arg0 = Shiboken::Converter<Qt::SizeHint >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QSizeF > cpp_arg1_auto_ptr;
            QSizeF cpp_arg1_tmp = QSizeF();
            QSizeF* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QSizeF* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QSizeF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QSizeF >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // effectiveSizeHint(Qt::SizeHint,QSizeF)const
            QSizeF cppResult = cppSelf->QGraphicsLayoutItem::effectiveSizeHint(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QSizeF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsLayoutItemFunc_effectiveSizeHint_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.SizeHint, PySide.QtCore.QSizeF = QSizeF()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsLayoutItem.effectiveSizeHint", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_geometry(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // geometry()const
            QRectF cppResult = cppSelf->QGraphicsLayoutItem::geometry();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_graphicsItem(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // graphicsItem()const
            QGraphicsItem * cppResult = cppSelf->QGraphicsLayoutItem::graphicsItem();
            pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_isLayout(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isLayout()const
            bool cppResult = cppSelf->QGraphicsLayoutItem::isLayout();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_maximumHeight(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maximumHeight()const
            qreal cppResult = cppSelf->QGraphicsLayoutItem::maximumHeight();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_maximumSize(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maximumSize()const
            QSizeF cppResult = cppSelf->QGraphicsLayoutItem::maximumSize();
            pyResult = Shiboken::Converter<QSizeF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_maximumWidth(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maximumWidth()const
            qreal cppResult = cppSelf->QGraphicsLayoutItem::maximumWidth();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_minimumHeight(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minimumHeight()const
            qreal cppResult = cppSelf->QGraphicsLayoutItem::minimumHeight();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_minimumSize(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minimumSize()const
            QSizeF cppResult = cppSelf->QGraphicsLayoutItem::minimumSize();
            pyResult = Shiboken::Converter<QSizeF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_minimumWidth(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minimumWidth()const
            qreal cppResult = cppSelf->QGraphicsLayoutItem::minimumWidth();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_ownedByLayout(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ownedByLayout()const
            bool cppResult = cppSelf->QGraphicsLayoutItem::ownedByLayout();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_parentLayoutItem(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parentLayoutItem()const
            QGraphicsLayoutItem * cppResult = cppSelf->QGraphicsLayoutItem::parentLayoutItem();
            pyResult = Shiboken::Converter<QGraphicsLayoutItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_preferredHeight(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // preferredHeight()const
            qreal cppResult = cppSelf->QGraphicsLayoutItem::preferredHeight();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_preferredSize(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // preferredSize()const
            QSizeF cppResult = cppSelf->QGraphicsLayoutItem::preferredSize();
            pyResult = Shiboken::Converter<QSizeF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_preferredWidth(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // preferredWidth()const
            qreal cppResult = cppSelf->QGraphicsLayoutItem::preferredWidth();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setGeometry(PyObject* self, PyObject* arg)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometry(QRectF)
    if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 0; // setGeometry(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setGeometry_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
            if (!Shiboken::Converter<QRectF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setGeometry(QRectF)
            cppSelf->QGraphicsLayoutItem::setGeometry(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setGeometry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsLayoutItem.setGeometry", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setGraphicsItem(PyObject* self, PyObject* arg)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGraphicsItem(QGraphicsItem*)
    if (Shiboken::Converter<QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // setGraphicsItem(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setGraphicsItem_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGraphicsItem(QGraphicsItem*)
            cppSelf->QGraphicsLayoutItem::setGraphicsItem(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setGraphicsItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsLayoutItem.setGraphicsItem", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setMaximumHeight(PyObject* self, PyObject* arg)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaximumHeight(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaximumHeight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setMaximumHeight_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMaximumHeight(qreal)
            cppSelf->QGraphicsLayoutItem::setMaximumHeight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setMaximumHeight_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsLayoutItem.setMaximumHeight", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setMaximumSize(PyObject* self, PyObject* args)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setMaximumSize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setMaximumSize(QSizeF)
    // 1: setMaximumSize(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setMaximumSize(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QSizeF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setMaximumSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setMaximumSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setMaximumSize(QSizeF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QSizeF > cpp_arg0_auto_ptr;
                QSizeF* cpp_arg0 = Shiboken::Converter<QSizeF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QSizeF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QSizeF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setMaximumSize(QSizeF)
                cppSelf->QGraphicsLayoutItem::setMaximumSize(*cpp_arg0);
                }
                break;
            }
            case 1: // setMaximumSize(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setMaximumSize(qreal,qreal)
                cppSelf->QGraphicsLayoutItem::setMaximumSize(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setMaximumSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSizeF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsLayoutItem.setMaximumSize", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setMaximumWidth(PyObject* self, PyObject* arg)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaximumWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaximumWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setMaximumWidth_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMaximumWidth(qreal)
            cppSelf->QGraphicsLayoutItem::setMaximumWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setMaximumWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsLayoutItem.setMaximumWidth", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setMinimumHeight(PyObject* self, PyObject* arg)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMinimumHeight(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMinimumHeight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setMinimumHeight_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMinimumHeight(qreal)
            cppSelf->QGraphicsLayoutItem::setMinimumHeight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setMinimumHeight_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsLayoutItem.setMinimumHeight", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setMinimumSize(PyObject* self, PyObject* args)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setMinimumSize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setMinimumSize(QSizeF)
    // 1: setMinimumSize(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setMinimumSize(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QSizeF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setMinimumSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setMinimumSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setMinimumSize(QSizeF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QSizeF > cpp_arg0_auto_ptr;
                QSizeF* cpp_arg0 = Shiboken::Converter<QSizeF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QSizeF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QSizeF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setMinimumSize(QSizeF)
                cppSelf->QGraphicsLayoutItem::setMinimumSize(*cpp_arg0);
                }
                break;
            }
            case 1: // setMinimumSize(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setMinimumSize(qreal,qreal)
                cppSelf->QGraphicsLayoutItem::setMinimumSize(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setMinimumSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSizeF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsLayoutItem.setMinimumSize", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setMinimumWidth(PyObject* self, PyObject* arg)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMinimumWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMinimumWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setMinimumWidth_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMinimumWidth(qreal)
            cppSelf->QGraphicsLayoutItem::setMinimumWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setMinimumWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsLayoutItem.setMinimumWidth", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setOwnedByLayout(PyObject* self, PyObject* arg)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOwnedByLayout(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOwnedByLayout(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setOwnedByLayout_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOwnedByLayout(bool)
            cppSelf->QGraphicsLayoutItem::setOwnedByLayout(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setOwnedByLayout_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsLayoutItem.setOwnedByLayout", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setParentLayoutItem(PyObject* self, PyObject* arg)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setParentLayoutItem(QGraphicsLayoutItem*)
    if (Shiboken::Converter<QGraphicsLayoutItem * >::isConvertible(arg)) {
        overloadId = 0; // setParentLayoutItem(QGraphicsLayoutItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setParentLayoutItem_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsLayoutItem* cpp_arg0 = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setParentLayoutItem(QGraphicsLayoutItem*)
            cppSelf->QGraphicsLayoutItem::setParentLayoutItem(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setParentLayoutItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsLayoutItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsLayoutItem.setParentLayoutItem", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setPreferredHeight(PyObject* self, PyObject* arg)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPreferredHeight(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPreferredHeight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setPreferredHeight_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPreferredHeight(qreal)
            cppSelf->QGraphicsLayoutItem::setPreferredHeight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setPreferredHeight_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsLayoutItem.setPreferredHeight", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setPreferredSize(PyObject* self, PyObject* args)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPreferredSize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPreferredSize(QSizeF)
    // 1: setPreferredSize(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setPreferredSize(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QSizeF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setPreferredSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setPreferredSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setPreferredSize(QSizeF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QSizeF > cpp_arg0_auto_ptr;
                QSizeF* cpp_arg0 = Shiboken::Converter<QSizeF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QSizeF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QSizeF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setPreferredSize(QSizeF)
                cppSelf->QGraphicsLayoutItem::setPreferredSize(*cpp_arg0);
                }
                break;
            }
            case 1: // setPreferredSize(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setPreferredSize(qreal,qreal)
                cppSelf->QGraphicsLayoutItem::setPreferredSize(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setPreferredSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSizeF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsLayoutItem.setPreferredSize", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setPreferredWidth(PyObject* self, PyObject* arg)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPreferredWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPreferredWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setPreferredWidth_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPreferredWidth(qreal)
            cppSelf->QGraphicsLayoutItem::setPreferredWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setPreferredWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsLayoutItem.setPreferredWidth", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_setSizePolicy(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "controlType" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem.setSizePolicy(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem.setSizePolicy(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem.setSizePolicy(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setSizePolicy", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
    // 1: setSizePolicy(QSizePolicy)
    if (numArgs == 1 && Shiboken::Converter<const QSizePolicy & >::isConvertible(pyargs[0])) {
        overloadId = 1; // setSizePolicy(QSizePolicy)
    } else if (numArgs >= 2 && Shiboken::Converter<QSizePolicy::Policy >::isConvertible(pyargs[0]) && Shiboken::Converter<QSizePolicy::Policy >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
        } else if (Shiboken::Converter<QSizePolicy::ControlType >::isConvertible(pyargs[2])) {
            overloadId = 0; // setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_setSizePolicy_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "controlType");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "controlType";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem.setSizePolicy(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QSizePolicy::Policy cpp_arg0 = Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[0]);
                QSizePolicy::Policy cpp_arg1 = Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[1]);
                QSizePolicy::ControlType cpp_arg2 = pyargs[2] ? Shiboken::Converter<QSizePolicy::ControlType >::toCpp(pyargs[2]) : QSizePolicy::DefaultType;

                if(!PyErr_Occurred()) {
                // setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
                cppSelf->QGraphicsLayoutItem::setSizePolicy(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // setSizePolicy(QSizePolicy)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSizePolicy* cpp_arg0 = Shiboken::Converter<QSizePolicy* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setSizePolicy(QSizePolicy)
                cppSelf->QGraphicsLayoutItem::setSizePolicy(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsLayoutItemFunc_setSizePolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSizePolicy.Policy, PySide.QtGui.QSizePolicy.Policy, PySide.QtGui.QSizePolicy.ControlType = QSizePolicy.DefaultType", "PySide.QtGui.QSizePolicy", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsLayoutItem.setSizePolicy", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_sizeHint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "constraint" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem.sizeHint(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem.sizeHint(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem.sizeHint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:sizeHint", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: sizeHint(Qt::SizeHint,QSizeF)const
    if (Shiboken::Converter<Qt::SizeHint >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // sizeHint(Qt::SizeHint,QSizeF)const
        } else if (Shiboken::Converter<const QSizeF & >::isConvertible(pyargs[1])) {
            overloadId = 0; // sizeHint(Qt::SizeHint,QSizeF)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsLayoutItemFunc_sizeHint_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "constraint");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "constraint";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsLayoutItem.sizeHint(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::SizeHint cpp_arg0 = Shiboken::Converter<Qt::SizeHint >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QSizeF > cpp_arg1_auto_ptr;
            QSizeF cpp_arg1_tmp = QSizeF();
            QSizeF* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QSizeF* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QSizeF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QSizeF >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // sizeHint(Qt::SizeHint,QSizeF)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QGraphicsLayoutItem.sizeHint()' not implemented.");
                return 0;
            }
            QSizeF cppResult = cppSelf->sizeHint(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QSizeF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsLayoutItemFunc_sizeHint_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.SizeHint, PySide.QtCore.QSizeF = QSizeF()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsLayoutItem.sizeHint", overloads);
        return 0;
}

static PyObject* SbkQGraphicsLayoutItemFunc_sizePolicy(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sizePolicy()const
            QSizePolicy cppResult = cppSelf->QGraphicsLayoutItem::sizePolicy();
            pyResult = Shiboken::Converter<QSizePolicy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsLayoutItemFunc_updateGeometry(PyObject* self)
{
    QGraphicsLayoutItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsLayoutItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // updateGeometry()
            cppSelf->QGraphicsLayoutItem::updateGeometry();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef SbkQGraphicsLayoutItem_methods[] = {
    {"contentsRect", (PyCFunction)SbkQGraphicsLayoutItemFunc_contentsRect, METH_NOARGS},
    {"effectiveSizeHint", (PyCFunction)SbkQGraphicsLayoutItemFunc_effectiveSizeHint, METH_VARARGS|METH_KEYWORDS},
    {"geometry", (PyCFunction)SbkQGraphicsLayoutItemFunc_geometry, METH_NOARGS},
    {"graphicsItem", (PyCFunction)SbkQGraphicsLayoutItemFunc_graphicsItem, METH_NOARGS},
    {"isLayout", (PyCFunction)SbkQGraphicsLayoutItemFunc_isLayout, METH_NOARGS},
    {"maximumHeight", (PyCFunction)SbkQGraphicsLayoutItemFunc_maximumHeight, METH_NOARGS},
    {"maximumSize", (PyCFunction)SbkQGraphicsLayoutItemFunc_maximumSize, METH_NOARGS},
    {"maximumWidth", (PyCFunction)SbkQGraphicsLayoutItemFunc_maximumWidth, METH_NOARGS},
    {"minimumHeight", (PyCFunction)SbkQGraphicsLayoutItemFunc_minimumHeight, METH_NOARGS},
    {"minimumSize", (PyCFunction)SbkQGraphicsLayoutItemFunc_minimumSize, METH_NOARGS},
    {"minimumWidth", (PyCFunction)SbkQGraphicsLayoutItemFunc_minimumWidth, METH_NOARGS},
    {"ownedByLayout", (PyCFunction)SbkQGraphicsLayoutItemFunc_ownedByLayout, METH_NOARGS},
    {"parentLayoutItem", (PyCFunction)SbkQGraphicsLayoutItemFunc_parentLayoutItem, METH_NOARGS},
    {"preferredHeight", (PyCFunction)SbkQGraphicsLayoutItemFunc_preferredHeight, METH_NOARGS},
    {"preferredSize", (PyCFunction)SbkQGraphicsLayoutItemFunc_preferredSize, METH_NOARGS},
    {"preferredWidth", (PyCFunction)SbkQGraphicsLayoutItemFunc_preferredWidth, METH_NOARGS},
    {"setGeometry", (PyCFunction)SbkQGraphicsLayoutItemFunc_setGeometry, METH_O},
    {"setGraphicsItem", (PyCFunction)SbkQGraphicsLayoutItemFunc_setGraphicsItem, METH_O},
    {"setMaximumHeight", (PyCFunction)SbkQGraphicsLayoutItemFunc_setMaximumHeight, METH_O},
    {"setMaximumSize", (PyCFunction)SbkQGraphicsLayoutItemFunc_setMaximumSize, METH_VARARGS},
    {"setMaximumWidth", (PyCFunction)SbkQGraphicsLayoutItemFunc_setMaximumWidth, METH_O},
    {"setMinimumHeight", (PyCFunction)SbkQGraphicsLayoutItemFunc_setMinimumHeight, METH_O},
    {"setMinimumSize", (PyCFunction)SbkQGraphicsLayoutItemFunc_setMinimumSize, METH_VARARGS},
    {"setMinimumWidth", (PyCFunction)SbkQGraphicsLayoutItemFunc_setMinimumWidth, METH_O},
    {"setOwnedByLayout", (PyCFunction)SbkQGraphicsLayoutItemFunc_setOwnedByLayout, METH_O},
    {"setParentLayoutItem", (PyCFunction)SbkQGraphicsLayoutItemFunc_setParentLayoutItem, METH_O},
    {"setPreferredHeight", (PyCFunction)SbkQGraphicsLayoutItemFunc_setPreferredHeight, METH_O},
    {"setPreferredSize", (PyCFunction)SbkQGraphicsLayoutItemFunc_setPreferredSize, METH_VARARGS},
    {"setPreferredWidth", (PyCFunction)SbkQGraphicsLayoutItemFunc_setPreferredWidth, METH_O},
    {"setSizePolicy", (PyCFunction)SbkQGraphicsLayoutItemFunc_setSizePolicy, METH_VARARGS|METH_KEYWORDS},
    {"sizeHint", (PyCFunction)SbkQGraphicsLayoutItemFunc_sizeHint, METH_VARARGS|METH_KEYWORDS},
    {"sizePolicy", (PyCFunction)SbkQGraphicsLayoutItemFunc_sizePolicy, METH_NOARGS},
    {"updateGeometry", (PyCFunction)SbkQGraphicsLayoutItemFunc_updateGeometry, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGraphicsLayoutItem_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsLayoutItem",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGraphicsLayoutItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGraphicsLayoutItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGraphicsLayoutItem >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGraphicsLayoutItem*",
    /*user_data*/           0
};
} //extern


void init_QGraphicsLayoutItem(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSLAYOUTITEM_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGraphicsLayoutItem_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQGraphicsLayoutItem_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGraphicsLayoutItem_Type));
    PyModule_AddObject(module, "QGraphicsLayoutItem",
        ((PyObject*)&SbkQGraphicsLayoutItem_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsLayoutItem >("QGraphicsLayoutItem*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsLayoutItem >(typeid(QGraphicsLayoutItem).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsLayoutItem >(typeid(QGraphicsLayoutItemWrapper).name());
    PySide::initQtMetaType<QGraphicsLayoutItem* >();
}

