/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qimage_wrapper.h"

// Extra includes
#include <QMatrix>
#include <QStringList>
#include <QVector>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qimage.h>
#include <qiodevice.h>
#include <qmatrix.h>
#include <qpaintengine.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qtransform.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QImageWrapper::QImageWrapper() : QImage() {
    // ... middle
}

QImageWrapper::QImageWrapper(const QSize & size, QImage::Format format) : QImage(size, format) {
    // ... middle
}

QImageWrapper::QImageWrapper(const QString & fileName, const char * format) : QImage(fileName, format) {
    // ... middle
}

QImageWrapper::QImageWrapper(int width, int height, QImage::Format format) : QImage(width, height, format) {
    // ... middle
}

int QImageWrapper::devType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        return this->QImage::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QImage.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

int QImageWrapper::metric(QPaintDevice::PaintDeviceMetric metric) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        return this->QImage::metric(metric);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toPython(metric)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QImage.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QPaintEngine * QImageWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        return this->QImage::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QImage.paintEngine", SbkType<QPaintEngine * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter<QPaintEngine * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QImage.paintEngine");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

QImageWrapper::~QImageWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQImage_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QImage >()))
        return -1;

    QImageWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QImage", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QImage()
    // 1: QImage(QImage)
    // 2: QImage(QSize,QImage::Format)
    // 3: QImage(QString,const char*)
    // 4: QImage(int,int,QImage::Format)
    if (numArgs == 0) {
        overloadId = 0; // QImage()
    } else if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QImage::Format >::isConvertible(pyargs[2])) {
        overloadId = 4; // QImage(int,int,QImage::Format)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QImage(QString,const char*)
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            overloadId = 3; // QImage(QString,const char*)
        }
    } else if (numArgs == 2 && Shiboken::Converter<const QSize & >::isConvertible(pyargs[0]) && Shiboken::Converter<QImage::Format >::isConvertible(pyargs[1])) {
        overloadId = 2; // QImage(QSize,QImage::Format)
    } else if (numArgs == 1 && Shiboken::Converter<const QImage & >::isConvertible(pyargs[0])) {
        overloadId = 1; // QImage(QImage)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImage_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QImage()
            {

                if(!PyErr_Occurred()) {
                // QImage()
                cptr = new QImageWrapper();
                }
                break;
            }
            case 1: // QImage(QImage)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QImage* cpp_arg0 = Shiboken::Converter<QImage* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QImage(QImage)
                cptr = new QImageWrapper(*reinterpret_cast<QImageWrapper*>(cpp_arg0));
                }
                break;
            }
            case 2: // QImage(QSize,QImage::Format)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);
                QImage::Format cpp_arg1 = Shiboken::Converter<QImage::Format >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QImage(QSize,QImage::Format)
                cptr = new QImageWrapper(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 3: // QImage(QString,const char*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QImage(QString,const char*)
                cptr = new QImageWrapper(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 4: // QImage(int,int,QImage::Format)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QImage::Format cpp_arg2 = Shiboken::Converter<QImage::Format >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // QImage(int,int,QImage::Format)
                cptr = new QImageWrapper(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QImage >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQImage_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQImage_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QImage", "PySide.QtCore.QSize, PySide.QtGui.QImage.Format", "QString, str = None", "int, int, PySide.QtGui.QImage.Format", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage", overloads);
        return -1;
}

static PyObject* SbkQImageFunc_allGray(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // allGray()const
            bool cppResult = cppSelf->QImage::allGray();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_alphaChannel(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // alphaChannel()const
            QImage cppResult = cppSelf->QImage::alphaChannel();
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_bitPlaneCount(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bitPlaneCount()const
            int cppResult = cppSelf->QImage::bitPlaneCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_byteCount(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // byteCount()const
            int cppResult = cppSelf->QImage::byteCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_bytesPerLine(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bytesPerLine()const
            int cppResult = cppSelf->QImage::bytesPerLine();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_cacheKey(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cacheKey()const
            qint64 cppResult = cppSelf->QImage::cacheKey();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_color(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: color(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // color(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_color_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // color(int)const
            unsigned int cppResult = cppSelf->QImage::color(cpp_arg0);
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_color_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.color", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_colorCount(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // colorCount()const
            int cppResult = cppSelf->QImage::colorCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_colorTable(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // colorTable()const
            QVector<unsigned int > cppResult = cppSelf->QImage::colorTable();
            pyResult = Shiboken::Converter<QVector<unsigned int > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_constBits(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // constBits()const
            const uchar * cppResult = cppSelf->QImage::constBits();
            pyResult = Shiboken::Converter<const uchar * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_constScanLine(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: constScanLine(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // constScanLine(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_constScanLine_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // constScanLine(int)const
            const uchar * cppResult = cppSelf->QImage::constScanLine(cpp_arg0);
            pyResult = Shiboken::Converter<const uchar * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_constScanLine_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.constScanLine", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_convertToFormat(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.convertToFormat(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.convertToFormat(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.convertToFormat(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:convertToFormat", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: convertToFormat(QImage::Format,QFlags<Qt::ImageConversionFlag>)const
    // 1: convertToFormat(QImage::Format,QVector<uint>,QFlags<Qt::ImageConversionFlag>)const
    if (Shiboken::Converter<QImage::Format >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // convertToFormat(QImage::Format,QFlags<Qt::ImageConversionFlag>)const
        } else if (Shiboken::Converter< QVector<unsigned int >  >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // convertToFormat(QImage::Format,QVector<uint>,QFlags<Qt::ImageConversionFlag>)const
            } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[2])) {
                overloadId = 1; // convertToFormat(QImage::Format,QVector<uint>,QFlags<Qt::ImageConversionFlag>)const
            }
        } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // convertToFormat(QImage::Format,QFlags<Qt::ImageConversionFlag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_convertToFormat_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // convertToFormat(QImage::Format,QFlags<Qt::ImageConversionFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "flags";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.convertToFormat(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QImage::Format cpp_arg0 = Shiboken::Converter<QImage::Format >::toCpp(pyargs[0]);
                QFlags<Qt::ImageConversionFlag> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[1]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                // convertToFormat(QImage::Format,QFlags<Qt::ImageConversionFlag>)const
                QImage cppResult = cppSelf->QImage::convertToFormat(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
                }
                break;
            }
            case 1: // convertToFormat(QImage::Format,QVector<uint>,QFlags<Qt::ImageConversionFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "flags";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.convertToFormat(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QImage::Format cpp_arg0 = Shiboken::Converter<QImage::Format >::toCpp(pyargs[0]);
                QVector<unsigned int > cpp_arg1 = Shiboken::Converter<QVector<unsigned int > >::toCpp(pyargs[1]);
                QFlags<Qt::ImageConversionFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[2]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                // convertToFormat(QImage::Format,QVector<uint>,QFlags<Qt::ImageConversionFlag>)const
                QImage cppResult = cppSelf->QImage::convertToFormat(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_convertToFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage.Format, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", "PySide.QtGui.QImage.Format, list, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.convertToFormat", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_copy(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "rect" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.copy(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.copy(): too many arguments");
        return 0;
    } else if (numArgs == 2 || numArgs == 3)
        goto SbkQImageFunc_copy_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:copy", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: copy(QRect)const
    // 1: copy(int,int,int,int)const
    if (numArgs == 0) {
        overloadId = 0; // copy(QRect)const
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // copy(int,int,int,int)const
    } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 0; // copy(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_copy_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // copy(QRect)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "rect");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "rect";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.copy(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect cpp_arg0_tmp = QRect();
                QRect* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QRect* >::toCpp(pyargs[0]) : &cpp_arg0_tmp;

                if(!PyErr_Occurred()) {
                // copy(QRect)const
                QImage cppResult = cppSelf->QImage::copy(*cpp_arg0);
                pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
                }
                break;
            }
            case 1: // copy(int,int,int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // copy(int,int,int,int)const
                QImage cppResult = cppSelf->QImage::copy(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_copy_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect = QRect()", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.copy", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_createAlphaMask(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.createAlphaMask(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.createAlphaMask(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:createAlphaMask", &arg))
        return 0;


    // Overloaded function decisor
    // 0: createAlphaMask(QFlags<Qt::ImageConversionFlag>)const
    if (numArgs == 0) {
        overloadId = 0; // createAlphaMask(QFlags<Qt::ImageConversionFlag>)const
    } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(arg)) {
        overloadId = 0; // createAlphaMask(QFlags<Qt::ImageConversionFlag>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_createAlphaMask_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (arg)
                        errorArgName = "flags";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.createAlphaMask(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFlags<Qt::ImageConversionFlag> cpp_arg0 = arg ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(arg) : Qt::AutoColor;

            if(!PyErr_Occurred()) {
            // createAlphaMask(QFlags<Qt::ImageConversionFlag>)const
            QImage cppResult = cppSelf->QImage::createAlphaMask(cpp_arg0);
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_createAlphaMask_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.createAlphaMask", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_createHeuristicMask(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "clipTight" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.createHeuristicMask(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.createHeuristicMask(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:createHeuristicMask", &arg))
        return 0;


    // Overloaded function decisor
    // 0: createHeuristicMask(bool)const
    if (numArgs == 0) {
        overloadId = 0; // createHeuristicMask(bool)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // createHeuristicMask(bool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_createHeuristicMask_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "clipTight");
                if (value) {
                    if (arg)
                        errorArgName = "clipTight";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.createHeuristicMask(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cpp_arg0 = arg ? Shiboken::Converter<bool >::toCpp(arg) : true;

            if(!PyErr_Occurred()) {
            // createHeuristicMask(bool)const
            QImage cppResult = cppSelf->QImage::createHeuristicMask(cpp_arg0);
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_createHeuristicMask_TypeError:
        const char* overloads[] = {"bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.createHeuristicMask", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_createMaskFromColor(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.createMaskFromColor(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.createMaskFromColor(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.createMaskFromColor(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createMaskFromColor", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createMaskFromColor(uint,Qt::MaskMode)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createMaskFromColor(uint,Qt::MaskMode)const
        } else if (Shiboken::Converter<Qt::MaskMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // createMaskFromColor(uint,Qt::MaskMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_createMaskFromColor_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.createMaskFromColor(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            unsigned int cpp_arg0 = Shiboken::Converter<unsigned int >::toCpp(pyargs[0]);
            Qt::MaskMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::MaskMode >::toCpp(pyargs[1]) : Qt::MaskInColor;

            if(!PyErr_Occurred()) {
            // createMaskFromColor(uint,Qt::MaskMode)const
            QImage cppResult = cppSelf->QImage::createMaskFromColor(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_createMaskFromColor_TypeError:
        const char* overloads[] = {"unsigned int, PySide.QtCore.Qt.MaskMode = Qt.MaskInColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.createMaskFromColor", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_depth(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // depth()const
            int cppResult = cppSelf->QImage::depth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_devType(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // devType()const
            int cppResult = cppSelf->QImage::devType();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_dotsPerMeterX(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dotsPerMeterX()const
            int cppResult = cppSelf->QImage::dotsPerMeterX();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_dotsPerMeterY(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dotsPerMeterY()const
            int cppResult = cppSelf->QImage::dotsPerMeterY();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_fill(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: fill(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // fill(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_fill_TypeError;

    // Call function/method
    {
        {
            uint cpp_arg0 = Shiboken::Converter<uint >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // fill(uint)
            cppSelf->QImage::fill(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageFunc_fill_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.fill", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_format(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // format()const
            QImage::Format cppResult = cppSelf->QImage::format();
            pyResult = Shiboken::Converter<QImage::Format >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_fromData(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.fromData(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.fromData(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.fromData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromData", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromData(QByteArray,const char*)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromData(QByteArray,const char*)
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            overloadId = 0; // fromData(QByteArray,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_fromData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.fromData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
            const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // fromData(QByteArray,const char*)
            QImage cppResult = QImage::fromData(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_fromData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, str = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.fromData", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_hasAlphaChannel(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasAlphaChannel()const
            bool cppResult = cppSelf->QImage::hasAlphaChannel();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_height(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // height()const
            int cppResult = cppSelf->QImage::height();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_invertPixels(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.invertPixels(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.invertPixels(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:invertPixels", &arg))
        return 0;


    // Overloaded function decisor
    // 0: invertPixels(QImage::InvertMode)
    if (numArgs == 0) {
        overloadId = 0; // invertPixels(QImage::InvertMode)
    } else if (Shiboken::Converter<QImage::InvertMode >::isConvertible(arg)) {
        overloadId = 0; // invertPixels(QImage::InvertMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_invertPixels_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (arg)
                        errorArgName = "mode";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.invertPixels(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QImage::InvertMode cpp_arg0 = arg ? Shiboken::Converter<QImage::InvertMode >::toCpp(arg) : QImage::InvertRgb;

            if(!PyErr_Occurred()) {
            // invertPixels(QImage::InvertMode)
            cppSelf->QImage::invertPixels(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageFunc_invertPixels_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage.InvertMode = InvertRgb", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.invertPixels", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_isGrayscale(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isGrayscale()const
            bool cppResult = cppSelf->QImage::isGrayscale();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_isNull(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QImage::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_load(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.load(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.load(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.load(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:load", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: load(QIODevice*,const char*)
    // 1: load(QString,const char*)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // load(QString,const char*)
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            overloadId = 1; // load(QString,const char*)
        }
    } else if (numArgs == 2 && Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
        overloadId = 0; // load(QIODevice*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_load_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // load(QIODevice*,const char*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // load(QIODevice*,const char*)
                bool cppResult = cppSelf->QImage::load(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // load(QString,const char*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.load(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // load(QString,const char*)
                bool cppResult = cppSelf->QImage::load(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_load_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, str", "QString, str = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.load", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_loadFromData(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "aformat" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.loadFromData(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.loadFromData(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.loadFromData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:loadFromData", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: loadFromData(QByteArray,const char*)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // loadFromData(QByteArray,const char*)
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            overloadId = 0; // loadFromData(QByteArray,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_loadFromData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "aformat");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "aformat";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.loadFromData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
            const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // loadFromData(QByteArray,const char*)
            bool cppResult = cppSelf->QImage::loadFromData(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_loadFromData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, str = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.loadFromData", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_metric(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: metric(QPaintDevice::PaintDeviceMetric)const
    if (Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::isConvertible(arg)) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_metric_TypeError;

    // Call function/method
    {
        {
            QPaintDevice::PaintDeviceMetric cpp_arg0 = Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // metric(QPaintDevice::PaintDeviceMetric)const
            int cppResult = cppSelf->QImage::metric(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_metric_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice.PaintDeviceMetric", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.metric", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_mirrored(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "horizontally", "vertically" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.mirrored(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.mirrored(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:mirrored", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: mirrored(bool,bool)const
    if (numArgs == 0) {
        overloadId = 0; // mirrored(bool,bool)const
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // mirrored(bool,bool)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // mirrored(bool,bool)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_mirrored_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "horizontally");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "horizontally";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "vertically");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "vertically";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.mirrored(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cpp_arg0 = pyargs[0] ? Shiboken::Converter<bool >::toCpp(pyargs[0]) : false;
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // mirrored(bool,bool)const
            QImage cppResult = cppSelf->QImage::mirrored(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_mirrored_TypeError:
        const char* overloads[] = {"bool = false, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.mirrored", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_numBytes(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // numBytes()const
            int cppResult = cppSelf->QImage::numBytes();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_numColors(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // numColors()const
            int cppResult = cppSelf->QImage::numColors();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_offset(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // offset()const
            QPoint cppResult = cppSelf->QImage::offset();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_paintEngine(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // paintEngine()const
            QPaintEngine * cppResult = cppSelf->QImage::paintEngine();
            pyResult = Shiboken::Converter<QPaintEngine * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_pixel(PyObject* self, PyObject* args)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "pixel", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: pixel(QPoint)const
    // 1: pixel(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // pixel(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // pixel(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_pixel_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // pixel(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // pixel(QPoint)const
                unsigned int cppResult = cppSelf->QImage::pixel(*cpp_arg0);
                pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 1: // pixel(int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // pixel(int,int)const
                unsigned int cppResult = cppSelf->QImage::pixel(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_pixel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.pixel", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_pixelIndex(PyObject* self, PyObject* args)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "pixelIndex", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: pixelIndex(QPoint)const
    // 1: pixelIndex(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // pixelIndex(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // pixelIndex(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_pixelIndex_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // pixelIndex(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // pixelIndex(QPoint)const
                int cppResult = cppSelf->QImage::pixelIndex(*cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // pixelIndex(int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // pixelIndex(int,int)const
                int cppResult = cppSelf->QImage::pixelIndex(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_pixelIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.pixelIndex", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_rect(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rect()const
            QRect cppResult = cppSelf->QImage::rect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_rgbSwapped(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rgbSwapped()const
            QImage cppResult = cppSelf->QImage::rgbSwapped();
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_save(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format", "quality" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.save(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.save(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.save(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:save", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: save(QIODevice*,const char*,int)const
    // 1: save(QString,const char*,int)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // save(QString,const char*,int)const
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // save(QString,const char*,int)const
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 1; // save(QString,const char*,int)const
            }
        }
    } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // save(QIODevice*,const char*,int)const
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // save(QIODevice*,const char*,int)const
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // save(QIODevice*,const char*,int)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_save_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // save(QIODevice*,const char*,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "quality");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "quality";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.save(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;

                if(!PyErr_Occurred()) {
                // save(QIODevice*,const char*,int)const
                bool cppResult = cppSelf->QImage::save(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // save(QString,const char*,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "quality");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "quality";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.save(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;

                if(!PyErr_Occurred()) {
                // save(QString,const char*,int)const
                bool cppResult = cppSelf->QImage::save(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_save_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, str = None, int = -1", "QString, str = None, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.save", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_scaled(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "aspectMode", "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.scaled(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.scaled(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.scaled(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:scaled", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
    // 1: scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
        } else if (Shiboken::Converter<Qt::AspectRatioMode >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
            } else if (Shiboken::Converter<Qt::TransformationMode >::isConvertible(pyargs[3])) {
                overloadId = 1; // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
            }
        }
    } else if (Shiboken::Converter<const QSize & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
        } else if (Shiboken::Converter<Qt::AspectRatioMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
            } else if (Shiboken::Converter<Qt::TransformationMode >::isConvertible(pyargs[2])) {
                overloadId = 0; // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_scaled_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aspectMode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "aspectMode";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "mode";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.scaled(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);
                Qt::AspectRatioMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[1]) : Qt::IgnoreAspectRatio;
                Qt::TransformationMode cpp_arg2 = pyargs[2] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[2]) : Qt::FastTransformation;

                if(!PyErr_Occurred()) {
                // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
                QImage cppResult = cppSelf->QImage::scaled(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
                }
                break;
            }
            case 1: // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aspectMode");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "aspectMode";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "mode";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.scaled(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                Qt::AspectRatioMode cpp_arg2 = pyargs[2] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[2]) : Qt::IgnoreAspectRatio;
                Qt::TransformationMode cpp_arg3 = pyargs[3] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[3]) : Qt::FastTransformation;

                if(!PyErr_Occurred()) {
                // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
                QImage cppResult = cppSelf->QImage::scaled(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_scaled_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtCore.Qt.AspectRatioMode = Qt.IgnoreAspectRatio, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", "int, int, PySide.QtCore.Qt.AspectRatioMode = Qt.IgnoreAspectRatio, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.scaled", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_scaledToHeight(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.scaledToHeight(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.scaledToHeight(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.scaledToHeight(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:scaledToHeight", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scaledToHeight(int,Qt::TransformationMode)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // scaledToHeight(int,Qt::TransformationMode)const
        } else if (Shiboken::Converter<Qt::TransformationMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // scaledToHeight(int,Qt::TransformationMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_scaledToHeight_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.scaledToHeight(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::TransformationMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[1]) : Qt::FastTransformation;

            if(!PyErr_Occurred()) {
            // scaledToHeight(int,Qt::TransformationMode)const
            QImage cppResult = cppSelf->QImage::scaledToHeight(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_scaledToHeight_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.scaledToHeight", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_scaledToWidth(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.scaledToWidth(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.scaledToWidth(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.scaledToWidth(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:scaledToWidth", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scaledToWidth(int,Qt::TransformationMode)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // scaledToWidth(int,Qt::TransformationMode)const
        } else if (Shiboken::Converter<Qt::TransformationMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // scaledToWidth(int,Qt::TransformationMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_scaledToWidth_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.scaledToWidth(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::TransformationMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[1]) : Qt::FastTransformation;

            if(!PyErr_Occurred()) {
            // scaledToWidth(int,Qt::TransformationMode)const
            QImage cppResult = cppSelf->QImage::scaledToWidth(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_scaledToWidth_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.scaledToWidth", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_setAlphaChannel(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlphaChannel(QImage)
    if (Shiboken::Converter<const QImage & >::isConvertible(arg)) {
        overloadId = 0; // setAlphaChannel(QImage)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_setAlphaChannel_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QImage* cpp_arg0 = Shiboken::Converter<QImage* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAlphaChannel(QImage)
            cppSelf->QImage::setAlphaChannel(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageFunc_setAlphaChannel_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.setAlphaChannel", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_setColor(PyObject* self, PyObject* args)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setColor", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setColor(int,uint)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setColor(int,uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_setColor_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            unsigned int cpp_arg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setColor(int,uint)
            cppSelf->QImage::setColor(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageFunc_setColor_TypeError:
        const char* overloads[] = {"int, unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.setColor", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_setColorCount(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColorCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setColorCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_setColorCount_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setColorCount(int)
            cppSelf->QImage::setColorCount(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageFunc_setColorCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.setColorCount", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_setDotsPerMeterX(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDotsPerMeterX(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDotsPerMeterX(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_setDotsPerMeterX_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDotsPerMeterX(int)
            cppSelf->QImage::setDotsPerMeterX(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageFunc_setDotsPerMeterX_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.setDotsPerMeterX", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_setDotsPerMeterY(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDotsPerMeterY(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDotsPerMeterY(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_setDotsPerMeterY_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDotsPerMeterY(int)
            cppSelf->QImage::setDotsPerMeterY(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageFunc_setDotsPerMeterY_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.setDotsPerMeterY", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_setNumColors(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNumColors(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setNumColors(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_setNumColors_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNumColors(int)
            cppSelf->QImage::setNumColors(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageFunc_setNumColors_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.setNumColors", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_setOffset(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOffset(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // setOffset(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_setOffset_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOffset(QPoint)
            cppSelf->QImage::setOffset(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageFunc_setOffset_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.setOffset", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_setPixel(PyObject* self, PyObject* args)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPixel", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setPixel(QPoint,uint)
    // 1: setPixel(int,int,uint)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // setPixel(int,int,uint)
    } else if (numArgs == 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setPixel(QPoint,uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_setPixel_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setPixel(QPoint,uint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                uint cpp_arg1 = Shiboken::Converter<uint >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setPixel(QPoint,uint)
                cppSelf->QImage::setPixel(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // setPixel(int,int,uint)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                uint cpp_arg2 = Shiboken::Converter<uint >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setPixel(int,int,uint)
                cppSelf->QImage::setPixel(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageFunc_setPixel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, unsigned int", "int, int, unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.setPixel", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_setText(PyObject* self, PyObject* args)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setText", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setText(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setText(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_setText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setText(QString,QString)
            cppSelf->QImage::setText(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageFunc_setText_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.setText", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_size(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            QSize cppResult = cppSelf->QImage::size();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_text(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "key" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.text(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.text(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:text", &arg))
        return 0;


    // Overloaded function decisor
    // 0: text(QString)const
    if (numArgs == 0) {
        overloadId = 0; // text(QString)const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // text(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_text_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "key");
                if (value) {
                    if (arg)
                        errorArgName = "key";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.text(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = arg ? Shiboken::Converter<QString >::toCpp(arg) : QString();

            if(!PyErr_Occurred()) {
            // text(QString)const
            QString cppResult = cppSelf->QImage::text(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_text_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.text", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_textKeys(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textKeys()const
            QStringList cppResult = cppSelf->QImage::textKeys();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageFunc_transformed(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.transformed(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.transformed(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.transformed(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:transformed", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: transformed(QMatrix,Qt::TransformationMode)const
    // 1: transformed(QTransform,Qt::TransformationMode)const
    if (Shiboken::Converter<const QTransform & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // transformed(QTransform,Qt::TransformationMode)const
        } else if (Shiboken::Converter<Qt::TransformationMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // transformed(QTransform,Qt::TransformationMode)const
        }
    } else if (Shiboken::Converter<const QMatrix & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // transformed(QMatrix,Qt::TransformationMode)const
        } else if (Shiboken::Converter<Qt::TransformationMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // transformed(QMatrix,Qt::TransformationMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_transformed_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // transformed(QMatrix,Qt::TransformationMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.transformed(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(pyargs[0]);
                Qt::TransformationMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[1]) : Qt::FastTransformation;

                if(!PyErr_Occurred()) {
                // transformed(QMatrix,Qt::TransformationMode)const
                QImage cppResult = cppSelf->QImage::transformed(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
                }
                break;
            }
            case 1: // transformed(QTransform,Qt::TransformationMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.transformed(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(pyargs[0]);
                Qt::TransformationMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[1]) : Qt::FastTransformation;

                if(!PyErr_Occurred()) {
                // transformed(QTransform,Qt::TransformationMode)const
                QImage cppResult = cppSelf->QImage::transformed(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_transformed_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", "PySide.QtGui.QTransform, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.transformed", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_trueMatrix(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "trueMatrix", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: trueMatrix(QMatrix,int,int)
    // 1: trueMatrix(QTransform,int,int)
    if (numArgs == 3 && Shiboken::Converter<const QTransform & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // trueMatrix(QTransform,int,int)
    } else if (numArgs == 3 && Shiboken::Converter<const QMatrix & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // trueMatrix(QMatrix,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_trueMatrix_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // trueMatrix(QMatrix,int,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // trueMatrix(QMatrix,int,int)
                QMatrix cppResult = QImage::trueMatrix(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QMatrix >::toPython(cppResult);
                }
                break;
            }
            case 1: // trueMatrix(QTransform,int,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // trueMatrix(QTransform,int,int)
                QTransform cppResult = QImage::trueMatrix(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_trueMatrix_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix, int, int", "PySide.QtGui.QTransform, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.trueMatrix", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_valid(PyObject* self, PyObject* args)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "valid", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: valid(QPoint)const
    // 1: valid(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // valid(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // valid(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc_valid_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // valid(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // valid(QPoint)const
                bool cppResult = cppSelf->QImage::valid(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // valid(int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // valid(int,int)const
                bool cppResult = cppSelf->QImage::valid(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc_valid_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.valid", overloads);
        return 0;
}

static PyObject* SbkQImageFunc_width(PyObject* self)
{
    QImage* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width()const
            int cppResult = cppSelf->QImage::width();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQImage_methods[] = {
    {"allGray", (PyCFunction)SbkQImageFunc_allGray, METH_NOARGS},
    {"alphaChannel", (PyCFunction)SbkQImageFunc_alphaChannel, METH_NOARGS},
    {"bitPlaneCount", (PyCFunction)SbkQImageFunc_bitPlaneCount, METH_NOARGS},
    {"byteCount", (PyCFunction)SbkQImageFunc_byteCount, METH_NOARGS},
    {"bytesPerLine", (PyCFunction)SbkQImageFunc_bytesPerLine, METH_NOARGS},
    {"cacheKey", (PyCFunction)SbkQImageFunc_cacheKey, METH_NOARGS},
    {"color", (PyCFunction)SbkQImageFunc_color, METH_O},
    {"colorCount", (PyCFunction)SbkQImageFunc_colorCount, METH_NOARGS},
    {"colorTable", (PyCFunction)SbkQImageFunc_colorTable, METH_NOARGS},
    {"constBits", (PyCFunction)SbkQImageFunc_constBits, METH_NOARGS},
    {"constScanLine", (PyCFunction)SbkQImageFunc_constScanLine, METH_O},
    {"convertToFormat", (PyCFunction)SbkQImageFunc_convertToFormat, METH_VARARGS|METH_KEYWORDS},
    {"copy", (PyCFunction)SbkQImageFunc_copy, METH_VARARGS|METH_KEYWORDS},
    {"createAlphaMask", (PyCFunction)SbkQImageFunc_createAlphaMask, METH_VARARGS|METH_KEYWORDS},
    {"createHeuristicMask", (PyCFunction)SbkQImageFunc_createHeuristicMask, METH_VARARGS|METH_KEYWORDS},
    {"createMaskFromColor", (PyCFunction)SbkQImageFunc_createMaskFromColor, METH_VARARGS|METH_KEYWORDS},
    {"depth", (PyCFunction)SbkQImageFunc_depth, METH_NOARGS},
    {"devType", (PyCFunction)SbkQImageFunc_devType, METH_NOARGS},
    {"dotsPerMeterX", (PyCFunction)SbkQImageFunc_dotsPerMeterX, METH_NOARGS},
    {"dotsPerMeterY", (PyCFunction)SbkQImageFunc_dotsPerMeterY, METH_NOARGS},
    {"fill", (PyCFunction)SbkQImageFunc_fill, METH_O},
    {"format", (PyCFunction)SbkQImageFunc_format, METH_NOARGS},
    {"fromData", (PyCFunction)SbkQImageFunc_fromData, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"hasAlphaChannel", (PyCFunction)SbkQImageFunc_hasAlphaChannel, METH_NOARGS},
    {"height", (PyCFunction)SbkQImageFunc_height, METH_NOARGS},
    {"invertPixels", (PyCFunction)SbkQImageFunc_invertPixels, METH_VARARGS|METH_KEYWORDS},
    {"isGrayscale", (PyCFunction)SbkQImageFunc_isGrayscale, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQImageFunc_isNull, METH_NOARGS},
    {"load", (PyCFunction)SbkQImageFunc_load, METH_VARARGS|METH_KEYWORDS},
    {"loadFromData", (PyCFunction)SbkQImageFunc_loadFromData, METH_VARARGS|METH_KEYWORDS},
    {"metric", (PyCFunction)SbkQImageFunc_metric, METH_O},
    {"mirrored", (PyCFunction)SbkQImageFunc_mirrored, METH_VARARGS|METH_KEYWORDS},
    {"numBytes", (PyCFunction)SbkQImageFunc_numBytes, METH_NOARGS},
    {"numColors", (PyCFunction)SbkQImageFunc_numColors, METH_NOARGS},
    {"offset", (PyCFunction)SbkQImageFunc_offset, METH_NOARGS},
    {"paintEngine", (PyCFunction)SbkQImageFunc_paintEngine, METH_NOARGS},
    {"pixel", (PyCFunction)SbkQImageFunc_pixel, METH_VARARGS},
    {"pixelIndex", (PyCFunction)SbkQImageFunc_pixelIndex, METH_VARARGS},
    {"rect", (PyCFunction)SbkQImageFunc_rect, METH_NOARGS},
    {"rgbSwapped", (PyCFunction)SbkQImageFunc_rgbSwapped, METH_NOARGS},
    {"save", (PyCFunction)SbkQImageFunc_save, METH_VARARGS|METH_KEYWORDS},
    {"scaled", (PyCFunction)SbkQImageFunc_scaled, METH_VARARGS|METH_KEYWORDS},
    {"scaledToHeight", (PyCFunction)SbkQImageFunc_scaledToHeight, METH_VARARGS|METH_KEYWORDS},
    {"scaledToWidth", (PyCFunction)SbkQImageFunc_scaledToWidth, METH_VARARGS|METH_KEYWORDS},
    {"setAlphaChannel", (PyCFunction)SbkQImageFunc_setAlphaChannel, METH_O},
    {"setColor", (PyCFunction)SbkQImageFunc_setColor, METH_VARARGS},
    {"setColorCount", (PyCFunction)SbkQImageFunc_setColorCount, METH_O},
    {"setDotsPerMeterX", (PyCFunction)SbkQImageFunc_setDotsPerMeterX, METH_O},
    {"setDotsPerMeterY", (PyCFunction)SbkQImageFunc_setDotsPerMeterY, METH_O},
    {"setNumColors", (PyCFunction)SbkQImageFunc_setNumColors, METH_O},
    {"setOffset", (PyCFunction)SbkQImageFunc_setOffset, METH_O},
    {"setPixel", (PyCFunction)SbkQImageFunc_setPixel, METH_VARARGS},
    {"setText", (PyCFunction)SbkQImageFunc_setText, METH_VARARGS},
    {"size", (PyCFunction)SbkQImageFunc_size, METH_NOARGS},
    {"text", (PyCFunction)SbkQImageFunc_text, METH_VARARGS|METH_KEYWORDS},
    {"textKeys", (PyCFunction)SbkQImageFunc_textKeys, METH_NOARGS},
    {"transformed", (PyCFunction)SbkQImageFunc_transformed, METH_VARARGS|METH_KEYWORDS},
    {"trueMatrix", (PyCFunction)SbkQImageFunc_trueMatrix, METH_VARARGS|METH_STATIC},
    {"valid", (PyCFunction)SbkQImageFunc_valid, METH_VARARGS},
    {"width", (PyCFunction)SbkQImageFunc_width, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQImageFunc___lshift__(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QImage >::checkType(arg) && !Shiboken::Converter<QImage >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QImage)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QImage)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QImage) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQImageFunc___rshift__(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QImage >::checkType(arg) && !Shiboken::Converter<QImage >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QImage&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QImage&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QImage&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQImage_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQImageFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQImageFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQImage_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QImage& cpp_self = *Shiboken::Converter<QImage* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QImage & >::isConvertible(other)) {
                // operator!=(const QImage & arg__1) const
                QImage* cpp_other = Shiboken::Converter<QImage* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QImage  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQImage_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QImage & >::isConvertible(other)) {
                // operator==(const QImage & arg__1) const
                QImage* cpp_other = Shiboken::Converter<QImage* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QImage  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQImage_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQImage_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

static void* SbkQImage_ObjCopierFunc(const void* ptr){
    return new QImageWrapper(*reinterpret_cast<const QImage*>(ptr));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQImage_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QImage",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQImage_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQImage_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQImage_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQImage_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          &SbkQImage_ObjCopierFunc,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QImage >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QImage",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQImage_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QImage*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &SbkQImage_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QImage_InvertMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QImage_InvertMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QImage_InvertMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "InvertMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QImage_InvertMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QImage_InvertMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QImage_InvertMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QImage_Format_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QImage_Format_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QImage_Format_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Format",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QImage_Format_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QImage_Format_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QImage_Format_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QImage(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QIMAGE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQImage_Type);

    SbkQImage_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX];
    // Fill type discovery information
    SbkQImage_Type.type_discovery = &SbkQImage_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]), &SbkQImage_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQImage_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQImage_Type));
    PyModule_AddObject(module, "QImage",
        ((PyObject*)&SbkQImage_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: InvertMode
    SbkPySide_QtGuiTypes[SBK_QIMAGE_INVERTMODE_IDX] = &SbkPySide_QtGui_QImage_InvertMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QImage_InvertMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QImage_InvertMode_Type);
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
            "InvertMode",((PyObject*)&SbkPySide_QtGui_QImage_InvertMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_InvertMode_Type,
        (long) QImage::InvertRgb, "InvertRgb");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "InvertRgb", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_InvertMode_Type.tp_dict,
        "InvertRgb", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_InvertMode_Type,
        (long) QImage::InvertRgba, "InvertRgba");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "InvertRgba", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_InvertMode_Type.tp_dict,
        "InvertRgba", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QImage::InvertMode");

    // init enum class: Format
    SbkPySide_QtGuiTypes[SBK_QIMAGE_FORMAT_IDX] = &SbkPySide_QtGui_QImage_Format_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QImage_Format_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QImage_Format_Type);
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
            "Format",((PyObject*)&SbkPySide_QtGui_QImage_Format_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_Invalid, "Format_Invalid");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_Invalid", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_Invalid", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_Mono, "Format_Mono");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_Mono", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_Mono", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_MonoLSB, "Format_MonoLSB");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_MonoLSB", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_MonoLSB", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_Indexed8, "Format_Indexed8");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_Indexed8", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_Indexed8", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_RGB32, "Format_RGB32");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_RGB32", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_RGB32", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_ARGB32, "Format_ARGB32");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_ARGB32", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_ARGB32", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_ARGB32_Premultiplied, "Format_ARGB32_Premultiplied");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_ARGB32_Premultiplied", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_ARGB32_Premultiplied", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_RGB16, "Format_RGB16");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_RGB16", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_RGB16", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_ARGB8565_Premultiplied, "Format_ARGB8565_Premultiplied");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_ARGB8565_Premultiplied", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_ARGB8565_Premultiplied", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_RGB666, "Format_RGB666");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_RGB666", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_RGB666", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_ARGB6666_Premultiplied, "Format_ARGB6666_Premultiplied");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_ARGB6666_Premultiplied", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_ARGB6666_Premultiplied", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_RGB555, "Format_RGB555");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_RGB555", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_RGB555", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_ARGB8555_Premultiplied, "Format_ARGB8555_Premultiplied");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_ARGB8555_Premultiplied", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_ARGB8555_Premultiplied", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_RGB888, "Format_RGB888");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_RGB888", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_RGB888", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_RGB444, "Format_RGB444");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_RGB444", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_RGB444", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImage_Format_Type,
        (long) QImage::Format_ARGB4444_Premultiplied, "Format_ARGB4444_Premultiplied");
    PyDict_SetItemString(SbkQImage_Type.super.ht_type.tp_dict,
        "Format_ARGB4444_Premultiplied", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format_Type.tp_dict,
        "Format_ARGB4444_Premultiplied", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QImage::Format");


    Shiboken::TypeResolver::createValueTypeResolver<QImage >("QImage");
    Shiboken::TypeResolver::createObjectTypeResolver<QImage >("QImage*");
    Shiboken::TypeResolver::createValueTypeResolver<QImage >(typeid(QImage).name());
    Shiboken::TypeResolver::createValueTypeResolver<QImage >(typeid(QImageWrapper).name());
    PySide::initQtMetaType<QImage >();
}

