/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtransform_wrapper.h"

// Extra includes
#include <qdatastream.h>
#include <qline.h>
#include <qmatrix.h>
#include <qpainterpath.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>
#include <qtransform.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTransform_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTransform >()))
        return -1;

    QTransform* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "h33" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTransform(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 9) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTransform(): too many arguments");
        return -1;
    } else if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 7)
        goto SbkQTransform_Init_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOOOOO:QTransform", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8])))
        return -1;

    // Overloaded function decisor
    // 0: QTransform(QTransform)
    // 1: QTransform()
    // 2: QTransform(QMatrix)
    // 3: QTransform(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
    // 4: QTransform(qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 1; // QTransform()
    } else if (numArgs >= 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        if (numArgs == 6) {
            overloadId = 4; // QTransform(qreal,qreal,qreal,qreal,qreal,qreal)
        } else if (numArgs >= 8 && SbkNumber_Check(pyargs[6]) && SbkNumber_Check(pyargs[7])) {
            if (numArgs == 8) {
                overloadId = 3; // QTransform(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
            } else if (SbkNumber_Check(pyargs[8])) {
                overloadId = 3; // QTransform(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QMatrix & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QTransform(QMatrix)
    } else if (numArgs == 1 && Shiboken::Converter<const QTransform & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QTransform(QTransform)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransform_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTransform(QTransform)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QTransform(QTransform)
                cptr = new QTransform(*cpp_arg0);
                }
                break;
            }
            case 1: // QTransform()
            {

                if(!PyErr_Occurred()) {
                // QTransform()
                cptr = new QTransform();
                }
                break;
            }
            case 2: // QTransform(QMatrix)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QTransform(QMatrix)
                cptr = new QTransform(*cpp_arg0);
                }
                break;
            }
            case 3: // QTransform(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "h33");
                    if (value) {
                        if (pyargs[8])
                            errorArgName = "h33";
                        else
                            pyargs[8] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTransform(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cpp_arg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);
                qreal cpp_arg6 = Shiboken::Converter<qreal >::toCpp(pyargs[6]);
                qreal cpp_arg7 = Shiboken::Converter<qreal >::toCpp(pyargs[7]);
                qreal cpp_arg8 = pyargs[8] ? Shiboken::Converter<qreal >::toCpp(pyargs[8]) : 1.0;

                if(!PyErr_Occurred()) {
                // QTransform(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
                cptr = new QTransform(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5, cpp_arg6, cpp_arg7, cpp_arg8);
                }
                break;
            }
            case 4: // QTransform(qreal,qreal,qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cpp_arg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                // QTransform(qreal,qreal,qreal,qreal,qreal,qreal)
                cptr = new QTransform(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTransform >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTransform_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTransform_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform", "", "PySide.QtGui.QMatrix", "float, float, float, float, float, float, float, float, float = 1.0", "float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform", overloads);
        return -1;
}

static PyObject* SbkQTransformFunc_adjoint(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // adjoint()const
            QTransform cppResult = cppSelf->QTransform::adjoint();
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_det(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // det()const
            qreal cppResult = cppSelf->QTransform::det();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_determinant(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // determinant()const
            qreal cppResult = cppSelf->QTransform::determinant();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_dx(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dx()const
            qreal cppResult = cppSelf->QTransform::dx();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_dy(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dy()const
            qreal cppResult = cppSelf->QTransform::dy();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_fromScale(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fromScale", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromScale(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // fromScale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_fromScale_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // fromScale(qreal,qreal)
            QTransform cppResult = QTransform::fromScale(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc_fromScale_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.fromScale", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_fromTranslate(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fromTranslate", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromTranslate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // fromTranslate(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_fromTranslate_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // fromTranslate(qreal,qreal)
            QTransform cppResult = QTransform::fromTranslate(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc_fromTranslate_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.fromTranslate", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_inverted(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // inverted(bool*)const
            // Begin code injection
            
            // TEMPLATE - fix_bool* - START
            bool ok_;
            QTransform retval_ = cppSelf->inverted(&ok_);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_bool* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_isAffine(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isAffine()const
            bool cppResult = cppSelf->QTransform::isAffine();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_isIdentity(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isIdentity()const
            bool cppResult = cppSelf->QTransform::isIdentity();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_isInvertible(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isInvertible()const
            bool cppResult = cppSelf->QTransform::isInvertible();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_isRotating(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isRotating()const
            bool cppResult = cppSelf->QTransform::isRotating();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_isScaling(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isScaling()const
            bool cppResult = cppSelf->QTransform::isScaling();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_isTranslating(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isTranslating()const
            bool cppResult = cppSelf->QTransform::isTranslating();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_m11(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // m11()const
            qreal cppResult = cppSelf->QTransform::m11();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_m12(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // m12()const
            qreal cppResult = cppSelf->QTransform::m12();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_m13(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // m13()const
            qreal cppResult = cppSelf->QTransform::m13();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_m21(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // m21()const
            qreal cppResult = cppSelf->QTransform::m21();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_m22(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // m22()const
            qreal cppResult = cppSelf->QTransform::m22();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_m23(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // m23()const
            qreal cppResult = cppSelf->QTransform::m23();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_m31(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // m31()const
            qreal cppResult = cppSelf->QTransform::m31();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_m32(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // m32()const
            qreal cppResult = cppSelf->QTransform::m32();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_m33(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // m33()const
            qreal cppResult = cppSelf->QTransform::m33();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_map(PyObject* self, PyObject* arg)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: map(QLine)const
    // 1: map(QLineF)const
    // 2: map(QPainterPath)const
    // 3: map(QPoint)const
    // 4: map(QPointF)const
    // 5: map(QPolygon)const
    // 6: map(QPolygonF)const
    // 7: map(QRegion)const
    if (Shiboken::Converter<const QPolygon & >::isConvertible(arg)) {
        overloadId = 5; // map(QPolygon)const
    } else if (Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 7; // map(QRegion)const
    } else if (Shiboken::Converter<const QPolygonF & >::isConvertible(arg)) {
        overloadId = 6; // map(QPolygonF)const
    } else if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 3; // map(QPoint)const
    } else if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 4; // map(QPointF)const
    } else if (Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 2; // map(QPainterPath)const
    } else if (Shiboken::Converter<const QLine & >::isConvertible(arg)) {
        overloadId = 0; // map(QLine)const
    } else if (Shiboken::Converter<const QLineF & >::isConvertible(arg)) {
        overloadId = 1; // map(QLineF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_map_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // map(QLine)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QLine* cpp_arg0 = Shiboken::Converter<QLine* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // map(QLine)const
                QLine cppResult = cppSelf->QTransform::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QLine >::toPython(cppResult);
                }
                break;
            }
            case 1: // map(QLineF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QLineF > cpp_arg0_auto_ptr;
                QLineF* cpp_arg0 = Shiboken::Converter<QLineF* >::toCpp(arg);
                if (!Shiboken::Converter<QLineF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QLineF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // map(QLineF)const
                QLineF cppResult = cppSelf->QTransform::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QLineF >::toPython(cppResult);
                }
                break;
            }
            case 2: // map(QPainterPath)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // map(QPainterPath)const
                QPainterPath cppResult = cppSelf->QTransform::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 3: // map(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // map(QPoint)const
                QPoint cppResult = cppSelf->QTransform::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
                }
                break;
            }
            case 4: // map(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
                if (!Shiboken::Converter<QPointF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // map(QPointF)const
                QPointF cppResult = cppSelf->QTransform::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 5: // map(QPolygon)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
                QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(arg);
                if (!Shiboken::Converter<QPolygon >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // map(QPolygon)const
                QPolygon cppResult = cppSelf->QTransform::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
                }
                break;
            }
            case 6: // map(QPolygonF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(arg);
                if (!Shiboken::Converter<QPolygonF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // map(QPolygonF)const
                QPolygonF cppResult = cppSelf->QTransform::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 7: // map(QRegion)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
                QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
                if (!Shiboken::Converter<QRegion >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // map(QRegion)const
                QRegion cppResult = cppSelf->QTransform::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc_map_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtGui.QPainterPath", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtGui.QPolygon", "PySide.QtGui.QPolygonF", "PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTransform.map", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_mapRect(PyObject* self, PyObject* arg)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapRect(QRect)const
    // 1: mapRect(QRectF)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // mapRect(QRect)const
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 1; // mapRect(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_mapRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapRect(QRect)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // mapRect(QRect)const
                QRect cppResult = cppSelf->QTransform::mapRect(*cpp_arg0);
                pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapRect(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
                if (!Shiboken::Converter<QRectF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapRect(QRectF)const
                QRectF cppResult = cppSelf->QTransform::mapRect(*cpp_arg0);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc_mapRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTransform.mapRect", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_mapToPolygon(PyObject* self, PyObject* arg)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapToPolygon(QRect)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // mapToPolygon(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_mapToPolygon_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mapToPolygon(QRect)const
            QPolygon cppResult = cppSelf->QTransform::mapToPolygon(*cpp_arg0);
            pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc_mapToPolygon_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTransform.mapToPolygon", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_quadToQuad(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "quadToQuad", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: quadToQuad(QPolygonF,QPolygonF,QTransform&)
    if (numArgs == 3 && Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[1]) && Shiboken::Converter<QTransform & >::isConvertible(pyargs[2])) {
        overloadId = 0; // quadToQuad(QPolygonF,QPolygonF,QTransform&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_quadToQuad_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
            QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QPolygonF > cpp_arg1_auto_ptr;
            QPolygonF* cpp_arg1 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg1);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QTransform* cpp_arg2 = Shiboken::Converter<QTransform* >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // quadToQuad(QPolygonF,QPolygonF,QTransform&)
            bool cppResult = QTransform::quadToQuad(*cpp_arg0, *cpp_arg1, *cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc_quadToQuad_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF, PySide.QtGui.QPolygonF, PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.quadToQuad", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_quadToSquare(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "quadToSquare", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: quadToSquare(QPolygonF,QTransform&)
    if (numArgs == 2 && Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[0]) && Shiboken::Converter<QTransform & >::isConvertible(pyargs[1])) {
        overloadId = 0; // quadToSquare(QPolygonF,QTransform&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_quadToSquare_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
            QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QTransform* cpp_arg1 = Shiboken::Converter<QTransform* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // quadToSquare(QPolygonF,QTransform&)
            bool cppResult = QTransform::quadToSquare(*cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc_quadToSquare_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF, PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.quadToSquare", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_reset(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reset()
            cppSelf->QTransform::reset();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTransformFunc_rotate(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "axis" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTransform.rotate(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTransform.rotate(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTransform.rotate(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:rotate", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: rotate(qreal,Qt::Axis)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // rotate(qreal,Qt::Axis)
        } else if (Shiboken::Converter<Qt::Axis >::isConvertible(pyargs[1])) {
            overloadId = 0; // rotate(qreal,Qt::Axis)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_rotate_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "axis");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "axis";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTransform.rotate(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            Qt::Axis cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::Axis >::toCpp(pyargs[1]) : Qt::ZAxis;

            if(!PyErr_Occurred()) {
            // rotate(qreal,Qt::Axis)
            QTransform & cppResult = cppSelf->QTransform::rotate(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QTransform & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc_rotate_TypeError:
        const char* overloads[] = {"float, PySide.QtCore.Qt.Axis = Qt.ZAxis", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.rotate", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_rotateRadians(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "axis" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTransform.rotateRadians(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTransform.rotateRadians(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTransform.rotateRadians(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:rotateRadians", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: rotateRadians(qreal,Qt::Axis)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // rotateRadians(qreal,Qt::Axis)
        } else if (Shiboken::Converter<Qt::Axis >::isConvertible(pyargs[1])) {
            overloadId = 0; // rotateRadians(qreal,Qt::Axis)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_rotateRadians_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "axis");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "axis";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTransform.rotateRadians(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            Qt::Axis cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::Axis >::toCpp(pyargs[1]) : Qt::ZAxis;

            if(!PyErr_Occurred()) {
            // rotateRadians(qreal,Qt::Axis)
            QTransform & cppResult = cppSelf->QTransform::rotateRadians(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QTransform & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc_rotateRadians_TypeError:
        const char* overloads[] = {"float, PySide.QtCore.Qt.Axis = Qt.ZAxis", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.rotateRadians", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_scale(PyObject* self, PyObject* args)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scale", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scale(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_scale_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // scale(qreal,qreal)
            QTransform & cppResult = cppSelf->QTransform::scale(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QTransform & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc_scale_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.scale", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_setMatrix(PyObject* self, PyObject* args)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setMatrix", 9, 9, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8])))
        return 0;


    // Overloaded function decisor
    // 0: setMatrix(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 9 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5]) && SbkNumber_Check(pyargs[6]) && SbkNumber_Check(pyargs[7]) && SbkNumber_Check(pyargs[8])) {
        overloadId = 0; // setMatrix(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_setMatrix_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
            qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
            qreal cpp_arg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);
            qreal cpp_arg6 = Shiboken::Converter<qreal >::toCpp(pyargs[6]);
            qreal cpp_arg7 = Shiboken::Converter<qreal >::toCpp(pyargs[7]);
            qreal cpp_arg8 = Shiboken::Converter<qreal >::toCpp(pyargs[8]);

            if(!PyErr_Occurred()) {
            // setMatrix(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
            cppSelf->QTransform::setMatrix(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5, cpp_arg6, cpp_arg7, cpp_arg8);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTransformFunc_setMatrix_TypeError:
        const char* overloads[] = {"float, float, float, float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.setMatrix", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_shear(PyObject* self, PyObject* args)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "shear", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: shear(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // shear(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_shear_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // shear(qreal,qreal)
            QTransform & cppResult = cppSelf->QTransform::shear(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QTransform & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc_shear_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.shear", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_squareToQuad(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "squareToQuad", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: squareToQuad(QPolygonF,QTransform&)
    if (numArgs == 2 && Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[0]) && Shiboken::Converter<QTransform & >::isConvertible(pyargs[1])) {
        overloadId = 0; // squareToQuad(QPolygonF,QTransform&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_squareToQuad_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
            QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QTransform* cpp_arg1 = Shiboken::Converter<QTransform* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // squareToQuad(QPolygonF,QTransform&)
            bool cppResult = QTransform::squareToQuad(*cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc_squareToQuad_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF, PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.squareToQuad", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_toAffine(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toAffine()const
            const QMatrix & cppResult = cppSelf->QTransform::toAffine();
            pyResult = Shiboken::Converter<const QMatrix & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_translate(PyObject* self, PyObject* args)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // translate(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc_translate_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // translate(qreal,qreal)
            QTransform & cppResult = cppSelf->QTransform::translate(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QTransform & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc_translate_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.translate", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc_transposed(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transposed()const
            QTransform cppResult = cppSelf->QTransform::transposed();
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTransformFunc_type(PyObject* self)
{
    QTransform* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // type()const
            QTransform::TransformationType cppResult = cppSelf->QTransform::type();
            pyResult = Shiboken::Converter<QTransform::TransformationType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQTransform_methods[] = {
    {"adjoint", (PyCFunction)SbkQTransformFunc_adjoint, METH_NOARGS},
    {"det", (PyCFunction)SbkQTransformFunc_det, METH_NOARGS},
    {"determinant", (PyCFunction)SbkQTransformFunc_determinant, METH_NOARGS},
    {"dx", (PyCFunction)SbkQTransformFunc_dx, METH_NOARGS},
    {"dy", (PyCFunction)SbkQTransformFunc_dy, METH_NOARGS},
    {"fromScale", (PyCFunction)SbkQTransformFunc_fromScale, METH_VARARGS|METH_STATIC},
    {"fromTranslate", (PyCFunction)SbkQTransformFunc_fromTranslate, METH_VARARGS|METH_STATIC},
    {"inverted", (PyCFunction)SbkQTransformFunc_inverted, METH_NOARGS},
    {"isAffine", (PyCFunction)SbkQTransformFunc_isAffine, METH_NOARGS},
    {"isIdentity", (PyCFunction)SbkQTransformFunc_isIdentity, METH_NOARGS},
    {"isInvertible", (PyCFunction)SbkQTransformFunc_isInvertible, METH_NOARGS},
    {"isRotating", (PyCFunction)SbkQTransformFunc_isRotating, METH_NOARGS},
    {"isScaling", (PyCFunction)SbkQTransformFunc_isScaling, METH_NOARGS},
    {"isTranslating", (PyCFunction)SbkQTransformFunc_isTranslating, METH_NOARGS},
    {"m11", (PyCFunction)SbkQTransformFunc_m11, METH_NOARGS},
    {"m12", (PyCFunction)SbkQTransformFunc_m12, METH_NOARGS},
    {"m13", (PyCFunction)SbkQTransformFunc_m13, METH_NOARGS},
    {"m21", (PyCFunction)SbkQTransformFunc_m21, METH_NOARGS},
    {"m22", (PyCFunction)SbkQTransformFunc_m22, METH_NOARGS},
    {"m23", (PyCFunction)SbkQTransformFunc_m23, METH_NOARGS},
    {"m31", (PyCFunction)SbkQTransformFunc_m31, METH_NOARGS},
    {"m32", (PyCFunction)SbkQTransformFunc_m32, METH_NOARGS},
    {"m33", (PyCFunction)SbkQTransformFunc_m33, METH_NOARGS},
    {"map", (PyCFunction)SbkQTransformFunc_map, METH_O},
    {"mapRect", (PyCFunction)SbkQTransformFunc_mapRect, METH_O},
    {"mapToPolygon", (PyCFunction)SbkQTransformFunc_mapToPolygon, METH_O},
    {"quadToQuad", (PyCFunction)SbkQTransformFunc_quadToQuad, METH_VARARGS|METH_STATIC},
    {"quadToSquare", (PyCFunction)SbkQTransformFunc_quadToSquare, METH_VARARGS|METH_STATIC},
    {"reset", (PyCFunction)SbkQTransformFunc_reset, METH_NOARGS},
    {"rotate", (PyCFunction)SbkQTransformFunc_rotate, METH_VARARGS|METH_KEYWORDS},
    {"rotateRadians", (PyCFunction)SbkQTransformFunc_rotateRadians, METH_VARARGS|METH_KEYWORDS},
    {"scale", (PyCFunction)SbkQTransformFunc_scale, METH_VARARGS},
    {"setMatrix", (PyCFunction)SbkQTransformFunc_setMatrix, METH_VARARGS},
    {"shear", (PyCFunction)SbkQTransformFunc_shear, METH_VARARGS},
    {"squareToQuad", (PyCFunction)SbkQTransformFunc_squareToQuad, METH_VARARGS|METH_STATIC},
    {"toAffine", (PyCFunction)SbkQTransformFunc_toAffine, METH_NOARGS},
    {"translate", (PyCFunction)SbkQTransformFunc_translate, METH_VARARGS},
    {"transposed", (PyCFunction)SbkQTransformFunc_transposed, METH_NOARGS},
    {"type", (PyCFunction)SbkQTransformFunc_type, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQTransformFunc___mul__(PyObject* self, PyObject* arg)
{
    QTransform* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTransform >::checkType(arg) && !Shiboken::Converter<QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QLine,QTransform)
    // 1: operator*(QLineF,QTransform)
    // 2: operator*(QPoint,QTransform)
    // 3: operator*(QPointF,QTransform)
    // 4: operator*(QTransform)const
    // 5: operator*(QTransform,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 5; // operator*(QTransform,qreal)
    } else if (!isReverse && Shiboken::Converter<const QTransform & >::isConvertible(arg)) {
        overloadId = 4; // operator*(QTransform)const
    } else if (isReverse && Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 2; // operator*(QPoint,QTransform)
    } else if (isReverse && Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 3; // operator*(QPointF,QTransform)
    } else if (isReverse && Shiboken::Converter<const QLine & >::isConvertible(arg)) {
        overloadId = 0; // operator*(QLine,QTransform)
    } else if (isReverse && Shiboken::Converter<const QLineF & >::isConvertible(arg)) {
        overloadId = 1; // operator*(QLineF,QTransform)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QLine,QTransform)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QLine* cpp_arg0 = Shiboken::Converter<QLine* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QLine,QTransform) [reverse operator]
                QLine cppResult = (*cpp_arg0) * (*cppSelf);
                pyResult = Shiboken::Converter<QLine >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QLineF,QTransform)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QLineF > cpp_arg0_auto_ptr;
                QLineF* cpp_arg0 = Shiboken::Converter<QLineF* >::toCpp(arg);
                if (!Shiboken::Converter<QLineF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QLineF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator*(QLineF,QTransform) [reverse operator]
                QLineF cppResult = (*cpp_arg0) * (*cppSelf);
                pyResult = Shiboken::Converter<QLineF >::toPython(cppResult);
                }
                break;
            }
            case 2: // operator*(QPoint,QTransform)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QPoint,QTransform) [reverse operator]
                QPoint cppResult = (*cpp_arg0) * (*cppSelf);
                pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
                }
                break;
            }
            case 3: // operator*(QPointF,QTransform)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
                if (!Shiboken::Converter<QPointF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator*(QPointF,QTransform) [reverse operator]
                QPointF cppResult = (*cpp_arg0) * (*cppSelf);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 4: // operator*(QTransform)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QTransform)const
                QTransform cppResult = (*cppSelf) * (*cpp_arg0);
                pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
                }
                break;
            }
            case 5: // operator*(QTransform,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QTransform,qreal)
                QTransform cppResult = (*cppSelf) * cpp_arg0;
                pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtGui.QTransform", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTransform.__mul__", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc___imul__(PyObject* self, PyObject* arg)
{
    QTransform* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTransform >::checkType(arg) && !Shiboken::Converter<QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator*=(QTransform)
    // 1: operator*=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 1; // operator*=(qreal)
    } else if (!isReverse && Shiboken::Converter<const QTransform & >::isConvertible(arg)) {
        overloadId = 0; // operator*=(QTransform)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc___imul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*=(QTransform)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*=(QTransform)
                (*cppSelf) *= (*cpp_arg0);
                }
                break;
            }
            case 1: // operator*=(qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*=(qreal)
                (*cppSelf) *= cpp_arg0;
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQTransformFunc___imul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTransform.__imul__", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc___add__(PyObject* self, PyObject* arg)
{
    QTransform* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTransform >::checkType(arg) && !Shiboken::Converter<QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QTransform,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator+(QTransform,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc___add___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator+(QTransform,qreal)
            QTransform cppResult = (*cppSelf) + cpp_arg0;
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc___add___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTransform.__add__", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc___iadd__(PyObject* self, PyObject* arg)
{
    QTransform* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTransform >::checkType(arg) && !Shiboken::Converter<QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator+=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc___iadd___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator+=(qreal)
            (*cppSelf) += cpp_arg0;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQTransformFunc___iadd___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTransform.__iadd__", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc___sub__(PyObject* self, PyObject* arg)
{
    QTransform* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTransform >::checkType(arg) && !Shiboken::Converter<QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rsub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rsub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator-(QTransform,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator-(QTransform,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc___sub___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator-(QTransform,qreal)
            QTransform cppResult = (*cppSelf) - cpp_arg0;
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc___sub___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTransform.__sub__", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc___isub__(PyObject* self, PyObject* arg)
{
    QTransform* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTransform >::checkType(arg) && !Shiboken::Converter<QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator-=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc___isub___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator-=(qreal)
            (*cppSelf) -= cpp_arg0;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQTransformFunc___isub___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTransform.__isub__", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc___div__(PyObject* self, PyObject* arg)
{
    QTransform* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTransform >::checkType(arg) && !Shiboken::Converter<QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rdiv__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rdiv__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator/(QTransform,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/(QTransform,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc___div___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator/(QTransform,qreal)
            QTransform cppResult = (*cppSelf) / cpp_arg0;
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc___div___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTransform.__div__", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc___idiv__(PyObject* self, PyObject* arg)
{
    QTransform* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTransform >::checkType(arg) && !Shiboken::Converter<QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator/=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc___idiv___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator/=(qreal)
            (*cppSelf) /= cpp_arg0;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQTransformFunc___idiv___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTransform.__idiv__", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc___lshift__(PyObject* self, PyObject* arg)
{
    QTransform* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTransform >::checkType(arg) && !Shiboken::Converter<QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QTransform)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QTransform)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QTransform) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTransform.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQTransformFunc___rshift__(PyObject* self, PyObject* arg)
{
    QTransform* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTransform >::checkType(arg) && !Shiboken::Converter<QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTransform* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QTransform&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QTransform&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTransformFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QTransform&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTransformFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTransform.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQTransform_as_number = {
    /*nb_add*/                  (binaryfunc)SbkQTransformFunc___add__,
    /*nb_subtract*/             (binaryfunc)SbkQTransformFunc___sub__,
    /*nb_multiply*/             (binaryfunc)SbkQTransformFunc___mul__,
    /*nb_divide*/               (binaryfunc)SbkQTransformFunc___div__,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQTransformFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQTransformFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)SbkQTransformFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)SbkQTransformFunc___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)SbkQTransformFunc___imul__,
    /*nb_inplace_divide*/       (binaryfunc)SbkQTransformFunc___idiv__,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQTransform_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QTransform& cpp_self = *Shiboken::Converter<QTransform* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QTransform & >::isConvertible(other)) {
                // operator!=(const QTransform & arg__1) const
                QTransform* cpp_other = Shiboken::Converter<QTransform* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTransform  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQTransform_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QTransform & >::isConvertible(other)) {
                // operator==(const QTransform & arg__1) const
                QTransform* cpp_other = Shiboken::Converter<QTransform* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTransform  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQTransform_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQTransform_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTransform_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTransform",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQTransform_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQTransform_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTransform_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTransform_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTransform >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTransform",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QTransform_TransformationType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTransform_TransformationType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTransform_TransformationType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "TransformationType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTransform_TransformationType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTransform_TransformationType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTransform_TransformationType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QTransform(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTRANSFORM_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTransform_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQTransform_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTransform_Type));
    PyModule_AddObject(module, "QTransform",
        ((PyObject*)&SbkQTransform_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: TransformationType
    SbkPySide_QtGuiTypes[SBK_QTRANSFORM_TRANSFORMATIONTYPE_IDX] = &SbkPySide_QtGui_QTransform_TransformationType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTransform_TransformationType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTransform_TransformationType_Type);
    PyDict_SetItemString(SbkQTransform_Type.super.ht_type.tp_dict,
            "TransformationType",((PyObject*)&SbkPySide_QtGui_QTransform_TransformationType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTransform_TransformationType_Type,
        (long) QTransform::TxNone, "TxNone");
    PyDict_SetItemString(SbkQTransform_Type.super.ht_type.tp_dict,
        "TxNone", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTransform_TransformationType_Type.tp_dict,
        "TxNone", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTransform_TransformationType_Type,
        (long) QTransform::TxTranslate, "TxTranslate");
    PyDict_SetItemString(SbkQTransform_Type.super.ht_type.tp_dict,
        "TxTranslate", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTransform_TransformationType_Type.tp_dict,
        "TxTranslate", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTransform_TransformationType_Type,
        (long) QTransform::TxScale, "TxScale");
    PyDict_SetItemString(SbkQTransform_Type.super.ht_type.tp_dict,
        "TxScale", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTransform_TransformationType_Type.tp_dict,
        "TxScale", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTransform_TransformationType_Type,
        (long) QTransform::TxRotate, "TxRotate");
    PyDict_SetItemString(SbkQTransform_Type.super.ht_type.tp_dict,
        "TxRotate", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTransform_TransformationType_Type.tp_dict,
        "TxRotate", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTransform_TransformationType_Type,
        (long) QTransform::TxShear, "TxShear");
    PyDict_SetItemString(SbkQTransform_Type.super.ht_type.tp_dict,
        "TxShear", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTransform_TransformationType_Type.tp_dict,
        "TxShear", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTransform_TransformationType_Type,
        (long) QTransform::TxProject, "TxProject");
    PyDict_SetItemString(SbkQTransform_Type.super.ht_type.tp_dict,
        "TxProject", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTransform_TransformationType_Type.tp_dict,
        "TxProject", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTransform::TransformationType");


    Shiboken::TypeResolver::createValueTypeResolver<QTransform >("QTransform");
    Shiboken::TypeResolver::createObjectTypeResolver<QTransform >("QTransform*");
    Shiboken::TypeResolver::createValueTypeResolver<QTransform >(typeid(QTransform).name());
    PySide::initQtMetaType<QTransform >();
}

