/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtreewidgetitem_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qbrush.h>
#include <qdatastream.h>
#include <qfont.h>
#include <qicon.h>
#include <qsize.h>
#include <qtreewidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QTreeWidgetItemWrapper::QTreeWidgetItemWrapper(QTreeWidget * view, QTreeWidgetItem * after, int type) : QTreeWidgetItem(view, after, type) {
    // ... middle
}

QTreeWidgetItemWrapper::QTreeWidgetItemWrapper(QTreeWidget * view, const QStringList & strings, int type) : QTreeWidgetItem(view, strings, type) {
    // ... middle
}

QTreeWidgetItemWrapper::QTreeWidgetItemWrapper(QTreeWidget * view, int type) : QTreeWidgetItem(view, type) {
    // ... middle
}

QTreeWidgetItemWrapper::QTreeWidgetItemWrapper(QTreeWidgetItem * parent, QTreeWidgetItem * after, int type) : QTreeWidgetItem(parent, after, type) {
    // ... middle
}

QTreeWidgetItemWrapper::QTreeWidgetItemWrapper(QTreeWidgetItem * parent, const QStringList & strings, int type) : QTreeWidgetItem(parent, strings, type) {
    // ... middle
}

QTreeWidgetItemWrapper::QTreeWidgetItemWrapper(QTreeWidgetItem * parent, int type) : QTreeWidgetItem(parent, type) {
    // ... middle
}

QTreeWidgetItemWrapper::QTreeWidgetItemWrapper(const QStringList & strings, int type) : QTreeWidgetItem(strings, type) {
    // ... middle
}

QTreeWidgetItemWrapper::QTreeWidgetItemWrapper(int type) : QTreeWidgetItem(type) {
    // ... middle
}

QTreeWidgetItem * QTreeWidgetItemWrapper::clone() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "clone"));
    if (py_override.isNull()) {
        return this->QTreeWidgetItem::clone();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QTreeWidgetItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidgetItem.clone", SbkType<QTreeWidgetItem * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QTreeWidgetItem * cppResult(Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QTreeWidgetItem.clone");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

QVariant QTreeWidgetItemWrapper::data(int column, int role) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "data"));
    if (py_override.isNull()) {
        return this->QTreeWidgetItem::data(column, role);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(ii)",
        column,
        role
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidgetItem.data", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetItemWrapper::setData(int column, int role, const QVariant & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setData"));
    if (py_override.isNull()) {
        return this->QTreeWidgetItem::setData(column, role, value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iiN)",
        column,
        role,
        Shiboken::Converter<QVariant >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QTreeWidgetItemWrapper::~QTreeWidgetItemWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTreeWidgetItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTreeWidgetItem >()))
        return -1;

    QTreeWidgetItemWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "type" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItem(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItem(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QTreeWidgetItem", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QTreeWidgetItem(QTreeWidget*,QTreeWidgetItem*,int)
    // 1: QTreeWidgetItem(QTreeWidget*,QStringList,int)
    // 2: QTreeWidgetItem(QTreeWidget*,int)
    // 3: QTreeWidgetItem(QTreeWidgetItem*,QTreeWidgetItem*,int)
    // 4: QTreeWidgetItem(QTreeWidgetItem*,QStringList,int)
    // 5: QTreeWidgetItem(QTreeWidgetItem*,int)
    // 6: QTreeWidgetItem(QStringList,int)
    // 7: QTreeWidgetItem(int)
    if (numArgs == 0) {
        overloadId = 7; // QTreeWidgetItem(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 7; // QTreeWidgetItem(int)
    } else if (Shiboken::Converter< QStringList  >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 6; // QTreeWidgetItem(QStringList,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 6; // QTreeWidgetItem(QStringList,int)
        }
    } else if (Shiboken::Converter<QTreeWidgetItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 5; // QTreeWidgetItem(QTreeWidgetItem*,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 5; // QTreeWidgetItem(QTreeWidgetItem*,int)
        } else if (Shiboken::Converter< QStringList  >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 4; // QTreeWidgetItem(QTreeWidgetItem*,QStringList,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 4; // QTreeWidgetItem(QTreeWidgetItem*,QStringList,int)
            }
        } else if (Shiboken::Converter<QTreeWidgetItem * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 3; // QTreeWidgetItem(QTreeWidgetItem*,QTreeWidgetItem*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 3; // QTreeWidgetItem(QTreeWidgetItem*,QTreeWidgetItem*,int)
            }
        }
    } else if (Shiboken::Converter<QTreeWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QTreeWidgetItem(QTreeWidget*,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 2; // QTreeWidgetItem(QTreeWidget*,int)
        } else if (Shiboken::Converter< QStringList  >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // QTreeWidgetItem(QTreeWidget*,QStringList,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 1; // QTreeWidgetItem(QTreeWidget*,QStringList,int)
            }
        } else if (Shiboken::Converter<QTreeWidgetItem * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // QTreeWidgetItem(QTreeWidget*,QTreeWidgetItem*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // QTreeWidgetItem(QTreeWidget*,QTreeWidgetItem*,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItem_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTreeWidgetItem(QTreeWidget*,QTreeWidgetItem*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "type";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItem(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QTreeWidget* cpp_arg0 = Shiboken::Converter<QTreeWidget* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QTreeWidgetItem* cpp_arg1 = Shiboken::Converter<QTreeWidgetItem* >::toCpp(pyargs[1]);
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : QTreeWidgetItem::Type;

                if(!PyErr_Occurred()) {
                // QTreeWidgetItem(QTreeWidget*,QTreeWidgetItem*,int)
                cptr = new QTreeWidgetItemWrapper(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QTreeWidgetItem(QTreeWidget*,QStringList,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "type";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItem(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QTreeWidget* cpp_arg0 = Shiboken::Converter<QTreeWidget* >::toCpp(pyargs[0]);
                QStringList cpp_arg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : QTreeWidgetItem::Type;

                if(!PyErr_Occurred()) {
                // QTreeWidgetItem(QTreeWidget*,QStringList,int)
                cptr = new QTreeWidgetItemWrapper(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 2: // QTreeWidgetItem(QTreeWidget*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "type";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItem(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QTreeWidget* cpp_arg0 = Shiboken::Converter<QTreeWidget* >::toCpp(pyargs[0]);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : QTreeWidgetItem::Type;

                if(!PyErr_Occurred()) {
                // QTreeWidgetItem(QTreeWidget*,int)
                cptr = new QTreeWidgetItemWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 3: // QTreeWidgetItem(QTreeWidgetItem*,QTreeWidgetItem*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "type";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItem(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QTreeWidgetItem* cpp_arg0 = Shiboken::Converter<QTreeWidgetItem* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QTreeWidgetItem* cpp_arg1 = Shiboken::Converter<QTreeWidgetItem* >::toCpp(pyargs[1]);
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : QTreeWidgetItem::Type;

                if(!PyErr_Occurred()) {
                // QTreeWidgetItem(QTreeWidgetItem*,QTreeWidgetItem*,int)
                cptr = new QTreeWidgetItemWrapper(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(pyargs[0], self);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 4: // QTreeWidgetItem(QTreeWidgetItem*,QStringList,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "type";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItem(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QTreeWidgetItem* cpp_arg0 = Shiboken::Converter<QTreeWidgetItem* >::toCpp(pyargs[0]);
                QStringList cpp_arg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : QTreeWidgetItem::Type;

                if(!PyErr_Occurred()) {
                // QTreeWidgetItem(QTreeWidgetItem*,QStringList,int)
                cptr = new QTreeWidgetItemWrapper(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(pyargs[0], self);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 5: // QTreeWidgetItem(QTreeWidgetItem*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "type";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItem(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QTreeWidgetItem* cpp_arg0 = Shiboken::Converter<QTreeWidgetItem* >::toCpp(pyargs[0]);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : QTreeWidgetItem::Type;

                if(!PyErr_Occurred()) {
                // QTreeWidgetItem(QTreeWidgetItem*,int)
                cptr = new QTreeWidgetItemWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[0], self);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 6: // QTreeWidgetItem(QStringList,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "type";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItem(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QStringList cpp_arg0 = Shiboken::Converter<QStringList >::toCpp(pyargs[0]);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : QTreeWidgetItem::Type;

                if(!PyErr_Occurred()) {
                // QTreeWidgetItem(QStringList,int)
                cptr = new QTreeWidgetItemWrapper(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 7: // QTreeWidgetItem(int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "type";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItem(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cpp_arg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : QTreeWidgetItem::Type;

                if(!PyErr_Occurred()) {
                // QTreeWidgetItem(int)
                cptr = new QTreeWidgetItemWrapper(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTreeWidgetItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTreeWidgetItem_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTreeWidgetItem_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidget, PySide.QtGui.QTreeWidgetItem, int = Type", "PySide.QtGui.QTreeWidget, list, int = Type", "PySide.QtGui.QTreeWidget, int = Type", "PySide.QtGui.QTreeWidgetItem, PySide.QtGui.QTreeWidgetItem, int = Type", "PySide.QtGui.QTreeWidgetItem, list, int = Type", "PySide.QtGui.QTreeWidgetItem, int = Type", "list, int = Type", "int = Type", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem", overloads);
        return -1;
}

static PyObject* SbkQTreeWidgetItemFunc_addChild(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addChild(QTreeWidgetItem*)
    if (Shiboken::Converter<QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // addChild(QTreeWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_addChild_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTreeWidgetItem* cpp_arg0 = Shiboken::Converter<QTreeWidgetItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addChild(QTreeWidgetItem*)
            cppSelf->QTreeWidgetItem::addChild(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_addChild_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.addChild", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_addChildren(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addChildren(QList<QTreeWidgetItem*>)
    if (Shiboken::Converter< QList<QTreeWidgetItem * >  >::isConvertible(arg)) {
        overloadId = 0; // addChildren(QList<QTreeWidgetItem*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_addChildren_TypeError;

    // Call function/method
    {
        {
            QList<QTreeWidgetItem * > cpp_arg0 = Shiboken::Converter<QList<QTreeWidgetItem * > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addChildren(QList<QTreeWidgetItem*>)
            cppSelf->QTreeWidgetItem::addChildren(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_addChildren_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.addChildren", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_background(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: background(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // background(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_background_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // background(int)const
            QBrush cppResult = cppSelf->QTreeWidgetItem::background(cpp_arg0);
            pyResult = Shiboken::Converter<QBrush >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_background_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.background", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_checkState(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: checkState(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // checkState(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_checkState_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // checkState(int)const
            Qt::CheckState cppResult = cppSelf->QTreeWidgetItem::checkState(cpp_arg0);
            pyResult = Shiboken::Converter<Qt::CheckState >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_checkState_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.checkState", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_child(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: child(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // child(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_child_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // child(int)const
            QTreeWidgetItem * cppResult = cppSelf->QTreeWidgetItem::child(cpp_arg0);
            pyResult = Shiboken::Converter<QTreeWidgetItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_child_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.child", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_childCount(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childCount()const
            int cppResult = cppSelf->QTreeWidgetItem::childCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_childIndicatorPolicy(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childIndicatorPolicy()const
            QTreeWidgetItem::ChildIndicatorPolicy cppResult = cppSelf->QTreeWidgetItem::childIndicatorPolicy();
            pyResult = Shiboken::Converter<QTreeWidgetItem::ChildIndicatorPolicy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_clone(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clone()const
            QTreeWidgetItem * cppResult = cppSelf->QTreeWidgetItem::clone();
            pyResult = Shiboken::Converter<QTreeWidgetItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_columnCount(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // columnCount()const
            int cppResult = cppSelf->QTreeWidgetItem::columnCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_data(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "data", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: data(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // data(int,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_data_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // data(int,int)const
            QVariant cppResult = cppSelf->QTreeWidgetItem::data(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_data_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.data", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_emitDataChanged(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // emitDataChanged()
            cppSelf->QTreeWidgetItem::emitDataChanged();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTreeWidgetItemFunc_flags(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // flags()const
            QFlags<Qt::ItemFlag> cppResult = cppSelf->QTreeWidgetItem::flags();
            pyResult = Shiboken::Converter<QFlags<Qt::ItemFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_font(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: font(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // font(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_font_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // font(int)const
            QFont cppResult = cppSelf->QTreeWidgetItem::font(cpp_arg0);
            pyResult = Shiboken::Converter<QFont >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_font_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.font", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_foreground(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: foreground(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // foreground(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_foreground_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // foreground(int)const
            QBrush cppResult = cppSelf->QTreeWidgetItem::foreground(cpp_arg0);
            pyResult = Shiboken::Converter<QBrush >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_foreground_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.foreground", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_icon(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: icon(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // icon(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_icon_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // icon(int)const
            QIcon cppResult = cppSelf->QTreeWidgetItem::icon(cpp_arg0);
            pyResult = Shiboken::Converter<QIcon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_icon_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.icon", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_indexOfChild(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfChild(QTreeWidgetItem*)const
    if (Shiboken::Converter<QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // indexOfChild(QTreeWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_indexOfChild_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTreeWidgetItem* cpp_arg0 = Shiboken::Converter<QTreeWidgetItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // indexOfChild(QTreeWidgetItem*)const
            int cppResult = cppSelf->QTreeWidgetItem::indexOfChild(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_indexOfChild_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.indexOfChild", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_insertChild(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertChild", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertChild(int,QTreeWidgetItem*)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QTreeWidgetItem * >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertChild(int,QTreeWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_insertChild_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QTreeWidgetItem* cpp_arg1 = Shiboken::Converter<QTreeWidgetItem* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // insertChild(int,QTreeWidgetItem*)
            cppSelf->QTreeWidgetItem::insertChild(cpp_arg0, cpp_arg1);
            Shiboken::setParent(self, pyargs[1]);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_insertChild_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.insertChild", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_insertChildren(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertChildren", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertChildren(int,QList<QTreeWidgetItem*>)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< QList<QTreeWidgetItem * >  >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertChildren(int,QList<QTreeWidgetItem*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_insertChildren_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QList<QTreeWidgetItem * > cpp_arg1 = Shiboken::Converter<QList<QTreeWidgetItem * > >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // insertChildren(int,QList<QTreeWidgetItem*>)
            cppSelf->QTreeWidgetItem::insertChildren(cpp_arg0, cpp_arg1);
            Shiboken::setParent(self, pyargs[1]);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_insertChildren_TypeError:
        const char* overloads[] = {"int, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.insertChildren", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_isDisabled(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isDisabled()const
            bool cppResult = cppSelf->QTreeWidgetItem::isDisabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_isExpanded(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isExpanded()const
            bool cppResult = cppSelf->QTreeWidgetItem::isExpanded();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_isFirstColumnSpanned(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isFirstColumnSpanned()const
            bool cppResult = cppSelf->QTreeWidgetItem::isFirstColumnSpanned();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_isHidden(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isHidden()const
            bool cppResult = cppSelf->QTreeWidgetItem::isHidden();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_isSelected(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSelected()const
            bool cppResult = cppSelf->QTreeWidgetItem::isSelected();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_parent(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parent()const
            QTreeWidgetItem * cppResult = cppSelf->QTreeWidgetItem::parent();
            pyResult = Shiboken::Converter<QTreeWidgetItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_removeChild(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeChild(QTreeWidgetItem*)
    if (Shiboken::Converter<QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // removeChild(QTreeWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_removeChild_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTreeWidgetItem* cpp_arg0 = Shiboken::Converter<QTreeWidgetItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeChild(QTreeWidgetItem*)
            cppSelf->QTreeWidgetItem::removeChild(cpp_arg0);
            Shiboken::setParent(Py_None, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_removeChild_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.removeChild", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setBackground(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setBackground", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setBackground(int,QBrush)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QBrush & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setBackground(int,QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setBackground_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QBrush > cpp_arg1_auto_ptr;
            QBrush* cpp_arg1 = Shiboken::Converter<QBrush* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QBrush >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QBrush >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setBackground(int,QBrush)
            cppSelf->QTreeWidgetItem::setBackground(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setBackground_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.setBackground", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setCheckState(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCheckState", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setCheckState(int,Qt::CheckState)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<Qt::CheckState >::isConvertible(pyargs[1])) {
        overloadId = 0; // setCheckState(int,Qt::CheckState)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setCheckState_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::CheckState cpp_arg1 = Shiboken::Converter<Qt::CheckState >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setCheckState(int,Qt::CheckState)
            cppSelf->QTreeWidgetItem::setCheckState(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setCheckState_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.CheckState", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.setCheckState", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setChildIndicatorPolicy(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setChildIndicatorPolicy(QTreeWidgetItem::ChildIndicatorPolicy)
    if (Shiboken::Converter<QTreeWidgetItem::ChildIndicatorPolicy >::isConvertible(arg)) {
        overloadId = 0; // setChildIndicatorPolicy(QTreeWidgetItem::ChildIndicatorPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setChildIndicatorPolicy_TypeError;

    // Call function/method
    {
        {
            QTreeWidgetItem::ChildIndicatorPolicy cpp_arg0 = Shiboken::Converter<QTreeWidgetItem::ChildIndicatorPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setChildIndicatorPolicy(QTreeWidgetItem::ChildIndicatorPolicy)
            cppSelf->QTreeWidgetItem::setChildIndicatorPolicy(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setChildIndicatorPolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem.ChildIndicatorPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.setChildIndicatorPolicy", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setData(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setData", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setData(int,int,QVariant)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[2])) {
        overloadId = 0; // setData(int,int,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setData_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            QVariant cpp_arg2 = Shiboken::Converter<QVariant >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // setData(int,int,QVariant)
            cppSelf->QTreeWidgetItem::setData(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setData_TypeError:
        const char* overloads[] = {"int, int, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.setData", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setDisabled(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDisabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDisabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setDisabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDisabled(bool)
            cppSelf->QTreeWidgetItem::setDisabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setDisabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.setDisabled", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setExpanded(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setExpanded(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setExpanded(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setExpanded_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setExpanded(bool)
            cppSelf->QTreeWidgetItem::setExpanded(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setExpanded_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.setExpanded", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setFirstColumnSpanned(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFirstColumnSpanned(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFirstColumnSpanned(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setFirstColumnSpanned_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFirstColumnSpanned(bool)
            cppSelf->QTreeWidgetItem::setFirstColumnSpanned(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setFirstColumnSpanned_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.setFirstColumnSpanned", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setFlags(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFlags(QFlags<Qt::ItemFlag>)
    if (Shiboken::Converter<QFlags<Qt::ItemFlag> >::isConvertible(arg)) {
        overloadId = 0; // setFlags(QFlags<Qt::ItemFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::ItemFlag> cpp_arg0 = Shiboken::Converter<QFlags<Qt::ItemFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFlags(QFlags<Qt::ItemFlag>)
            cppSelf->QTreeWidgetItem::setFlags(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setFlags_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ItemFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.setFlags", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setFont(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFont", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFont(int,QFont)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QFont & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setFont(int,QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setFont_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QFont > cpp_arg1_auto_ptr;
            QFont* cpp_arg1 = Shiboken::Converter<QFont* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QFont >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QFont >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setFont(int,QFont)
            cppSelf->QTreeWidgetItem::setFont(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setFont_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.setFont", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setForeground(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setForeground", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setForeground(int,QBrush)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QBrush & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setForeground(int,QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setForeground_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QBrush > cpp_arg1_auto_ptr;
            QBrush* cpp_arg1 = Shiboken::Converter<QBrush* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QBrush >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QBrush >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setForeground(int,QBrush)
            cppSelf->QTreeWidgetItem::setForeground(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setForeground_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.setForeground", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setHidden(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHidden(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHidden(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setHidden_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHidden(bool)
            cppSelf->QTreeWidgetItem::setHidden(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setHidden_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.setHidden", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setIcon(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setIcon", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setIcon(int,QIcon)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QIcon & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setIcon(int,QIcon)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setIcon_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QIcon > cpp_arg1_auto_ptr;
            QIcon* cpp_arg1 = Shiboken::Converter<QIcon* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QIcon >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QIcon >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setIcon(int,QIcon)
            cppSelf->QTreeWidgetItem::setIcon(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setIcon_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QIcon", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.setIcon", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setSelected(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSelected(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSelected(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setSelected_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSelected(bool)
            cppSelf->QTreeWidgetItem::setSelected(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setSelected_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.setSelected", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setSizeHint(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSizeHint", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setSizeHint(int,QSize)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QSize & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setSizeHint(int,QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setSizeHint_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QSize* cpp_arg1 = Shiboken::Converter<QSize* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setSizeHint(int,QSize)
            cppSelf->QTreeWidgetItem::setSizeHint(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setSizeHint_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.setSizeHint", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setStatusTip(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setStatusTip", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setStatusTip(int,QString)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setStatusTip(int,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setStatusTip_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setStatusTip(int,QString)
            cppSelf->QTreeWidgetItem::setStatusTip(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setStatusTip_TypeError:
        const char* overloads[] = {"int, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.setStatusTip", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setText(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setText", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setText(int,QString)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setText(int,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setText_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setText(int,QString)
            cppSelf->QTreeWidgetItem::setText(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setText_TypeError:
        const char* overloads[] = {"int, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.setText", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setTextAlignment(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setTextAlignment", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setTextAlignment(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setTextAlignment(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setTextAlignment_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setTextAlignment(int,int)
            cppSelf->QTreeWidgetItem::setTextAlignment(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setTextAlignment_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.setTextAlignment", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setToolTip(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setToolTip", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setToolTip(int,QString)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setToolTip(int,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setToolTip_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setToolTip(int,QString)
            cppSelf->QTreeWidgetItem::setToolTip(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setToolTip_TypeError:
        const char* overloads[] = {"int, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.setToolTip", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_setWhatsThis(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setWhatsThis", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setWhatsThis(int,QString)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setWhatsThis(int,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_setWhatsThis_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setWhatsThis(int,QString)
            cppSelf->QTreeWidgetItem::setWhatsThis(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_setWhatsThis_TypeError:
        const char* overloads[] = {"int, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.setWhatsThis", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_sizeHint(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sizeHint(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // sizeHint(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_sizeHint_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // sizeHint(int)const
            QSize cppResult = cppSelf->QTreeWidgetItem::sizeHint(cpp_arg0);
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_sizeHint_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.sizeHint", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_sortChildren(PyObject* self, PyObject* args)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sortChildren", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: sortChildren(int,Qt::SortOrder)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<Qt::SortOrder >::isConvertible(pyargs[1])) {
        overloadId = 0; // sortChildren(int,Qt::SortOrder)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_sortChildren_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::SortOrder cpp_arg1 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // sortChildren(int,Qt::SortOrder)
            cppSelf->QTreeWidgetItem::sortChildren(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTreeWidgetItemFunc_sortChildren_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.SortOrder", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItem.sortChildren", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_statusTip(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: statusTip(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // statusTip(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_statusTip_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // statusTip(int)const
            QString cppResult = cppSelf->QTreeWidgetItem::statusTip(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_statusTip_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.statusTip", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_takeChild(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: takeChild(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // takeChild(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_takeChild_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // takeChild(int)
            QTreeWidgetItem * cppResult = cppSelf->QTreeWidgetItem::takeChild(cpp_arg0);
            pyResult = Shiboken::Converter<QTreeWidgetItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_takeChild_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.takeChild", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_takeChildren(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // takeChildren()
            QList<QTreeWidgetItem * > cppResult = cppSelf->QTreeWidgetItem::takeChildren();
            pyResult = Shiboken::Converter<QList<QTreeWidgetItem * > >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_text(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: text(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // text(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_text_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // text(int)const
            QString cppResult = cppSelf->QTreeWidgetItem::text(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_text_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.text", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_textAlignment(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: textAlignment(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // textAlignment(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_textAlignment_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // textAlignment(int)const
            int cppResult = cppSelf->QTreeWidgetItem::textAlignment(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_textAlignment_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.textAlignment", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_toolTip(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toolTip(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // toolTip(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_toolTip_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // toolTip(int)const
            QString cppResult = cppSelf->QTreeWidgetItem::toolTip(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_toolTip_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.toolTip", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc_treeWidget(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // treeWidget()const
            QTreeWidget * cppResult = cppSelf->QTreeWidgetItem::treeWidget();
            pyResult = Shiboken::Converter<QTreeWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_type(PyObject* self)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // type()const
            int cppResult = cppSelf->QTreeWidgetItem::type();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTreeWidgetItemFunc_whatsThis(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: whatsThis(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // whatsThis(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc_whatsThis_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // whatsThis(int)const
            QString cppResult = cppSelf->QTreeWidgetItem::whatsThis(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc_whatsThis_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.whatsThis", overloads);
        return 0;
}

static PyMethodDef SbkQTreeWidgetItem_methods[] = {
    {"addChild", (PyCFunction)SbkQTreeWidgetItemFunc_addChild, METH_O},
    {"addChildren", (PyCFunction)SbkQTreeWidgetItemFunc_addChildren, METH_O},
    {"background", (PyCFunction)SbkQTreeWidgetItemFunc_background, METH_O},
    {"checkState", (PyCFunction)SbkQTreeWidgetItemFunc_checkState, METH_O},
    {"child", (PyCFunction)SbkQTreeWidgetItemFunc_child, METH_O},
    {"childCount", (PyCFunction)SbkQTreeWidgetItemFunc_childCount, METH_NOARGS},
    {"childIndicatorPolicy", (PyCFunction)SbkQTreeWidgetItemFunc_childIndicatorPolicy, METH_NOARGS},
    {"clone", (PyCFunction)SbkQTreeWidgetItemFunc_clone, METH_NOARGS},
    {"columnCount", (PyCFunction)SbkQTreeWidgetItemFunc_columnCount, METH_NOARGS},
    {"data", (PyCFunction)SbkQTreeWidgetItemFunc_data, METH_VARARGS},
    {"emitDataChanged", (PyCFunction)SbkQTreeWidgetItemFunc_emitDataChanged, METH_NOARGS},
    {"flags", (PyCFunction)SbkQTreeWidgetItemFunc_flags, METH_NOARGS},
    {"font", (PyCFunction)SbkQTreeWidgetItemFunc_font, METH_O},
    {"foreground", (PyCFunction)SbkQTreeWidgetItemFunc_foreground, METH_O},
    {"icon", (PyCFunction)SbkQTreeWidgetItemFunc_icon, METH_O},
    {"indexOfChild", (PyCFunction)SbkQTreeWidgetItemFunc_indexOfChild, METH_O},
    {"insertChild", (PyCFunction)SbkQTreeWidgetItemFunc_insertChild, METH_VARARGS},
    {"insertChildren", (PyCFunction)SbkQTreeWidgetItemFunc_insertChildren, METH_VARARGS},
    {"isDisabled", (PyCFunction)SbkQTreeWidgetItemFunc_isDisabled, METH_NOARGS},
    {"isExpanded", (PyCFunction)SbkQTreeWidgetItemFunc_isExpanded, METH_NOARGS},
    {"isFirstColumnSpanned", (PyCFunction)SbkQTreeWidgetItemFunc_isFirstColumnSpanned, METH_NOARGS},
    {"isHidden", (PyCFunction)SbkQTreeWidgetItemFunc_isHidden, METH_NOARGS},
    {"isSelected", (PyCFunction)SbkQTreeWidgetItemFunc_isSelected, METH_NOARGS},
    {"parent", (PyCFunction)SbkQTreeWidgetItemFunc_parent, METH_NOARGS},
    {"removeChild", (PyCFunction)SbkQTreeWidgetItemFunc_removeChild, METH_O},
    {"setBackground", (PyCFunction)SbkQTreeWidgetItemFunc_setBackground, METH_VARARGS},
    {"setCheckState", (PyCFunction)SbkQTreeWidgetItemFunc_setCheckState, METH_VARARGS},
    {"setChildIndicatorPolicy", (PyCFunction)SbkQTreeWidgetItemFunc_setChildIndicatorPolicy, METH_O},
    {"setData", (PyCFunction)SbkQTreeWidgetItemFunc_setData, METH_VARARGS},
    {"setDisabled", (PyCFunction)SbkQTreeWidgetItemFunc_setDisabled, METH_O},
    {"setExpanded", (PyCFunction)SbkQTreeWidgetItemFunc_setExpanded, METH_O},
    {"setFirstColumnSpanned", (PyCFunction)SbkQTreeWidgetItemFunc_setFirstColumnSpanned, METH_O},
    {"setFlags", (PyCFunction)SbkQTreeWidgetItemFunc_setFlags, METH_O},
    {"setFont", (PyCFunction)SbkQTreeWidgetItemFunc_setFont, METH_VARARGS},
    {"setForeground", (PyCFunction)SbkQTreeWidgetItemFunc_setForeground, METH_VARARGS},
    {"setHidden", (PyCFunction)SbkQTreeWidgetItemFunc_setHidden, METH_O},
    {"setIcon", (PyCFunction)SbkQTreeWidgetItemFunc_setIcon, METH_VARARGS},
    {"setSelected", (PyCFunction)SbkQTreeWidgetItemFunc_setSelected, METH_O},
    {"setSizeHint", (PyCFunction)SbkQTreeWidgetItemFunc_setSizeHint, METH_VARARGS},
    {"setStatusTip", (PyCFunction)SbkQTreeWidgetItemFunc_setStatusTip, METH_VARARGS},
    {"setText", (PyCFunction)SbkQTreeWidgetItemFunc_setText, METH_VARARGS},
    {"setTextAlignment", (PyCFunction)SbkQTreeWidgetItemFunc_setTextAlignment, METH_VARARGS},
    {"setToolTip", (PyCFunction)SbkQTreeWidgetItemFunc_setToolTip, METH_VARARGS},
    {"setWhatsThis", (PyCFunction)SbkQTreeWidgetItemFunc_setWhatsThis, METH_VARARGS},
    {"sizeHint", (PyCFunction)SbkQTreeWidgetItemFunc_sizeHint, METH_O},
    {"sortChildren", (PyCFunction)SbkQTreeWidgetItemFunc_sortChildren, METH_VARARGS},
    {"statusTip", (PyCFunction)SbkQTreeWidgetItemFunc_statusTip, METH_O},
    {"takeChild", (PyCFunction)SbkQTreeWidgetItemFunc_takeChild, METH_O},
    {"takeChildren", (PyCFunction)SbkQTreeWidgetItemFunc_takeChildren, METH_NOARGS},
    {"text", (PyCFunction)SbkQTreeWidgetItemFunc_text, METH_O},
    {"textAlignment", (PyCFunction)SbkQTreeWidgetItemFunc_textAlignment, METH_O},
    {"toolTip", (PyCFunction)SbkQTreeWidgetItemFunc_toolTip, METH_O},
    {"treeWidget", (PyCFunction)SbkQTreeWidgetItemFunc_treeWidget, METH_NOARGS},
    {"type", (PyCFunction)SbkQTreeWidgetItemFunc_type, METH_NOARGS},
    {"whatsThis", (PyCFunction)SbkQTreeWidgetItemFunc_whatsThis, METH_O},
    {0} // Sentinel
};

static PyObject* SbkQTreeWidgetItemFunc___lshift__(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTreeWidgetItem* >::checkType(arg) && !Shiboken::Converter<QTreeWidgetItem* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QTreeWidgetItem)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QTreeWidgetItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QTreeWidgetItem) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQTreeWidgetItemFunc___rshift__(PyObject* self, PyObject* arg)
{
    QTreeWidgetItem* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTreeWidgetItem* >::checkType(arg) && !Shiboken::Converter<QTreeWidgetItem* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QTreeWidgetItem&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QTreeWidgetItem&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTreeWidgetItemFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QTreeWidgetItem&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTreeWidgetItemFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItem.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQTreeWidgetItem_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQTreeWidgetItemFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQTreeWidgetItemFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQTreeWidgetItem_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QTreeWidgetItem& cpp_self = *Shiboken::Converter<QTreeWidgetItem* >::toCpp(self);

    switch (op) {
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQTreeWidgetItem_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

static long SbkQTreeWidgetItem_HashFunc(PyObject* obj){
    return qHash(Shiboken::Converter<QTreeWidgetItem* >::toCpp(obj));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTreeWidgetItem_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTreeWidgetItem",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQTreeWidgetItem_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &SbkQTreeWidgetItem_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQTreeWidgetItem_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTreeWidgetItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTreeWidgetItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTreeWidgetItem >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTreeWidgetItem*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QTreeWidgetItem_ItemType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTreeWidgetItem_ItemType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTreeWidgetItem_ItemType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ItemType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTreeWidgetItem_ItemType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTreeWidgetItem_ItemType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTreeWidgetItem_ItemType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ChildIndicatorPolicy",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QTreeWidgetItem(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTREEWIDGETITEM_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTreeWidgetItem_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQTreeWidgetItem_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTreeWidgetItem_Type));
    PyModule_AddObject(module, "QTreeWidgetItem",
        ((PyObject*)&SbkQTreeWidgetItem_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ItemType
    SbkPySide_QtGuiTypes[SBK_QTREEWIDGETITEM_ITEMTYPE_IDX] = &SbkPySide_QtGui_QTreeWidgetItem_ItemType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTreeWidgetItem_ItemType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTreeWidgetItem_ItemType_Type);
    PyDict_SetItemString(SbkQTreeWidgetItem_Type.super.ht_type.tp_dict,
            "ItemType",((PyObject*)&SbkPySide_QtGui_QTreeWidgetItem_ItemType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTreeWidgetItem_ItemType_Type,
        (long) QTreeWidgetItem::Type, "Type");
    PyDict_SetItemString(SbkQTreeWidgetItem_Type.super.ht_type.tp_dict,
        "Type", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItem_ItemType_Type.tp_dict,
        "Type", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTreeWidgetItem_ItemType_Type,
        (long) QTreeWidgetItem::UserType, "UserType");
    PyDict_SetItemString(SbkQTreeWidgetItem_Type.super.ht_type.tp_dict,
        "UserType", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItem_ItemType_Type.tp_dict,
        "UserType", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTreeWidgetItem::ItemType");

    // init enum class: ChildIndicatorPolicy
    SbkPySide_QtGuiTypes[SBK_QTREEWIDGETITEM_CHILDINDICATORPOLICY_IDX] = &SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_Type);
    PyDict_SetItemString(SbkQTreeWidgetItem_Type.super.ht_type.tp_dict,
            "ChildIndicatorPolicy",((PyObject*)&SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_Type,
        (long) QTreeWidgetItem::ShowIndicator, "ShowIndicator");
    PyDict_SetItemString(SbkQTreeWidgetItem_Type.super.ht_type.tp_dict,
        "ShowIndicator", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_Type.tp_dict,
        "ShowIndicator", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_Type,
        (long) QTreeWidgetItem::DontShowIndicator, "DontShowIndicator");
    PyDict_SetItemString(SbkQTreeWidgetItem_Type.super.ht_type.tp_dict,
        "DontShowIndicator", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_Type.tp_dict,
        "DontShowIndicator", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_Type,
        (long) QTreeWidgetItem::DontShowIndicatorWhenChildless, "DontShowIndicatorWhenChildless");
    PyDict_SetItemString(SbkQTreeWidgetItem_Type.super.ht_type.tp_dict,
        "DontShowIndicatorWhenChildless", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItem_ChildIndicatorPolicy_Type.tp_dict,
        "DontShowIndicatorWhenChildless", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTreeWidgetItem::ChildIndicatorPolicy");


    Shiboken::TypeResolver::createObjectTypeResolver<QTreeWidgetItem >("QTreeWidgetItem*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTreeWidgetItem >(typeid(QTreeWidgetItem).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QTreeWidgetItem >(typeid(QTreeWidgetItemWrapper).name());
    PySide::initQtMetaType<QTreeWidgetItem* >();
}

