/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qundocommand_wrapper.h"

// Extra includes
#include <qundostack.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QUndoCommandWrapper::QUndoCommandWrapper(QUndoCommand * parent) : QUndoCommand(parent) {
    // ... middle
}

QUndoCommandWrapper::QUndoCommandWrapper(const QString & text, QUndoCommand * parent) : QUndoCommand(text, parent) {
    // ... middle
}

int QUndoCommandWrapper::id() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "id"));
    if (py_override.isNull()) {
        return this->QUndoCommand::id();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QUndoCommand.id", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

bool QUndoCommandWrapper::mergeWith(const QUndoCommand * other)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mergeWith"));
    if (py_override.isNull()) {
        return this->QUndoCommand::mergeWith(other);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QUndoCommand * >::toPython(other)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QUndoCommand.mergeWith", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

void QUndoCommandWrapper::redo()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "redo"));
    if (py_override.isNull()) {
        return this->QUndoCommand::redo();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QUndoCommandWrapper::undo()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "undo"));
    if (py_override.isNull()) {
        return this->QUndoCommand::undo();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QUndoCommandWrapper::~QUndoCommandWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQUndoCommand_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QUndoCommand >()))
        return -1;

    QUndoCommandWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QUndoCommand(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QUndoCommand(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QUndoCommand", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QUndoCommand(QUndoCommand*)
    // 1: QUndoCommand(QString,QUndoCommand*)
    if (numArgs == 0) {
        overloadId = 0; // QUndoCommand(QUndoCommand*)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QUndoCommand(QString,QUndoCommand*)
        } else if (Shiboken::Converter<QUndoCommand * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QUndoCommand(QString,QUndoCommand*)
        }
    } else if (Shiboken::Converter<QUndoCommand * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QUndoCommand(QUndoCommand*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUndoCommand_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QUndoCommand(QUndoCommand*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QUndoCommand(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QUndoCommand* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QUndoCommand* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QUndoCommand(QUndoCommand*)
                cptr = new QUndoCommandWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QUndoCommand(QString,QUndoCommand*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QUndoCommand(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QUndoCommand* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QUndoCommand* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QUndoCommand(QString,QUndoCommand*)
                cptr = new QUndoCommandWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QUndoCommand >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQUndoCommand_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQUndoCommand_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QUndoCommand = None", "QString, PySide.QtGui.QUndoCommand = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QUndoCommand", overloads);
        return -1;
}

static PyObject* SbkQUndoCommandFunc_child(PyObject* self, PyObject* arg)
{
    QUndoCommand* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUndoCommand* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: child(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // child(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUndoCommandFunc_child_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // child(int)const
            const QUndoCommand * cppResult = cppSelf->QUndoCommand::child(cpp_arg0);
            pyResult = Shiboken::Converter< QUndoCommand * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUndoCommandFunc_child_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QUndoCommand.child", overloads);
        return 0;
}

static PyObject* SbkQUndoCommandFunc_childCount(PyObject* self)
{
    QUndoCommand* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUndoCommand* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childCount()const
            int cppResult = cppSelf->QUndoCommand::childCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUndoCommandFunc_id(PyObject* self)
{
    QUndoCommand* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUndoCommand* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // id()const
            int cppResult = cppSelf->QUndoCommand::id();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUndoCommandFunc_mergeWith(PyObject* self, PyObject* arg)
{
    QUndoCommand* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUndoCommand* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mergeWith(const QUndoCommand*)
    if (Shiboken::Converter< QUndoCommand * >::isConvertible(arg)) {
        overloadId = 0; // mergeWith(const QUndoCommand*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUndoCommandFunc_mergeWith_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QUndoCommand* cpp_arg0 = Shiboken::Converter<QUndoCommand* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mergeWith(const QUndoCommand*)
            bool cppResult = cppSelf->QUndoCommand::mergeWith(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUndoCommandFunc_mergeWith_TypeError:
        const char* overloads[] = {"PySide.QtGui.QUndoCommand", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QUndoCommand.mergeWith", overloads);
        return 0;
}

static PyObject* SbkQUndoCommandFunc_redo(PyObject* self)
{
    QUndoCommand* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUndoCommand* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // redo()
            cppSelf->QUndoCommand::redo();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQUndoCommandFunc_setText(PyObject* self, PyObject* arg)
{
    QUndoCommand* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUndoCommand* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUndoCommandFunc_setText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setText(QString)
            cppSelf->QUndoCommand::setText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUndoCommandFunc_setText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QUndoCommand.setText", overloads);
        return 0;
}

static PyObject* SbkQUndoCommandFunc_text(PyObject* self)
{
    QUndoCommand* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUndoCommand* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // text()const
            QString cppResult = cppSelf->QUndoCommand::text();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUndoCommandFunc_undo(PyObject* self)
{
    QUndoCommand* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUndoCommand* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // undo()
            cppSelf->QUndoCommand::undo();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef SbkQUndoCommand_methods[] = {
    {"child", (PyCFunction)SbkQUndoCommandFunc_child, METH_O},
    {"childCount", (PyCFunction)SbkQUndoCommandFunc_childCount, METH_NOARGS},
    {"id", (PyCFunction)SbkQUndoCommandFunc_id, METH_NOARGS},
    {"mergeWith", (PyCFunction)SbkQUndoCommandFunc_mergeWith, METH_O},
    {"redo", (PyCFunction)SbkQUndoCommandFunc_redo, METH_NOARGS},
    {"setText", (PyCFunction)SbkQUndoCommandFunc_setText, METH_O},
    {"text", (PyCFunction)SbkQUndoCommandFunc_text, METH_NOARGS},
    {"undo", (PyCFunction)SbkQUndoCommandFunc_undo, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQUndoCommand_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QUndoCommand",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQUndoCommand_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQUndoCommand_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QUndoCommand >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QUndoCommand*",
    /*user_data*/           0
};
} //extern


void init_QUndoCommand(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QUNDOCOMMAND_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQUndoCommand_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQUndoCommand_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQUndoCommand_Type));
    PyModule_AddObject(module, "QUndoCommand",
        ((PyObject*)&SbkQUndoCommand_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QUndoCommand >("QUndoCommand*");
    Shiboken::TypeResolver::createObjectTypeResolver<QUndoCommand >(typeid(QUndoCommand).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QUndoCommand >(typeid(QUndoCommandWrapper).name());
    PySide::initQtMetaType<QUndoCommand* >();
}

