/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qnetworkrequest_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qnetworkrequest.h>
#include <qobject.h>
#include <qsslconfiguration.h>
#include <qurl.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQNetworkRequest_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QNetworkRequest >()))
        return -1;

    QNetworkRequest* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "url" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkRequest(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkRequest(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|O:QNetworkRequest", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QNetworkRequest(QNetworkRequest)
    // 1: QNetworkRequest(QUrl)
    if (numArgs == 0) {
        overloadId = 1; // QNetworkRequest(QUrl)
    } else if (Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 1; // QNetworkRequest(QUrl)
    } else if (numArgs == 1 && Shiboken::Converter<const QNetworkRequest & >::isConvertible(arg)) {
        overloadId = 0; // QNetworkRequest(QNetworkRequest)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkRequest_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QNetworkRequest(QNetworkRequest)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QNetworkRequest* cpp_arg0 = Shiboken::Converter<QNetworkRequest* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QNetworkRequest(QNetworkRequest)
                cptr = new QNetworkRequest(*cpp_arg0);
                }
                break;
            }
            case 1: // QNetworkRequest(QUrl)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "url");
                    if (value) {
                        if (arg)
                            errorArgName = "url";
                        else
                            arg = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkRequest(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
                QUrl cpp_arg0_tmp = QUrl();
                QUrl* cpp_arg0 = arg ? Shiboken::Converter<QUrl* >::toCpp(arg) : &cpp_arg0_tmp;
                if (arg && !Shiboken::Converter<QUrl >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QNetworkRequest(QUrl)
                cptr = new QNetworkRequest(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QNetworkRequest >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQNetworkRequest_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQNetworkRequest_Init_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest", "PySide.QtCore.QUrl = QUrl()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkRequest", overloads);
        return -1;
}

static PyObject* SbkQNetworkRequestFunc_attribute(PyObject* self, PyObject* args, PyObject* kwds)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "defaultValue" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkRequest.attribute(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkRequest.attribute(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkRequest.attribute(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:attribute", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: attribute(QNetworkRequest::Attribute,QVariant)const
    if (Shiboken::Converter<QNetworkRequest::Attribute >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // attribute(QNetworkRequest::Attribute,QVariant)const
        } else if (Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
            overloadId = 0; // attribute(QNetworkRequest::Attribute,QVariant)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkRequestFunc_attribute_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "defaultValue");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "defaultValue";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkRequest.attribute(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QNetworkRequest::Attribute cpp_arg0 = Shiboken::Converter<QNetworkRequest::Attribute >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = pyargs[1] ? Shiboken::Converter<QVariant >::toCpp(pyargs[1]) : QVariant();

            if(!PyErr_Occurred()) {
            // attribute(QNetworkRequest::Attribute,QVariant)const
            QVariant cppResult = cppSelf->QNetworkRequest::attribute(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQNetworkRequestFunc_attribute_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest.Attribute, QVariant = QVariant()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkRequest.attribute", overloads);
        return 0;
}

static PyObject* SbkQNetworkRequestFunc_hasRawHeader(PyObject* self, PyObject* arg)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasRawHeader(QByteArray)const
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // hasRawHeader(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkRequestFunc_hasRawHeader_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // hasRawHeader(QByteArray)const
            bool cppResult = cppSelf->QNetworkRequest::hasRawHeader(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQNetworkRequestFunc_hasRawHeader_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkRequest.hasRawHeader", overloads);
        return 0;
}

static PyObject* SbkQNetworkRequestFunc_header(PyObject* self, PyObject* arg)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: header(QNetworkRequest::KnownHeaders)const
    if (Shiboken::Converter<QNetworkRequest::KnownHeaders >::isConvertible(arg)) {
        overloadId = 0; // header(QNetworkRequest::KnownHeaders)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkRequestFunc_header_TypeError;

    // Call function/method
    {
        {
            QNetworkRequest::KnownHeaders cpp_arg0 = Shiboken::Converter<QNetworkRequest::KnownHeaders >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // header(QNetworkRequest::KnownHeaders)const
            QVariant cppResult = cppSelf->QNetworkRequest::header(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQNetworkRequestFunc_header_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest.KnownHeaders", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkRequest.header", overloads);
        return 0;
}

static PyObject* SbkQNetworkRequestFunc_originatingObject(PyObject* self)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // originatingObject()const
            QObject * cppResult = cppSelf->QNetworkRequest::originatingObject();
            pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkRequestFunc_priority(PyObject* self)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // priority()const
            QNetworkRequest::Priority cppResult = cppSelf->QNetworkRequest::priority();
            pyResult = Shiboken::Converter<QNetworkRequest::Priority >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkRequestFunc_rawHeader(PyObject* self, PyObject* arg)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rawHeader(QByteArray)const
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // rawHeader(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkRequestFunc_rawHeader_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // rawHeader(QByteArray)const
            QByteArray cppResult = cppSelf->QNetworkRequest::rawHeader(*cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQNetworkRequestFunc_rawHeader_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkRequest.rawHeader", overloads);
        return 0;
}

static PyObject* SbkQNetworkRequestFunc_rawHeaderList(PyObject* self)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rawHeaderList()const
            QList<QByteArray > cppResult = cppSelf->QNetworkRequest::rawHeaderList();
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkRequestFunc_setAttribute(PyObject* self, PyObject* args)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttribute", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAttribute(QNetworkRequest::Attribute,QVariant)
    if (numArgs == 2 && Shiboken::Converter<QNetworkRequest::Attribute >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setAttribute(QNetworkRequest::Attribute,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkRequestFunc_setAttribute_TypeError;

    // Call function/method
    {
        {
            QNetworkRequest::Attribute cpp_arg0 = Shiboken::Converter<QNetworkRequest::Attribute >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setAttribute(QNetworkRequest::Attribute,QVariant)
            cppSelf->QNetworkRequest::setAttribute(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQNetworkRequestFunc_setAttribute_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest.Attribute, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkRequest.setAttribute", overloads);
        return 0;
}

static PyObject* SbkQNetworkRequestFunc_setHeader(PyObject* self, PyObject* args)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setHeader", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setHeader(QNetworkRequest::KnownHeaders,QVariant)
    if (numArgs == 2 && Shiboken::Converter<QNetworkRequest::KnownHeaders >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setHeader(QNetworkRequest::KnownHeaders,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkRequestFunc_setHeader_TypeError;

    // Call function/method
    {
        {
            QNetworkRequest::KnownHeaders cpp_arg0 = Shiboken::Converter<QNetworkRequest::KnownHeaders >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setHeader(QNetworkRequest::KnownHeaders,QVariant)
            cppSelf->QNetworkRequest::setHeader(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQNetworkRequestFunc_setHeader_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest.KnownHeaders, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkRequest.setHeader", overloads);
        return 0;
}

static PyObject* SbkQNetworkRequestFunc_setOriginatingObject(PyObject* self, PyObject* arg)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOriginatingObject(QObject*)
    if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // setOriginatingObject(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkRequestFunc_setOriginatingObject_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOriginatingObject(QObject*)
            cppSelf->QNetworkRequest::setOriginatingObject(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQNetworkRequestFunc_setOriginatingObject_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkRequest.setOriginatingObject", overloads);
        return 0;
}

static PyObject* SbkQNetworkRequestFunc_setPriority(PyObject* self, PyObject* arg)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPriority(QNetworkRequest::Priority)
    if (Shiboken::Converter<QNetworkRequest::Priority >::isConvertible(arg)) {
        overloadId = 0; // setPriority(QNetworkRequest::Priority)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkRequestFunc_setPriority_TypeError;

    // Call function/method
    {
        {
            QNetworkRequest::Priority cpp_arg0 = Shiboken::Converter<QNetworkRequest::Priority >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPriority(QNetworkRequest::Priority)
            cppSelf->QNetworkRequest::setPriority(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQNetworkRequestFunc_setPriority_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest.Priority", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkRequest.setPriority", overloads);
        return 0;
}

static PyObject* SbkQNetworkRequestFunc_setRawHeader(PyObject* self, PyObject* args)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setRawHeader", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRawHeader(QByteArray,QByteArray)
    if (numArgs == 2 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setRawHeader(QByteArray,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkRequestFunc_setRawHeader_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
            QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setRawHeader(QByteArray,QByteArray)
            cppSelf->QNetworkRequest::setRawHeader(*cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQNetworkRequestFunc_setRawHeader_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkRequest.setRawHeader", overloads);
        return 0;
}

static PyObject* SbkQNetworkRequestFunc_setSslConfiguration(PyObject* self, PyObject* arg)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSslConfiguration(QSslConfiguration)
    if (Shiboken::Converter<const QSslConfiguration & >::isConvertible(arg)) {
        overloadId = 0; // setSslConfiguration(QSslConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkRequestFunc_setSslConfiguration_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QSslConfiguration* cpp_arg0 = Shiboken::Converter<QSslConfiguration* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSslConfiguration(QSslConfiguration)
            cppSelf->QNetworkRequest::setSslConfiguration(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQNetworkRequestFunc_setSslConfiguration_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSslConfiguration", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkRequest.setSslConfiguration", overloads);
        return 0;
}

static PyObject* SbkQNetworkRequestFunc_setUrl(PyObject* self, PyObject* arg)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUrl(QUrl)
    if (Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkRequestFunc_setUrl_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
            QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
            if (!Shiboken::Converter<QUrl >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setUrl(QUrl)
            cppSelf->QNetworkRequest::setUrl(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQNetworkRequestFunc_setUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkRequest.setUrl", overloads);
        return 0;
}

static PyObject* SbkQNetworkRequestFunc_sslConfiguration(PyObject* self)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sslConfiguration()const
            QSslConfiguration cppResult = cppSelf->QNetworkRequest::sslConfiguration();
            pyResult = Shiboken::Converter<QSslConfiguration >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkRequestFunc_url(PyObject* self)
{
    QNetworkRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // url()const
            QUrl cppResult = cppSelf->QNetworkRequest::url();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQNetworkRequest_methods[] = {
    {"attribute", (PyCFunction)SbkQNetworkRequestFunc_attribute, METH_VARARGS|METH_KEYWORDS},
    {"hasRawHeader", (PyCFunction)SbkQNetworkRequestFunc_hasRawHeader, METH_O},
    {"header", (PyCFunction)SbkQNetworkRequestFunc_header, METH_O},
    {"originatingObject", (PyCFunction)SbkQNetworkRequestFunc_originatingObject, METH_NOARGS},
    {"priority", (PyCFunction)SbkQNetworkRequestFunc_priority, METH_NOARGS},
    {"rawHeader", (PyCFunction)SbkQNetworkRequestFunc_rawHeader, METH_O},
    {"rawHeaderList", (PyCFunction)SbkQNetworkRequestFunc_rawHeaderList, METH_NOARGS},
    {"setAttribute", (PyCFunction)SbkQNetworkRequestFunc_setAttribute, METH_VARARGS},
    {"setHeader", (PyCFunction)SbkQNetworkRequestFunc_setHeader, METH_VARARGS},
    {"setOriginatingObject", (PyCFunction)SbkQNetworkRequestFunc_setOriginatingObject, METH_O},
    {"setPriority", (PyCFunction)SbkQNetworkRequestFunc_setPriority, METH_O},
    {"setRawHeader", (PyCFunction)SbkQNetworkRequestFunc_setRawHeader, METH_VARARGS},
    {"setSslConfiguration", (PyCFunction)SbkQNetworkRequestFunc_setSslConfiguration, METH_O},
    {"setUrl", (PyCFunction)SbkQNetworkRequestFunc_setUrl, METH_O},
    {"sslConfiguration", (PyCFunction)SbkQNetworkRequestFunc_sslConfiguration, METH_NOARGS},
    {"url", (PyCFunction)SbkQNetworkRequestFunc_url, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQNetworkRequest_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QNetworkRequest& cpp_self = *Shiboken::Converter<QNetworkRequest* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QNetworkRequest & >::isConvertible(other)) {
                // operator!=(const QNetworkRequest & other) const
                QNetworkRequest* cpp_other = Shiboken::Converter<QNetworkRequest* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QNetworkRequest  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQNetworkRequest_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QNetworkRequest & >::isConvertible(other)) {
                // operator==(const QNetworkRequest & other) const
                QNetworkRequest* cpp_other = Shiboken::Converter<QNetworkRequest* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QNetworkRequest  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQNetworkRequest_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQNetworkRequest_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQNetworkRequest_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QNetworkRequest",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQNetworkRequest_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQNetworkRequest_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQNetworkRequest_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QNetworkRequest >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QNetworkRequest",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "CacheLoadControl",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "KnownHeaders",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QNetworkRequest_Priority_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QNetworkRequest_Priority_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QNetworkRequest_Priority_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Priority",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QNetworkRequest_Priority_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QNetworkRequest_Priority_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QNetworkRequest_Priority_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QNetworkRequest_Attribute_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QNetworkRequest_Attribute_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Attribute",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QNetworkRequest_Attribute_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QNetworkRequest_Attribute_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QNetworkRequest_Attribute_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QNetworkRequest_LoadControl_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QNetworkRequest_LoadControl_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QNetworkRequest_LoadControl_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "LoadControl",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QNetworkRequest_LoadControl_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QNetworkRequest_LoadControl_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QNetworkRequest_LoadControl_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QNetworkRequest(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QNETWORKREQUEST_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQNetworkRequest_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQNetworkRequest_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQNetworkRequest_Type));
    PyModule_AddObject(module, "QNetworkRequest",
        ((PyObject*)&SbkQNetworkRequest_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: CacheLoadControl
    SbkPySide_QtNetworkTypes[SBK_QNETWORKREQUEST_CACHELOADCONTROL_IDX] = &SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_Type);
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
            "CacheLoadControl",((PyObject*)&SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_Type,
        (long) QNetworkRequest::AlwaysNetwork, "AlwaysNetwork");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "AlwaysNetwork", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_Type.tp_dict,
        "AlwaysNetwork", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_Type,
        (long) QNetworkRequest::PreferNetwork, "PreferNetwork");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "PreferNetwork", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_Type.tp_dict,
        "PreferNetwork", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_Type,
        (long) QNetworkRequest::PreferCache, "PreferCache");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "PreferCache", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_Type.tp_dict,
        "PreferCache", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_Type,
        (long) QNetworkRequest::AlwaysCache, "AlwaysCache");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "AlwaysCache", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_CacheLoadControl_Type.tp_dict,
        "AlwaysCache", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkRequest::CacheLoadControl");

    // init enum class: KnownHeaders
    SbkPySide_QtNetworkTypes[SBK_QNETWORKREQUEST_KNOWNHEADERS_IDX] = &SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type);
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
            "KnownHeaders",((PyObject*)&SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type,
        (long) QNetworkRequest::ContentTypeHeader, "ContentTypeHeader");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "ContentTypeHeader", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type.tp_dict,
        "ContentTypeHeader", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type,
        (long) QNetworkRequest::ContentLengthHeader, "ContentLengthHeader");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "ContentLengthHeader", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type.tp_dict,
        "ContentLengthHeader", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type,
        (long) QNetworkRequest::LocationHeader, "LocationHeader");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "LocationHeader", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type.tp_dict,
        "LocationHeader", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type,
        (long) QNetworkRequest::LastModifiedHeader, "LastModifiedHeader");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "LastModifiedHeader", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type.tp_dict,
        "LastModifiedHeader", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type,
        (long) QNetworkRequest::CookieHeader, "CookieHeader");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "CookieHeader", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type.tp_dict,
        "CookieHeader", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type,
        (long) QNetworkRequest::SetCookieHeader, "SetCookieHeader");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "SetCookieHeader", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_KnownHeaders_Type.tp_dict,
        "SetCookieHeader", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkRequest::KnownHeaders");

    // init enum class: Priority
    SbkPySide_QtNetworkTypes[SBK_QNETWORKREQUEST_PRIORITY_IDX] = &SbkPySide_QtNetwork_QNetworkRequest_Priority_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkRequest_Priority_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QNetworkRequest_Priority_Type);
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
            "Priority",((PyObject*)&SbkPySide_QtNetwork_QNetworkRequest_Priority_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Priority_Type,
        (long) QNetworkRequest::HighPriority, "HighPriority");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "HighPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Priority_Type.tp_dict,
        "HighPriority", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Priority_Type,
        (long) QNetworkRequest::NormalPriority, "NormalPriority");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "NormalPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Priority_Type.tp_dict,
        "NormalPriority", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Priority_Type,
        (long) QNetworkRequest::LowPriority, "LowPriority");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "LowPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Priority_Type.tp_dict,
        "LowPriority", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkRequest::Priority");

    // init enum class: Attribute
    SbkPySide_QtNetworkTypes[SBK_QNETWORKREQUEST_ATTRIBUTE_IDX] = &SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type);
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
            "Attribute",((PyObject*)&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::HttpStatusCodeAttribute, "HttpStatusCodeAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "HttpStatusCodeAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "HttpStatusCodeAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::HttpReasonPhraseAttribute, "HttpReasonPhraseAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "HttpReasonPhraseAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "HttpReasonPhraseAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::RedirectionTargetAttribute, "RedirectionTargetAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "RedirectionTargetAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "RedirectionTargetAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::ConnectionEncryptedAttribute, "ConnectionEncryptedAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "ConnectionEncryptedAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "ConnectionEncryptedAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::CacheLoadControlAttribute, "CacheLoadControlAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "CacheLoadControlAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "CacheLoadControlAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::CacheSaveControlAttribute, "CacheSaveControlAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "CacheSaveControlAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "CacheSaveControlAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::SourceIsFromCacheAttribute, "SourceIsFromCacheAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "SourceIsFromCacheAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "SourceIsFromCacheAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::DoNotBufferUploadDataAttribute, "DoNotBufferUploadDataAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "DoNotBufferUploadDataAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "DoNotBufferUploadDataAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::HttpPipeliningAllowedAttribute, "HttpPipeliningAllowedAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "HttpPipeliningAllowedAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "HttpPipeliningAllowedAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::HttpPipeliningWasUsedAttribute, "HttpPipeliningWasUsedAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "HttpPipeliningWasUsedAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "HttpPipeliningWasUsedAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::CustomVerbAttribute, "CustomVerbAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "CustomVerbAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "CustomVerbAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::CookieLoadControlAttribute, "CookieLoadControlAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "CookieLoadControlAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "CookieLoadControlAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::AuthenticationReuseAttribute, "AuthenticationReuseAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "AuthenticationReuseAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "AuthenticationReuseAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::CookieSaveControlAttribute, "CookieSaveControlAttribute");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "CookieSaveControlAttribute", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "CookieSaveControlAttribute", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::User, "User");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "User", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "User", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type,
        (long) QNetworkRequest::UserMax, "UserMax");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "UserMax", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_Attribute_Type.tp_dict,
        "UserMax", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkRequest::Attribute");

    // init enum class: LoadControl
    SbkPySide_QtNetworkTypes[SBK_QNETWORKREQUEST_LOADCONTROL_IDX] = &SbkPySide_QtNetwork_QNetworkRequest_LoadControl_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkRequest_LoadControl_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QNetworkRequest_LoadControl_Type);
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
            "LoadControl",((PyObject*)&SbkPySide_QtNetwork_QNetworkRequest_LoadControl_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_LoadControl_Type,
        (long) QNetworkRequest::Automatic, "Automatic");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "Automatic", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_LoadControl_Type.tp_dict,
        "Automatic", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkRequest_LoadControl_Type,
        (long) QNetworkRequest::Manual, "Manual");
    PyDict_SetItemString(SbkQNetworkRequest_Type.super.ht_type.tp_dict,
        "Manual", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkRequest_LoadControl_Type.tp_dict,
        "Manual", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkRequest::LoadControl");


    Shiboken::TypeResolver::createValueTypeResolver<QNetworkRequest >("QNetworkRequest");
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkRequest >("QNetworkRequest*");
    Shiboken::TypeResolver::createValueTypeResolver<QNetworkRequest >(typeid(QNetworkRequest).name());
    PySide::initQtMetaType<QNetworkRequest >();
}

