/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qsslkey_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qiodevice.h>
#include <qsslkey.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQSslKey_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QSslKey >()))
        return -1;

    QSslKey* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format", "passPhrase", "type" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslKey(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:QSslKey", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QSslKey()
    // 1: QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
    // 2: QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
    // 3: QSslKey(QSslKey)
    if (numArgs == 0) {
        overloadId = 0; // QSslKey()
    } else if (numArgs == 1 && Shiboken::Converter<const QSslKey & >::isConvertible(pyargs[0])) {
        overloadId = 3; // QSslKey(QSslKey)
    } else if (numArgs >= 2 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0]) && Shiboken::Converter<QSsl::KeyAlgorithm >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
        } else if (Shiboken::Converter<QSsl::EncodingFormat >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 2; // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
            } else if (Shiboken::Converter<QSsl::KeyType >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 2; // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[4])) {
                    overloadId = 2; // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                }
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0]) && Shiboken::Converter<QSsl::KeyAlgorithm >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
        } else if (Shiboken::Converter<QSsl::EncodingFormat >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
            } else if (Shiboken::Converter<QSsl::KeyType >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 1; // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[4])) {
                    overloadId = 1; // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslKey_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSslKey()
            {

                if(!PyErr_Occurred()) {
                // QSslKey()
                cptr = new QSslKey();
                }
                break;
            }
            case 1: // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "format";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "type";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "passPhrase");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "passPhrase";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);
                QSsl::KeyAlgorithm cpp_arg1 = Shiboken::Converter<QSsl::KeyAlgorithm >::toCpp(pyargs[1]);
                QSsl::EncodingFormat cpp_arg2 = pyargs[2] ? Shiboken::Converter<QSsl::EncodingFormat >::toCpp(pyargs[2]) : QSsl::Pem;
                QSsl::KeyType cpp_arg3 = pyargs[3] ? Shiboken::Converter<QSsl::KeyType >::toCpp(pyargs[3]) : QSsl::PrivateKey;
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg4_auto_ptr;
                QByteArray cpp_arg4_tmp = QByteArray();
                QByteArray* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QByteArray* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
                if (pyargs[4] && !Shiboken::Converter<QByteArray >::checkType(pyargs[4]))
                    cpp_arg4_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg4);

                if(!PyErr_Occurred()) {
                // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                cptr = new QSslKey(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, *cpp_arg4);
                }
                break;
            }
            case 2: // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "format";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "type";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "passPhrase");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "passPhrase";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                QSsl::KeyAlgorithm cpp_arg1 = Shiboken::Converter<QSsl::KeyAlgorithm >::toCpp(pyargs[1]);
                QSsl::EncodingFormat cpp_arg2 = pyargs[2] ? Shiboken::Converter<QSsl::EncodingFormat >::toCpp(pyargs[2]) : QSsl::Pem;
                QSsl::KeyType cpp_arg3 = pyargs[3] ? Shiboken::Converter<QSsl::KeyType >::toCpp(pyargs[3]) : QSsl::PrivateKey;
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg4_auto_ptr;
                QByteArray cpp_arg4_tmp = QByteArray();
                QByteArray* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QByteArray* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
                if (pyargs[4] && !Shiboken::Converter<QByteArray >::checkType(pyargs[4]))
                    cpp_arg4_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg4);

                if(!PyErr_Occurred()) {
                // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                cptr = new QSslKey(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, *cpp_arg4);
                }
                break;
            }
            case 3: // QSslKey(QSslKey)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QSslKey* cpp_arg0 = Shiboken::Converter<QSslKey* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QSslKey(QSslKey)
                cptr = new QSslKey(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QSslKey >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQSslKey_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQSslKey_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QIODevice, PySide.QtNetwork.QSsl.KeyAlgorithm, PySide.QtNetwork.QSsl.EncodingFormat = QSsl.Pem, PySide.QtNetwork.QSsl.KeyType = QSsl.PrivateKey, PySide.QtCore.QByteArray = QByteArray()", "PySide.QtCore.QByteArray, PySide.QtNetwork.QSsl.KeyAlgorithm, PySide.QtNetwork.QSsl.EncodingFormat = QSsl.Pem, PySide.QtNetwork.QSsl.KeyType = QSsl.PrivateKey, PySide.QtCore.QByteArray = QByteArray()", "PySide.QtNetwork.QSslKey", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslKey", overloads);
        return -1;
}

static PyObject* SbkQSslKeyFunc_algorithm(PyObject* self)
{
    QSslKey* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // algorithm()const
            QSsl::KeyAlgorithm cppResult = cppSelf->QSslKey::algorithm();
            pyResult = Shiboken::Converter<QSsl::KeyAlgorithm >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslKeyFunc_clear(PyObject* self)
{
    QSslKey* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslKey* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QSslKey::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSslKeyFunc_handle(PyObject* self)
{
    QSslKey* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // handle()const
            Qt::HANDLE cppResult = cppSelf->QSslKey::handle();
            pyResult = Shiboken::Converter<Qt::HANDLE >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslKeyFunc_isNull(PyObject* self)
{
    QSslKey* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QSslKey::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslKeyFunc_length(PyObject* self)
{
    QSslKey* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // length()const
            int cppResult = cppSelf->QSslKey::length();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslKeyFunc_toDer(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslKey* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "passPhrase" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toDer(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toDer(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toDer", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toDer(QByteArray)const
    if (numArgs == 0) {
        overloadId = 0; // toDer(QByteArray)const
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // toDer(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslKeyFunc_toDer_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "passPhrase");
                if (value) {
                    if (arg)
                        errorArgName = "passPhrase";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toDer(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray cpp_arg0_tmp = QByteArray();
            QByteArray* cpp_arg0 = arg ? Shiboken::Converter<QByteArray* >::toCpp(arg) : &cpp_arg0_tmp;
            if (arg && !Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // toDer(QByteArray)const
            QByteArray cppResult = cppSelf->QSslKey::toDer(*cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSslKeyFunc_toDer_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslKey.toDer", overloads);
        return 0;
}

static PyObject* SbkQSslKeyFunc_toPem(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslKey* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "passPhrase" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toPem(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toPem(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toPem", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toPem(QByteArray)const
    if (numArgs == 0) {
        overloadId = 0; // toPem(QByteArray)const
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // toPem(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslKeyFunc_toPem_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "passPhrase");
                if (value) {
                    if (arg)
                        errorArgName = "passPhrase";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toPem(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray cpp_arg0_tmp = QByteArray();
            QByteArray* cpp_arg0 = arg ? Shiboken::Converter<QByteArray* >::toCpp(arg) : &cpp_arg0_tmp;
            if (arg && !Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // toPem(QByteArray)const
            QByteArray cppResult = cppSelf->QSslKey::toPem(*cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSslKeyFunc_toPem_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslKey.toPem", overloads);
        return 0;
}

static PyObject* SbkQSslKeyFunc_type(PyObject* self)
{
    QSslKey* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // type()const
            QSsl::KeyType cppResult = cppSelf->QSslKey::type();
            pyResult = Shiboken::Converter<QSsl::KeyType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQSslKey_methods[] = {
    {"algorithm", (PyCFunction)SbkQSslKeyFunc_algorithm, METH_NOARGS},
    {"clear", (PyCFunction)SbkQSslKeyFunc_clear, METH_NOARGS},
    {"handle", (PyCFunction)SbkQSslKeyFunc_handle, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQSslKeyFunc_isNull, METH_NOARGS},
    {"length", (PyCFunction)SbkQSslKeyFunc_length, METH_NOARGS},
    {"toDer", (PyCFunction)SbkQSslKeyFunc_toDer, METH_VARARGS|METH_KEYWORDS},
    {"toPem", (PyCFunction)SbkQSslKeyFunc_toPem, METH_VARARGS|METH_KEYWORDS},
    {"type", (PyCFunction)SbkQSslKeyFunc_type, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQSslKey_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QSslKey& cpp_self = *Shiboken::Converter<QSslKey* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QSslKey & >::isConvertible(other)) {
                // operator!=(const QSslKey & key) const
                QSslKey* cpp_other = Shiboken::Converter<QSslKey* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QSslKey  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQSslKey_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QSslKey & >::isConvertible(other)) {
                // operator==(const QSslKey & key) const
                QSslKey* cpp_other = Shiboken::Converter<QSslKey* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QSslKey  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQSslKey_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQSslKey_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQSslKey_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QSslKey",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQSslKey_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQSslKey_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQSslKey_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QSslKey >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QSslKey",
    /*user_data*/           0
};
} //extern


void init_QSslKey(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QSSLKEY_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQSslKey_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQSslKey_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQSslKey_Type));
    PyModule_AddObject(module, "QSslKey",
        ((PyObject*)&SbkQSslKey_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QSslKey >("QSslKey");
    Shiboken::TypeResolver::createObjectTypeResolver<QSslKey >("QSslKey*");
    Shiboken::TypeResolver::createValueTypeResolver<QSslKey >(typeid(QSslKey).name());
    PySide::initQtMetaType<QSslKey >();
}

