/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtopengl_python.h"

#include "qglcontext_wrapper.h"

// Extra includes
#include <qcolor.h>
#include <qgl.h>
#include <qimage.h>
#include <qpaintdevice.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qrect.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGLContextWrapper::QGLContextWrapper(const QGLFormat & format) : QGLContext(format) {
    // ... middle
}

QGLContextWrapper::QGLContextWrapper(const QGLFormat & format, QPaintDevice * device) : QGLContext(format, device) {
    // ... middle
}

bool QGLContextWrapper::chooseContext(const QGLContext * shareContext)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "chooseContext"));
    if (py_override.isNull()) {
        return this->QGLContext::chooseContext(shareContext);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QGLContext * >::toPython(shareContext)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLContext.chooseContext", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QGLContextWrapper::create(const QGLContext * shareContext)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "create"));
    if (py_override.isNull()) {
        return this->QGLContext::create(shareContext);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QGLContext * >::toPython(shareContext)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLContext.create", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

void QGLContextWrapper::doneCurrent()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "doneCurrent"));
    if (py_override.isNull()) {
        return this->QGLContext::doneCurrent();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGLContextWrapper::makeCurrent()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "makeCurrent"));
    if (py_override.isNull()) {
        return this->QGLContext::makeCurrent();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGLContextWrapper::swapBuffers() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "swapBuffers"));
    if (py_override.isNull()) {
        return this->QGLContext::swapBuffers();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QGLContextWrapper::~QGLContextWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGLContext_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLContext >()))
        return -1;

    QGLContextWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QGLContext", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QGLContext(QGLFormat)
    // 1: QGLContext(QGLFormat,QPaintDevice*)
    if (Shiboken::Converter<const QGLFormat & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QGLContext(QGLFormat)
        } else if (numArgs == 2 && Shiboken::Converter<QPaintDevice * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QGLContext(QGLFormat,QPaintDevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLContext_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGLContext(QGLFormat)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QGLFormat > cpp_arg0_auto_ptr;
                QGLFormat* cpp_arg0 = Shiboken::Converter<QGLFormat* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QGLFormat >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QGLFormat >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QGLContext(QGLFormat)
                cptr = new QGLContextWrapper(*cpp_arg0);
                }
                break;
            }
            case 1: // QGLContext(QGLFormat,QPaintDevice*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QGLFormat > cpp_arg0_auto_ptr;
                QGLFormat* cpp_arg0 = Shiboken::Converter<QGLFormat* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QGLFormat >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QGLFormat >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QPaintDevice* cpp_arg1 = Shiboken::Converter<QPaintDevice* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QGLContext(QGLFormat,QPaintDevice*)
                cptr = new QGLContextWrapper(*cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGLContext >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGLContext_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQGLContext_Init_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLFormat", "PySide.QtOpenGL.QGLFormat, PySide.QtGui.QPaintDevice", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLContext", overloads);
        return -1;
}

static PyObject* SbkQGLContextFunc_areSharing(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "areSharing", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: areSharing(const QGLContext*,const QGLContext*)
    if (numArgs == 2 && Shiboken::Converter< QGLContext * >::isConvertible(pyargs[0]) && Shiboken::Converter< QGLContext * >::isConvertible(pyargs[1])) {
        overloadId = 0; // areSharing(const QGLContext*,const QGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLContextFunc_areSharing_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QGLContext* cpp_arg0 = Shiboken::Converter<QGLContext* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QGLContext* cpp_arg1 = Shiboken::Converter<QGLContext* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // areSharing(const QGLContext*,const QGLContext*)
            bool cppResult = QGLContext::areSharing(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLContextFunc_areSharing_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLContext, PySide.QtOpenGL.QGLContext", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLContext.areSharing", overloads);
        return 0;
}

static PyObject* SbkQGLContextFunc_bindTexture(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format", "target" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.bindTexture(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.bindTexture(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.bindTexture(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:bindTexture", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: bindTexture(QImage,uint,int)
    // 1: bindTexture(QImage,uint,int,QFlags<QGLContext::BindOption>)
    // 2: bindTexture(QPixmap,uint,int)
    // 3: bindTexture(QPixmap,uint,int,QFlags<QGLContext::BindOption>)
    // 4: bindTexture(QString)
    if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        overloadId = 4; // bindTexture(QString)
    } else if (Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // bindTexture(QPixmap,uint,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // bindTexture(QPixmap,uint,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 2; // bindTexture(QPixmap,uint,int)
                } else if (numArgs == 4 && Shiboken::Converter<QFlags<QGLContext::BindOption> >::isConvertible(pyargs[3])) {
                    overloadId = 3; // bindTexture(QPixmap,uint,int,QFlags<QGLContext::BindOption>)
                }
            }
        }
    } else if (Shiboken::Converter<const QImage & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // bindTexture(QImage,uint,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // bindTexture(QImage,uint,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // bindTexture(QImage,uint,int)
                } else if (numArgs == 4 && Shiboken::Converter<QFlags<QGLContext::BindOption> >::isConvertible(pyargs[3])) {
                    overloadId = 1; // bindTexture(QImage,uint,int,QFlags<QGLContext::BindOption>)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLContextFunc_bindTexture_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // bindTexture(QImage,uint,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "target";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "format";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.bindTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QImage* cpp_arg0 = Shiboken::Converter<QImage* >::toCpp(pyargs[0]);
                unsigned int cpp_arg1 = pyargs[1] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[1]) : 0x0DE1;
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0x1908;

                if(!PyErr_Occurred()) {
                // bindTexture(QImage,uint,int)
                unsigned int cppResult = cppSelf->QGLContext::bindTexture(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 1: // bindTexture(QImage,uint,int,QFlags<QGLContext::BindOption>)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QImage* cpp_arg0 = Shiboken::Converter<QImage* >::toCpp(pyargs[0]);
                unsigned int cpp_arg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                QFlags<QGLContext::BindOption> cpp_arg3 = Shiboken::Converter<QFlags<QGLContext::BindOption> >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // bindTexture(QImage,uint,int,QFlags<QGLContext::BindOption>)
                unsigned int cppResult = cppSelf->QGLContext::bindTexture(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 2: // bindTexture(QPixmap,uint,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "target";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "format";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.bindTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg0_auto_ptr;
                QPixmap* cpp_arg0 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg0);
                unsigned int cpp_arg1 = pyargs[1] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[1]) : 0x0DE1;
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0x1908;

                if(!PyErr_Occurred()) {
                // bindTexture(QPixmap,uint,int)
                unsigned int cppResult = cppSelf->QGLContext::bindTexture(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 3: // bindTexture(QPixmap,uint,int,QFlags<QGLContext::BindOption>)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg0_auto_ptr;
                QPixmap* cpp_arg0 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg0);
                unsigned int cpp_arg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                QFlags<QGLContext::BindOption> cpp_arg3 = Shiboken::Converter<QFlags<QGLContext::BindOption> >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // bindTexture(QPixmap,uint,int,QFlags<QGLContext::BindOption>)
                unsigned int cppResult = cppSelf->QGLContext::bindTexture(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 4: // bindTexture(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // bindTexture(QString)
                unsigned int cppResult = cppSelf->QGLContext::bindTexture(cpp_arg0);
                pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLContextFunc_bindTexture_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage, unsigned int = 0x0DE1, int = 0x1908", "PySide.QtGui.QImage, unsigned int, int, PySide.QtOpenGL.QGLContext.BindOptions", "PySide.QtGui.QPixmap, unsigned int = 0x0DE1, int = 0x1908", "PySide.QtGui.QPixmap, unsigned int, int, PySide.QtOpenGL.QGLContext.BindOptions", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLContext.bindTexture", overloads);
        return 0;
}

static PyObject* SbkQGLContextFunc_chooseContext(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "shareContext" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.chooseContext(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.chooseContext(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:chooseContext", &arg))
        return 0;


    // Overloaded function decisor
    // 0: chooseContext(const QGLContext*)
    if (numArgs == 0) {
        overloadId = 0; // chooseContext(const QGLContext*)
    } else if (Shiboken::Converter< QGLContext * >::isConvertible(arg)) {
        overloadId = 0; // chooseContext(const QGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLContextFunc_chooseContext_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "shareContext");
                if (value) {
                    if (arg)
                        errorArgName = "shareContext";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.chooseContext(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGLContext* cpp_arg0 = arg ? Shiboken::Converter<QGLContext* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // chooseContext(const QGLContext*)
            bool cppResult = cppSelf->QGLContext::chooseContext(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLContextFunc_chooseContext_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLContext = None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.chooseContext", overloads);
        return 0;
}

static PyObject* SbkQGLContextFunc_colorIndex(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: colorIndex(QColor)const
    if (Shiboken::Converter<const QColor & >::isConvertible(arg)) {
        overloadId = 0; // colorIndex(QColor)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLContextFunc_colorIndex_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QColor > cpp_arg0_auto_ptr;
            QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(arg);
            if (!Shiboken::Converter<QColor >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // colorIndex(QColor)const
            uint cppResult = cppSelf->QGLContext::colorIndex(*cpp_arg0);
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLContextFunc_colorIndex_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.colorIndex", overloads);
        return 0;
}

static PyObject* SbkQGLContextFunc_create(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "shareContext" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.create(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.create(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:create", &arg))
        return 0;


    // Overloaded function decisor
    // 0: create(const QGLContext*)
    if (numArgs == 0) {
        overloadId = 0; // create(const QGLContext*)
    } else if (Shiboken::Converter< QGLContext * >::isConvertible(arg)) {
        overloadId = 0; // create(const QGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLContextFunc_create_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "shareContext");
                if (value) {
                    if (arg)
                        errorArgName = "shareContext";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.create(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGLContext* cpp_arg0 = arg ? Shiboken::Converter<QGLContext* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // create(const QGLContext*)
            bool cppResult = cppSelf->QGLContext::create(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLContextFunc_create_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLContext = None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.create", overloads);
        return 0;
}

static PyObject* SbkQGLContextFunc_currentContext(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentContext()
            const QGLContext * cppResult = QGLContext::currentContext();
            pyResult = Shiboken::Converter< QGLContext * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLContextFunc_deleteTexture(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: deleteTexture(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // deleteTexture(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLContextFunc_deleteTexture_TypeError;

    // Call function/method
    {
        {
            unsigned int cpp_arg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // deleteTexture(uint)
            cppSelf->QGLContext::deleteTexture(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLContextFunc_deleteTexture_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.deleteTexture", overloads);
        return 0;
}

static PyObject* SbkQGLContextFunc_device(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // device()const
            QPaintDevice * cppResult = cppSelf->QGLContext::device();
            pyResult = Shiboken::Converter<QPaintDevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLContextFunc_deviceIsPixmap(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // deviceIsPixmap()const
            bool cppResult = cppSelf->QGLContext::deviceIsPixmap();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLContextFunc_doneCurrent(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // doneCurrent()
            cppSelf->QGLContext::doneCurrent();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGLContextFunc_drawTexture(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "textureTarget" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.drawTexture(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.drawTexture(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.drawTexture(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:drawTexture", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: drawTexture(QPointF,uint,uint)
    // 1: drawTexture(QRectF,uint,uint)
    if (numArgs >= 2 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // drawTexture(QRectF,uint,uint)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 1; // drawTexture(QRectF,uint,uint)
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // drawTexture(QPointF,uint,uint)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // drawTexture(QPointF,uint,uint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLContextFunc_drawTexture_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawTexture(QPointF,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "textureTarget");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "textureTarget";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.drawTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                unsigned int cpp_arg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                unsigned int cpp_arg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                // drawTexture(QPointF,uint,uint)
                cppSelf->QGLContext::drawTexture(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // drawTexture(QRectF,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "textureTarget");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "textureTarget";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.drawTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                unsigned int cpp_arg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                unsigned int cpp_arg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                // drawTexture(QRectF,uint,uint)
                cppSelf->QGLContext::drawTexture(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLContextFunc_drawTexture_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, unsigned int, unsigned int = 0x0DE1", "PySide.QtCore.QRectF, unsigned int, unsigned int = 0x0DE1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLContext.drawTexture", overloads);
        return 0;
}

static PyObject* SbkQGLContextFunc_format(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // format()const
            QGLFormat cppResult = cppSelf->QGLContext::format();
            pyResult = Shiboken::Converter<QGLFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLContextFunc_initialized(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // initialized()const
            bool cppResult = cppSelf->QGLContext::initialized();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLContextFunc_isSharing(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSharing()const
            bool cppResult = cppSelf->QGLContext::isSharing();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLContextFunc_isValid(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QGLContext::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLContextFunc_makeCurrent(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // makeCurrent()
            cppSelf->QGLContext::makeCurrent();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGLContextFunc_overlayTransparentColor(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // overlayTransparentColor()const
            QColor cppResult = cppSelf->QGLContext::overlayTransparentColor();
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLContextFunc_requestedFormat(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // requestedFormat()const
            QGLFormat cppResult = cppSelf->QGLContext::requestedFormat();
            pyResult = Shiboken::Converter<QGLFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLContextFunc_reset(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reset()
            cppSelf->QGLContext::reset();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGLContextFunc_setFormat(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFormat(QGLFormat)
    if (Shiboken::Converter<const QGLFormat & >::isConvertible(arg)) {
        overloadId = 0; // setFormat(QGLFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLContextFunc_setFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QGLFormat > cpp_arg0_auto_ptr;
            QGLFormat* cpp_arg0 = Shiboken::Converter<QGLFormat* >::toCpp(arg);
            if (!Shiboken::Converter<QGLFormat >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QGLFormat >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setFormat(QGLFormat)
            cppSelf->QGLContext::setFormat(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLContextFunc_setFormat_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.setFormat", overloads);
        return 0;
}

static PyObject* SbkQGLContextFunc_setInitialized(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInitialized(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setInitialized(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLContextFunc_setInitialized_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setInitialized(bool)
            cppSelf->QGLContext::setInitialized(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLContextFunc_setInitialized_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.setInitialized", overloads);
        return 0;
}

static PyObject* SbkQGLContextFunc_setTextureCacheLimit(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextureCacheLimit(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTextureCacheLimit(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLContextFunc_setTextureCacheLimit_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTextureCacheLimit(int)
            QGLContext::setTextureCacheLimit(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLContextFunc_setTextureCacheLimit_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.setTextureCacheLimit", overloads);
        return 0;
}

static PyObject* SbkQGLContextFunc_setValid(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setValid(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setValid(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLContextFunc_setValid_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setValid(bool)
            cppSelf->QGLContext::setValid(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLContextFunc_setValid_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.setValid", overloads);
        return 0;
}

static PyObject* SbkQGLContextFunc_setWindowCreated(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowCreated(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWindowCreated(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLContextFunc_setWindowCreated_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWindowCreated(bool)
            cppSelf->QGLContext::setWindowCreated(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLContextFunc_setWindowCreated_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.setWindowCreated", overloads);
        return 0;
}

static PyObject* SbkQGLContextFunc_swapBuffers(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // swapBuffers()const
            cppSelf->QGLContext::swapBuffers();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGLContextFunc_textureCacheLimit(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textureCacheLimit()
            int cppResult = QGLContext::textureCacheLimit();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLContextFunc_windowCreated(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // windowCreated()const
            bool cppResult = cppSelf->QGLContext::windowCreated();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQGLContext_methods[] = {
    {"areSharing", (PyCFunction)SbkQGLContextFunc_areSharing, METH_VARARGS|METH_STATIC},
    {"bindTexture", (PyCFunction)SbkQGLContextFunc_bindTexture, METH_VARARGS|METH_KEYWORDS},
    {"chooseContext", (PyCFunction)SbkQGLContextFunc_chooseContext, METH_VARARGS|METH_KEYWORDS},
    {"colorIndex", (PyCFunction)SbkQGLContextFunc_colorIndex, METH_O},
    {"create", (PyCFunction)SbkQGLContextFunc_create, METH_VARARGS|METH_KEYWORDS},
    {"currentContext", (PyCFunction)SbkQGLContextFunc_currentContext, METH_NOARGS|METH_STATIC},
    {"deleteTexture", (PyCFunction)SbkQGLContextFunc_deleteTexture, METH_O},
    {"device", (PyCFunction)SbkQGLContextFunc_device, METH_NOARGS},
    {"deviceIsPixmap", (PyCFunction)SbkQGLContextFunc_deviceIsPixmap, METH_NOARGS},
    {"doneCurrent", (PyCFunction)SbkQGLContextFunc_doneCurrent, METH_NOARGS},
    {"drawTexture", (PyCFunction)SbkQGLContextFunc_drawTexture, METH_VARARGS|METH_KEYWORDS},
    {"format", (PyCFunction)SbkQGLContextFunc_format, METH_NOARGS},
    {"initialized", (PyCFunction)SbkQGLContextFunc_initialized, METH_NOARGS},
    {"isSharing", (PyCFunction)SbkQGLContextFunc_isSharing, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQGLContextFunc_isValid, METH_NOARGS},
    {"makeCurrent", (PyCFunction)SbkQGLContextFunc_makeCurrent, METH_NOARGS},
    {"overlayTransparentColor", (PyCFunction)SbkQGLContextFunc_overlayTransparentColor, METH_NOARGS},
    {"requestedFormat", (PyCFunction)SbkQGLContextFunc_requestedFormat, METH_NOARGS},
    {"reset", (PyCFunction)SbkQGLContextFunc_reset, METH_NOARGS},
    {"setFormat", (PyCFunction)SbkQGLContextFunc_setFormat, METH_O},
    {"setInitialized", (PyCFunction)SbkQGLContextFunc_setInitialized, METH_O},
    {"setTextureCacheLimit", (PyCFunction)SbkQGLContextFunc_setTextureCacheLimit, METH_O|METH_STATIC},
    {"setValid", (PyCFunction)SbkQGLContextFunc_setValid, METH_O},
    {"setWindowCreated", (PyCFunction)SbkQGLContextFunc_setWindowCreated, METH_O},
    {"swapBuffers", (PyCFunction)SbkQGLContextFunc_swapBuffers, METH_NOARGS},
    {"textureCacheLimit", (PyCFunction)SbkQGLContextFunc_textureCacheLimit, METH_NOARGS|METH_STATIC},
    {"windowCreated", (PyCFunction)SbkQGLContextFunc_windowCreated, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGLContext_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLContext",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGLContext_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGLContext_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGLContext >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGLContext*",
    /*user_data*/           0
};
} //extern

PyObject* SbkPySide_QtOpenGL_QGLContext_BindOption___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGLContext::BindOptions >::checkType(self) && Shiboken::Converter<QGLContext::BindOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGLContext::BindOptions >::toPython(
        Shiboken::Converter<QGLContext::BindOptions>::toCpp(self)
        & Shiboken::Converter< QGLContext::BindOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLContext_BindOption___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGLContext::BindOptions >::checkType(self) && Shiboken::Converter<QGLContext::BindOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGLContext::BindOptions >::toPython(
        Shiboken::Converter<QGLContext::BindOptions>::toCpp(self)
        | Shiboken::Converter< QGLContext::BindOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLContext_BindOption___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGLContext::BindOptions >::checkType(self) && Shiboken::Converter<QGLContext::BindOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGLContext::BindOptions >::toPython(
        Shiboken::Converter<QGLContext::BindOptions>::toCpp(self)
        ^ Shiboken::Converter< QGLContext::BindOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLContext_BindOption___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLContext::BindOptions >::toPython(
        ~Shiboken::Converter<QGLContext::BindOptions >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtOpenGL_QGLContext_BindOption_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtOpenGL_QGLContext_BindOption___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtOpenGL_QGLContext_BindOption___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtOpenGL_QGLContext_BindOption___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtOpenGL_QGLContext_BindOption___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtOpenGL_QGLContext_BindOption_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtOpenGL_QGLContext_BindOption_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtOpenGL_QGLContext_BindOption_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "BindOption",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtOpenGL_QGLContext_BindOption_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtOpenGL_QGLContext_BindOption_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtOpenGL_QGLContext_BindOption_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtOpenGL_QGLContext_BindOption_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtOpenGL_QGLContext_BindOptions_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "BindOptions",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtOpenGL_QGLContext_BindOption_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QGLContext(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLCONTEXT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGLContext_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQGLContext_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGLContext_Type));
    PyModule_AddObject(module, "QGLContext",
        ((PyObject*)&SbkQGLContext_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: BindOption
    SbkPySide_QtOpenGLTypes[SBK_QGLCONTEXT_BINDOPTION_IDX] = &SbkPySide_QtOpenGL_QGLContext_BindOption_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtOpenGL_QGLContext_BindOption_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtOpenGL_QGLContext_BindOption_Type);
    PyDict_SetItemString(SbkQGLContext_Type.super.ht_type.tp_dict,
            "BindOption",((PyObject*)&SbkPySide_QtOpenGL_QGLContext_BindOption_Type));

    // init flags class: QFlags<QGLContext::BindOption>
    SbkPySide_QtOpenGLTypes[SBK_QFLAGS_QGLCONTEXT_BINDOPTION__IDX] = &SbkPySide_QtOpenGL_QGLContext_BindOptions_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtOpenGL_QGLContext_BindOptions_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtOpenGL_QGLContext_BindOptions_Type);
    PyDict_SetItemString(SbkQGLContext_Type.super.ht_type.tp_dict,
            "BindOptions",((PyObject*)&SbkPySide_QtOpenGL_QGLContext_BindOptions_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLContext_BindOption_Type,
        (long) QGLContext::NoBindOption, "NoBindOption");
    PyDict_SetItemString(SbkQGLContext_Type.super.ht_type.tp_dict,
        "NoBindOption", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption_Type.tp_dict,
        "NoBindOption", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLContext_BindOption_Type,
        (long) QGLContext::InvertedYBindOption, "InvertedYBindOption");
    PyDict_SetItemString(SbkQGLContext_Type.super.ht_type.tp_dict,
        "InvertedYBindOption", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption_Type.tp_dict,
        "InvertedYBindOption", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLContext_BindOption_Type,
        (long) QGLContext::MipmapBindOption, "MipmapBindOption");
    PyDict_SetItemString(SbkQGLContext_Type.super.ht_type.tp_dict,
        "MipmapBindOption", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption_Type.tp_dict,
        "MipmapBindOption", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLContext_BindOption_Type,
        (long) QGLContext::PremultipliedAlphaBindOption, "PremultipliedAlphaBindOption");
    PyDict_SetItemString(SbkQGLContext_Type.super.ht_type.tp_dict,
        "PremultipliedAlphaBindOption", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption_Type.tp_dict,
        "PremultipliedAlphaBindOption", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLContext_BindOption_Type,
        (long) QGLContext::LinearFilteringBindOption, "LinearFilteringBindOption");
    PyDict_SetItemString(SbkQGLContext_Type.super.ht_type.tp_dict,
        "LinearFilteringBindOption", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption_Type.tp_dict,
        "LinearFilteringBindOption", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLContext_BindOption_Type,
        (long) QGLContext::MemoryManagedBindOption, "MemoryManagedBindOption");
    PyDict_SetItemString(SbkQGLContext_Type.super.ht_type.tp_dict,
        "MemoryManagedBindOption", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption_Type.tp_dict,
        "MemoryManagedBindOption", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLContext_BindOption_Type,
        (long) QGLContext::CanFlipNativePixmapBindOption, "CanFlipNativePixmapBindOption");
    PyDict_SetItemString(SbkQGLContext_Type.super.ht_type.tp_dict,
        "CanFlipNativePixmapBindOption", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption_Type.tp_dict,
        "CanFlipNativePixmapBindOption", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLContext_BindOption_Type,
        (long) QGLContext::DefaultBindOption, "DefaultBindOption");
    PyDict_SetItemString(SbkQGLContext_Type.super.ht_type.tp_dict,
        "DefaultBindOption", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption_Type.tp_dict,
        "DefaultBindOption", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLContext_BindOption_Type,
        (long) QGLContext::InternalBindOption, "InternalBindOption");
    PyDict_SetItemString(SbkQGLContext_Type.super.ht_type.tp_dict,
        "InternalBindOption", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption_Type.tp_dict,
        "InternalBindOption", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGLContext::BindOption");


    Shiboken::TypeResolver::createObjectTypeResolver<QGLContext >("QGLContext*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLContext >(typeid(QGLContext).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGLContext >(typeid(QGLContextWrapper).name());
    PySide::initQtMetaType<QGLContext* >();
}

