/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtscript_python.h"

#include "qscriptengineagent_wrapper.h"

// Extra includes
#include <qscriptengine.h>
#include <qscriptengineagent.h>
#include <qscriptvalue.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QScriptEngineAgentWrapper::QScriptEngineAgentWrapper(QScriptEngine * engine) : QScriptEngineAgent(engine) {
    // ... middle
}

void QScriptEngineAgentWrapper::contextPop()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contextPop"));
    if (py_override.isNull()) {
        return this->QScriptEngineAgent::contextPop();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QScriptEngineAgentWrapper::contextPush()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contextPush"));
    if (py_override.isNull()) {
        return this->QScriptEngineAgent::contextPush();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QScriptEngineAgentWrapper::exceptionCatch(qint64 scriptId, const QScriptValue & exception)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "exceptionCatch"));
    if (py_override.isNull()) {
        return this->QScriptEngineAgent::exceptionCatch(scriptId, exception);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(LN)",
        Shiboken::Converter<long long >::toPython(scriptId),
        Shiboken::Converter<const QScriptValue & >::toPython(exception)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QScriptEngineAgentWrapper::exceptionThrow(qint64 scriptId, const QScriptValue & exception, bool hasHandler)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "exceptionThrow"));
    if (py_override.isNull()) {
        return this->QScriptEngineAgent::exceptionThrow(scriptId, exception, hasHandler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(LNN)",
        Shiboken::Converter<long long >::toPython(scriptId),
        Shiboken::Converter<const QScriptValue & >::toPython(exception),
        Shiboken::Converter<bool >::toPython(hasHandler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QVariant QScriptEngineAgentWrapper::extension(QScriptEngineAgent::Extension extension, const QVariant & argument)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "extension"));
    if (py_override.isNull()) {
        return this->QScriptEngineAgent::extension(extension, argument);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QScriptEngineAgent::Extension >::toPython(extension),
        Shiboken::Converter<QVariant >::toPython(argument)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptEngineAgent.extension", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QScriptEngineAgentWrapper::functionEntry(qint64 scriptId)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "functionEntry"));
    if (py_override.isNull()) {
        return this->QScriptEngineAgent::functionEntry(scriptId);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        Shiboken::Converter<long long >::toPython(scriptId)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QScriptEngineAgentWrapper::functionExit(qint64 scriptId, const QScriptValue & returnValue)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "functionExit"));
    if (py_override.isNull()) {
        return this->QScriptEngineAgent::functionExit(scriptId, returnValue);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(LN)",
        Shiboken::Converter<long long >::toPython(scriptId),
        Shiboken::Converter<const QScriptValue & >::toPython(returnValue)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QScriptEngineAgentWrapper::positionChange(qint64 scriptId, int lineNumber, int columnNumber)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "positionChange"));
    if (py_override.isNull()) {
        return this->QScriptEngineAgent::positionChange(scriptId, lineNumber, columnNumber);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Lii)",
        Shiboken::Converter<long long >::toPython(scriptId),
        lineNumber,
        columnNumber
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QScriptEngineAgentWrapper::scriptLoad(qint64 id, const QString & program, const QString & fileName, int baseLineNumber)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "scriptLoad"));
    if (py_override.isNull()) {
        return this->QScriptEngineAgent::scriptLoad(id, program, fileName, baseLineNumber);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(LNNi)",
        Shiboken::Converter<long long >::toPython(id),
        Shiboken::Converter<QString >::toPython(program),
        Shiboken::Converter<QString >::toPython(fileName),
        baseLineNumber
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QScriptEngineAgentWrapper::scriptUnload(qint64 id)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "scriptUnload"));
    if (py_override.isNull()) {
        return this->QScriptEngineAgent::scriptUnload(id);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        Shiboken::Converter<long long >::toPython(id)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QScriptEngineAgentWrapper::supportsExtension(QScriptEngineAgent::Extension extension) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "supportsExtension"));
    if (py_override.isNull()) {
        return this->QScriptEngineAgent::supportsExtension(extension);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QScriptEngineAgent::Extension >::toPython(extension)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptEngineAgent.supportsExtension", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QScriptEngineAgentWrapper::~QScriptEngineAgentWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQScriptEngineAgent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QScriptEngineAgent >()))
        return -1;

    QScriptEngineAgentWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QScriptEngineAgent", 1, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QScriptEngineAgent(QScriptEngine*)
    if (numArgs == 1 && Shiboken::Converter<QScriptEngine * >::isConvertible(arg)) {
        overloadId = 0; // QScriptEngineAgent(QScriptEngine*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineAgent_Init_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QScriptEngine* cpp_arg0 = Shiboken::Converter<QScriptEngine* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // QScriptEngineAgent(QScriptEngine*)
            cptr = new QScriptEngineAgentWrapper(cpp_arg0);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QScriptEngineAgent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQScriptEngineAgent_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQScriptEngineAgent_Init_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptEngine", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent", overloads);
        return -1;
}

static PyObject* SbkQScriptEngineAgentFunc_contextPop(PyObject* self)
{
    QScriptEngineAgent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineAgent* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // contextPop()
            cppSelf->QScriptEngineAgent::contextPop();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQScriptEngineAgentFunc_contextPush(PyObject* self)
{
    QScriptEngineAgent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineAgent* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // contextPush()
            cppSelf->QScriptEngineAgent::contextPush();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQScriptEngineAgentFunc_engine(PyObject* self)
{
    QScriptEngineAgent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineAgent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // engine()const
            QScriptEngine * cppResult = cppSelf->QScriptEngineAgent::engine();
            pyResult = Shiboken::Converter<QScriptEngine * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineAgentFunc_exceptionCatch(PyObject* self, PyObject* args)
{
    QScriptEngineAgent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "exceptionCatch", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: exceptionCatch(qint64,QScriptValue)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[1])) {
        overloadId = 0; // exceptionCatch(qint64,QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineAgentFunc_exceptionCatch_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg1_auto_ptr;
            QScriptValue* cpp_arg1 = Shiboken::Converter<QScriptValue* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QScriptValue >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // exceptionCatch(qint64,QScriptValue)
            cppSelf->QScriptEngineAgent::exceptionCatch(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineAgentFunc_exceptionCatch_TypeError:
        const char* overloads[] = {"long long, PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent.exceptionCatch", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineAgentFunc_exceptionThrow(PyObject* self, PyObject* args)
{
    QScriptEngineAgent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "exceptionThrow", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: exceptionThrow(qint64,QScriptValue,bool)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // exceptionThrow(qint64,QScriptValue,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineAgentFunc_exceptionThrow_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg1_auto_ptr;
            QScriptValue* cpp_arg1 = Shiboken::Converter<QScriptValue* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QScriptValue >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg1);
            bool cpp_arg2 = Shiboken::Converter<bool >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // exceptionThrow(qint64,QScriptValue,bool)
            cppSelf->QScriptEngineAgent::exceptionThrow(cpp_arg0, *cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineAgentFunc_exceptionThrow_TypeError:
        const char* overloads[] = {"long long, PySide.QtScript.QScriptValue, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent.exceptionThrow", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineAgentFunc_extension(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngineAgent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineAgent* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "argument" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngineAgent.extension(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngineAgent.extension(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngineAgent.extension(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:extension", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: extension(QScriptEngineAgent::Extension,QVariant)
    if (Shiboken::Converter<QScriptEngineAgent::Extension >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // extension(QScriptEngineAgent::Extension,QVariant)
        } else if (Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
            overloadId = 0; // extension(QScriptEngineAgent::Extension,QVariant)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineAgentFunc_extension_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "argument");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "argument";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngineAgent.extension(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QScriptEngineAgent::Extension cpp_arg0 = Shiboken::Converter<QScriptEngineAgent::Extension >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = pyargs[1] ? Shiboken::Converter<QVariant >::toCpp(pyargs[1]) : QVariant();

            if(!PyErr_Occurred()) {
            // extension(QScriptEngineAgent::Extension,QVariant)
            QVariant cppResult = cppSelf->QScriptEngineAgent::extension(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineAgentFunc_extension_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptEngineAgent.Extension, QVariant = QVariant()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent.extension", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineAgentFunc_functionEntry(PyObject* self, PyObject* arg)
{
    QScriptEngineAgent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: functionEntry(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // functionEntry(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineAgentFunc_functionEntry_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // functionEntry(qint64)
            cppSelf->QScriptEngineAgent::functionEntry(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineAgentFunc_functionEntry_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngineAgent.functionEntry", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineAgentFunc_functionExit(PyObject* self, PyObject* args)
{
    QScriptEngineAgent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "functionExit", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: functionExit(qint64,QScriptValue)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[1])) {
        overloadId = 0; // functionExit(qint64,QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineAgentFunc_functionExit_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg1_auto_ptr;
            QScriptValue* cpp_arg1 = Shiboken::Converter<QScriptValue* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QScriptValue >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // functionExit(qint64,QScriptValue)
            cppSelf->QScriptEngineAgent::functionExit(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineAgentFunc_functionExit_TypeError:
        const char* overloads[] = {"long long, PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent.functionExit", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineAgentFunc_positionChange(PyObject* self, PyObject* args)
{
    QScriptEngineAgent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "positionChange", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: positionChange(qint64,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // positionChange(qint64,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineAgentFunc_positionChange_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // positionChange(qint64,int,int)
            cppSelf->QScriptEngineAgent::positionChange(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineAgentFunc_positionChange_TypeError:
        const char* overloads[] = {"long long, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent.positionChange", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineAgentFunc_scriptLoad(PyObject* self, PyObject* args)
{
    QScriptEngineAgent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scriptLoad", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: scriptLoad(qint64,QString,QString,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // scriptLoad(qint64,QString,QString,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineAgentFunc_scriptLoad_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
            int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // scriptLoad(qint64,QString,QString,int)
            cppSelf->QScriptEngineAgent::scriptLoad(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineAgentFunc_scriptLoad_TypeError:
        const char* overloads[] = {"long long, QString, QString, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent.scriptLoad", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineAgentFunc_scriptUnload(PyObject* self, PyObject* arg)
{
    QScriptEngineAgent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: scriptUnload(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // scriptUnload(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineAgentFunc_scriptUnload_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // scriptUnload(qint64)
            cppSelf->QScriptEngineAgent::scriptUnload(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineAgentFunc_scriptUnload_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngineAgent.scriptUnload", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineAgentFunc_supportsExtension(PyObject* self, PyObject* arg)
{
    QScriptEngineAgent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineAgent* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: supportsExtension(QScriptEngineAgent::Extension)const
    if (Shiboken::Converter<QScriptEngineAgent::Extension >::isConvertible(arg)) {
        overloadId = 0; // supportsExtension(QScriptEngineAgent::Extension)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineAgentFunc_supportsExtension_TypeError;

    // Call function/method
    {
        {
            QScriptEngineAgent::Extension cpp_arg0 = Shiboken::Converter<QScriptEngineAgent::Extension >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // supportsExtension(QScriptEngineAgent::Extension)const
            bool cppResult = cppSelf->QScriptEngineAgent::supportsExtension(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineAgentFunc_supportsExtension_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptEngineAgent.Extension", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngineAgent.supportsExtension", overloads);
        return 0;
}

static PyMethodDef SbkQScriptEngineAgent_methods[] = {
    {"contextPop", (PyCFunction)SbkQScriptEngineAgentFunc_contextPop, METH_NOARGS},
    {"contextPush", (PyCFunction)SbkQScriptEngineAgentFunc_contextPush, METH_NOARGS},
    {"engine", (PyCFunction)SbkQScriptEngineAgentFunc_engine, METH_NOARGS},
    {"exceptionCatch", (PyCFunction)SbkQScriptEngineAgentFunc_exceptionCatch, METH_VARARGS},
    {"exceptionThrow", (PyCFunction)SbkQScriptEngineAgentFunc_exceptionThrow, METH_VARARGS},
    {"extension", (PyCFunction)SbkQScriptEngineAgentFunc_extension, METH_VARARGS|METH_KEYWORDS},
    {"functionEntry", (PyCFunction)SbkQScriptEngineAgentFunc_functionEntry, METH_O},
    {"functionExit", (PyCFunction)SbkQScriptEngineAgentFunc_functionExit, METH_VARARGS},
    {"positionChange", (PyCFunction)SbkQScriptEngineAgentFunc_positionChange, METH_VARARGS},
    {"scriptLoad", (PyCFunction)SbkQScriptEngineAgentFunc_scriptLoad, METH_VARARGS},
    {"scriptUnload", (PyCFunction)SbkQScriptEngineAgentFunc_scriptUnload, METH_O},
    {"supportsExtension", (PyCFunction)SbkQScriptEngineAgentFunc_supportsExtension, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQScriptEngineAgent_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtScript.QScriptEngineAgent",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQScriptEngineAgent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQScriptEngineAgent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QScriptEngineAgent >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QScriptEngineAgent*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtScript_QScriptEngineAgent_Extension_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtScript_QScriptEngineAgent_Extension_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtScript_QScriptEngineAgent_Extension_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Extension",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtScript_QScriptEngineAgent_Extension_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtScript_QScriptEngineAgent_Extension_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtScript_QScriptEngineAgent_Extension_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QScriptEngineAgent(PyObject* module)
{
    SbkPySide_QtScriptTypes[SBK_QSCRIPTENGINEAGENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQScriptEngineAgent_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQScriptEngineAgent_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQScriptEngineAgent_Type));
    PyModule_AddObject(module, "QScriptEngineAgent",
        ((PyObject*)&SbkQScriptEngineAgent_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Extension
    SbkPySide_QtScriptTypes[SBK_QSCRIPTENGINEAGENT_EXTENSION_IDX] = &SbkPySide_QtScript_QScriptEngineAgent_Extension_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtScript_QScriptEngineAgent_Extension_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtScript_QScriptEngineAgent_Extension_Type);
    PyDict_SetItemString(SbkQScriptEngineAgent_Type.super.ht_type.tp_dict,
            "Extension",((PyObject*)&SbkPySide_QtScript_QScriptEngineAgent_Extension_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptEngineAgent_Extension_Type,
        (long) QScriptEngineAgent::DebuggerInvocationRequest, "DebuggerInvocationRequest");
    PyDict_SetItemString(SbkQScriptEngineAgent_Type.super.ht_type.tp_dict,
        "DebuggerInvocationRequest", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngineAgent_Extension_Type.tp_dict,
        "DebuggerInvocationRequest", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptEngineAgent::Extension");


    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngineAgent >("QScriptEngineAgent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngineAgent >(typeid(QScriptEngineAgent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngineAgent >(typeid(QScriptEngineAgentWrapper).name());
    PySide::initQtMetaType<QScriptEngineAgent* >();
}

