/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtsql_python.h"

#include "qsqlquery_wrapper.h"

// Extra includes
#include <QMap>
#include <QSize>
#include <QSqlError>
#include <QSqlRecord>
#include <QStringList>
#include <qsqldatabase.h>
#include <qsqldriver.h>
#include <qsqlerror.h>
#include <qsqlquery.h>
#include <qsqlrecord.h>
#include <qsqlresult.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQSqlQuery_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QSqlQuery >()))
        return -1;

    QSqlQuery* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "db", "query" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlQuery(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlQuery(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QSqlQuery", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QSqlQuery(QSqlDatabase)
    // 1: QSqlQuery(QSqlResult*)
    // 2: QSqlQuery(QSqlQuery)
    // 3: QSqlQuery(QString,QSqlDatabase)
    if (numArgs == 0) {
        overloadId = 3; // QSqlQuery(QString,QSqlDatabase)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QSqlQuery(QString,QSqlDatabase)
        } else if (Shiboken::Converter<QSqlDatabase >::isConvertible(pyargs[1])) {
            overloadId = 3; // QSqlQuery(QString,QSqlDatabase)
        }
    } else if (numArgs == 1 && Shiboken::Converter<QSqlResult * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QSqlQuery(QSqlResult*)
    } else if (numArgs == 1 && Shiboken::Converter<const QSqlQuery & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QSqlQuery(QSqlQuery)
    } else if (numArgs == 1 && Shiboken::Converter<QSqlDatabase >::isConvertible(pyargs[0])) {
        overloadId = 0; // QSqlQuery(QSqlDatabase)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlQuery_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSqlQuery(QSqlDatabase)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QSqlDatabase* cpp_arg0 = Shiboken::Converter<QSqlDatabase* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QSqlQuery(QSqlDatabase)
                cptr = new QSqlQuery(*cpp_arg0);
                }
                break;
            }
            case 1: // QSqlQuery(QSqlResult*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QSqlResult* cpp_arg0 = Shiboken::Converter<QSqlResult* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QSqlQuery(QSqlResult*)
                cptr = new QSqlQuery(cpp_arg0);
                }
                break;
            }
            case 2: // QSqlQuery(QSqlQuery)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QSqlQuery > cpp_arg0_auto_ptr;
                QSqlQuery* cpp_arg0 = Shiboken::Converter<QSqlQuery* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QSqlQuery >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QSqlQuery >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QSqlQuery(QSqlQuery)
                cptr = new QSqlQuery(*cpp_arg0);
                }
                break;
            }
            case 3: // QSqlQuery(QString,QSqlDatabase)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "query");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "query";
                        else
                            pyargs[0] = value;
                    }
                    value = PyDict_GetItemString(kwds, "db");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "db";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlQuery(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QSqlDatabase cpp_arg1_tmp = QSqlDatabase();
                QSqlDatabase* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QSqlDatabase* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;

                if(!PyErr_Occurred()) {
                // QSqlQuery(QString,QSqlDatabase)
                cptr = new QSqlQuery(cpp_arg0, *cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QSqlQuery >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQSqlQuery_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQSqlQuery_Init_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlDatabase", "PySide.QtSql.QSqlResult", "PySide.QtSql.QSqlQuery", "QString = QString(), PySide.QtSql.QSqlDatabase = QSqlDatabase()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlQuery", overloads);
        return -1;
}

static PyObject* SbkQSqlQueryFunc_addBindValue(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "type" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlQuery.addBindValue(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlQuery.addBindValue(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlQuery.addBindValue(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:addBindValue", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addBindValue(QVariant,QFlags<QSql::ParamTypeFlag>)
    if (Shiboken::Converter<QVariant >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addBindValue(QVariant,QFlags<QSql::ParamTypeFlag>)
        } else if (Shiboken::Converter<QFlags<QSql::ParamTypeFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // addBindValue(QVariant,QFlags<QSql::ParamTypeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlQueryFunc_addBindValue_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "type";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlQuery.addBindValue(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QVariant cpp_arg0 = Shiboken::Converter<QVariant >::toCpp(pyargs[0]);
            QFlags<QSql::ParamTypeFlag> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<QSql::ParamTypeFlag> >::toCpp(pyargs[1]) : QSql::In;

            if(!PyErr_Occurred()) {
            // addBindValue(QVariant,QFlags<QSql::ParamTypeFlag>)
            cppSelf->QSqlQuery::addBindValue(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlQueryFunc_addBindValue_TypeError:
        const char* overloads[] = {"QVariant, PySide.QtSql.QSql.ParamType = QSql.In", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlQuery.addBindValue", overloads);
        return 0;
}

static PyObject* SbkQSqlQueryFunc_at(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // at()const
            int cppResult = cppSelf->QSqlQuery::at();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_bindValue(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "type" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlQuery.bindValue(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlQuery.bindValue(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlQuery.bindValue(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:bindValue", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: bindValue(QString,QVariant,QFlags<QSql::ParamTypeFlag>)
    // 1: bindValue(int,QVariant,QFlags<QSql::ParamTypeFlag>)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // bindValue(int,QVariant,QFlags<QSql::ParamTypeFlag>)
        } else if (Shiboken::Converter<QFlags<QSql::ParamTypeFlag> >::isConvertible(pyargs[2])) {
            overloadId = 1; // bindValue(int,QVariant,QFlags<QSql::ParamTypeFlag>)
        }
    } else if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // bindValue(QString,QVariant,QFlags<QSql::ParamTypeFlag>)
        } else if (Shiboken::Converter<QFlags<QSql::ParamTypeFlag> >::isConvertible(pyargs[2])) {
            overloadId = 0; // bindValue(QString,QVariant,QFlags<QSql::ParamTypeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlQueryFunc_bindValue_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // bindValue(QString,QVariant,QFlags<QSql::ParamTypeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "type";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlQuery.bindValue(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);
                QFlags<QSql::ParamTypeFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<QSql::ParamTypeFlag> >::toCpp(pyargs[2]) : QSql::In;

                if(!PyErr_Occurred()) {
                // bindValue(QString,QVariant,QFlags<QSql::ParamTypeFlag>)
                cppSelf->QSqlQuery::bindValue(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // bindValue(int,QVariant,QFlags<QSql::ParamTypeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "type";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlQuery.bindValue(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);
                QFlags<QSql::ParamTypeFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<QSql::ParamTypeFlag> >::toCpp(pyargs[2]) : QSql::In;

                if(!PyErr_Occurred()) {
                // bindValue(int,QVariant,QFlags<QSql::ParamTypeFlag>)
                cppSelf->QSqlQuery::bindValue(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlQueryFunc_bindValue_TypeError:
        const char* overloads[] = {"QString, QVariant, PySide.QtSql.QSql.ParamType = QSql.In", "int, QVariant, PySide.QtSql.QSql.ParamType = QSql.In", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlQuery.bindValue", overloads);
        return 0;
}

static PyObject* SbkQSqlQueryFunc_boundValue(PyObject* self, PyObject* arg)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: boundValue(QString)const
    // 1: boundValue(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // boundValue(int)const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // boundValue(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlQueryFunc_boundValue_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // boundValue(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // boundValue(QString)const
                QVariant cppResult = cppSelf->QSqlQuery::boundValue(cpp_arg0);
                pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
                }
                break;
            }
            case 1: // boundValue(int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // boundValue(int)const
                QVariant cppResult = cppSelf->QSqlQuery::boundValue(cpp_arg0);
                pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlQueryFunc_boundValue_TypeError:
        const char* overloads[] = {"QString", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlQuery.boundValue", overloads);
        return 0;
}

static PyObject* SbkQSqlQueryFunc_boundValues(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // boundValues()const
            QMap<QString, QVariant > cppResult = cppSelf->QSqlQuery::boundValues();
            pyResult = Shiboken::Converter<QMap<QString, QVariant > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_clear(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);


    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // clear()
            threadStateSaver.save();
            cppSelf->QSqlQuery::clear();
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSqlQueryFunc_driver(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // driver()const
            const QSqlDriver * cppResult = cppSelf->QSqlQuery::driver();
            pyResult = Shiboken::Converter<const QSqlDriver * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_execBatch(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlQuery.execBatch(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlQuery.execBatch(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:execBatch", &arg))
        return 0;


    // Overloaded function decisor
    // 0: execBatch(QSqlQuery::BatchExecutionMode)
    if (numArgs == 0) {
        overloadId = 0; // execBatch(QSqlQuery::BatchExecutionMode)
    } else if (Shiboken::Converter<QSqlQuery::BatchExecutionMode >::isConvertible(arg)) {
        overloadId = 0; // execBatch(QSqlQuery::BatchExecutionMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlQueryFunc_execBatch_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (arg)
                        errorArgName = "mode";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlQuery.execBatch(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QSqlQuery::BatchExecutionMode cpp_arg0 = arg ? Shiboken::Converter<QSqlQuery::BatchExecutionMode >::toCpp(arg) : QSqlQuery::ValuesAsRows;

            if(!PyErr_Occurred()) {
            // execBatch(QSqlQuery::BatchExecutionMode)
            bool cppResult = cppSelf->QSqlQuery::execBatch(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlQueryFunc_execBatch_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlQuery.BatchExecutionMode = ValuesAsRows", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlQuery.execBatch", overloads);
        return 0;
}

static PyObject* SbkQSqlQueryFunc_exec_(PyObject* self, PyObject* arg)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: exec()
    // 1: exec(QString)
    if (numArgs == 0) {
        overloadId = 0; // exec()
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // exec(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlQueryFunc_exec__TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // exec()
            {

                if(!PyErr_Occurred()) {
                // exec()
                threadStateSaver.save();
                bool cppResult = cppSelf->QSqlQuery::exec();
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // exec(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // exec(QString)
                threadStateSaver.save();
                bool cppResult = cppSelf->QSqlQuery::exec(cpp_arg0);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlQueryFunc_exec__TypeError:
        const char* overloads[] = {"", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlQuery.exec_", overloads);
        return 0;
}

static PyObject* SbkQSqlQueryFunc_executedQuery(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // executedQuery()const
            QString cppResult = cppSelf->QSqlQuery::executedQuery();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_finish(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // finish()
            cppSelf->QSqlQuery::finish();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSqlQueryFunc_first(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // first()
            threadStateSaver.save();
            bool cppResult = cppSelf->QSqlQuery::first();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_isActive(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isActive()const
            bool cppResult = cppSelf->QSqlQuery::isActive();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_isForwardOnly(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isForwardOnly()const
            bool cppResult = cppSelf->QSqlQuery::isForwardOnly();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_isNull(PyObject* self, PyObject* arg)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isNull(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // isNull(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlQueryFunc_isNull_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isNull(int)const
            bool cppResult = cppSelf->QSqlQuery::isNull(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlQueryFunc_isNull_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlQuery.isNull", overloads);
        return 0;
}

static PyObject* SbkQSqlQueryFunc_isSelect(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSelect()const
            bool cppResult = cppSelf->QSqlQuery::isSelect();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_isValid(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QSqlQuery::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_last(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // last()
            threadStateSaver.save();
            bool cppResult = cppSelf->QSqlQuery::last();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_lastError(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastError()const
            QSqlError cppResult = cppSelf->QSqlQuery::lastError();
            pyResult = Shiboken::Converter<QSqlError >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_lastInsertId(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastInsertId()const
            QVariant cppResult = cppSelf->QSqlQuery::lastInsertId();
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_lastQuery(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastQuery()const
            QString cppResult = cppSelf->QSqlQuery::lastQuery();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_next(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // next()
            threadStateSaver.save();
            bool cppResult = cppSelf->QSqlQuery::next();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_nextResult(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nextResult()
            bool cppResult = cppSelf->QSqlQuery::nextResult();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_numRowsAffected(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // numRowsAffected()const
            int cppResult = cppSelf->QSqlQuery::numRowsAffected();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_numericalPrecisionPolicy(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // numericalPrecisionPolicy()const
            QSql::NumericalPrecisionPolicy cppResult = cppSelf->QSqlQuery::numericalPrecisionPolicy();
            pyResult = Shiboken::Converter<QSql::NumericalPrecisionPolicy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_prepare(PyObject* self, PyObject* arg)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: prepare(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // prepare(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlQueryFunc_prepare_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // prepare(QString)
            threadStateSaver.save();
            bool cppResult = cppSelf->QSqlQuery::prepare(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlQueryFunc_prepare_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlQuery.prepare", overloads);
        return 0;
}

static PyObject* SbkQSqlQueryFunc_previous(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // previous()
            threadStateSaver.save();
            bool cppResult = cppSelf->QSqlQuery::previous();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_record(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // record()const
            QSqlRecord cppResult = cppSelf->QSqlQuery::record();
            pyResult = Shiboken::Converter<QSqlRecord >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_result(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // result()const
            const QSqlResult * cppResult = cppSelf->QSqlQuery::result();
            pyResult = Shiboken::Converter< QSqlResult * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_seek(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "relative" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlQuery.seek(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlQuery.seek(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlQuery.seek(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:seek", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: seek(int,bool)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // seek(int,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // seek(int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlQueryFunc_seek_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "relative");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "relative";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlQuery.seek(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
            // seek(int,bool)
            threadStateSaver.save();
            bool cppResult = cppSelf->QSqlQuery::seek(cpp_arg0, cpp_arg1);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlQueryFunc_seek_TypeError:
        const char* overloads[] = {"int, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlQuery.seek", overloads);
        return 0;
}

static PyObject* SbkQSqlQueryFunc_setForwardOnly(PyObject* self, PyObject* arg)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setForwardOnly(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setForwardOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlQueryFunc_setForwardOnly_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setForwardOnly(bool)
            cppSelf->QSqlQuery::setForwardOnly(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlQueryFunc_setForwardOnly_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlQuery.setForwardOnly", overloads);
        return 0;
}

static PyObject* SbkQSqlQueryFunc_setNumericalPrecisionPolicy(PyObject* self, PyObject* arg)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    if (Shiboken::Converter<QSql::NumericalPrecisionPolicy >::isConvertible(arg)) {
        overloadId = 0; // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlQueryFunc_setNumericalPrecisionPolicy_TypeError;

    // Call function/method
    {
        {
            QSql::NumericalPrecisionPolicy cpp_arg0 = Shiboken::Converter<QSql::NumericalPrecisionPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
            cppSelf->QSqlQuery::setNumericalPrecisionPolicy(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlQueryFunc_setNumericalPrecisionPolicy_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSql.NumericalPrecisionPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlQuery.setNumericalPrecisionPolicy", overloads);
        return 0;
}

static PyObject* SbkQSqlQueryFunc_size(PyObject* self)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            int cppResult = cppSelf->QSqlQuery::size();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlQueryFunc_value(PyObject* self, PyObject* arg)
{
    QSqlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlQuery* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: value(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // value(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlQueryFunc_value_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // value(int)const
            QVariant cppResult = cppSelf->QSqlQuery::value(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlQueryFunc_value_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlQuery.value", overloads);
        return 0;
}

static PyMethodDef SbkQSqlQuery_methods[] = {
    {"addBindValue", (PyCFunction)SbkQSqlQueryFunc_addBindValue, METH_VARARGS|METH_KEYWORDS},
    {"at", (PyCFunction)SbkQSqlQueryFunc_at, METH_NOARGS},
    {"bindValue", (PyCFunction)SbkQSqlQueryFunc_bindValue, METH_VARARGS|METH_KEYWORDS},
    {"boundValue", (PyCFunction)SbkQSqlQueryFunc_boundValue, METH_O},
    {"boundValues", (PyCFunction)SbkQSqlQueryFunc_boundValues, METH_NOARGS},
    {"clear", (PyCFunction)SbkQSqlQueryFunc_clear, METH_NOARGS},
    {"driver", (PyCFunction)SbkQSqlQueryFunc_driver, METH_NOARGS},
    {"execBatch", (PyCFunction)SbkQSqlQueryFunc_execBatch, METH_VARARGS|METH_KEYWORDS},
    {"exec_", (PyCFunction)SbkQSqlQueryFunc_exec_, METH_NOARGS|METH_O},
    {"executedQuery", (PyCFunction)SbkQSqlQueryFunc_executedQuery, METH_NOARGS},
    {"finish", (PyCFunction)SbkQSqlQueryFunc_finish, METH_NOARGS},
    {"first", (PyCFunction)SbkQSqlQueryFunc_first, METH_NOARGS},
    {"isActive", (PyCFunction)SbkQSqlQueryFunc_isActive, METH_NOARGS},
    {"isForwardOnly", (PyCFunction)SbkQSqlQueryFunc_isForwardOnly, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQSqlQueryFunc_isNull, METH_O},
    {"isSelect", (PyCFunction)SbkQSqlQueryFunc_isSelect, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQSqlQueryFunc_isValid, METH_NOARGS},
    {"last", (PyCFunction)SbkQSqlQueryFunc_last, METH_NOARGS},
    {"lastError", (PyCFunction)SbkQSqlQueryFunc_lastError, METH_NOARGS},
    {"lastInsertId", (PyCFunction)SbkQSqlQueryFunc_lastInsertId, METH_NOARGS},
    {"lastQuery", (PyCFunction)SbkQSqlQueryFunc_lastQuery, METH_NOARGS},
    {"next", (PyCFunction)SbkQSqlQueryFunc_next, METH_NOARGS},
    {"nextResult", (PyCFunction)SbkQSqlQueryFunc_nextResult, METH_NOARGS},
    {"numRowsAffected", (PyCFunction)SbkQSqlQueryFunc_numRowsAffected, METH_NOARGS},
    {"numericalPrecisionPolicy", (PyCFunction)SbkQSqlQueryFunc_numericalPrecisionPolicy, METH_NOARGS},
    {"prepare", (PyCFunction)SbkQSqlQueryFunc_prepare, METH_O},
    {"previous", (PyCFunction)SbkQSqlQueryFunc_previous, METH_NOARGS},
    {"record", (PyCFunction)SbkQSqlQueryFunc_record, METH_NOARGS},
    {"result", (PyCFunction)SbkQSqlQueryFunc_result, METH_NOARGS},
    {"seek", (PyCFunction)SbkQSqlQueryFunc_seek, METH_VARARGS|METH_KEYWORDS},
    {"setForwardOnly", (PyCFunction)SbkQSqlQueryFunc_setForwardOnly, METH_O},
    {"setNumericalPrecisionPolicy", (PyCFunction)SbkQSqlQueryFunc_setNumericalPrecisionPolicy, METH_O},
    {"size", (PyCFunction)SbkQSqlQueryFunc_size, METH_NOARGS},
    {"value", (PyCFunction)SbkQSqlQueryFunc_value, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQSqlQuery_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtSql.QSqlQuery",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQSqlQuery_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQSqlQuery_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QSqlQuery >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QSqlQuery",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "BatchExecutionMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QSqlQuery(PyObject* module)
{
    SbkPySide_QtSqlTypes[SBK_QSQLQUERY_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQSqlQuery_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQSqlQuery_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQSqlQuery_Type));
    PyModule_AddObject(module, "QSqlQuery",
        ((PyObject*)&SbkQSqlQuery_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: BatchExecutionMode
    SbkPySide_QtSqlTypes[SBK_QSQLQUERY_BATCHEXECUTIONMODE_IDX] = &SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_Type);
    PyDict_SetItemString(SbkQSqlQuery_Type.super.ht_type.tp_dict,
            "BatchExecutionMode",((PyObject*)&SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_Type,
        (long) QSqlQuery::ValuesAsRows, "ValuesAsRows");
    PyDict_SetItemString(SbkQSqlQuery_Type.super.ht_type.tp_dict,
        "ValuesAsRows", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_Type.tp_dict,
        "ValuesAsRows", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_Type,
        (long) QSqlQuery::ValuesAsColumns, "ValuesAsColumns");
    PyDict_SetItemString(SbkQSqlQuery_Type.super.ht_type.tp_dict,
        "ValuesAsColumns", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlQuery_BatchExecutionMode_Type.tp_dict,
        "ValuesAsColumns", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSqlQuery::BatchExecutionMode");


    Shiboken::TypeResolver::createValueTypeResolver<QSqlQuery >("QSqlQuery");
    Shiboken::TypeResolver::createObjectTypeResolver<QSqlQuery >("QSqlQuery*");
    Shiboken::TypeResolver::createValueTypeResolver<QSqlQuery >(typeid(QSqlQuery).name());
    PySide::initQtMetaType<QSqlQuery >();
}

