/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qxmlserializer_wrapper.h"

// Extra includes
#include <qabstractxmlnodemodel.h>
#include <qabstractxmlreceiver.h>
#include <qiodevice.h>
#include <qtextcodec.h>
#include <qxmlname.h>
#include <qxmlquery.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QXmlSerializerWrapper::QXmlSerializerWrapper(const QXmlQuery & query, QIODevice * outputDevice) : QXmlSerializer(query, outputDevice) {
    // ... middle
}

void QXmlSerializerWrapper::atomicValue(const QVariant & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "atomicValue"));
    if (py_override.isNull()) {
        return this->QXmlSerializer::atomicValue(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QVariant >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSerializerWrapper::attribute(const QXmlName & name, const QStringRef & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "attribute"));
    if (py_override.isNull()) {
        return this->QXmlSerializer::attribute(name, value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QXmlName & >::toPython(name),
        Shiboken::Converter<QStringRef >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSerializerWrapper::characters(const QStringRef & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "characters"));
    if (py_override.isNull()) {
        return this->QXmlSerializer::characters(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QStringRef >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSerializerWrapper::comment(const QString & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "comment"));
    if (py_override.isNull()) {
        return this->QXmlSerializer::comment(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QString >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSerializerWrapper::endDocument()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "endDocument"));
    if (py_override.isNull()) {
        return this->QXmlSerializer::endDocument();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSerializerWrapper::endElement()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "endElement"));
    if (py_override.isNull()) {
        return this->QXmlSerializer::endElement();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSerializerWrapper::endOfSequence()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "endOfSequence"));
    if (py_override.isNull()) {
        return this->QXmlSerializer::endOfSequence();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSerializerWrapper::namespaceBinding(const QXmlName & nb)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "namespaceBinding"));
    if (py_override.isNull()) {
        return this->QXmlSerializer::namespaceBinding(nb);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QXmlName & >::toPython(nb)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSerializerWrapper::processingInstruction(const QXmlName & name, const QString & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "processingInstruction"));
    if (py_override.isNull()) {
        return this->QXmlSerializer::processingInstruction(name, value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QXmlName & >::toPython(name),
        Shiboken::Converter<QString >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSerializerWrapper::startDocument()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "startDocument"));
    if (py_override.isNull()) {
        return this->QXmlSerializer::startDocument();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSerializerWrapper::startElement(const QXmlName & name)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "startElement"));
    if (py_override.isNull()) {
        return this->QXmlSerializer::startElement(name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QXmlName & >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSerializerWrapper::startOfSequence()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "startOfSequence"));
    if (py_override.isNull()) {
        return this->QXmlSerializer::startOfSequence();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSerializerWrapper::whitespaceOnly(const QStringRef & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "whitespaceOnly"));
    if (py_override.isNull()) {
        return this->QAbstractXmlReceiver::whitespaceOnly(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QStringRef >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QXmlSerializerWrapper::~QXmlSerializerWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlSerializer_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlSerializer >()))
        return -1;

    QXmlSerializerWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlSerializer", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlSerializer(QXmlQuery,QIODevice*)
    if (numArgs == 2 && Shiboken::Converter<const QXmlQuery & >::isConvertible(pyargs[0]) && Shiboken::Converter<QIODevice * >::isConvertible(pyargs[1])) {
        overloadId = 0; // QXmlSerializer(QXmlQuery,QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSerializer_Init_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return -1;
            std::auto_ptr<QXmlQuery > cpp_arg0_auto_ptr;
            QXmlQuery* cpp_arg0 = Shiboken::Converter<QXmlQuery* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QXmlQuery >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QXmlQuery >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return -1;
            QIODevice* cpp_arg1 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // QXmlSerializer(QXmlQuery,QIODevice*)
            cptr = new QXmlSerializerWrapper(*cpp_arg0, cpp_arg1);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlSerializer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlSerializer_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlSerializer_Init_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlQuery, PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlSerializer", overloads);
        return -1;
}

static PyObject* SbkQXmlSerializerFunc_atomicValue(PyObject* self, PyObject* arg)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: atomicValue(QVariant)
    if (Shiboken::Converter<QVariant >::isConvertible(arg)) {
        overloadId = 0; // atomicValue(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSerializerFunc_atomicValue_TypeError;

    // Call function/method
    {
        {
            QVariant cpp_arg0 = Shiboken::Converter<QVariant >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // atomicValue(QVariant)
            cppSelf->QXmlSerializer::atomicValue(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSerializerFunc_atomicValue_TypeError:
        const char* overloads[] = {"QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSerializer.atomicValue", overloads);
        return 0;
}

static PyObject* SbkQXmlSerializerFunc_attribute(PyObject* self, PyObject* args)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "attribute", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: attribute(QXmlName,QStringRef)
    if (numArgs == 2 && Shiboken::Converter<const QXmlName & >::isConvertible(pyargs[0]) && Shiboken::Converter<QStringRef >::isConvertible(pyargs[1])) {
        overloadId = 0; // attribute(QXmlName,QStringRef)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSerializerFunc_attribute_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QXmlName* cpp_arg0 = Shiboken::Converter<QXmlName* >::toCpp(pyargs[0]);
            QString  cpp_arg1_qstring = Shiboken::Converter<QString>::toCpp(pyargs[1])
;
            QStringRef cpp_arg1(&cpp_arg1_qstring);

            if(!PyErr_Occurred()) {
            // attribute(QXmlName,QStringRef)
            cppSelf->QXmlSerializer::attribute(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSerializerFunc_attribute_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName, QStringRef", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlSerializer.attribute", overloads);
        return 0;
}

static PyObject* SbkQXmlSerializerFunc_characters(PyObject* self, PyObject* arg)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: characters(QStringRef)
    if (Shiboken::Converter<QStringRef >::isConvertible(arg)) {
        overloadId = 0; // characters(QStringRef)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSerializerFunc_characters_TypeError;

    // Call function/method
    {
        {
            QString  cpp_arg0_qstring = Shiboken::Converter<QString>::toCpp(arg)
;
            QStringRef cpp_arg0(&cpp_arg0_qstring);

            if(!PyErr_Occurred()) {
            // characters(QStringRef)
            cppSelf->QXmlSerializer::characters(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSerializerFunc_characters_TypeError:
        const char* overloads[] = {"QStringRef", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSerializer.characters", overloads);
        return 0;
}

static PyObject* SbkQXmlSerializerFunc_codec(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // codec()const
            const QTextCodec * cppResult = cppSelf->QXmlSerializer::codec();
            pyResult = Shiboken::Converter< QTextCodec * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlSerializerFunc_comment(PyObject* self, PyObject* arg)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: comment(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // comment(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSerializerFunc_comment_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // comment(QString)
            cppSelf->QXmlSerializer::comment(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSerializerFunc_comment_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSerializer.comment", overloads);
        return 0;
}

static PyObject* SbkQXmlSerializerFunc_endDocument(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endDocument()
            cppSelf->QXmlSerializer::endDocument();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlSerializerFunc_endElement(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endElement()
            cppSelf->QXmlSerializer::endElement();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlSerializerFunc_endOfSequence(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endOfSequence()
            cppSelf->QXmlSerializer::endOfSequence();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlSerializerFunc_namespaceBinding(PyObject* self, PyObject* arg)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: namespaceBinding(QXmlName)
    if (Shiboken::Converter<const QXmlName & >::isConvertible(arg)) {
        overloadId = 0; // namespaceBinding(QXmlName)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSerializerFunc_namespaceBinding_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlName* cpp_arg0 = Shiboken::Converter<QXmlName* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // namespaceBinding(QXmlName)
            cppSelf->QXmlSerializer::namespaceBinding(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSerializerFunc_namespaceBinding_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSerializer.namespaceBinding", overloads);
        return 0;
}

static PyObject* SbkQXmlSerializerFunc_outputDevice(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // outputDevice()const
            QIODevice * cppResult = cppSelf->QXmlSerializer::outputDevice();
            pyResult = Shiboken::Converter<QIODevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlSerializerFunc_processingInstruction(PyObject* self, PyObject* args)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "processingInstruction", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: processingInstruction(QXmlName,QString)
    if (numArgs == 2 && Shiboken::Converter<const QXmlName & >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // processingInstruction(QXmlName,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSerializerFunc_processingInstruction_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QXmlName* cpp_arg0 = Shiboken::Converter<QXmlName* >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // processingInstruction(QXmlName,QString)
            cppSelf->QXmlSerializer::processingInstruction(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSerializerFunc_processingInstruction_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlSerializer.processingInstruction", overloads);
        return 0;
}

static PyObject* SbkQXmlSerializerFunc_setCodec(PyObject* self, PyObject* arg)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCodec(const QTextCodec*)
    if (Shiboken::Converter< QTextCodec * >::isConvertible(arg)) {
        overloadId = 0; // setCodec(const QTextCodec*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSerializerFunc_setCodec_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextCodec* cpp_arg0 = Shiboken::Converter<QTextCodec* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCodec(const QTextCodec*)
            cppSelf->QXmlSerializer::setCodec(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSerializerFunc_setCodec_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextCodec", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSerializer.setCodec", overloads);
        return 0;
}

static PyObject* SbkQXmlSerializerFunc_startDocument(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // startDocument()
            cppSelf->QXmlSerializer::startDocument();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlSerializerFunc_startElement(PyObject* self, PyObject* arg)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: startElement(QXmlName)
    if (Shiboken::Converter<const QXmlName & >::isConvertible(arg)) {
        overloadId = 0; // startElement(QXmlName)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSerializerFunc_startElement_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlName* cpp_arg0 = Shiboken::Converter<QXmlName* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // startElement(QXmlName)
            cppSelf->QXmlSerializer::startElement(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSerializerFunc_startElement_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSerializer.startElement", overloads);
        return 0;
}

static PyObject* SbkQXmlSerializerFunc_startOfSequence(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSerializer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // startOfSequence()
            cppSelf->QXmlSerializer::startOfSequence();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef SbkQXmlSerializer_methods[] = {
    {"atomicValue", (PyCFunction)SbkQXmlSerializerFunc_atomicValue, METH_O},
    {"attribute", (PyCFunction)SbkQXmlSerializerFunc_attribute, METH_VARARGS},
    {"characters", (PyCFunction)SbkQXmlSerializerFunc_characters, METH_O},
    {"codec", (PyCFunction)SbkQXmlSerializerFunc_codec, METH_NOARGS},
    {"comment", (PyCFunction)SbkQXmlSerializerFunc_comment, METH_O},
    {"endDocument", (PyCFunction)SbkQXmlSerializerFunc_endDocument, METH_NOARGS},
    {"endElement", (PyCFunction)SbkQXmlSerializerFunc_endElement, METH_NOARGS},
    {"endOfSequence", (PyCFunction)SbkQXmlSerializerFunc_endOfSequence, METH_NOARGS},
    {"namespaceBinding", (PyCFunction)SbkQXmlSerializerFunc_namespaceBinding, METH_O},
    {"outputDevice", (PyCFunction)SbkQXmlSerializerFunc_outputDevice, METH_NOARGS},
    {"processingInstruction", (PyCFunction)SbkQXmlSerializerFunc_processingInstruction, METH_VARARGS},
    {"setCodec", (PyCFunction)SbkQXmlSerializerFunc_setCodec, METH_O},
    {"startDocument", (PyCFunction)SbkQXmlSerializerFunc_startDocument, METH_NOARGS},
    {"startElement", (PyCFunction)SbkQXmlSerializerFunc_startElement, METH_O},
    {"startOfSequence", (PyCFunction)SbkQXmlSerializerFunc_startOfSequence, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlSerializer_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QXmlSerializer",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlSerializer_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlSerializer_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlSerializer >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlSerializer*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQXmlSerializer_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QAbstractXmlReceiver >()) && dynamic_cast<QXmlSerializer*>(reinterpret_cast<QAbstractXmlReceiver*>(cptr)))
        return &SbkQXmlSerializer_Type;
    return 0;
}


void init_QXmlSerializer(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLSERIALIZER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlSerializer_Type);

    SbkQXmlSerializer_Type.super.ht_type.tp_base = SbkPySide_QtXmlPatternsTypes[SBK_QABSTRACTXMLRECEIVER_IDX];
    // Fill type discovery information
    SbkQXmlSerializer_Type.type_discovery = &SbkQXmlSerializer_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtXmlPatternsTypes[SBK_QABSTRACTXMLRECEIVER_IDX]), &SbkQXmlSerializer_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlSerializer_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlSerializer_Type));
    PyModule_AddObject(module, "QXmlSerializer",
        ((PyObject*)&SbkQXmlSerializer_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSerializer >("QXmlSerializer*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSerializer >(typeid(QXmlSerializer).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSerializer >(typeid(QXmlSerializerWrapper).name());
    PySide::initQtMetaType<QXmlSerializer* >();
}

