/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_backendinterface_wrapper.h"

// Extra includes
#include <QList>
#include <QSet>
#include <QStringList>
#include <pysideconversions.h>
#include <qbytearray.h>
#include <qobject.h>

using namespace Shiboken;
using namespace Phonon;

// Native ---------------------------------------------------------

BackendInterfaceWrapper::BackendInterfaceWrapper() : Phonon::BackendInterface() {
    // ... middle
}

QStringList BackendInterfaceWrapper::availableMimeTypes() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "availableMimeTypes"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.availableMimeTypes()' not implemented.");
        return QStringList();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStringList();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QStringList >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.availableMimeTypes", "list", pyResult->ob_type->tp_name);
        return QStringList();
    }
    QStringList cppResult(Shiboken::Converter<QStringList >::toCpp(pyResult));
    return cppResult;
}

bool BackendInterfaceWrapper::connectNodes(QObject * arg__1, QObject * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNodes"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.connectNodes()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QObject * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.connectNodes", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QObject * BackendInterfaceWrapper::createObject(Phonon::BackendInterface::Class c, QObject * parent, const QList<QVariant > & args)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "createObject"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.createObject()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter<Phonon::BackendInterface::Class >::toPython(c),
        Shiboken::Converter<QObject * >::toPython(parent),
        Shiboken::Converter< QList<QVariant >  >::toPython(args)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QObject * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.createObject", SbkType<QObject * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QObject * cppResult(Shiboken::Converter<QObject * >::toCpp(pyResult));
    return cppResult;
}

bool BackendInterfaceWrapper::disconnectNodes(QObject * arg__1, QObject * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNodes"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.disconnectNodes()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QObject * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.disconnectNodes", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool BackendInterfaceWrapper::endConnectionChange(QSet<QObject * > arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "endConnectionChange"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.endConnectionChange()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QSet<QObject * > >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.endConnectionChange", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QList<int > BackendInterfaceWrapper::objectDescriptionIndexes(Phonon::ObjectDescriptionType type) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "objectDescriptionIndexes"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.objectDescriptionIndexes()' not implemented.");
        return QList<int >();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<Phonon::ObjectDescriptionType >::toPython(type)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<int >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QList<int > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.objectDescriptionIndexes", "list", pyResult->ob_type->tp_name);
        return QList<int >();
    }
    QList<int > cppResult(Shiboken::Converter<QList<int > >::toCpp(pyResult));
    return cppResult;
}

QHash<QByteArray, QVariant > BackendInterfaceWrapper::objectDescriptionProperties(Phonon::ObjectDescriptionType type, int index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "objectDescriptionProperties"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.objectDescriptionProperties()' not implemented.");
        return QHash<QByteArray, QVariant >();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Ni)",
        Shiboken::Converter<Phonon::ObjectDescriptionType >::toPython(type),
        index
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QHash<QByteArray, QVariant >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QHash<QByteArray, QVariant > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.objectDescriptionProperties", "hash", pyResult->ob_type->tp_name);
        return QHash<QByteArray, QVariant >();
    }
    QHash<QByteArray, QVariant > cppResult(Shiboken::Converter<QHash<QByteArray, QVariant > >::toCpp(pyResult));
    return cppResult;
}

bool BackendInterfaceWrapper::startConnectionChange(QSet<QObject * > arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "startConnectionChange"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.startConnectionChange()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QSet<QObject * > >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "BackendInterface.startConnectionChange", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

BackendInterfaceWrapper::~BackendInterfaceWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkPhonon_BackendInterface_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::BackendInterface >()))
        return -1;

    BackendInterfaceWrapper* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'Phonon::BackendInterface' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // BackendInterface()
            cptr = new BackendInterfaceWrapper();
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::BackendInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* SbkPhonon_BackendInterfaceFunc_availableMimeTypes(PyObject* self)
{
    Phonon::BackendInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::BackendInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // availableMimeTypes()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.availableMimeTypes()' not implemented.");
                return 0;
            }
            QStringList cppResult = cppSelf->availableMimeTypes();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_BackendInterfaceFunc_connectNodes(PyObject* self, PyObject* args)
{
    Phonon::BackendInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::BackendInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "connectNodes", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: connectNodes(QObject*,QObject*)
    if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
        overloadId = 0; // connectNodes(QObject*,QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_BackendInterfaceFunc_connectNodes_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QObject* cpp_arg1 = Shiboken::Converter<QObject* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // connectNodes(QObject*,QObject*)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.connectNodes()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->connectNodes(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkPhonon_BackendInterfaceFunc_connectNodes_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.BackendInterface.connectNodes", overloads);
        return 0;
}

static PyObject* SbkPhonon_BackendInterfaceFunc_createObject(PyObject* self, PyObject* args, PyObject* kwds)
{
    Phonon::BackendInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::BackendInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "args" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.phonon.BackendInterface.createObject(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.BackendInterface.createObject(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.BackendInterface.createObject(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:createObject", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: createObject(Phonon::BackendInterface::Class,QObject*,QList<QVariant>)
    if (numArgs >= 2 && Shiboken::Converter<Phonon::BackendInterface::Class >::isConvertible(pyargs[0]) && Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // createObject(Phonon::BackendInterface::Class,QObject*,QList<QVariant>)
        } else if (Shiboken::Converter< QList<QVariant >  >::isConvertible(pyargs[2])) {
            overloadId = 0; // createObject(Phonon::BackendInterface::Class,QObject*,QList<QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_BackendInterfaceFunc_createObject_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "args");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "args";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.phonon.BackendInterface.createObject(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Phonon::BackendInterface::Class cpp_arg0 = Shiboken::Converter<Phonon::BackendInterface::Class >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QObject* cpp_arg1 = Shiboken::Converter<QObject* >::toCpp(pyargs[1]);
            QList<QVariant > cpp_arg2 = pyargs[2] ? Shiboken::Converter<QList<QVariant > >::toCpp(pyargs[2]) : QList< QVariant >();

            if(!PyErr_Occurred()) {
            // createObject(Phonon::BackendInterface::Class,QObject*,QList<QVariant>)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.createObject()' not implemented.");
                return 0;
            }
            QObject * cppResult = cppSelf->createObject(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkPhonon_BackendInterfaceFunc_createObject_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::BackendInterface.Class, PySide.QtCore.QObject, list = QList< QVariant >()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.BackendInterface.createObject", overloads);
        return 0;
}

static PyObject* SbkPhonon_BackendInterfaceFunc_disconnectNodes(PyObject* self, PyObject* args)
{
    Phonon::BackendInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::BackendInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "disconnectNodes", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: disconnectNodes(QObject*,QObject*)
    if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
        overloadId = 0; // disconnectNodes(QObject*,QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_BackendInterfaceFunc_disconnectNodes_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QObject* cpp_arg1 = Shiboken::Converter<QObject* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // disconnectNodes(QObject*,QObject*)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.disconnectNodes()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->disconnectNodes(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkPhonon_BackendInterfaceFunc_disconnectNodes_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.BackendInterface.disconnectNodes", overloads);
        return 0;
}

static PyObject* SbkPhonon_BackendInterfaceFunc_endConnectionChange(PyObject* self, PyObject* arg)
{
    Phonon::BackendInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::BackendInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: endConnectionChange(QSet<QObject*>)
    if (Shiboken::Converter<QSet<QObject * > >::isConvertible(arg)) {
        overloadId = 0; // endConnectionChange(QSet<QObject*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_BackendInterfaceFunc_endConnectionChange_TypeError;

    // Call function/method
    {
        {
            QSet<QObject * > cpp_arg0 = Shiboken::Converter<QSet<QObject * > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // endConnectionChange(QSet<QObject*>)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.endConnectionChange()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->endConnectionChange(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkPhonon_BackendInterfaceFunc_endConnectionChange_TypeError:
        const char* overloads[] = {"QSet", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.BackendInterface.endConnectionChange", overloads);
        return 0;
}

static PyObject* SbkPhonon_BackendInterfaceFunc_objectDescriptionIndexes(PyObject* self, PyObject* arg)
{
    Phonon::BackendInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::BackendInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: objectDescriptionIndexes(Phonon::ObjectDescriptionType)const
    if (Shiboken::Converter<Phonon::ObjectDescriptionType >::isConvertible(arg)) {
        overloadId = 0; // objectDescriptionIndexes(Phonon::ObjectDescriptionType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_BackendInterfaceFunc_objectDescriptionIndexes_TypeError;

    // Call function/method
    {
        {
            Phonon::ObjectDescriptionType cpp_arg0 = Shiboken::Converter<Phonon::ObjectDescriptionType >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // objectDescriptionIndexes(Phonon::ObjectDescriptionType)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.objectDescriptionIndexes()' not implemented.");
                return 0;
            }
            QList<int > cppResult = cppSelf->objectDescriptionIndexes(cpp_arg0);
            pyResult = Shiboken::Converter<QList<int > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkPhonon_BackendInterfaceFunc_objectDescriptionIndexes_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon.ObjectDescriptionType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.BackendInterface.objectDescriptionIndexes", overloads);
        return 0;
}

static PyObject* SbkPhonon_BackendInterfaceFunc_objectDescriptionProperties(PyObject* self, PyObject* args)
{
    Phonon::BackendInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::BackendInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "objectDescriptionProperties", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: objectDescriptionProperties(Phonon::ObjectDescriptionType,int)const
    if (numArgs == 2 && Shiboken::Converter<Phonon::ObjectDescriptionType >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // objectDescriptionProperties(Phonon::ObjectDescriptionType,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_BackendInterfaceFunc_objectDescriptionProperties_TypeError;

    // Call function/method
    {
        {
            Phonon::ObjectDescriptionType cpp_arg0 = Shiboken::Converter<Phonon::ObjectDescriptionType >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // objectDescriptionProperties(Phonon::ObjectDescriptionType,int)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.objectDescriptionProperties()' not implemented.");
                return 0;
            }
            QHash<QByteArray, QVariant > cppResult = cppSelf->objectDescriptionProperties(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QHash<QByteArray, QVariant > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkPhonon_BackendInterfaceFunc_objectDescriptionProperties_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon.ObjectDescriptionType, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.BackendInterface.objectDescriptionProperties", overloads);
        return 0;
}

static PyObject* SbkPhonon_BackendInterfaceFunc_startConnectionChange(PyObject* self, PyObject* arg)
{
    Phonon::BackendInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::BackendInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: startConnectionChange(QSet<QObject*>)
    if (Shiboken::Converter<QSet<QObject * > >::isConvertible(arg)) {
        overloadId = 0; // startConnectionChange(QSet<QObject*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_BackendInterfaceFunc_startConnectionChange_TypeError;

    // Call function/method
    {
        {
            QSet<QObject * > cpp_arg0 = Shiboken::Converter<QSet<QObject * > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // startConnectionChange(QSet<QObject*>)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'BackendInterface.startConnectionChange()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->startConnectionChange(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkPhonon_BackendInterfaceFunc_startConnectionChange_TypeError:
        const char* overloads[] = {"QSet", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.BackendInterface.startConnectionChange", overloads);
        return 0;
}

static PyMethodDef SbkPhonon_BackendInterface_methods[] = {
    {"availableMimeTypes", (PyCFunction)SbkPhonon_BackendInterfaceFunc_availableMimeTypes, METH_NOARGS},
    {"connectNodes", (PyCFunction)SbkPhonon_BackendInterfaceFunc_connectNodes, METH_VARARGS},
    {"createObject", (PyCFunction)SbkPhonon_BackendInterfaceFunc_createObject, METH_VARARGS|METH_KEYWORDS},
    {"disconnectNodes", (PyCFunction)SbkPhonon_BackendInterfaceFunc_disconnectNodes, METH_VARARGS},
    {"endConnectionChange", (PyCFunction)SbkPhonon_BackendInterfaceFunc_endConnectionChange, METH_O},
    {"objectDescriptionIndexes", (PyCFunction)SbkPhonon_BackendInterfaceFunc_objectDescriptionIndexes, METH_O},
    {"objectDescriptionProperties", (PyCFunction)SbkPhonon_BackendInterfaceFunc_objectDescriptionProperties, METH_VARARGS},
    {"startConnectionChange", (PyCFunction)SbkPhonon_BackendInterfaceFunc_startConnectionChange, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkPhonon_BackendInterface_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.BackendInterface",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkPhonon_BackendInterface_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkPhonon_BackendInterface_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<Phonon::BackendInterface >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "Phonon::BackendInterface*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_phonon_Phonon_BackendInterface_Class_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_phonon_Phonon_BackendInterface_Class_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_phonon_Phonon_BackendInterface_Class_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Class",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_phonon_Phonon_BackendInterface_Class_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_phonon_Phonon_BackendInterface_Class_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_phonon_Phonon_BackendInterface_Class_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_Phonon_BackendInterface(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkPhonon_BackendInterface_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkPhonon_BackendInterface_Type) < 0)
        return;

    PyDict_SetItemString(module,"BackendInterface", (PyObject*)&SbkPhonon_BackendInterface_Type);
    // Initialize enums
    PyObject* enum_item;

    // init enum class: Class
    SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_CLASS_IDX] = &SbkPySide_phonon_Phonon_BackendInterface_Class_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_phonon_Phonon_BackendInterface_Class_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_phonon_Phonon_BackendInterface_Class_Type);
    PyDict_SetItemString(SbkPhonon_BackendInterface_Type.super.ht_type.tp_dict,
            "Class",((PyObject*)&SbkPySide_phonon_Phonon_BackendInterface_Class_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_BackendInterface_Class_Type,
        (long) Phonon::BackendInterface::MediaObjectClass, "MediaObjectClass");
    PyDict_SetItemString(SbkPhonon_BackendInterface_Type.super.ht_type.tp_dict,
        "MediaObjectClass", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_BackendInterface_Class_Type.tp_dict,
        "MediaObjectClass", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_BackendInterface_Class_Type,
        (long) Phonon::BackendInterface::VolumeFaderEffectClass, "VolumeFaderEffectClass");
    PyDict_SetItemString(SbkPhonon_BackendInterface_Type.super.ht_type.tp_dict,
        "VolumeFaderEffectClass", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_BackendInterface_Class_Type.tp_dict,
        "VolumeFaderEffectClass", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_BackendInterface_Class_Type,
        (long) Phonon::BackendInterface::AudioOutputClass, "AudioOutputClass");
    PyDict_SetItemString(SbkPhonon_BackendInterface_Type.super.ht_type.tp_dict,
        "AudioOutputClass", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_BackendInterface_Class_Type.tp_dict,
        "AudioOutputClass", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_BackendInterface_Class_Type,
        (long) Phonon::BackendInterface::AudioDataOutputClass, "AudioDataOutputClass");
    PyDict_SetItemString(SbkPhonon_BackendInterface_Type.super.ht_type.tp_dict,
        "AudioDataOutputClass", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_BackendInterface_Class_Type.tp_dict,
        "AudioDataOutputClass", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_BackendInterface_Class_Type,
        (long) Phonon::BackendInterface::VisualizationClass, "VisualizationClass");
    PyDict_SetItemString(SbkPhonon_BackendInterface_Type.super.ht_type.tp_dict,
        "VisualizationClass", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_BackendInterface_Class_Type.tp_dict,
        "VisualizationClass", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_BackendInterface_Class_Type,
        (long) Phonon::BackendInterface::VideoDataOutputClass, "VideoDataOutputClass");
    PyDict_SetItemString(SbkPhonon_BackendInterface_Type.super.ht_type.tp_dict,
        "VideoDataOutputClass", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_BackendInterface_Class_Type.tp_dict,
        "VideoDataOutputClass", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_BackendInterface_Class_Type,
        (long) Phonon::BackendInterface::EffectClass, "EffectClass");
    PyDict_SetItemString(SbkPhonon_BackendInterface_Type.super.ht_type.tp_dict,
        "EffectClass", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_BackendInterface_Class_Type.tp_dict,
        "EffectClass", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_BackendInterface_Class_Type,
        (long) Phonon::BackendInterface::VideoWidgetClass, "VideoWidgetClass");
    PyDict_SetItemString(SbkPhonon_BackendInterface_Type.super.ht_type.tp_dict,
        "VideoWidgetClass", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_BackendInterface_Class_Type.tp_dict,
        "VideoWidgetClass", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::BackendInterface::Class");


    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::BackendInterface >("Phonon::BackendInterface*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::BackendInterface >(typeid(Phonon::BackendInterface).name());
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::BackendInterface >(typeid(BackendInterfaceWrapper).name());
    PySide::initQtMetaType<Phonon::BackendInterface* >();
}

