/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtcore_python.h"

#include "qabstractitemmodel_wrapper.h"

// Extra includes
#include <QList>
#include <QMap>
#include <QStringList>
#include <pysideconversions.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdatastream.h>
#include <qmimedata.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QAbstractItemModelWrapper::QAbstractItemModelWrapper(QObject * parent) : QAbstractItemModel(parent), m_metaObject(0) {
    // ... middle
}

QModelIndex QAbstractItemModelWrapper::buddy(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "buddy"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::buddy(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QModelIndex();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QModelIndex >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.buddy", SbkType<QModelIndex >()->tp_name, pyResult->ob_type->tp_name);
        return QModelIndex();
    }
    QModelIndex cppResult(Shiboken::Converter<QModelIndex >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemModelWrapper::canFetchMore(const QModelIndex & parent) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "canFetchMore"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::canFetchMore(parent);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(parent)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.canFetchMore", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemModelWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QAbstractItemModelWrapper::columnCount(const QModelIndex & parent) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "columnCount"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemModel.columnCount()' not implemented.");
        return int(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(parent)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.columnCount", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemModelWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemModelWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QAbstractItemModelWrapper::data(const QModelIndex & index, int role) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "data"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemModel.data()' not implemented.");
        return QVariant(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Ni)",
        Shiboken::Converter<const QModelIndex & >::toPython(index),
        role
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.data", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemModelWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QAbstractItemModelWrapper::dropMimeData(const QMimeData * data, Qt::DropAction action, int row, int column, const QModelIndex & parent)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dropMimeData"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::dropMimeData(data, action, row, column, parent);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNiiN)",
        Shiboken::Converter<const QMimeData * >::toPython(data),
        Shiboken::Converter<Qt::DropAction >::toPython(action),
        row,
        column,
        Shiboken::Converter<const QModelIndex & >::toPython(parent)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.dropMimeData", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemModelWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QAbstractItemModelWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QAbstractItemModelWrapper::fetchMore(const QModelIndex & parent)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "fetchMore"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::fetchMore(parent);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(parent)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QFlags<Qt::ItemFlag> QAbstractItemModelWrapper::flags(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "flags"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::flags(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<Qt::ItemFlag>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QFlags<Qt::ItemFlag> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.flags", SbkType<QFlags<Qt::ItemFlag> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<Qt::ItemFlag>();
    }
    QFlags<Qt::ItemFlag> cppResult(Shiboken::Converter<QFlags<Qt::ItemFlag> >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemModelWrapper::hasChildren(const QModelIndex & parent) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hasChildren"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::hasChildren(parent);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(parent)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.hasChildren", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QVariant QAbstractItemModelWrapper::headerData(int section, Qt::Orientation orientation, int role) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "headerData"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::headerData(section, orientation, role);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iNi)",
        section,
        Shiboken::Converter<Qt::Orientation >::toPython(orientation),
        role
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.headerData", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

QModelIndex QAbstractItemModelWrapper::index(int row, int column, const QModelIndex & parent) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "index"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemModel.index()' not implemented.");
        return QModelIndex();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iiN)",
        row,
        column,
        Shiboken::Converter<const QModelIndex & >::toPython(parent)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QModelIndex();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QModelIndex >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.index", SbkType<QModelIndex >()->tp_name, pyResult->ob_type->tp_name);
        return QModelIndex();
    }
    QModelIndex cppResult(Shiboken::Converter<QModelIndex >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemModelWrapper::insertColumns(int column, int count, const QModelIndex & parent)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "insertColumns"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::insertColumns(column, count, parent);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iiN)",
        column,
        count,
        Shiboken::Converter<const QModelIndex & >::toPython(parent)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.insertColumns", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemModelWrapper::insertRows(int row, int count, const QModelIndex & parent)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "insertRows"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::insertRows(row, count, parent);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iiN)",
        row,
        count,
        Shiboken::Converter<const QModelIndex & >::toPython(parent)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.insertRows", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QMap<int, QVariant > QAbstractItemModelWrapper::itemData(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "itemData"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::itemData(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QMap<int, QVariant >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QMap<int, QVariant > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.itemData", "map", pyResult->ob_type->tp_name);
        return QMap<int, QVariant >();
    }
    QMap<int, QVariant > cppResult(Shiboken::Converter<QMap<int, QVariant > >::toCpp(pyResult));
    return cppResult;
}

QList<QModelIndex > QAbstractItemModelWrapper::match(const QModelIndex & start, int role, const QVariant & value, int hits, QFlags<Qt::MatchFlag> flags) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "match"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::match(start, role, value, hits, flags);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NiNiN)",
        Shiboken::Converter<const QModelIndex & >::toPython(start),
        role,
        Shiboken::Converter<QVariant >::toPython(value),
        hits,
        Shiboken::Converter<QFlags<Qt::MatchFlag> >::toPython(flags)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<QModelIndex >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QList<QModelIndex > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.match", "list", pyResult->ob_type->tp_name);
        return QList<QModelIndex >();
    }
    QList<QModelIndex > cppResult(Shiboken::Converter<QList<QModelIndex > >::toCpp(pyResult));
    return cppResult;
}

QMimeData * QAbstractItemModelWrapper::mimeData(const QList<QModelIndex > & indexes) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mimeData"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::mimeData(indexes);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QList<QModelIndex >  >::toPython(indexes)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QMimeData * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.mimeData", SbkType<QMimeData * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QMimeData * cppResult(Shiboken::Converter<QMimeData * >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(pyResult.object());
    return cppResult;
}

QStringList QAbstractItemModelWrapper::mimeTypes() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mimeTypes"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::mimeTypes();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStringList();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QStringList >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.mimeTypes", "list", pyResult->ob_type->tp_name);
        return QStringList();
    }
    QStringList cppResult(Shiboken::Converter<QStringList >::toCpp(pyResult));
    return cppResult;
}

QModelIndex QAbstractItemModelWrapper::parent(const QModelIndex & child) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "parent"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemModel.parent()' not implemented.");
        return QModelIndex();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(child)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QModelIndex();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QModelIndex >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.parent", SbkType<QModelIndex >()->tp_name, pyResult->ob_type->tp_name);
        return QModelIndex();
    }
    QModelIndex cppResult(Shiboken::Converter<QModelIndex >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemModelWrapper::removeColumns(int column, int count, const QModelIndex & parent)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "removeColumns"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::removeColumns(column, count, parent);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iiN)",
        column,
        count,
        Shiboken::Converter<const QModelIndex & >::toPython(parent)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.removeColumns", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemModelWrapper::removeRows(int row, int count, const QModelIndex & parent)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "removeRows"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::removeRows(row, count, parent);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iiN)",
        row,
        count,
        Shiboken::Converter<const QModelIndex & >::toPython(parent)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.removeRows", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemModelWrapper::revert()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "revert"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::revert();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

int QAbstractItemModelWrapper::rowCount(const QModelIndex & parent) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "rowCount"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemModel.rowCount()' not implemented.");
        return int(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(parent)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.rowCount", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemModelWrapper::setData(const QModelIndex & index, const QVariant & value, int role)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setData"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::setData(index, value, role);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNi)",
        Shiboken::Converter<const QModelIndex & >::toPython(index),
        Shiboken::Converter<QVariant >::toPython(value),
        role
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.setData", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemModelWrapper::setHeaderData(int section, Qt::Orientation orientation, const QVariant & value, int role)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setHeaderData"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::setHeaderData(section, orientation, value, role);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iNNi)",
        section,
        Shiboken::Converter<Qt::Orientation >::toPython(orientation),
        Shiboken::Converter<QVariant >::toPython(value),
        role
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.setHeaderData", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemModelWrapper::setItemData(const QModelIndex & index, const QMap<int, QVariant > & roles)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setItemData"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::setItemData(index, roles);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QModelIndex & >::toPython(index),
        Shiboken::Converter< QMap<int, QVariant >  >::toPython(roles)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.setItemData", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemModelWrapper::sort(int column, Qt::SortOrder order)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sort"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::sort(column, order);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iN)",
        column,
        Shiboken::Converter<Qt::SortOrder >::toPython(order)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QSize QAbstractItemModelWrapper::span(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "span"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::span(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.span", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemModelWrapper::submit()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "submit"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::submit();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.submit", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QFlags<Qt::DropAction> QAbstractItemModelWrapper::supportedDropActions() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "supportedDropActions"));
    if (py_override.isNull()) {
        return this->QAbstractItemModel::supportedDropActions();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<Qt::DropAction>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QFlags<Qt::DropAction> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemModel.supportedDropActions", SbkType<QFlags<Qt::DropAction> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<Qt::DropAction>();
    }
    QFlags<Qt::DropAction> cppResult(Shiboken::Converter<QFlags<Qt::DropAction> >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemModelWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QAbstractItemModelWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QAbstractItemModel::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QAbstractItemModelWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QAbstractItemModel::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QAbstractItemModelWrapper::~QAbstractItemModelWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQAbstractItemModel_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QAbstractItemModel >()))
        return -1;

    QAbstractItemModelWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTITEMMODEL_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QAbstractItemModel' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QAbstractItemModel", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QAbstractItemModel(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QAbstractItemModel(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QAbstractItemModel(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModel_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QAbstractItemModel(QObject*)
            cptr = new QAbstractItemModelWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QAbstractItemModel >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQAbstractItemModel_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQAbstractItemModel_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel", overloads);
        return -1;
}

static PyObject* SbkQAbstractItemModelFunc_beginInsertColumns(PyObject* self, PyObject* args)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "beginInsertColumns", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: beginInsertColumns(QModelIndex,int,int)
    if (numArgs == 3 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // beginInsertColumns(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_beginInsertColumns_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // beginInsertColumns(QModelIndex,int,int)
            cppSelf->QAbstractItemModel::beginInsertColumns(*cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemModelFunc_beginInsertColumns_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.beginInsertColumns", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_beginInsertRows(PyObject* self, PyObject* args)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "beginInsertRows", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: beginInsertRows(QModelIndex,int,int)
    if (numArgs == 3 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // beginInsertRows(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_beginInsertRows_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // beginInsertRows(QModelIndex,int,int)
            cppSelf->QAbstractItemModel::beginInsertRows(*cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemModelFunc_beginInsertRows_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.beginInsertRows", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_beginMoveColumns(PyObject* self, PyObject* args)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "beginMoveColumns", 5, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: beginMoveColumns(QModelIndex,int,int,QModelIndex,int)
    if (numArgs == 5 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
        overloadId = 0; // beginMoveColumns(QModelIndex,int,int,QModelIndex,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_beginMoveColumns_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                return 0;
            QModelIndex* cpp_arg3 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[3]);
            int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);

            if(!PyErr_Occurred()) {
            // beginMoveColumns(QModelIndex,int,int,QModelIndex,int)
            bool cppResult = cppSelf->QAbstractItemModel::beginMoveColumns(*cpp_arg0, cpp_arg1, cpp_arg2, *cpp_arg3, cpp_arg4);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_beginMoveColumns_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, int, PySide.QtCore.QModelIndex, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.beginMoveColumns", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_beginMoveRows(PyObject* self, PyObject* args)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "beginMoveRows", 5, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: beginMoveRows(QModelIndex,int,int,QModelIndex,int)
    if (numArgs == 5 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
        overloadId = 0; // beginMoveRows(QModelIndex,int,int,QModelIndex,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_beginMoveRows_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                return 0;
            QModelIndex* cpp_arg3 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[3]);
            int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);

            if(!PyErr_Occurred()) {
            // beginMoveRows(QModelIndex,int,int,QModelIndex,int)
            bool cppResult = cppSelf->QAbstractItemModel::beginMoveRows(*cpp_arg0, cpp_arg1, cpp_arg2, *cpp_arg3, cpp_arg4);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_beginMoveRows_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, int, PySide.QtCore.QModelIndex, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.beginMoveRows", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_beginRemoveColumns(PyObject* self, PyObject* args)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "beginRemoveColumns", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: beginRemoveColumns(QModelIndex,int,int)
    if (numArgs == 3 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // beginRemoveColumns(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_beginRemoveColumns_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // beginRemoveColumns(QModelIndex,int,int)
            cppSelf->QAbstractItemModel::beginRemoveColumns(*cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemModelFunc_beginRemoveColumns_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.beginRemoveColumns", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_beginRemoveRows(PyObject* self, PyObject* args)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "beginRemoveRows", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: beginRemoveRows(QModelIndex,int,int)
    if (numArgs == 3 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // beginRemoveRows(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_beginRemoveRows_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // beginRemoveRows(QModelIndex,int,int)
            cppSelf->QAbstractItemModel::beginRemoveRows(*cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemModelFunc_beginRemoveRows_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.beginRemoveRows", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_beginResetModel(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // beginResetModel()
            cppSelf->QAbstractItemModel::beginResetModel();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemModelFunc_buddy(PyObject* self, PyObject* arg)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: buddy(QModelIndex)const
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // buddy(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_buddy_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // buddy(QModelIndex)const
            QModelIndex cppResult = cppSelf->QAbstractItemModel::buddy(*cpp_arg0);
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_buddy_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractItemModel.buddy", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_canFetchMore(PyObject* self, PyObject* arg)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: canFetchMore(QModelIndex)const
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // canFetchMore(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_canFetchMore_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // canFetchMore(QModelIndex)const
            bool cppResult = cppSelf->QAbstractItemModel::canFetchMore(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_canFetchMore_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractItemModel.canFetchMore", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_changePersistentIndex(PyObject* self, PyObject* args)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "changePersistentIndex", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: changePersistentIndex(QModelIndex,QModelIndex)
    if (numArgs == 2 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[1])) {
        overloadId = 0; // changePersistentIndex(QModelIndex,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_changePersistentIndex_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QModelIndex* cpp_arg1 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // changePersistentIndex(QModelIndex,QModelIndex)
            cppSelf->QAbstractItemModel::changePersistentIndex(*cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemModelFunc_changePersistentIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.changePersistentIndex", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_changePersistentIndexList(PyObject* self, PyObject* args)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "changePersistentIndexList", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: changePersistentIndexList(QList<QModelIndex>,QList<QModelIndex>)
    if (numArgs == 2 && Shiboken::Converter< QList<QModelIndex >  >::isConvertible(pyargs[0]) && Shiboken::Converter< QList<QModelIndex >  >::isConvertible(pyargs[1])) {
        overloadId = 0; // changePersistentIndexList(QList<QModelIndex>,QList<QModelIndex>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_changePersistentIndexList_TypeError;

    // Call function/method
    {
        {
            QList<QModelIndex > cpp_arg0 = Shiboken::Converter<QList<QModelIndex > >::toCpp(pyargs[0]);
            QList<QModelIndex > cpp_arg1 = Shiboken::Converter<QList<QModelIndex > >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // changePersistentIndexList(QList<QModelIndex>,QList<QModelIndex>)
            cppSelf->QAbstractItemModel::changePersistentIndexList(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemModelFunc_changePersistentIndexList_TypeError:
        const char* overloads[] = {"list, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.changePersistentIndexList", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_columnCount(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.columnCount(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.columnCount(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:columnCount", &arg))
        return 0;


    // Overloaded function decisor
    // 0: columnCount(QModelIndex)const
    if (numArgs == 0) {
        overloadId = 0; // columnCount(QModelIndex)const
    } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // columnCount(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_columnCount_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.columnCount(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex cpp_arg0_tmp = QModelIndex();
            QModelIndex* cpp_arg0 = arg ? Shiboken::Converter<QModelIndex* >::toCpp(arg) : &cpp_arg0_tmp;

            if(!PyErr_Occurred()) {
            // columnCount(QModelIndex)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemModel.columnCount()' not implemented.");
                return 0;
            }
            int cppResult = cppSelf->columnCount(*cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_columnCount_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex = QModelIndex()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractItemModel.columnCount", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_createIndex(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "id" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.createIndex(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.createIndex(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.createIndex(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:createIndex", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: createIndex(int,int,PyObject*)const
    // 1: createIndex(int,int,int)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // createIndex(int,int,int)const
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 1; // createIndex(int,int,int)const
        } else if (numArgs == 3 && PyObject_Check(pyargs[2])) {
            overloadId = 0; // createIndex(int,int,PyObject*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_createIndex_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // createIndex(int,int,PyObject*)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // createIndex(int,int,PyObject*)const
                // Begin code injection
                
                pyResult = Shiboken::Converter<QModelIndex >::toPython(cppSelf->createIndex(cpp_arg0, cpp_arg1, pyargs[3-1]));
                
                // End of code injection


                }
                break;
            }
            case 1: // createIndex(int,int,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "id");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "id";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.createIndex(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // createIndex(int,int,int)const
                QModelIndex cppResult = cppSelf->QAbstractItemModel::createIndex(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_createIndex_TypeError:
        const char* overloads[] = {"int, int, PyObject", "int, int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.createIndex", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_data(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "role" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.data(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.data(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.data(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:data", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: data(QModelIndex,int)const
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // data(QModelIndex,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // data(QModelIndex,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_data_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "role");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "role";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.data(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : Qt::DisplayRole;

            if(!PyErr_Occurred()) {
            // data(QModelIndex,int)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemModel.data()' not implemented.");
                return 0;
            }
            QVariant cppResult = cppSelf->data(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_data_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int = Qt.DisplayRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.data", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_decodeData(PyObject* self, PyObject* args)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "decodeData", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: decodeData(int,int,QModelIndex,QDataStream&)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[2]) && Shiboken::Converter<QDataStream & >::isConvertible(pyargs[3])) {
        overloadId = 0; // decodeData(int,int,QModelIndex,QDataStream&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_decodeData_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QModelIndex* cpp_arg2 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[2]);
            if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                return 0;
            QDataStream* cpp_arg3 = Shiboken::Converter<QDataStream* >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // decodeData(int,int,QModelIndex,QDataStream&)
            bool cppResult = cppSelf->QAbstractItemModel::decodeData(cpp_arg0, cpp_arg1, *cpp_arg2, *cpp_arg3);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_decodeData_TypeError:
        const char* overloads[] = {"int, int, PySide.QtCore.QModelIndex, PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.decodeData", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_dropMimeData(PyObject* self, PyObject* args)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "dropMimeData", 5, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: dropMimeData(const QMimeData*,Qt::DropAction,int,int,QModelIndex)
    if (numArgs == 5 && Shiboken::Converter<const QMimeData * >::isConvertible(pyargs[0]) && Shiboken::Converter<Qt::DropAction >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[4])) {
        overloadId = 0; // dropMimeData(const QMimeData*,Qt::DropAction,int,int,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_dropMimeData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QMimeData* cpp_arg0 = Shiboken::Converter<QMimeData* >::toCpp(pyargs[0]);
            Qt::DropAction cpp_arg1 = Shiboken::Converter<Qt::DropAction >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
            if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                return 0;
            QModelIndex* cpp_arg4 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[4]);

            if(!PyErr_Occurred()) {
            // dropMimeData(const QMimeData*,Qt::DropAction,int,int,QModelIndex)
            bool cppResult = cppSelf->QAbstractItemModel::dropMimeData(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, *cpp_arg4);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_dropMimeData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMimeData, PySide.QtCore.Qt.DropAction, int, int, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.dropMimeData", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_encodeData(PyObject* self, PyObject* args)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "encodeData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: encodeData(QList<QModelIndex>,QDataStream&)const
    if (numArgs == 2 && Shiboken::Converter< QList<QModelIndex >  >::isConvertible(pyargs[0]) && Shiboken::Converter<QDataStream & >::isConvertible(pyargs[1])) {
        overloadId = 0; // encodeData(QList<QModelIndex>,QDataStream&)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_encodeData_TypeError;

    // Call function/method
    {
        {
            QList<QModelIndex > cpp_arg0 = Shiboken::Converter<QList<QModelIndex > >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QDataStream* cpp_arg1 = Shiboken::Converter<QDataStream* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // encodeData(QList<QModelIndex>,QDataStream&)const
            cppSelf->QAbstractItemModel::encodeData(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemModelFunc_encodeData_TypeError:
        const char* overloads[] = {"list, PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.encodeData", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_endInsertColumns(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endInsertColumns()
            cppSelf->QAbstractItemModel::endInsertColumns();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemModelFunc_endInsertRows(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endInsertRows()
            cppSelf->QAbstractItemModel::endInsertRows();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemModelFunc_endMoveColumns(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endMoveColumns()
            cppSelf->QAbstractItemModel::endMoveColumns();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemModelFunc_endMoveRows(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endMoveRows()
            cppSelf->QAbstractItemModel::endMoveRows();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemModelFunc_endRemoveColumns(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endRemoveColumns()
            cppSelf->QAbstractItemModel::endRemoveColumns();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemModelFunc_endRemoveRows(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endRemoveRows()
            cppSelf->QAbstractItemModel::endRemoveRows();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemModelFunc_endResetModel(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endResetModel()
            cppSelf->QAbstractItemModel::endResetModel();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemModelFunc_fetchMore(PyObject* self, PyObject* arg)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: fetchMore(QModelIndex)
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // fetchMore(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_fetchMore_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // fetchMore(QModelIndex)
            cppSelf->QAbstractItemModel::fetchMore(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemModelFunc_fetchMore_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractItemModel.fetchMore", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_flags(PyObject* self, PyObject* arg)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: flags(QModelIndex)const
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // flags(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_flags_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // flags(QModelIndex)const
            QFlags<Qt::ItemFlag> cppResult = cppSelf->QAbstractItemModel::flags(*cpp_arg0);
            pyResult = Shiboken::Converter<QFlags<Qt::ItemFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_flags_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractItemModel.flags", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_hasChildren(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.hasChildren(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.hasChildren(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:hasChildren", &arg))
        return 0;


    // Overloaded function decisor
    // 0: hasChildren(QModelIndex)const
    if (numArgs == 0) {
        overloadId = 0; // hasChildren(QModelIndex)const
    } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // hasChildren(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_hasChildren_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.hasChildren(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex cpp_arg0_tmp = QModelIndex();
            QModelIndex* cpp_arg0 = arg ? Shiboken::Converter<QModelIndex* >::toCpp(arg) : &cpp_arg0_tmp;

            if(!PyErr_Occurred()) {
            // hasChildren(QModelIndex)const
            bool cppResult = cppSelf->QAbstractItemModel::hasChildren(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_hasChildren_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex = QModelIndex()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractItemModel.hasChildren", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_hasIndex(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.hasIndex(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.hasIndex(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.hasIndex(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:hasIndex", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: hasIndex(int,int,QModelIndex)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // hasIndex(int,int,QModelIndex)const
        } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[2])) {
            overloadId = 0; // hasIndex(int,int,QModelIndex)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_hasIndex_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "parent";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.hasIndex(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QModelIndex cpp_arg2_tmp = QModelIndex();
            QModelIndex* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QModelIndex* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;

            if(!PyErr_Occurred()) {
            // hasIndex(int,int,QModelIndex)const
            bool cppResult = cppSelf->QAbstractItemModel::hasIndex(cpp_arg0, cpp_arg1, *cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_hasIndex_TypeError:
        const char* overloads[] = {"int, int, PySide.QtCore.QModelIndex = QModelIndex()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.hasIndex", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_headerData(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "role" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.headerData(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.headerData(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.headerData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:headerData", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: headerData(int,Qt::Orientation,int)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<Qt::Orientation >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // headerData(int,Qt::Orientation,int)const
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // headerData(int,Qt::Orientation,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_headerData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "role");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "role";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.headerData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::Orientation cpp_arg1 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[1]);
            int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : Qt::DisplayRole;

            if(!PyErr_Occurred()) {
            // headerData(int,Qt::Orientation,int)const
            QVariant cppResult = cppSelf->QAbstractItemModel::headerData(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_headerData_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.Orientation, int = Qt.DisplayRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.headerData", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_index(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.index(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.index(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.index(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:index", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: index(int,int,QModelIndex)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // index(int,int,QModelIndex)const
        } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[2])) {
            overloadId = 0; // index(int,int,QModelIndex)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_index_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "parent";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.index(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QModelIndex cpp_arg2_tmp = QModelIndex();
            QModelIndex* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QModelIndex* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;

            if(!PyErr_Occurred()) {
            // index(int,int,QModelIndex)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemModel.index()' not implemented.");
                return 0;
            }
            QModelIndex cppResult = cppSelf->index(cpp_arg0, cpp_arg1, *cpp_arg2);
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_index_TypeError:
        const char* overloads[] = {"int, int, PySide.QtCore.QModelIndex = QModelIndex()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.index", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_insertColumn(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertColumn(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertColumn(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertColumn(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:insertColumn", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertColumn(int,QModelIndex)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // insertColumn(int,QModelIndex)
        } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[1])) {
            overloadId = 0; // insertColumn(int,QModelIndex)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_insertColumn_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "parent";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertColumn(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QModelIndex cpp_arg1_tmp = QModelIndex();
            QModelIndex* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QModelIndex* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;

            if(!PyErr_Occurred()) {
            // insertColumn(int,QModelIndex)
            bool cppResult = cppSelf->QAbstractItemModel::insertColumn(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_insertColumn_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QModelIndex = QModelIndex()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.insertColumn", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_insertColumns(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertColumns(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertColumns(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertColumns(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:insertColumns", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: insertColumns(int,int,QModelIndex)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // insertColumns(int,int,QModelIndex)
        } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[2])) {
            overloadId = 0; // insertColumns(int,int,QModelIndex)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_insertColumns_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "parent";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertColumns(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QModelIndex cpp_arg2_tmp = QModelIndex();
            QModelIndex* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QModelIndex* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;

            if(!PyErr_Occurred()) {
            // insertColumns(int,int,QModelIndex)
            bool cppResult = cppSelf->QAbstractItemModel::insertColumns(cpp_arg0, cpp_arg1, *cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_insertColumns_TypeError:
        const char* overloads[] = {"int, int, PySide.QtCore.QModelIndex = QModelIndex()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.insertColumns", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_insertRow(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertRow(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertRow(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertRow(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:insertRow", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertRow(int,QModelIndex)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // insertRow(int,QModelIndex)
        } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[1])) {
            overloadId = 0; // insertRow(int,QModelIndex)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_insertRow_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "parent";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertRow(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QModelIndex cpp_arg1_tmp = QModelIndex();
            QModelIndex* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QModelIndex* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;

            if(!PyErr_Occurred()) {
            // insertRow(int,QModelIndex)
            bool cppResult = cppSelf->QAbstractItemModel::insertRow(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_insertRow_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QModelIndex = QModelIndex()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.insertRow", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_insertRows(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertRows(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertRows(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertRows(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:insertRows", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: insertRows(int,int,QModelIndex)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // insertRows(int,int,QModelIndex)
        } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[2])) {
            overloadId = 0; // insertRows(int,int,QModelIndex)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_insertRows_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "parent";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.insertRows(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QModelIndex cpp_arg2_tmp = QModelIndex();
            QModelIndex* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QModelIndex* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;

            if(!PyErr_Occurred()) {
            // insertRows(int,int,QModelIndex)
            bool cppResult = cppSelf->QAbstractItemModel::insertRows(cpp_arg0, cpp_arg1, *cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_insertRows_TypeError:
        const char* overloads[] = {"int, int, PySide.QtCore.QModelIndex = QModelIndex()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.insertRows", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_itemData(PyObject* self, PyObject* arg)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: itemData(QModelIndex)const
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // itemData(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_itemData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // itemData(QModelIndex)const
            QMap<int, QVariant > cppResult = cppSelf->QAbstractItemModel::itemData(*cpp_arg0);
            pyResult = Shiboken::Converter<QMap<int, QVariant > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_itemData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractItemModel.itemData", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_match(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags", "hits" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.match(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.match(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.match(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:match", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: match(QModelIndex,int,QVariant,int,QFlags<Qt::MatchFlag>)const
    if (numArgs >= 3 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // match(QModelIndex,int,QVariant,int,QFlags<Qt::MatchFlag>)const
        } else if (SbkNumber_Check(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // match(QModelIndex,int,QVariant,int,QFlags<Qt::MatchFlag>)const
            } else if (Shiboken::Converter<QFlags<Qt::MatchFlag> >::isConvertible(pyargs[4])) {
                overloadId = 0; // match(QModelIndex,int,QVariant,int,QFlags<Qt::MatchFlag>)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_match_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "hits");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "hits";
                    else
                        pyargs[3] = value;
                }
                value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "flags";
                    else
                        pyargs[4] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.match(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            QVariant cpp_arg2 = Shiboken::Converter<QVariant >::toCpp(pyargs[2]);
            int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 1;
            QFlags<Qt::MatchFlag> cpp_arg4 = pyargs[4] ? Shiboken::Converter<QFlags<Qt::MatchFlag> >::toCpp(pyargs[4]) : Qt::MatchFlags(Qt::MatchStartsWith|Qt::MatchWrap);

            if(!PyErr_Occurred()) {
            // match(QModelIndex,int,QVariant,int,QFlags<Qt::MatchFlag>)const
            QList<QModelIndex > cppResult = cppSelf->QAbstractItemModel::match(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
            pyResult = Shiboken::Converter<QList<QModelIndex > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_match_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, QVariant, int = 1, PySide.QtCore.Qt.MatchFlags = Qt.MatchFlags(Qt.MatchStartsWith|Qt.MatchWrap)", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.match", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_mimeData(PyObject* self, PyObject* arg)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mimeData(QList<QModelIndex>)const
    if (Shiboken::Converter< QList<QModelIndex >  >::isConvertible(arg)) {
        overloadId = 0; // mimeData(QList<QModelIndex>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_mimeData_TypeError;

    // Call function/method
    {
        {
            QList<QModelIndex > cpp_arg0 = Shiboken::Converter<QList<QModelIndex > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mimeData(QList<QModelIndex>)const
            QMimeData * cppResult = cppSelf->QAbstractItemModel::mimeData(cpp_arg0);
            pyResult = Shiboken::Converter<QMimeData * >::toPython(cppResult);

            // Ownership transferences.
            BindingManager::instance().invalidateWrapper(pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_mimeData_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractItemModel.mimeData", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_mimeTypes(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // mimeTypes()const
            QStringList cppResult = cppSelf->QAbstractItemModel::mimeTypes();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemModelFunc_parent(PyObject* self, PyObject* arg)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: parent()const
    // 1: parent(QModelIndex)const
    if (numArgs == 0) {
        overloadId = 0; // parent()const
    } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 1; // parent(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_parent_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // parent()const
            {

                if(!PyErr_Occurred()) {
                // parent()const
                QObject * cppResult = cppSelf->QAbstractItemModel::parent();
                pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);

                // Ownership transferences.
                Shiboken::setParent(pyResult, self);
                }
                break;
            }
            case 1: // parent(QModelIndex)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // parent(QModelIndex)const
                if (SbkBaseWrapper_containsCppWrapper(self)) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemModel.parent()' not implemented.");
                    return 0;
                }
                QModelIndex cppResult = cppSelf->parent(*cpp_arg0);
                pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_parent_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractItemModel.parent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_persistentIndexList(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // persistentIndexList()const
            QList<QModelIndex > cppResult = cppSelf->QAbstractItemModel::persistentIndexList();
            pyResult = Shiboken::Converter<QList<QModelIndex > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemModelFunc_removeColumn(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeColumn(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeColumn(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeColumn(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:removeColumn", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: removeColumn(int,QModelIndex)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // removeColumn(int,QModelIndex)
        } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[1])) {
            overloadId = 0; // removeColumn(int,QModelIndex)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_removeColumn_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "parent";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeColumn(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QModelIndex cpp_arg1_tmp = QModelIndex();
            QModelIndex* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QModelIndex* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;

            if(!PyErr_Occurred()) {
            // removeColumn(int,QModelIndex)
            bool cppResult = cppSelf->QAbstractItemModel::removeColumn(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_removeColumn_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QModelIndex = QModelIndex()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.removeColumn", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_removeColumns(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeColumns(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeColumns(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeColumns(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:removeColumns", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: removeColumns(int,int,QModelIndex)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // removeColumns(int,int,QModelIndex)
        } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[2])) {
            overloadId = 0; // removeColumns(int,int,QModelIndex)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_removeColumns_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "parent";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeColumns(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QModelIndex cpp_arg2_tmp = QModelIndex();
            QModelIndex* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QModelIndex* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;

            if(!PyErr_Occurred()) {
            // removeColumns(int,int,QModelIndex)
            bool cppResult = cppSelf->QAbstractItemModel::removeColumns(cpp_arg0, cpp_arg1, *cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_removeColumns_TypeError:
        const char* overloads[] = {"int, int, PySide.QtCore.QModelIndex = QModelIndex()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.removeColumns", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_removeRow(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeRow(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeRow(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeRow(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:removeRow", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: removeRow(int,QModelIndex)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // removeRow(int,QModelIndex)
        } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[1])) {
            overloadId = 0; // removeRow(int,QModelIndex)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_removeRow_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "parent";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeRow(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QModelIndex cpp_arg1_tmp = QModelIndex();
            QModelIndex* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QModelIndex* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;

            if(!PyErr_Occurred()) {
            // removeRow(int,QModelIndex)
            bool cppResult = cppSelf->QAbstractItemModel::removeRow(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_removeRow_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QModelIndex = QModelIndex()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.removeRow", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_removeRows(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeRows(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeRows(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeRows(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:removeRows", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: removeRows(int,int,QModelIndex)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // removeRows(int,int,QModelIndex)
        } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[2])) {
            overloadId = 0; // removeRows(int,int,QModelIndex)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_removeRows_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "parent";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.removeRows(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QModelIndex cpp_arg2_tmp = QModelIndex();
            QModelIndex* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QModelIndex* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;

            if(!PyErr_Occurred()) {
            // removeRows(int,int,QModelIndex)
            bool cppResult = cppSelf->QAbstractItemModel::removeRows(cpp_arg0, cpp_arg1, *cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_removeRows_TypeError:
        const char* overloads[] = {"int, int, PySide.QtCore.QModelIndex = QModelIndex()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.removeRows", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_reset(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reset()
            cppSelf->QAbstractItemModel::reset();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemModelFunc_revert(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // revert()
            cppSelf->QAbstractItemModel::revert();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemModelFunc_roleNames(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // roleNames()const
            const QHash<int, QByteArray > & cppResult = cppSelf->QAbstractItemModel::roleNames();
            pyResult = Shiboken::Converter< QHash<int, QByteArray >  >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemModelFunc_rowCount(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.rowCount(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.rowCount(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:rowCount", &arg))
        return 0;


    // Overloaded function decisor
    // 0: rowCount(QModelIndex)const
    if (numArgs == 0) {
        overloadId = 0; // rowCount(QModelIndex)const
    } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // rowCount(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_rowCount_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.rowCount(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex cpp_arg0_tmp = QModelIndex();
            QModelIndex* cpp_arg0 = arg ? Shiboken::Converter<QModelIndex* >::toCpp(arg) : &cpp_arg0_tmp;

            if(!PyErr_Occurred()) {
            // rowCount(QModelIndex)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemModel.rowCount()' not implemented.");
                return 0;
            }
            int cppResult = cppSelf->rowCount(*cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_rowCount_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex = QModelIndex()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractItemModel.rowCount", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_setData(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "role" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.setData(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.setData(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.setData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setData", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setData(QModelIndex,QVariant,int)
    if (numArgs >= 2 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // setData(QModelIndex,QVariant,int)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // setData(QModelIndex,QVariant,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_setData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "role");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "role";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.setData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);
            int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : Qt::EditRole;

            if(!PyErr_Occurred()) {
            // setData(QModelIndex,QVariant,int)
            bool cppResult = cppSelf->QAbstractItemModel::setData(*cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_setData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, QVariant, int = Qt.EditRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.setData", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_setHeaderData(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "role" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.setHeaderData(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.setHeaderData(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.setHeaderData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setHeaderData", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setHeaderData(int,Qt::Orientation,QVariant,int)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<Qt::Orientation >::isConvertible(pyargs[1]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setHeaderData(int,Qt::Orientation,QVariant,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setHeaderData(int,Qt::Orientation,QVariant,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_setHeaderData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "role");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "role";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.setHeaderData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::Orientation cpp_arg1 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[1]);
            QVariant cpp_arg2 = Shiboken::Converter<QVariant >::toCpp(pyargs[2]);
            int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : Qt::EditRole;

            if(!PyErr_Occurred()) {
            // setHeaderData(int,Qt::Orientation,QVariant,int)
            bool cppResult = cppSelf->QAbstractItemModel::setHeaderData(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_setHeaderData_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.Orientation, QVariant, int = Qt.EditRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.setHeaderData", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_setItemData(PyObject* self, PyObject* args)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setItemData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setItemData(QModelIndex,QMap<int,QVariant>)
    if (numArgs == 2 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && Shiboken::Converter< QMap<int, QVariant >  >::isConvertible(pyargs[1])) {
        overloadId = 0; // setItemData(QModelIndex,QMap<int,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_setItemData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            QMap<int, QVariant > cpp_arg1 = Shiboken::Converter<QMap<int, QVariant > >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setItemData(QModelIndex,QMap<int,QVariant>)
            bool cppResult = cppSelf->QAbstractItemModel::setItemData(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_setItemData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, dict", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.setItemData", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_setRoleNames(PyObject* self, PyObject* arg)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRoleNames(QHash<int,QByteArray>)
    if (Shiboken::Converter< QHash<int, QByteArray >  >::isConvertible(arg)) {
        overloadId = 0; // setRoleNames(QHash<int,QByteArray>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_setRoleNames_TypeError;

    // Call function/method
    {
        {
            QHash<int, QByteArray > cpp_arg0 = Shiboken::Converter<QHash<int, QByteArray > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRoleNames(QHash<int,QByteArray>)
            cppSelf->QAbstractItemModel::setRoleNames(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemModelFunc_setRoleNames_TypeError:
        const char* overloads[] = {"dict", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractItemModel.setRoleNames", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_setSupportedDragActions(PyObject* self, PyObject* arg)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSupportedDragActions(QFlags<Qt::DropAction>)
    if (Shiboken::Converter<QFlags<Qt::DropAction> >::isConvertible(arg)) {
        overloadId = 0; // setSupportedDragActions(QFlags<Qt::DropAction>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_setSupportedDragActions_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::DropAction> cpp_arg0 = Shiboken::Converter<QFlags<Qt::DropAction> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSupportedDragActions(QFlags<Qt::DropAction>)
            cppSelf->QAbstractItemModel::setSupportedDragActions(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemModelFunc_setSupportedDragActions_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DropActions", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractItemModel.setSupportedDragActions", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_sibling(PyObject* self, PyObject* args)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sibling", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: sibling(int,int,QModelIndex)const
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[2])) {
        overloadId = 0; // sibling(int,int,QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_sibling_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QModelIndex* cpp_arg2 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // sibling(int,int,QModelIndex)const
            QModelIndex cppResult = cppSelf->QAbstractItemModel::sibling(cpp_arg0, cpp_arg1, *cpp_arg2);
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_sibling_TypeError:
        const char* overloads[] = {"int, int, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.sibling", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_sort(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "order" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.sort(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.sort(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.sort(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:sort", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: sort(int,Qt::SortOrder)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // sort(int,Qt::SortOrder)
        } else if (Shiboken::Converter<Qt::SortOrder >::isConvertible(pyargs[1])) {
            overloadId = 0; // sort(int,Qt::SortOrder)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_sort_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "order");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "order";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractItemModel.sort(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::SortOrder cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[1]) : Qt::AscendingOrder;

            if(!PyErr_Occurred()) {
            // sort(int,Qt::SortOrder)
            cppSelf->QAbstractItemModel::sort(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemModelFunc_sort_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.SortOrder = Qt.AscendingOrder", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractItemModel.sort", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_span(PyObject* self, PyObject* arg)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: span(QModelIndex)const
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // span(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemModelFunc_span_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // span(QModelIndex)const
            QSize cppResult = cppSelf->QAbstractItemModel::span(*cpp_arg0);
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemModelFunc_span_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractItemModel.span", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemModelFunc_submit(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // submit()
            bool cppResult = cppSelf->QAbstractItemModel::submit();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemModelFunc_supportedDragActions(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedDragActions()const
            QFlags<Qt::DropAction> cppResult = cppSelf->QAbstractItemModel::supportedDragActions();
            pyResult = Shiboken::Converter<QFlags<Qt::DropAction> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemModelFunc_supportedDropActions(PyObject* self)
{
    QAbstractItemModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedDropActions()const
            QFlags<Qt::DropAction> cppResult = cppSelf->QAbstractItemModel::supportedDropActions();
            pyResult = Shiboken::Converter<QFlags<Qt::DropAction> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQAbstractItemModel_methods[] = {
    {"beginInsertColumns", (PyCFunction)SbkQAbstractItemModelFunc_beginInsertColumns, METH_VARARGS},
    {"beginInsertRows", (PyCFunction)SbkQAbstractItemModelFunc_beginInsertRows, METH_VARARGS},
    {"beginMoveColumns", (PyCFunction)SbkQAbstractItemModelFunc_beginMoveColumns, METH_VARARGS},
    {"beginMoveRows", (PyCFunction)SbkQAbstractItemModelFunc_beginMoveRows, METH_VARARGS},
    {"beginRemoveColumns", (PyCFunction)SbkQAbstractItemModelFunc_beginRemoveColumns, METH_VARARGS},
    {"beginRemoveRows", (PyCFunction)SbkQAbstractItemModelFunc_beginRemoveRows, METH_VARARGS},
    {"beginResetModel", (PyCFunction)SbkQAbstractItemModelFunc_beginResetModel, METH_NOARGS},
    {"buddy", (PyCFunction)SbkQAbstractItemModelFunc_buddy, METH_O},
    {"canFetchMore", (PyCFunction)SbkQAbstractItemModelFunc_canFetchMore, METH_O},
    {"changePersistentIndex", (PyCFunction)SbkQAbstractItemModelFunc_changePersistentIndex, METH_VARARGS},
    {"changePersistentIndexList", (PyCFunction)SbkQAbstractItemModelFunc_changePersistentIndexList, METH_VARARGS},
    {"columnCount", (PyCFunction)SbkQAbstractItemModelFunc_columnCount, METH_VARARGS|METH_KEYWORDS},
    {"createIndex", (PyCFunction)SbkQAbstractItemModelFunc_createIndex, METH_VARARGS|METH_KEYWORDS},
    {"data", (PyCFunction)SbkQAbstractItemModelFunc_data, METH_VARARGS|METH_KEYWORDS},
    {"decodeData", (PyCFunction)SbkQAbstractItemModelFunc_decodeData, METH_VARARGS},
    {"dropMimeData", (PyCFunction)SbkQAbstractItemModelFunc_dropMimeData, METH_VARARGS},
    {"encodeData", (PyCFunction)SbkQAbstractItemModelFunc_encodeData, METH_VARARGS},
    {"endInsertColumns", (PyCFunction)SbkQAbstractItemModelFunc_endInsertColumns, METH_NOARGS},
    {"endInsertRows", (PyCFunction)SbkQAbstractItemModelFunc_endInsertRows, METH_NOARGS},
    {"endMoveColumns", (PyCFunction)SbkQAbstractItemModelFunc_endMoveColumns, METH_NOARGS},
    {"endMoveRows", (PyCFunction)SbkQAbstractItemModelFunc_endMoveRows, METH_NOARGS},
    {"endRemoveColumns", (PyCFunction)SbkQAbstractItemModelFunc_endRemoveColumns, METH_NOARGS},
    {"endRemoveRows", (PyCFunction)SbkQAbstractItemModelFunc_endRemoveRows, METH_NOARGS},
    {"endResetModel", (PyCFunction)SbkQAbstractItemModelFunc_endResetModel, METH_NOARGS},
    {"fetchMore", (PyCFunction)SbkQAbstractItemModelFunc_fetchMore, METH_O},
    {"flags", (PyCFunction)SbkQAbstractItemModelFunc_flags, METH_O},
    {"hasChildren", (PyCFunction)SbkQAbstractItemModelFunc_hasChildren, METH_VARARGS|METH_KEYWORDS},
    {"hasIndex", (PyCFunction)SbkQAbstractItemModelFunc_hasIndex, METH_VARARGS|METH_KEYWORDS},
    {"headerData", (PyCFunction)SbkQAbstractItemModelFunc_headerData, METH_VARARGS|METH_KEYWORDS},
    {"index", (PyCFunction)SbkQAbstractItemModelFunc_index, METH_VARARGS|METH_KEYWORDS},
    {"insertColumn", (PyCFunction)SbkQAbstractItemModelFunc_insertColumn, METH_VARARGS|METH_KEYWORDS},
    {"insertColumns", (PyCFunction)SbkQAbstractItemModelFunc_insertColumns, METH_VARARGS|METH_KEYWORDS},
    {"insertRow", (PyCFunction)SbkQAbstractItemModelFunc_insertRow, METH_VARARGS|METH_KEYWORDS},
    {"insertRows", (PyCFunction)SbkQAbstractItemModelFunc_insertRows, METH_VARARGS|METH_KEYWORDS},
    {"itemData", (PyCFunction)SbkQAbstractItemModelFunc_itemData, METH_O},
    {"match", (PyCFunction)SbkQAbstractItemModelFunc_match, METH_VARARGS|METH_KEYWORDS},
    {"mimeData", (PyCFunction)SbkQAbstractItemModelFunc_mimeData, METH_O},
    {"mimeTypes", (PyCFunction)SbkQAbstractItemModelFunc_mimeTypes, METH_NOARGS},
    {"parent", (PyCFunction)SbkQAbstractItemModelFunc_parent, METH_NOARGS|METH_O},
    {"persistentIndexList", (PyCFunction)SbkQAbstractItemModelFunc_persistentIndexList, METH_NOARGS},
    {"removeColumn", (PyCFunction)SbkQAbstractItemModelFunc_removeColumn, METH_VARARGS|METH_KEYWORDS},
    {"removeColumns", (PyCFunction)SbkQAbstractItemModelFunc_removeColumns, METH_VARARGS|METH_KEYWORDS},
    {"removeRow", (PyCFunction)SbkQAbstractItemModelFunc_removeRow, METH_VARARGS|METH_KEYWORDS},
    {"removeRows", (PyCFunction)SbkQAbstractItemModelFunc_removeRows, METH_VARARGS|METH_KEYWORDS},
    {"reset", (PyCFunction)SbkQAbstractItemModelFunc_reset, METH_NOARGS},
    {"revert", (PyCFunction)SbkQAbstractItemModelFunc_revert, METH_NOARGS},
    {"roleNames", (PyCFunction)SbkQAbstractItemModelFunc_roleNames, METH_NOARGS},
    {"rowCount", (PyCFunction)SbkQAbstractItemModelFunc_rowCount, METH_VARARGS|METH_KEYWORDS},
    {"setData", (PyCFunction)SbkQAbstractItemModelFunc_setData, METH_VARARGS|METH_KEYWORDS},
    {"setHeaderData", (PyCFunction)SbkQAbstractItemModelFunc_setHeaderData, METH_VARARGS|METH_KEYWORDS},
    {"setItemData", (PyCFunction)SbkQAbstractItemModelFunc_setItemData, METH_VARARGS},
    {"setRoleNames", (PyCFunction)SbkQAbstractItemModelFunc_setRoleNames, METH_O},
    {"setSupportedDragActions", (PyCFunction)SbkQAbstractItemModelFunc_setSupportedDragActions, METH_O},
    {"sibling", (PyCFunction)SbkQAbstractItemModelFunc_sibling, METH_VARARGS},
    {"sort", (PyCFunction)SbkQAbstractItemModelFunc_sort, METH_VARARGS|METH_KEYWORDS},
    {"span", (PyCFunction)SbkQAbstractItemModelFunc_span, METH_O},
    {"submit", (PyCFunction)SbkQAbstractItemModelFunc_submit, METH_NOARGS},
    {"supportedDragActions", (PyCFunction)SbkQAbstractItemModelFunc_supportedDragActions, METH_NOARGS},
    {"supportedDropActions", (PyCFunction)SbkQAbstractItemModelFunc_supportedDropActions, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQAbstractItemModel_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QAbstractItemModel",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQAbstractItemModel_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQAbstractItemModel_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QAbstractItemModel >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QAbstractItemModel*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQAbstractItemModel_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QAbstractItemModel*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQAbstractItemModel_Type;
    return 0;
}


void init_QAbstractItemModel(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QABSTRACTITEMMODEL_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQAbstractItemModel_Type);

    SbkQAbstractItemModel_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQAbstractItemModel_Type.type_discovery = &SbkQAbstractItemModel_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQAbstractItemModel_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQAbstractItemModel_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQAbstractItemModel_Type));
    PyModule_AddObject(module, "QAbstractItemModel",
        ((PyObject*)&SbkQAbstractItemModel_Type));

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("columnsAboutToBeRemoved", "const QModelIndex&,int,int", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "columnsAboutToBeRemoved", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("rowsMoved", "const QModelIndex&,int,int,const QModelIndex&,int", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "rowsMoved", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("columnsRemoved", "const QModelIndex&,int,int", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "columnsRemoved", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("columnsMoved", "const QModelIndex&,int,int,const QModelIndex&,int", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "columnsMoved", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("rowsAboutToBeInserted", "const QModelIndex&,int,int", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "rowsAboutToBeInserted", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("columnsInserted", "const QModelIndex&,int,int", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "columnsInserted", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("rowsRemoved", "const QModelIndex&,int,int", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "rowsRemoved", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("rowsInserted", "const QModelIndex&,int,int", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "rowsInserted", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("dataChanged", "const QModelIndex&,const QModelIndex&", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "dataChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("headerDataChanged", "Qt::Orientation,int,int", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "headerDataChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("rowsAboutToBeMoved", "const QModelIndex&,int,int,const QModelIndex&,int", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "rowsAboutToBeMoved", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("modelReset", "void", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "modelReset", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("rowsAboutToBeRemoved", "const QModelIndex&,int,int", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "rowsAboutToBeRemoved", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("columnsAboutToBeInserted", "const QModelIndex&,int,int", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "columnsAboutToBeInserted", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("layoutAboutToBeChanged", "void", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "layoutAboutToBeChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("layoutChanged", "void", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "layoutChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("modelAboutToBeReset", "void", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "modelAboutToBeReset", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("columnsAboutToBeMoved", "const QModelIndex&,int,int,const QModelIndex&,int", NULL);
    PyDict_SetItemString(SbkQAbstractItemModel_Type.super.ht_type.tp_dict, "columnsAboutToBeMoved", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractItemModel >("QAbstractItemModel*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractItemModel >(typeid(QAbstractItemModel).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractItemModel >(typeid(QAbstractItemModelWrapper).name());
    PySide::initQtMetaType<QAbstractItemModel* >();
}

