/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qgraphicsitem_wrapper.h"

// Extra includes
#include <QList>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qgraphicseffect.h>
#include <qgraphicsitem.h>
#include <qgraphicsscene.h>
#include <qgraphicssceneevent.h>
#include <qgraphicstransform.h>
#include <qgraphicswidget.h>
#include <qpainter.h>
#include <qpainterpath.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qstyleoption.h>
#include <qtransform.h>
#include <qwidget.h>

using namespace Shiboken;


// Native ---------------------------------------------------------

QGraphicsItemWrapper::QGraphicsItemWrapper(QGraphicsItem * parent, QGraphicsScene * scene) : QGraphicsItem(parent, scene) {
    // ... middle
}

void QGraphicsItemWrapper::advance(int phase)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "advance"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::advance(phase);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        phase
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QRectF QGraphicsItemWrapper::boundingRect() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "boundingRect"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QGraphicsItem.boundingRect()' not implemented.");
        return QRectF();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRectF();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QRectF >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItem.boundingRect", SbkType<QRectF >()->tp_name, pyResult->ob_type->tp_name);
        return QRectF();
    }
    QRectF cppResult(Shiboken::Converter<QRectF >::toCpp(pyResult));
    return cppResult;
}

bool QGraphicsItemWrapper::collidesWithItem(const QGraphicsItem * other, Qt::ItemSelectionMode mode) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "collidesWithItem"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::collidesWithItem(other, mode);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< QGraphicsItem * >::toPython(other),
        Shiboken::Converter<Qt::ItemSelectionMode >::toPython(mode)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItem.collidesWithItem", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QGraphicsItemWrapper::collidesWithPath(const QPainterPath & path, Qt::ItemSelectionMode mode) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "collidesWithPath"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::collidesWithPath(path, mode);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QPainterPath & >::toPython(path),
        Shiboken::Converter<Qt::ItemSelectionMode >::toPython(mode)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItem.collidesWithPath", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QGraphicsItemWrapper::contains(const QPointF & point) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contains"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::contains(point);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QPointF & >::toPython(point)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItem.contains", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsItemWrapper::contextMenuEvent(QGraphicsSceneContextMenuEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::contextMenuEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneContextMenuEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::dragEnterEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::dragLeaveEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::dragMoveEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::dropEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QGraphicsItemWrapper::extension(const QVariant & variant) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "extension"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::extension(variant);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QVariant >::toPython(variant)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItem.extension", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsItemWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::hoverEnterEvent(QGraphicsSceneHoverEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hoverEnterEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::hoverEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneHoverEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::hoverLeaveEvent(QGraphicsSceneHoverEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hoverLeaveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::hoverLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneHoverEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::hoverMoveEvent(QGraphicsSceneHoverEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hoverMoveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::hoverMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneHoverEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QInputMethodEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QGraphicsItemWrapper::inputMethodQuery(Qt::InputMethodQuery query) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::inputMethodQuery(query);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<Qt::InputMethodQuery >::toPython(query)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItem.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

bool QGraphicsItemWrapper::isObscuredBy(const QGraphicsItem * item) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "isObscuredBy"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::isObscuredBy(item);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QGraphicsItem * >::toPython(item)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItem.isObscuredBy", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

QVariant QGraphicsItemWrapper::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "itemChange"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::itemChange(change, value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QGraphicsItem::GraphicsItemChange >::toPython(change),
        Shiboken::Converter<QVariant >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItem.itemChange", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsItemWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::mouseDoubleClickEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::mouseMoveEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::mousePressEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemWrapper::mouseReleaseEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QPainterPath QGraphicsItemWrapper::opaqueArea() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "opaqueArea"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::opaqueArea();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPainterPath();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPainterPath >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItem.opaqueArea", SbkType<QPainterPath >()->tp_name, pyResult->ob_type->tp_name);
        return QPainterPath();
    }
    QPainterPath cppResult(Shiboken::Converter<QPainterPath >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsItemWrapper::paint(QPainter * painter, const QStyleOptionGraphicsItem * option, QWidget * widget)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paint"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QGraphicsItem.paint()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter<QPainter * >::toPython(painter),
        Shiboken::Converter<const QStyleOptionGraphicsItem * >::toPython(option),
        Shiboken::Converter<QWidget * >::toPython(widget)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QGraphicsItemWrapper::sceneEvent(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sceneEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::sceneEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItem.sceneEvent", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QGraphicsItemWrapper::sceneEventFilter(QGraphicsItem * watched, QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sceneEventFilter"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::sceneEventFilter(watched, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QGraphicsItem * >::toPython(watched),
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItem.sceneEventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

QPainterPath QGraphicsItemWrapper::shape() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "shape"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::shape();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPainterPath();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPainterPath >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItem.shape", SbkType<QPainterPath >()->tp_name, pyResult->ob_type->tp_name);
        return QPainterPath();
    }
    QPainterPath cppResult(Shiboken::Converter<QPainterPath >::toCpp(pyResult));
    return cppResult;
}

int QGraphicsItemWrapper::type() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "type"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::type();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItem.type", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsItemWrapper::wheelEvent(QGraphicsSceneWheelEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::wheelEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneWheelEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QGraphicsItemWrapper::~QGraphicsItemWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGraphicsItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsItem >()))
        return -1;

    QGraphicsItemWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSITEM_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QGraphicsItem' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent", "scene" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QGraphicsItem", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsItem(QGraphicsItem*,QGraphicsScene*)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsItem(QGraphicsItem*,QGraphicsScene*)
    } else if (Shiboken::Converter<QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QGraphicsItem(QGraphicsItem*,QGraphicsScene*)
        } else if (Shiboken::Converter<QGraphicsScene * >::isConvertible(pyargs[1])) {
            overloadId = 0; // QGraphicsItem(QGraphicsItem*,QGraphicsScene*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItem_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "scene");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "scene";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return -1;
            QGraphicsItem* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]) : 0;
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return -1;
            QGraphicsScene* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QGraphicsScene* >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // QGraphicsItem(QGraphicsItem*,QGraphicsScene*)
            cptr = new QGraphicsItemWrapper(cpp_arg0, cpp_arg1);
            Shiboken::setParent(pyargs[0], self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGraphicsItem_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQGraphicsItem_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem = None, PySide.QtGui.QGraphicsScene = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem", overloads);
        return -1;
}

static PyObject* SbkQGraphicsItemFunc_acceptDrops(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // acceptDrops()const
            bool cppResult = cppSelf->QGraphicsItem::acceptDrops();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_acceptHoverEvents(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // acceptHoverEvents()const
            bool cppResult = cppSelf->QGraphicsItem::acceptHoverEvents();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_acceptTouchEvents(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // acceptTouchEvents()const
            bool cppResult = cppSelf->QGraphicsItem::acceptTouchEvents();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_acceptedMouseButtons(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // acceptedMouseButtons()const
            QFlags<Qt::MouseButton> cppResult = cppSelf->QGraphicsItem::acceptedMouseButtons();
            pyResult = Shiboken::Converter<QFlags<Qt::MouseButton> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_acceptsHoverEvents(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // acceptsHoverEvents()const
            bool cppResult = cppSelf->QGraphicsItem::acceptsHoverEvents();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_addToIndex(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // addToIndex()
            cppSelf->QGraphicsItem::addToIndex();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemFunc_advance(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: advance(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // advance(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_advance_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // advance(int)
            cppSelf->QGraphicsItem::advance(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_advance_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.advance", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_boundingRect(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // boundingRect()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QGraphicsItem.boundingRect()' not implemented.");
                return 0;
            }
            QRectF cppResult = cppSelf->boundingRect();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_boundingRegion(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: boundingRegion(QTransform)const
    if (Shiboken::Converter<const QTransform & >::isConvertible(arg)) {
        overloadId = 0; // boundingRegion(QTransform)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_boundingRegion_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // boundingRegion(QTransform)const
            QRegion cppResult = cppSelf->QGraphicsItem::boundingRegion(*cpp_arg0);
            pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_boundingRegion_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.boundingRegion", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_boundingRegionGranularity(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // boundingRegionGranularity()const
            qreal cppResult = cppSelf->QGraphicsItem::boundingRegionGranularity();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_cacheMode(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cacheMode()const
            QGraphicsItem::CacheMode cppResult = cppSelf->QGraphicsItem::cacheMode();
            pyResult = Shiboken::Converter<QGraphicsItem::CacheMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_childItems(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childItems()const
            QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsItem::childItems();
            pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_childrenBoundingRect(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childrenBoundingRect()const
            QRectF cppResult = cppSelf->QGraphicsItem::childrenBoundingRect();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_clearFocus(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearFocus()
            cppSelf->QGraphicsItem::clearFocus();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemFunc_clipPath(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clipPath()const
            QPainterPath cppResult = cppSelf->QGraphicsItem::clipPath();
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_collidesWithItem(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.collidesWithItem(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.collidesWithItem(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.collidesWithItem(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:collidesWithItem", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: collidesWithItem(const QGraphicsItem*,Qt::ItemSelectionMode)const
    if (Shiboken::Converter< QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // collidesWithItem(const QGraphicsItem*,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // collidesWithItem(const QGraphicsItem*,Qt::ItemSelectionMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_collidesWithItem_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.collidesWithItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
            Qt::ItemSelectionMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

            if(!PyErr_Occurred()) {
            // collidesWithItem(const QGraphicsItem*,Qt::ItemSelectionMode)const
            bool cppResult = cppSelf->QGraphicsItem::collidesWithItem(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_collidesWithItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.collidesWithItem", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_collidesWithPath(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.collidesWithPath(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.collidesWithPath(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.collidesWithPath(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:collidesWithPath", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: collidesWithPath(QPainterPath,Qt::ItemSelectionMode)const
    if (Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // collidesWithPath(QPainterPath,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // collidesWithPath(QPainterPath,Qt::ItemSelectionMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_collidesWithPath_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.collidesWithPath(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);
            Qt::ItemSelectionMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

            if(!PyErr_Occurred()) {
            // collidesWithPath(QPainterPath,Qt::ItemSelectionMode)const
            bool cppResult = cppSelf->QGraphicsItem::collidesWithPath(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_collidesWithPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.collidesWithPath", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_collidingItems(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.collidingItems(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.collidingItems(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:collidingItems", &arg))
        return 0;


    // Overloaded function decisor
    // 0: collidingItems(Qt::ItemSelectionMode)const
    if (numArgs == 0) {
        overloadId = 0; // collidingItems(Qt::ItemSelectionMode)const
    } else if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(arg)) {
        overloadId = 0; // collidingItems(Qt::ItemSelectionMode)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_collidingItems_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (arg)
                        errorArgName = "mode";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.collidingItems(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::ItemSelectionMode cpp_arg0 = arg ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(arg) : Qt::IntersectsItemShape;

            if(!PyErr_Occurred()) {
            // collidingItems(Qt::ItemSelectionMode)const
            QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsItem::collidingItems(cpp_arg0);
            pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_collidingItems_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.collidingItems", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_commonAncestorItem(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: commonAncestorItem(const QGraphicsItem*)const
    if (Shiboken::Converter< QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // commonAncestorItem(const QGraphicsItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_commonAncestorItem_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // commonAncestorItem(const QGraphicsItem*)const
            QGraphicsItem * cppResult = cppSelf->QGraphicsItem::commonAncestorItem(cpp_arg0);
            pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_commonAncestorItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.commonAncestorItem", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_contains(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(QPointF)const
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // contains(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_contains_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // contains(QPointF)const
            bool cppResult = cppSelf->QGraphicsItem::contains(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.contains", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_contextMenuEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: contextMenuEvent(QGraphicsSceneContextMenuEvent*)
    if (Shiboken::Converter<QGraphicsSceneContextMenuEvent * >::isConvertible(arg)) {
        overloadId = 0; // contextMenuEvent(QGraphicsSceneContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_contextMenuEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneContextMenuEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneContextMenuEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // contextMenuEvent(QGraphicsSceneContextMenuEvent*)
            cppSelf->QGraphicsItem::contextMenuEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_contextMenuEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneContextMenuEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.contextMenuEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_cursor(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cursor()const
            QCursor cppResult = cppSelf->QGraphicsItem::cursor();
            pyResult = Shiboken::Converter<QCursor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_data(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: data(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // data(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_data_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // data(int)const
            QVariant cppResult = cppSelf->QGraphicsItem::data(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_data_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.data", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_deviceTransform(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: deviceTransform(QTransform)const
    if (Shiboken::Converter<const QTransform & >::isConvertible(arg)) {
        overloadId = 0; // deviceTransform(QTransform)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_deviceTransform_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // deviceTransform(QTransform)const
            QTransform cppResult = cppSelf->QGraphicsItem::deviceTransform(*cpp_arg0);
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_deviceTransform_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.deviceTransform", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_dragEnterEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragEnterEvent(QGraphicsSceneDragDropEvent*)
    if (Shiboken::Converter<QGraphicsSceneDragDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragEnterEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_dragEnterEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneDragDropEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneDragDropEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragEnterEvent(QGraphicsSceneDragDropEvent*)
            cppSelf->QGraphicsItem::dragEnterEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_dragEnterEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneDragDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.dragEnterEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_dragLeaveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragLeaveEvent(QGraphicsSceneDragDropEvent*)
    if (Shiboken::Converter<QGraphicsSceneDragDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragLeaveEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_dragLeaveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneDragDropEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneDragDropEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragLeaveEvent(QGraphicsSceneDragDropEvent*)
            cppSelf->QGraphicsItem::dragLeaveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_dragLeaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneDragDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.dragLeaveEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_dragMoveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragMoveEvent(QGraphicsSceneDragDropEvent*)
    if (Shiboken::Converter<QGraphicsSceneDragDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragMoveEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_dragMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneDragDropEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneDragDropEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragMoveEvent(QGraphicsSceneDragDropEvent*)
            cppSelf->QGraphicsItem::dragMoveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_dragMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneDragDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.dragMoveEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_dropEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dropEvent(QGraphicsSceneDragDropEvent*)
    if (Shiboken::Converter<QGraphicsSceneDragDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dropEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_dropEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneDragDropEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneDragDropEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dropEvent(QGraphicsSceneDragDropEvent*)
            cppSelf->QGraphicsItem::dropEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_dropEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneDragDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.dropEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_effectiveOpacity(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // effectiveOpacity()const
            qreal cppResult = cppSelf->QGraphicsItem::effectiveOpacity();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_ensureVisible(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "rect", "xmargin", "ymargin" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.ensureVisible(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.ensureVisible(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:ensureVisible", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: ensureVisible(QRectF,int,int)
    // 1: ensureVisible(qreal,qreal,qreal,qreal,int,int)
    if (numArgs == 0) {
        overloadId = 0; // ensureVisible(QRectF,int,int)
    } else if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 1; // ensureVisible(qreal,qreal,qreal,qreal,int,int)
        } else if (SbkNumber_Check(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 1; // ensureVisible(qreal,qreal,qreal,qreal,int,int)
            } else if (SbkNumber_Check(pyargs[5])) {
                overloadId = 1; // ensureVisible(qreal,qreal,qreal,qreal,int,int)
            }
        }
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // ensureVisible(QRectF,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // ensureVisible(QRectF,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // ensureVisible(QRectF,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_ensureVisible_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // ensureVisible(QRectF,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "rect");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "rect";
                        else
                            pyargs[0] = value;
                    }
                    value = PyDict_GetItemString(kwds, "xmargin");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "xmargin";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "ymargin");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "ymargin";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.ensureVisible(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF cpp_arg0_tmp = QRectF();
                QRectF* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QRectF* >::toCpp(pyargs[0]) : &cpp_arg0_tmp;
                if (pyargs[0] && !Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 50;
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 50;

                if(!PyErr_Occurred()) {
                // ensureVisible(QRectF,int,int)
                cppSelf->QGraphicsItem::ensureVisible(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // ensureVisible(qreal,qreal,qreal,qreal,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "xmargin");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "xmargin";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "ymargin");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "ymargin";
                        else
                            pyargs[5] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.ensureVisible(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                int cpp_arg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 50;
                int cpp_arg5 = pyargs[5] ? Shiboken::Converter<int >::toCpp(pyargs[5]) : 50;

                if(!PyErr_Occurred()) {
                // ensureVisible(qreal,qreal,qreal,qreal,int,int)
                cppSelf->QGraphicsItem::ensureVisible(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_ensureVisible_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF = QRectF(), int = 50, int = 50", "float, float, float, float, int = 50, int = 50", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.ensureVisible", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_extension(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: extension(QVariant)const
    if (Shiboken::Converter<QVariant >::isConvertible(arg)) {
        overloadId = 0; // extension(QVariant)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_extension_TypeError;

    // Call function/method
    {
        {
            QVariant cpp_arg0 = Shiboken::Converter<QVariant >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // extension(QVariant)const
            QVariant cppResult = cppSelf->QGraphicsItem::extension(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_extension_TypeError:
        const char* overloads[] = {"QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.extension", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_filtersChildEvents(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // filtersChildEvents()const
            bool cppResult = cppSelf->QGraphicsItem::filtersChildEvents();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_flags(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // flags()const
            QFlags<QGraphicsItem::GraphicsItemFlag> cppResult = cppSelf->QGraphicsItem::flags();
            pyResult = Shiboken::Converter<QFlags<QGraphicsItem::GraphicsItemFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_focusInEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusInEvent(QFocusEvent*)
    if (Shiboken::Converter<QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_focusInEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QFocusEvent* cpp_arg0 = Shiboken::Converter<QFocusEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusInEvent(QFocusEvent*)
            cppSelf->QGraphicsItem::focusInEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_focusInEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.focusInEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_focusItem(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // focusItem()const
            QGraphicsItem * cppResult = cppSelf->QGraphicsItem::focusItem();
            pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_focusOutEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusOutEvent(QFocusEvent*)
    if (Shiboken::Converter<QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_focusOutEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QFocusEvent* cpp_arg0 = Shiboken::Converter<QFocusEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusOutEvent(QFocusEvent*)
            cppSelf->QGraphicsItem::focusOutEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_focusOutEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.focusOutEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_focusProxy(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // focusProxy()const
            QGraphicsItem * cppResult = cppSelf->QGraphicsItem::focusProxy();
            pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_focusScopeItem(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // focusScopeItem()const
            QGraphicsItem * cppResult = cppSelf->QGraphicsItem::focusScopeItem();
            pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_grabKeyboard(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // grabKeyboard()
            cppSelf->QGraphicsItem::grabKeyboard();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemFunc_grabMouse(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // grabMouse()
            cppSelf->QGraphicsItem::grabMouse();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemFunc_graphicsEffect(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // graphicsEffect()const
            QGraphicsEffect * cppResult = cppSelf->QGraphicsItem::graphicsEffect();
            pyResult = Shiboken::Converter<QGraphicsEffect * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_group(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // group()const
            QGraphicsItemGroup * cppResult = cppSelf->QGraphicsItem::group();
            pyResult = Shiboken::Converter<QGraphicsItemGroup * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_handlesChildEvents(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // handlesChildEvents()const
            bool cppResult = cppSelf->QGraphicsItem::handlesChildEvents();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_hasCursor(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasCursor()const
            bool cppResult = cppSelf->QGraphicsItem::hasCursor();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_hasFocus(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasFocus()const
            bool cppResult = cppSelf->QGraphicsItem::hasFocus();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_hide(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hide()
            cppSelf->QGraphicsItem::hide();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemFunc_hoverEnterEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: hoverEnterEvent(QGraphicsSceneHoverEvent*)
    if (Shiboken::Converter<QGraphicsSceneHoverEvent * >::isConvertible(arg)) {
        overloadId = 0; // hoverEnterEvent(QGraphicsSceneHoverEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_hoverEnterEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneHoverEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneHoverEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hoverEnterEvent(QGraphicsSceneHoverEvent*)
            cppSelf->QGraphicsItem::hoverEnterEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_hoverEnterEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneHoverEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.hoverEnterEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_hoverLeaveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: hoverLeaveEvent(QGraphicsSceneHoverEvent*)
    if (Shiboken::Converter<QGraphicsSceneHoverEvent * >::isConvertible(arg)) {
        overloadId = 0; // hoverLeaveEvent(QGraphicsSceneHoverEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_hoverLeaveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneHoverEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneHoverEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hoverLeaveEvent(QGraphicsSceneHoverEvent*)
            cppSelf->QGraphicsItem::hoverLeaveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_hoverLeaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneHoverEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.hoverLeaveEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_hoverMoveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: hoverMoveEvent(QGraphicsSceneHoverEvent*)
    if (Shiboken::Converter<QGraphicsSceneHoverEvent * >::isConvertible(arg)) {
        overloadId = 0; // hoverMoveEvent(QGraphicsSceneHoverEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_hoverMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneHoverEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneHoverEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hoverMoveEvent(QGraphicsSceneHoverEvent*)
            cppSelf->QGraphicsItem::hoverMoveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_hoverMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneHoverEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.hoverMoveEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_inputMethodEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodEvent(QInputMethodEvent*)
    if (Shiboken::Converter<QInputMethodEvent * >::isConvertible(arg)) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_inputMethodEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QInputMethodEvent* cpp_arg0 = Shiboken::Converter<QInputMethodEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodEvent(QInputMethodEvent*)
            cppSelf->QGraphicsItem::inputMethodEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_inputMethodEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputMethodEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.inputMethodEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_inputMethodHints(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // inputMethodHints()const
            QFlags<Qt::InputMethodHint> cppResult = cppSelf->QGraphicsItem::inputMethodHints();
            pyResult = Shiboken::Converter<QFlags<Qt::InputMethodHint> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_inputMethodQuery(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodQuery(Qt::InputMethodQuery)const
    if (Shiboken::Converter<Qt::InputMethodQuery >::isConvertible(arg)) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_inputMethodQuery_TypeError;

    // Call function/method
    {
        {
            Qt::InputMethodQuery cpp_arg0 = Shiboken::Converter<Qt::InputMethodQuery >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodQuery(Qt::InputMethodQuery)const
            QVariant cppResult = cppSelf->QGraphicsItem::inputMethodQuery(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_inputMethodQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodQuery", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.inputMethodQuery", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_installSceneEventFilter(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: installSceneEventFilter(QGraphicsItem*)
    if (Shiboken::Converter<QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // installSceneEventFilter(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_installSceneEventFilter_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // installSceneEventFilter(QGraphicsItem*)
            cppSelf->QGraphicsItem::installSceneEventFilter(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_installSceneEventFilter_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.installSceneEventFilter", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_isActive(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isActive()const
            bool cppResult = cppSelf->QGraphicsItem::isActive();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_isAncestorOf(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isAncestorOf(const QGraphicsItem*)const
    if (Shiboken::Converter< QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // isAncestorOf(const QGraphicsItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_isAncestorOf_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isAncestorOf(const QGraphicsItem*)const
            bool cppResult = cppSelf->QGraphicsItem::isAncestorOf(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_isAncestorOf_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.isAncestorOf", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_isBlockedByModalPanel(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isBlockedByModalPanel(QGraphicsItem**)const
            // Begin code injection
            
            QGraphicsItem *item_ = NULL;
            bool retval_ = cppSelf->isBlockedByModalPanel(&item_);
            pyResult = Shiboken::makeTuple(retval_, item_);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_isClipped(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isClipped()const
            bool cppResult = cppSelf->QGraphicsItem::isClipped();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_isEnabled(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEnabled()const
            bool cppResult = cppSelf->QGraphicsItem::isEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_isObscured(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQGraphicsItemFunc_isObscured_TypeError;

    if (!PyArg_UnpackTuple(args, "isObscured", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: isObscured()const
    // 1: isObscured(QRectF)const
    // 2: isObscured(qreal,qreal,qreal,qreal)const
    if (numArgs == 0) {
        overloadId = 0; // isObscured()const
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 2; // isObscured(qreal,qreal,qreal,qreal)const
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // isObscured(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_isObscured_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // isObscured()const
            {

                if(!PyErr_Occurred()) {
                // isObscured()const
                bool cppResult = cppSelf->QGraphicsItem::isObscured();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // isObscured(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // isObscured(QRectF)const
                bool cppResult = cppSelf->QGraphicsItem::isObscured(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // isObscured(qreal,qreal,qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // isObscured(qreal,qreal,qreal,qreal)const
                bool cppResult = cppSelf->QGraphicsItem::isObscured(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_isObscured_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.isObscured", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_isObscuredBy(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isObscuredBy(const QGraphicsItem*)const
    if (Shiboken::Converter< QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // isObscuredBy(const QGraphicsItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_isObscuredBy_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isObscuredBy(const QGraphicsItem*)const
            bool cppResult = cppSelf->QGraphicsItem::isObscuredBy(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_isObscuredBy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.isObscuredBy", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_isPanel(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isPanel()const
            bool cppResult = cppSelf->QGraphicsItem::isPanel();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_isSelected(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSelected()const
            bool cppResult = cppSelf->QGraphicsItem::isSelected();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_isUnderMouse(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isUnderMouse()const
            bool cppResult = cppSelf->QGraphicsItem::isUnderMouse();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_isVisible(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isVisible()const
            bool cppResult = cppSelf->QGraphicsItem::isVisible();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_isVisibleTo(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isVisibleTo(const QGraphicsItem*)const
    if (Shiboken::Converter< QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // isVisibleTo(const QGraphicsItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_isVisibleTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isVisibleTo(const QGraphicsItem*)const
            bool cppResult = cppSelf->QGraphicsItem::isVisibleTo(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_isVisibleTo_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.isVisibleTo", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_isWidget(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isWidget()const
            bool cppResult = cppSelf->QGraphicsItem::isWidget();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_isWindow(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isWindow()const
            bool cppResult = cppSelf->QGraphicsItem::isWindow();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_itemChange(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemChange", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: itemChange(QGraphicsItem::GraphicsItemChange,QVariant)
    if (numArgs == 2 && Shiboken::Converter<QGraphicsItem::GraphicsItemChange >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // itemChange(QGraphicsItem::GraphicsItemChange,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_itemChange_TypeError;

    // Call function/method
    {
        {
            QGraphicsItem::GraphicsItemChange cpp_arg0 = Shiboken::Converter<QGraphicsItem::GraphicsItemChange >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // itemChange(QGraphicsItem::GraphicsItemChange,QVariant)
            QVariant cppResult = cppSelf->QGraphicsItem::itemChange(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_itemChange_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem.GraphicsItemChange, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.itemChange", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_itemTransform(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "ok" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.itemTransform(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.itemTransform(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.itemTransform(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:itemTransform", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: itemTransform(const QGraphicsItem*,bool*)const
    if (Shiboken::Converter< QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // itemTransform(const QGraphicsItem*,bool*)const
        } else if (PyBool_Check(pyargs[1])) {
            overloadId = 0; // itemTransform(const QGraphicsItem*,bool*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_itemTransform_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "ok");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "ok";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.itemTransform(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
            bool * cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool * >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // itemTransform(const QGraphicsItem*,bool*)const
            QTransform cppResult = cppSelf->QGraphicsItem::itemTransform(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_itemTransform_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, bool = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.itemTransform", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_keyPressEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyPressEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_keyPressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyPressEvent(QKeyEvent*)
            cppSelf->QGraphicsItem::keyPressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_keyPressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.keyPressEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_keyReleaseEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyReleaseEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_keyReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyReleaseEvent(QKeyEvent*)
            cppSelf->QGraphicsItem::keyReleaseEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_keyReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.keyReleaseEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mapFromItem(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4)
        goto SbkQGraphicsItemFunc_mapFromItem_TypeError;

    if (!PyArg_UnpackTuple(args, "mapFromItem", 2, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: mapFromItem(const QGraphicsItem*,QPainterPath)const
    // 1: mapFromItem(const QGraphicsItem*,QPointF)const
    // 2: mapFromItem(const QGraphicsItem*,QPolygonF)const
    // 3: mapFromItem(const QGraphicsItem*,QRectF)const
    // 4: mapFromItem(const QGraphicsItem*,qreal,qreal)const
    // 5: mapFromItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
    if (Shiboken::Converter< QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs >= 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 4; // mapFromItem(const QGraphicsItem*,qreal,qreal)const
            } else if (numArgs == 5 && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
                overloadId = 5; // mapFromItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
            }
        } else if (numArgs == 2 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1])) {
            overloadId = 3; // mapFromItem(const QGraphicsItem*,QRectF)const
        } else if (numArgs == 2 && Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[1])) {
            overloadId = 2; // mapFromItem(const QGraphicsItem*,QPolygonF)const
        } else if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
            overloadId = 1; // mapFromItem(const QGraphicsItem*,QPointF)const
        } else if (numArgs == 2 && Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[1])) {
            overloadId = 0; // mapFromItem(const QGraphicsItem*,QPainterPath)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mapFromItem_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapFromItem(const QGraphicsItem*,QPainterPath)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QPainterPath* cpp_arg1 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // mapFromItem(const QGraphicsItem*,QPainterPath)const
                QPainterPath cppResult = cppSelf->QGraphicsItem::mapFromItem(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapFromItem(const QGraphicsItem*,QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
                QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // mapFromItem(const QGraphicsItem*,QPointF)const
                QPointF cppResult = cppSelf->QGraphicsItem::mapFromItem(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 2: // mapFromItem(const QGraphicsItem*,QPolygonF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg1_auto_ptr;
                QPolygonF* cpp_arg1 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // mapFromItem(const QGraphicsItem*,QPolygonF)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapFromItem(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 3: // mapFromItem(const QGraphicsItem*,QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
                QRectF* cpp_arg1 = Shiboken::Converter<QRectF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // mapFromItem(const QGraphicsItem*,QRectF)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapFromItem(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 4: // mapFromItem(const QGraphicsItem*,qreal,qreal)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // mapFromItem(const QGraphicsItem*,qreal,qreal)const
                QPointF cppResult = cppSelf->QGraphicsItem::mapFromItem(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 5: // mapFromItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // mapFromItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapFromItem(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_mapFromItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtGui.QPainterPath", "PySide.QtGui.QGraphicsItem, PySide.QtCore.QPointF", "PySide.QtGui.QGraphicsItem, PySide.QtGui.QPolygonF", "PySide.QtGui.QGraphicsItem, PySide.QtCore.QRectF", "PySide.QtGui.QGraphicsItem, float, float", "PySide.QtGui.QGraphicsItem, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.mapFromItem", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mapFromParent(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQGraphicsItemFunc_mapFromParent_TypeError;

    if (!PyArg_UnpackTuple(args, "mapFromParent", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: mapFromParent(QPainterPath)const
    // 1: mapFromParent(QPointF)const
    // 2: mapFromParent(QPolygonF)const
    // 3: mapFromParent(QRectF)const
    // 4: mapFromParent(qreal,qreal)const
    // 5: mapFromParent(qreal,qreal,qreal,qreal)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 4; // mapFromParent(qreal,qreal)const
        } else if (numArgs == 4 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 5; // mapFromParent(qreal,qreal,qreal,qreal)const
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 3; // mapFromParent(QRectF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[0])) {
        overloadId = 2; // mapFromParent(QPolygonF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // mapFromParent(QPointF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0])) {
        overloadId = 0; // mapFromParent(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mapFromParent_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapFromParent(QPainterPath)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // mapFromParent(QPainterPath)const
                QPainterPath cppResult = cppSelf->QGraphicsItem::mapFromParent(*cpp_arg0);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapFromParent(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapFromParent(QPointF)const
                QPointF cppResult = cppSelf->QGraphicsItem::mapFromParent(*cpp_arg0);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 2: // mapFromParent(QPolygonF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapFromParent(QPolygonF)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapFromParent(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 3: // mapFromParent(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapFromParent(QRectF)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapFromParent(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 4: // mapFromParent(qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // mapFromParent(qreal,qreal)const
                QPointF cppResult = cppSelf->QGraphicsItem::mapFromParent(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 5: // mapFromParent(qreal,qreal,qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // mapFromParent(qreal,qreal,qreal,qreal)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapFromParent(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_mapFromParent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtCore.QPointF", "PySide.QtGui.QPolygonF", "PySide.QtCore.QRectF", "float, float", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.mapFromParent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mapFromScene(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQGraphicsItemFunc_mapFromScene_TypeError;

    if (!PyArg_UnpackTuple(args, "mapFromScene", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: mapFromScene(QPainterPath)const
    // 1: mapFromScene(QPointF)const
    // 2: mapFromScene(QPolygonF)const
    // 3: mapFromScene(QRectF)const
    // 4: mapFromScene(qreal,qreal)const
    // 5: mapFromScene(qreal,qreal,qreal,qreal)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 4; // mapFromScene(qreal,qreal)const
        } else if (numArgs == 4 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 5; // mapFromScene(qreal,qreal,qreal,qreal)const
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 3; // mapFromScene(QRectF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[0])) {
        overloadId = 2; // mapFromScene(QPolygonF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // mapFromScene(QPointF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0])) {
        overloadId = 0; // mapFromScene(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mapFromScene_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapFromScene(QPainterPath)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // mapFromScene(QPainterPath)const
                QPainterPath cppResult = cppSelf->QGraphicsItem::mapFromScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapFromScene(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapFromScene(QPointF)const
                QPointF cppResult = cppSelf->QGraphicsItem::mapFromScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 2: // mapFromScene(QPolygonF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapFromScene(QPolygonF)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapFromScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 3: // mapFromScene(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapFromScene(QRectF)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapFromScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 4: // mapFromScene(qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // mapFromScene(qreal,qreal)const
                QPointF cppResult = cppSelf->QGraphicsItem::mapFromScene(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 5: // mapFromScene(qreal,qreal,qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // mapFromScene(qreal,qreal,qreal,qreal)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapFromScene(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_mapFromScene_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtCore.QPointF", "PySide.QtGui.QPolygonF", "PySide.QtCore.QRectF", "float, float", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.mapFromScene", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mapRectFromItem(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3 || numArgs == 4)
        goto SbkQGraphicsItemFunc_mapRectFromItem_TypeError;

    if (!PyArg_UnpackTuple(args, "mapRectFromItem", 2, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: mapRectFromItem(const QGraphicsItem*,QRectF)const
    // 1: mapRectFromItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
    if (Shiboken::Converter< QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 5 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
            overloadId = 1; // mapRectFromItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
        } else if (numArgs == 2 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1])) {
            overloadId = 0; // mapRectFromItem(const QGraphicsItem*,QRectF)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mapRectFromItem_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapRectFromItem(const QGraphicsItem*,QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
                QRectF* cpp_arg1 = Shiboken::Converter<QRectF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // mapRectFromItem(const QGraphicsItem*,QRectF)const
                QRectF cppResult = cppSelf->QGraphicsItem::mapRectFromItem(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapRectFromItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // mapRectFromItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
                QRectF cppResult = cppSelf->QGraphicsItem::mapRectFromItem(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_mapRectFromItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtCore.QRectF", "PySide.QtGui.QGraphicsItem, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.mapRectFromItem", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mapRectFromParent(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQGraphicsItemFunc_mapRectFromParent_TypeError;

    if (!PyArg_UnpackTuple(args, "mapRectFromParent", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: mapRectFromParent(QRectF)const
    // 1: mapRectFromParent(qreal,qreal,qreal,qreal)const
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // mapRectFromParent(qreal,qreal,qreal,qreal)const
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // mapRectFromParent(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mapRectFromParent_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapRectFromParent(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapRectFromParent(QRectF)const
                QRectF cppResult = cppSelf->QGraphicsItem::mapRectFromParent(*cpp_arg0);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapRectFromParent(qreal,qreal,qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // mapRectFromParent(qreal,qreal,qreal,qreal)const
                QRectF cppResult = cppSelf->QGraphicsItem::mapRectFromParent(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_mapRectFromParent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.mapRectFromParent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mapRectFromScene(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQGraphicsItemFunc_mapRectFromScene_TypeError;

    if (!PyArg_UnpackTuple(args, "mapRectFromScene", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: mapRectFromScene(QRectF)const
    // 1: mapRectFromScene(qreal,qreal,qreal,qreal)const
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // mapRectFromScene(qreal,qreal,qreal,qreal)const
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // mapRectFromScene(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mapRectFromScene_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapRectFromScene(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapRectFromScene(QRectF)const
                QRectF cppResult = cppSelf->QGraphicsItem::mapRectFromScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapRectFromScene(qreal,qreal,qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // mapRectFromScene(qreal,qreal,qreal,qreal)const
                QRectF cppResult = cppSelf->QGraphicsItem::mapRectFromScene(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_mapRectFromScene_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.mapRectFromScene", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mapRectToItem(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3 || numArgs == 4)
        goto SbkQGraphicsItemFunc_mapRectToItem_TypeError;

    if (!PyArg_UnpackTuple(args, "mapRectToItem", 2, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: mapRectToItem(const QGraphicsItem*,QRectF)const
    // 1: mapRectToItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
    if (Shiboken::Converter< QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 5 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
            overloadId = 1; // mapRectToItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
        } else if (numArgs == 2 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1])) {
            overloadId = 0; // mapRectToItem(const QGraphicsItem*,QRectF)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mapRectToItem_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapRectToItem(const QGraphicsItem*,QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
                QRectF* cpp_arg1 = Shiboken::Converter<QRectF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // mapRectToItem(const QGraphicsItem*,QRectF)const
                QRectF cppResult = cppSelf->QGraphicsItem::mapRectToItem(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapRectToItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // mapRectToItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
                QRectF cppResult = cppSelf->QGraphicsItem::mapRectToItem(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_mapRectToItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtCore.QRectF", "PySide.QtGui.QGraphicsItem, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.mapRectToItem", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mapRectToParent(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQGraphicsItemFunc_mapRectToParent_TypeError;

    if (!PyArg_UnpackTuple(args, "mapRectToParent", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: mapRectToParent(QRectF)const
    // 1: mapRectToParent(qreal,qreal,qreal,qreal)const
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // mapRectToParent(qreal,qreal,qreal,qreal)const
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // mapRectToParent(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mapRectToParent_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapRectToParent(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapRectToParent(QRectF)const
                QRectF cppResult = cppSelf->QGraphicsItem::mapRectToParent(*cpp_arg0);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapRectToParent(qreal,qreal,qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // mapRectToParent(qreal,qreal,qreal,qreal)const
                QRectF cppResult = cppSelf->QGraphicsItem::mapRectToParent(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_mapRectToParent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.mapRectToParent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mapRectToScene(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQGraphicsItemFunc_mapRectToScene_TypeError;

    if (!PyArg_UnpackTuple(args, "mapRectToScene", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: mapRectToScene(QRectF)const
    // 1: mapRectToScene(qreal,qreal,qreal,qreal)const
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // mapRectToScene(qreal,qreal,qreal,qreal)const
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // mapRectToScene(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mapRectToScene_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapRectToScene(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapRectToScene(QRectF)const
                QRectF cppResult = cppSelf->QGraphicsItem::mapRectToScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapRectToScene(qreal,qreal,qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // mapRectToScene(qreal,qreal,qreal,qreal)const
                QRectF cppResult = cppSelf->QGraphicsItem::mapRectToScene(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_mapRectToScene_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.mapRectToScene", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mapToItem(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4)
        goto SbkQGraphicsItemFunc_mapToItem_TypeError;

    if (!PyArg_UnpackTuple(args, "mapToItem", 2, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: mapToItem(const QGraphicsItem*,QPainterPath)const
    // 1: mapToItem(const QGraphicsItem*,QPointF)const
    // 2: mapToItem(const QGraphicsItem*,QPolygonF)const
    // 3: mapToItem(const QGraphicsItem*,QRectF)const
    // 4: mapToItem(const QGraphicsItem*,qreal,qreal)const
    // 5: mapToItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
    if (Shiboken::Converter< QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs >= 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 4; // mapToItem(const QGraphicsItem*,qreal,qreal)const
            } else if (numArgs == 5 && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
                overloadId = 5; // mapToItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
            }
        } else if (numArgs == 2 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1])) {
            overloadId = 3; // mapToItem(const QGraphicsItem*,QRectF)const
        } else if (numArgs == 2 && Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[1])) {
            overloadId = 2; // mapToItem(const QGraphicsItem*,QPolygonF)const
        } else if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
            overloadId = 1; // mapToItem(const QGraphicsItem*,QPointF)const
        } else if (numArgs == 2 && Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[1])) {
            overloadId = 0; // mapToItem(const QGraphicsItem*,QPainterPath)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mapToItem_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapToItem(const QGraphicsItem*,QPainterPath)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QPainterPath* cpp_arg1 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // mapToItem(const QGraphicsItem*,QPainterPath)const
                QPainterPath cppResult = cppSelf->QGraphicsItem::mapToItem(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapToItem(const QGraphicsItem*,QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
                QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // mapToItem(const QGraphicsItem*,QPointF)const
                QPointF cppResult = cppSelf->QGraphicsItem::mapToItem(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 2: // mapToItem(const QGraphicsItem*,QPolygonF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg1_auto_ptr;
                QPolygonF* cpp_arg1 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // mapToItem(const QGraphicsItem*,QPolygonF)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapToItem(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 3: // mapToItem(const QGraphicsItem*,QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
                QRectF* cpp_arg1 = Shiboken::Converter<QRectF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // mapToItem(const QGraphicsItem*,QRectF)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapToItem(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 4: // mapToItem(const QGraphicsItem*,qreal,qreal)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // mapToItem(const QGraphicsItem*,qreal,qreal)const
                QPointF cppResult = cppSelf->QGraphicsItem::mapToItem(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 5: // mapToItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // mapToItem(const QGraphicsItem*,qreal,qreal,qreal,qreal)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapToItem(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_mapToItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtGui.QPainterPath", "PySide.QtGui.QGraphicsItem, PySide.QtCore.QPointF", "PySide.QtGui.QGraphicsItem, PySide.QtGui.QPolygonF", "PySide.QtGui.QGraphicsItem, PySide.QtCore.QRectF", "PySide.QtGui.QGraphicsItem, float, float", "PySide.QtGui.QGraphicsItem, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.mapToItem", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mapToParent(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQGraphicsItemFunc_mapToParent_TypeError;

    if (!PyArg_UnpackTuple(args, "mapToParent", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: mapToParent(QPainterPath)const
    // 1: mapToParent(QPointF)const
    // 2: mapToParent(QPolygonF)const
    // 3: mapToParent(QRectF)const
    // 4: mapToParent(qreal,qreal)const
    // 5: mapToParent(qreal,qreal,qreal,qreal)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 4; // mapToParent(qreal,qreal)const
        } else if (numArgs == 4 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 5; // mapToParent(qreal,qreal,qreal,qreal)const
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 3; // mapToParent(QRectF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[0])) {
        overloadId = 2; // mapToParent(QPolygonF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // mapToParent(QPointF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0])) {
        overloadId = 0; // mapToParent(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mapToParent_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapToParent(QPainterPath)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // mapToParent(QPainterPath)const
                QPainterPath cppResult = cppSelf->QGraphicsItem::mapToParent(*cpp_arg0);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapToParent(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapToParent(QPointF)const
                QPointF cppResult = cppSelf->QGraphicsItem::mapToParent(*cpp_arg0);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 2: // mapToParent(QPolygonF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapToParent(QPolygonF)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapToParent(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 3: // mapToParent(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapToParent(QRectF)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapToParent(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 4: // mapToParent(qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // mapToParent(qreal,qreal)const
                QPointF cppResult = cppSelf->QGraphicsItem::mapToParent(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 5: // mapToParent(qreal,qreal,qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // mapToParent(qreal,qreal,qreal,qreal)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapToParent(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_mapToParent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtCore.QPointF", "PySide.QtGui.QPolygonF", "PySide.QtCore.QRectF", "float, float", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.mapToParent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mapToScene(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQGraphicsItemFunc_mapToScene_TypeError;

    if (!PyArg_UnpackTuple(args, "mapToScene", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: mapToScene(QPainterPath)const
    // 1: mapToScene(QPointF)const
    // 2: mapToScene(QPolygonF)const
    // 3: mapToScene(QRectF)const
    // 4: mapToScene(qreal,qreal)const
    // 5: mapToScene(qreal,qreal,qreal,qreal)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 4; // mapToScene(qreal,qreal)const
        } else if (numArgs == 4 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 5; // mapToScene(qreal,qreal,qreal,qreal)const
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 3; // mapToScene(QRectF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[0])) {
        overloadId = 2; // mapToScene(QPolygonF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // mapToScene(QPointF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0])) {
        overloadId = 0; // mapToScene(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mapToScene_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapToScene(QPainterPath)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // mapToScene(QPainterPath)const
                QPainterPath cppResult = cppSelf->QGraphicsItem::mapToScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapToScene(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapToScene(QPointF)const
                QPointF cppResult = cppSelf->QGraphicsItem::mapToScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 2: // mapToScene(QPolygonF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapToScene(QPolygonF)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapToScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 3: // mapToScene(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapToScene(QRectF)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapToScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 4: // mapToScene(qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // mapToScene(qreal,qreal)const
                QPointF cppResult = cppSelf->QGraphicsItem::mapToScene(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 5: // mapToScene(qreal,qreal,qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // mapToScene(qreal,qreal,qreal,qreal)const
                QPolygonF cppResult = cppSelf->QGraphicsItem::mapToScene(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_mapToScene_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtCore.QPointF", "PySide.QtGui.QPolygonF", "PySide.QtCore.QRectF", "float, float", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.mapToScene", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mouseDoubleClickEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseDoubleClickEvent(QGraphicsSceneMouseEvent*)
    if (Shiboken::Converter<QGraphicsSceneMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseDoubleClickEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mouseDoubleClickEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneMouseEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseDoubleClickEvent(QGraphicsSceneMouseEvent*)
            cppSelf->QGraphicsItem::mouseDoubleClickEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_mouseDoubleClickEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.mouseDoubleClickEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mouseMoveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseMoveEvent(QGraphicsSceneMouseEvent*)
    if (Shiboken::Converter<QGraphicsSceneMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseMoveEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mouseMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneMouseEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseMoveEvent(QGraphicsSceneMouseEvent*)
            cppSelf->QGraphicsItem::mouseMoveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_mouseMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.mouseMoveEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mousePressEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mousePressEvent(QGraphicsSceneMouseEvent*)
    if (Shiboken::Converter<QGraphicsSceneMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mousePressEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mousePressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneMouseEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mousePressEvent(QGraphicsSceneMouseEvent*)
            cppSelf->QGraphicsItem::mousePressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_mousePressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.mousePressEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_mouseReleaseEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseReleaseEvent(QGraphicsSceneMouseEvent*)
    if (Shiboken::Converter<QGraphicsSceneMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseReleaseEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_mouseReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneMouseEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseReleaseEvent(QGraphicsSceneMouseEvent*)
            cppSelf->QGraphicsItem::mouseReleaseEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_mouseReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.mouseReleaseEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_moveBy(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "moveBy", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: moveBy(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // moveBy(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_moveBy_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // moveBy(qreal,qreal)
            cppSelf->QGraphicsItem::moveBy(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_moveBy_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.moveBy", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_opacity(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // opacity()const
            qreal cppResult = cppSelf->QGraphicsItem::opacity();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_opaqueArea(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // opaqueArea()const
            QPainterPath cppResult = cppSelf->QGraphicsItem::opaqueArea();
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_paint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "widget" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.paint(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.paint(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.paint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:paint", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
    if (numArgs >= 2 && Shiboken::Converter<QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter<const QStyleOptionGraphicsItem * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
        } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[2])) {
            overloadId = 0; // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_paint_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "widget";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.paint(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QStyleOptionGraphicsItem* cpp_arg1 = Shiboken::Converter<QStyleOptionGraphicsItem* >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QWidget* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
            // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QGraphicsItem.paint()' not implemented.");
                return 0;
            }
            cppSelf->paint(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_paint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtGui.QStyleOptionGraphicsItem, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.paint", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_panel(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // panel()const
            QGraphicsItem * cppResult = cppSelf->QGraphicsItem::panel();
            pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_panelModality(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // panelModality()const
            QGraphicsItem::PanelModality cppResult = cppSelf->QGraphicsItem::panelModality();
            pyResult = Shiboken::Converter<QGraphicsItem::PanelModality >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_parentItem(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parentItem()const
            QGraphicsItem * cppResult = cppSelf->QGraphicsItem::parentItem();
            pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);

            // Ownership transferences.
            SbkBaseWrapper_setOwnership(pyResult, true);
            Shiboken::setParent(pyResult, self);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_parentObject(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parentObject()const
            QGraphicsObject * cppResult = cppSelf->QGraphicsItem::parentObject();
            pyResult = Shiboken::Converter<QGraphicsObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_parentWidget(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parentWidget()const
            QGraphicsWidget * cppResult = cppSelf->QGraphicsItem::parentWidget();
            pyResult = Shiboken::Converter<QGraphicsWidget * >::toPython(cppResult);

            // Ownership transferences.
            Shiboken::setParent(pyResult, self);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_pos(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pos()const
            QPointF cppResult = cppSelf->QGraphicsItem::pos();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_prepareGeometryChange(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // prepareGeometryChange()
            cppSelf->QGraphicsItem::prepareGeometryChange();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemFunc_removeFromIndex(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // removeFromIndex()
            cppSelf->QGraphicsItem::removeFromIndex();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemFunc_removeSceneEventFilter(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeSceneEventFilter(QGraphicsItem*)
    if (Shiboken::Converter<QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // removeSceneEventFilter(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_removeSceneEventFilter_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeSceneEventFilter(QGraphicsItem*)
            cppSelf->QGraphicsItem::removeSceneEventFilter(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_removeSceneEventFilter_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.removeSceneEventFilter", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_resetTransform(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resetTransform()
            cppSelf->QGraphicsItem::resetTransform();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemFunc_rotate(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: rotate(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // rotate(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_rotate_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // rotate(qreal)
            cppSelf->QGraphicsItem::rotate(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_rotate_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.rotate", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_rotation(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rotation()const
            qreal cppResult = cppSelf->QGraphicsItem::rotation();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_scale(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs == 1)
        goto SbkQGraphicsItemFunc_scale_TypeError;

    if (!PyArg_UnpackTuple(args, "scale", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scale()const
    // 1: scale(qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // scale()const
    } else if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // scale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_scale_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // scale()const
            {

                if(!PyErr_Occurred()) {
                // scale()const
                qreal cppResult = cppSelf->QGraphicsItem::scale();
                pyResult = Shiboken::Converter<double >::toPython(cppResult);
                }
                break;
            }
            case 1: // scale(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // scale(qreal,qreal)
                cppSelf->QGraphicsItem::scale(cpp_arg0, cpp_arg1);
                pyResult = Py_None;
                Py_INCREF(Py_None);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_scale_TypeError:
        const char* overloads[] = {"", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.scale", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_scene(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scene()const
            QGraphicsScene * cppResult = cppSelf->QGraphicsItem::scene();
            pyResult = Shiboken::Converter<QGraphicsScene * >::toPython(cppResult);

            // Ownership transferences.
            SbkBaseWrapper_setOwnership(pyResult, true);
            Shiboken::setParent(pyResult, self);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_sceneBoundingRect(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sceneBoundingRect()const
            QRectF cppResult = cppSelf->QGraphicsItem::sceneBoundingRect();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_sceneEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sceneEvent(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // sceneEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_sceneEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // sceneEvent(QEvent*)
            bool cppResult = cppSelf->QGraphicsItem::sceneEvent(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_sceneEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.sceneEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_sceneEventFilter(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sceneEventFilter", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: sceneEventFilter(QGraphicsItem*,QEvent*)
    if (numArgs == 2 && Shiboken::Converter<QGraphicsItem * >::isConvertible(pyargs[0]) && Shiboken::Converter<QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // sceneEventFilter(QGraphicsItem*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_sceneEventFilter_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QEvent* cpp_arg1 = Shiboken::Converter<QEvent* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // sceneEventFilter(QGraphicsItem*,QEvent*)
            bool cppResult = cppSelf->QGraphicsItem::sceneEventFilter(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemFunc_sceneEventFilter_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.sceneEventFilter", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_scenePos(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scenePos()const
            QPointF cppResult = cppSelf->QGraphicsItem::scenePos();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_sceneTransform(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sceneTransform()const
            QTransform cppResult = cppSelf->QGraphicsItem::sceneTransform();
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_scroll(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "rect" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.scroll(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.scroll(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.scroll(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:scroll", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: scroll(qreal,qreal,QRectF)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // scroll(qreal,qreal,QRectF)
        } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[2])) {
            overloadId = 0; // scroll(qreal,qreal,QRectF)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_scroll_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "rect");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "rect";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.scroll(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            std::auto_ptr<QRectF > cpp_arg2_auto_ptr;
            QRectF cpp_arg2_tmp = QRectF();
            QRectF* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QRectF* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
            if (pyargs[2] && !Shiboken::Converter<QRectF >::checkType(pyargs[2]))
                cpp_arg2_auto_ptr = std::auto_ptr<QRectF >(cpp_arg2);

            if(!PyErr_Occurred()) {
            // scroll(qreal,qreal,QRectF)
            cppSelf->QGraphicsItem::scroll(cpp_arg0, cpp_arg1, *cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_scroll_TypeError:
        const char* overloads[] = {"float, float, PySide.QtCore.QRectF = QRectF()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.scroll", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setAcceptDrops(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAcceptDrops(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAcceptDrops(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setAcceptDrops_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAcceptDrops(bool)
            cppSelf->QGraphicsItem::setAcceptDrops(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setAcceptDrops_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setAcceptDrops", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setAcceptHoverEvents(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAcceptHoverEvents(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAcceptHoverEvents(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setAcceptHoverEvents_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAcceptHoverEvents(bool)
            cppSelf->QGraphicsItem::setAcceptHoverEvents(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setAcceptHoverEvents_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setAcceptHoverEvents", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setAcceptTouchEvents(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAcceptTouchEvents(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAcceptTouchEvents(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setAcceptTouchEvents_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAcceptTouchEvents(bool)
            cppSelf->QGraphicsItem::setAcceptTouchEvents(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setAcceptTouchEvents_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setAcceptTouchEvents", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setAcceptedMouseButtons(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAcceptedMouseButtons(QFlags<Qt::MouseButton>)
    if (Shiboken::Converter<QFlags<Qt::MouseButton> >::isConvertible(arg)) {
        overloadId = 0; // setAcceptedMouseButtons(QFlags<Qt::MouseButton>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setAcceptedMouseButtons_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::MouseButton> cpp_arg0 = Shiboken::Converter<QFlags<Qt::MouseButton> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAcceptedMouseButtons(QFlags<Qt::MouseButton>)
            cppSelf->QGraphicsItem::setAcceptedMouseButtons(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setAcceptedMouseButtons_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.MouseButtons", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setAcceptedMouseButtons", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setAcceptsHoverEvents(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAcceptsHoverEvents(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAcceptsHoverEvents(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setAcceptsHoverEvents_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAcceptsHoverEvents(bool)
            cppSelf->QGraphicsItem::setAcceptsHoverEvents(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setAcceptsHoverEvents_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setAcceptsHoverEvents", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setActive(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setActive(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setActive(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setActive_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setActive(bool)
            cppSelf->QGraphicsItem::setActive(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setActive_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setActive", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setBoundingRegionGranularity(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBoundingRegionGranularity(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBoundingRegionGranularity(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setBoundingRegionGranularity_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBoundingRegionGranularity(qreal)
            cppSelf->QGraphicsItem::setBoundingRegionGranularity(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setBoundingRegionGranularity_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setBoundingRegionGranularity", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setCacheMode(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "cacheSize" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setCacheMode(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setCacheMode(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setCacheMode(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setCacheMode", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setCacheMode(QGraphicsItem::CacheMode,QSize)
    if (Shiboken::Converter<QGraphicsItem::CacheMode >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setCacheMode(QGraphicsItem::CacheMode,QSize)
        } else if (Shiboken::Converter<const QSize & >::isConvertible(pyargs[1])) {
            overloadId = 0; // setCacheMode(QGraphicsItem::CacheMode,QSize)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setCacheMode_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "cacheSize");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "cacheSize";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setCacheMode(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QGraphicsItem::CacheMode cpp_arg0 = Shiboken::Converter<QGraphicsItem::CacheMode >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QSize cpp_arg1_tmp = QSize();
            QSize* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QSize* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;

            if(!PyErr_Occurred()) {
            // setCacheMode(QGraphicsItem::CacheMode,QSize)
            cppSelf->QGraphicsItem::setCacheMode(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setCacheMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem.CacheMode, PySide.QtCore.QSize = QSize()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.setCacheMode", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setCursor(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCursor(QCursor)
    if (Shiboken::Converter<const QCursor & >::isConvertible(arg)) {
        overloadId = 0; // setCursor(QCursor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setCursor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QCursor > cpp_arg0_auto_ptr;
            QCursor* cpp_arg0 = Shiboken::Converter<QCursor* >::toCpp(arg);
            if (!Shiboken::Converter<QCursor >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QCursor >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setCursor(QCursor)
            cppSelf->QGraphicsItem::setCursor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setCursor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QCursor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setCursor", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setData(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setData(int,QVariant)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setData(int,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setData_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setData(int,QVariant)
            cppSelf->QGraphicsItem::setData(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setData_TypeError:
        const char* overloads[] = {"int, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.setData", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setEnabled(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setEnabled(bool)
            cppSelf->QGraphicsItem::setEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setEnabled", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setFiltersChildEvents(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFiltersChildEvents(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFiltersChildEvents(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setFiltersChildEvents_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFiltersChildEvents(bool)
            cppSelf->QGraphicsItem::setFiltersChildEvents(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setFiltersChildEvents_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setFiltersChildEvents", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setFlag(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "enabled" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setFlag(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setFlag(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setFlag(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setFlag", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFlag(QGraphicsItem::GraphicsItemFlag,bool)
    if (Shiboken::Converter<QGraphicsItem::GraphicsItemFlag >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setFlag(QGraphicsItem::GraphicsItemFlag,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setFlag(QGraphicsItem::GraphicsItemFlag,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setFlag_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "enabled");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "enabled";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setFlag(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QGraphicsItem::GraphicsItemFlag cpp_arg0 = Shiboken::Converter<QGraphicsItem::GraphicsItemFlag >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // setFlag(QGraphicsItem::GraphicsItemFlag,bool)
            cppSelf->QGraphicsItem::setFlag(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setFlag_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem.GraphicsItemFlag, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.setFlag", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setFlags(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFlags(QFlags<QGraphicsItem::GraphicsItemFlag>)
    if (Shiboken::Converter<QFlags<QGraphicsItem::GraphicsItemFlag> >::isConvertible(arg)) {
        overloadId = 0; // setFlags(QFlags<QGraphicsItem::GraphicsItemFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<QGraphicsItem::GraphicsItemFlag> cpp_arg0 = Shiboken::Converter<QFlags<QGraphicsItem::GraphicsItemFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFlags(QFlags<QGraphicsItem::GraphicsItemFlag>)
            cppSelf->QGraphicsItem::setFlags(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setFlags_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem.GraphicsItemFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setFlags", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setFocus(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "focusReason" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setFocus(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setFocus(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:setFocus", &arg))
        return 0;


    // Overloaded function decisor
    // 0: setFocus(Qt::FocusReason)
    if (numArgs == 0) {
        overloadId = 0; // setFocus(Qt::FocusReason)
    } else if (Shiboken::Converter<Qt::FocusReason >::isConvertible(arg)) {
        overloadId = 0; // setFocus(Qt::FocusReason)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setFocus_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "focusReason");
                if (value) {
                    if (arg)
                        errorArgName = "focusReason";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setFocus(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::FocusReason cpp_arg0 = arg ? Shiboken::Converter<Qt::FocusReason >::toCpp(arg) : Qt::OtherFocusReason;

            if(!PyErr_Occurred()) {
            // setFocus(Qt::FocusReason)
            cppSelf->QGraphicsItem::setFocus(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setFocus_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.FocusReason = Qt.OtherFocusReason", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setFocus", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setFocusProxy(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFocusProxy(QGraphicsItem*)
    if (Shiboken::Converter<QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // setFocusProxy(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setFocusProxy_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFocusProxy(QGraphicsItem*)
            cppSelf->QGraphicsItem::setFocusProxy(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setFocusProxy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setFocusProxy", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setGraphicsEffect(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGraphicsEffect(QGraphicsEffect*)
    if (Shiboken::Converter<QGraphicsEffect * >::isConvertible(arg)) {
        overloadId = 0; // setGraphicsEffect(QGraphicsEffect*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setGraphicsEffect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsEffect* cpp_arg0 = Shiboken::Converter<QGraphicsEffect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGraphicsEffect(QGraphicsEffect*)
            cppSelf->QGraphicsItem::setGraphicsEffect(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setGraphicsEffect_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsEffect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setGraphicsEffect", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setGroup(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGroup(QGraphicsItemGroup*)
    if (Shiboken::Converter<QGraphicsItemGroup * >::isConvertible(arg)) {
        overloadId = 0; // setGroup(QGraphicsItemGroup*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setGroup_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItemGroup* cpp_arg0 = Shiboken::Converter<QGraphicsItemGroup* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGroup(QGraphicsItemGroup*)
            cppSelf->QGraphicsItem::setGroup(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setGroup_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItemGroup", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setGroup", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setHandlesChildEvents(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHandlesChildEvents(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHandlesChildEvents(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setHandlesChildEvents_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHandlesChildEvents(bool)
            cppSelf->QGraphicsItem::setHandlesChildEvents(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setHandlesChildEvents_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setHandlesChildEvents", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setInputMethodHints(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInputMethodHints(QFlags<Qt::InputMethodHint>)
    if (Shiboken::Converter<QFlags<Qt::InputMethodHint> >::isConvertible(arg)) {
        overloadId = 0; // setInputMethodHints(QFlags<Qt::InputMethodHint>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setInputMethodHints_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::InputMethodHint> cpp_arg0 = Shiboken::Converter<QFlags<Qt::InputMethodHint> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setInputMethodHints(QFlags<Qt::InputMethodHint>)
            cppSelf->QGraphicsItem::setInputMethodHints(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setInputMethodHints_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodHints", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setInputMethodHints", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setOpacity(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOpacity(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOpacity(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setOpacity_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOpacity(qreal)
            cppSelf->QGraphicsItem::setOpacity(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setOpacity_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setOpacity", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setPanelModality(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPanelModality(QGraphicsItem::PanelModality)
    if (Shiboken::Converter<QGraphicsItem::PanelModality >::isConvertible(arg)) {
        overloadId = 0; // setPanelModality(QGraphicsItem::PanelModality)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setPanelModality_TypeError;

    // Call function/method
    {
        {
            QGraphicsItem::PanelModality cpp_arg0 = Shiboken::Converter<QGraphicsItem::PanelModality >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPanelModality(QGraphicsItem::PanelModality)
            cppSelf->QGraphicsItem::setPanelModality(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setPanelModality_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem.PanelModality", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setPanelModality", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setParentItem(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setParentItem(QGraphicsItem*)
    if (Shiboken::Converter<QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // setParentItem(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setParentItem_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setParentItem(QGraphicsItem*)
            cppSelf->QGraphicsItem::setParentItem(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setParentItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setParentItem", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setPos(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPos", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPos(QPointF)
    // 1: setPos(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setPos(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setPos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setPos_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setPos(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setPos(QPointF)
                cppSelf->QGraphicsItem::setPos(*cpp_arg0);
                }
                break;
            }
            case 1: // setPos(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setPos(qreal,qreal)
                cppSelf->QGraphicsItem::setPos(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.setPos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setRotation(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRotation(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRotation(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setRotation_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRotation(qreal)
            cppSelf->QGraphicsItem::setRotation(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setRotation_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setRotation", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setScale(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScale(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setScale(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setScale_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScale(qreal)
            cppSelf->QGraphicsItem::setScale(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setScale_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setScale", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setSelected(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSelected(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSelected(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setSelected_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSelected(bool)
            cppSelf->QGraphicsItem::setSelected(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setSelected_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setSelected", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setToolTip(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setToolTip(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setToolTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setToolTip_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setToolTip(QString)
            cppSelf->QGraphicsItem::setToolTip(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setToolTip_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setToolTip", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setTransform(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "combine" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setTransform(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setTransform(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setTransform(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setTransform", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setTransform(QTransform,bool)
    if (Shiboken::Converter<const QTransform & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setTransform(QTransform,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setTransform(QTransform,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setTransform_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "combine");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "combine";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.setTransform(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
            // setTransform(QTransform,bool)
            cppSelf->QGraphicsItem::setTransform(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setTransform_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.setTransform", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setTransformOriginPoint(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setTransformOriginPoint", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setTransformOriginPoint(QPointF)
    // 1: setTransformOriginPoint(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setTransformOriginPoint(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setTransformOriginPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setTransformOriginPoint_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setTransformOriginPoint(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setTransformOriginPoint(QPointF)
                cppSelf->QGraphicsItem::setTransformOriginPoint(*cpp_arg0);
                }
                break;
            }
            case 1: // setTransformOriginPoint(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setTransformOriginPoint(qreal,qreal)
                cppSelf->QGraphicsItem::setTransformOriginPoint(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setTransformOriginPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.setTransformOriginPoint", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setTransformations(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTransformations(QList<QGraphicsTransform*>)
    if (Shiboken::Converter< QList<QGraphicsTransform * >  >::isConvertible(arg)) {
        overloadId = 0; // setTransformations(QList<QGraphicsTransform*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setTransformations_TypeError;

    // Call function/method
    {
        {
            QList<QGraphicsTransform * > cpp_arg0 = Shiboken::Converter<QList<QGraphicsTransform * > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTransformations(QList<QGraphicsTransform*>)
            cppSelf->QGraphicsItem::setTransformations(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setTransformations_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setTransformations", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setVisible(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setVisible_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVisible(bool)
            cppSelf->QGraphicsItem::setVisible(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setVisible", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setX(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setX(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setX(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setX_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setX(qreal)
            cppSelf->QGraphicsItem::setX(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setX_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setX", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setY(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setY(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setY(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setY_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setY(qreal)
            cppSelf->QGraphicsItem::setY(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setY_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setY", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_setZValue(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setZValue(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setZValue(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_setZValue_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setZValue(qreal)
            cppSelf->QGraphicsItem::setZValue(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_setZValue_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.setZValue", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_shape(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // shape()const
            QPainterPath cppResult = cppSelf->QGraphicsItem::shape();
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_shear(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "shear", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: shear(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // shear(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_shear_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // shear(qreal,qreal)
            cppSelf->QGraphicsItem::shear(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_shear_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.shear", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_show(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // show()
            cppSelf->QGraphicsItem::show();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemFunc_stackBefore(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: stackBefore(const QGraphicsItem*)
    if (Shiboken::Converter< QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // stackBefore(const QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_stackBefore_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // stackBefore(const QGraphicsItem*)
            cppSelf->QGraphicsItem::stackBefore(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_stackBefore_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.stackBefore", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_toGraphicsObject(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toGraphicsObject()
            QGraphicsObject * cppResult = cppSelf->QGraphicsItem::toGraphicsObject();
            pyResult = Shiboken::Converter<QGraphicsObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_toolTip(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toolTip()const
            QString cppResult = cppSelf->QGraphicsItem::toolTip();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_topLevelItem(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // topLevelItem()const
            QGraphicsItem * cppResult = cppSelf->QGraphicsItem::topLevelItem();
            pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_topLevelWidget(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // topLevelWidget()const
            QGraphicsWidget * cppResult = cppSelf->QGraphicsItem::topLevelWidget();
            pyResult = Shiboken::Converter<QGraphicsWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_transform(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transform()const
            QTransform cppResult = cppSelf->QGraphicsItem::transform();
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_transformOriginPoint(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transformOriginPoint()const
            QPointF cppResult = cppSelf->QGraphicsItem::transformOriginPoint();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_transformations(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transformations()const
            QList<QGraphicsTransform * > cppResult = cppSelf->QGraphicsItem::transformations();
            pyResult = Shiboken::Converter<QList<QGraphicsTransform * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_translate(PyObject* self, PyObject* args)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // translate(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_translate_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // translate(qreal,qreal)
            cppSelf->QGraphicsItem::translate(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_translate_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.translate", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_type(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // type()const
            int cppResult = cppSelf->QGraphicsItem::type();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_ungrabKeyboard(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ungrabKeyboard()
            cppSelf->QGraphicsItem::ungrabKeyboard();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemFunc_ungrabMouse(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ungrabMouse()
            cppSelf->QGraphicsItem::ungrabMouse();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemFunc_unsetCursor(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // unsetCursor()
            cppSelf->QGraphicsItem::unsetCursor();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemFunc_update(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "rect" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.update(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.update(): too many arguments");
        return 0;
    } else if (numArgs == 2 || numArgs == 3)
        goto SbkQGraphicsItemFunc_update_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:update", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: update(QRectF)
    // 1: update(qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // update(QRectF)
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // update(qreal,qreal,qreal,qreal)
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // update(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_update_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // update(QRectF)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "rect");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "rect";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItem.update(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF cpp_arg0_tmp = QRectF();
                QRectF* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QRectF* >::toCpp(pyargs[0]) : &cpp_arg0_tmp;
                if (pyargs[0] && !Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // update(QRectF)
                cppSelf->QGraphicsItem::update(*cpp_arg0);
                }
                break;
            }
            case 1: // update(qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // update(qreal,qreal,qreal,qreal)
                cppSelf->QGraphicsItem::update(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_update_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF = QRectF()", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItem.update", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_updateMicroFocus(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // updateMicroFocus()
            cppSelf->QGraphicsItem::updateMicroFocus();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemFunc_wheelEvent(PyObject* self, PyObject* arg)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: wheelEvent(QGraphicsSceneWheelEvent*)
    if (Shiboken::Converter<QGraphicsSceneWheelEvent * >::isConvertible(arg)) {
        overloadId = 0; // wheelEvent(QGraphicsSceneWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemFunc_wheelEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneWheelEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneWheelEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // wheelEvent(QGraphicsSceneWheelEvent*)
            cppSelf->QGraphicsItem::wheelEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemFunc_wheelEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneWheelEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItem.wheelEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemFunc_window(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // window()const
            QGraphicsWidget * cppResult = cppSelf->QGraphicsItem::window();
            pyResult = Shiboken::Converter<QGraphicsWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_x(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // x()const
            qreal cppResult = cppSelf->QGraphicsItem::x();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_y(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // y()const
            qreal cppResult = cppSelf->QGraphicsItem::y();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemFunc_zValue(PyObject* self)
{
    QGraphicsItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // zValue()const
            qreal cppResult = cppSelf->QGraphicsItem::zValue();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQGraphicsItem_methods[] = {
    {"acceptDrops", (PyCFunction)SbkQGraphicsItemFunc_acceptDrops, METH_NOARGS},
    {"acceptHoverEvents", (PyCFunction)SbkQGraphicsItemFunc_acceptHoverEvents, METH_NOARGS},
    {"acceptTouchEvents", (PyCFunction)SbkQGraphicsItemFunc_acceptTouchEvents, METH_NOARGS},
    {"acceptedMouseButtons", (PyCFunction)SbkQGraphicsItemFunc_acceptedMouseButtons, METH_NOARGS},
    {"acceptsHoverEvents", (PyCFunction)SbkQGraphicsItemFunc_acceptsHoverEvents, METH_NOARGS},
    {"addToIndex", (PyCFunction)SbkQGraphicsItemFunc_addToIndex, METH_NOARGS},
    {"advance", (PyCFunction)SbkQGraphicsItemFunc_advance, METH_O},
    {"boundingRect", (PyCFunction)SbkQGraphicsItemFunc_boundingRect, METH_NOARGS},
    {"boundingRegion", (PyCFunction)SbkQGraphicsItemFunc_boundingRegion, METH_O},
    {"boundingRegionGranularity", (PyCFunction)SbkQGraphicsItemFunc_boundingRegionGranularity, METH_NOARGS},
    {"cacheMode", (PyCFunction)SbkQGraphicsItemFunc_cacheMode, METH_NOARGS},
    {"childItems", (PyCFunction)SbkQGraphicsItemFunc_childItems, METH_NOARGS},
    {"childrenBoundingRect", (PyCFunction)SbkQGraphicsItemFunc_childrenBoundingRect, METH_NOARGS},
    {"clearFocus", (PyCFunction)SbkQGraphicsItemFunc_clearFocus, METH_NOARGS},
    {"clipPath", (PyCFunction)SbkQGraphicsItemFunc_clipPath, METH_NOARGS},
    {"collidesWithItem", (PyCFunction)SbkQGraphicsItemFunc_collidesWithItem, METH_VARARGS|METH_KEYWORDS},
    {"collidesWithPath", (PyCFunction)SbkQGraphicsItemFunc_collidesWithPath, METH_VARARGS|METH_KEYWORDS},
    {"collidingItems", (PyCFunction)SbkQGraphicsItemFunc_collidingItems, METH_VARARGS|METH_KEYWORDS},
    {"commonAncestorItem", (PyCFunction)SbkQGraphicsItemFunc_commonAncestorItem, METH_O},
    {"contains", (PyCFunction)SbkQGraphicsItemFunc_contains, METH_O},
    {"contextMenuEvent", (PyCFunction)SbkQGraphicsItemFunc_contextMenuEvent, METH_O},
    {"cursor", (PyCFunction)SbkQGraphicsItemFunc_cursor, METH_NOARGS},
    {"data", (PyCFunction)SbkQGraphicsItemFunc_data, METH_O},
    {"deviceTransform", (PyCFunction)SbkQGraphicsItemFunc_deviceTransform, METH_O},
    {"dragEnterEvent", (PyCFunction)SbkQGraphicsItemFunc_dragEnterEvent, METH_O},
    {"dragLeaveEvent", (PyCFunction)SbkQGraphicsItemFunc_dragLeaveEvent, METH_O},
    {"dragMoveEvent", (PyCFunction)SbkQGraphicsItemFunc_dragMoveEvent, METH_O},
    {"dropEvent", (PyCFunction)SbkQGraphicsItemFunc_dropEvent, METH_O},
    {"effectiveOpacity", (PyCFunction)SbkQGraphicsItemFunc_effectiveOpacity, METH_NOARGS},
    {"ensureVisible", (PyCFunction)SbkQGraphicsItemFunc_ensureVisible, METH_VARARGS|METH_KEYWORDS},
    {"extension", (PyCFunction)SbkQGraphicsItemFunc_extension, METH_O},
    {"filtersChildEvents", (PyCFunction)SbkQGraphicsItemFunc_filtersChildEvents, METH_NOARGS},
    {"flags", (PyCFunction)SbkQGraphicsItemFunc_flags, METH_NOARGS},
    {"focusInEvent", (PyCFunction)SbkQGraphicsItemFunc_focusInEvent, METH_O},
    {"focusItem", (PyCFunction)SbkQGraphicsItemFunc_focusItem, METH_NOARGS},
    {"focusOutEvent", (PyCFunction)SbkQGraphicsItemFunc_focusOutEvent, METH_O},
    {"focusProxy", (PyCFunction)SbkQGraphicsItemFunc_focusProxy, METH_NOARGS},
    {"focusScopeItem", (PyCFunction)SbkQGraphicsItemFunc_focusScopeItem, METH_NOARGS},
    {"grabKeyboard", (PyCFunction)SbkQGraphicsItemFunc_grabKeyboard, METH_NOARGS},
    {"grabMouse", (PyCFunction)SbkQGraphicsItemFunc_grabMouse, METH_NOARGS},
    {"graphicsEffect", (PyCFunction)SbkQGraphicsItemFunc_graphicsEffect, METH_NOARGS},
    {"group", (PyCFunction)SbkQGraphicsItemFunc_group, METH_NOARGS},
    {"handlesChildEvents", (PyCFunction)SbkQGraphicsItemFunc_handlesChildEvents, METH_NOARGS},
    {"hasCursor", (PyCFunction)SbkQGraphicsItemFunc_hasCursor, METH_NOARGS},
    {"hasFocus", (PyCFunction)SbkQGraphicsItemFunc_hasFocus, METH_NOARGS},
    {"hide", (PyCFunction)SbkQGraphicsItemFunc_hide, METH_NOARGS},
    {"hoverEnterEvent", (PyCFunction)SbkQGraphicsItemFunc_hoverEnterEvent, METH_O},
    {"hoverLeaveEvent", (PyCFunction)SbkQGraphicsItemFunc_hoverLeaveEvent, METH_O},
    {"hoverMoveEvent", (PyCFunction)SbkQGraphicsItemFunc_hoverMoveEvent, METH_O},
    {"inputMethodEvent", (PyCFunction)SbkQGraphicsItemFunc_inputMethodEvent, METH_O},
    {"inputMethodHints", (PyCFunction)SbkQGraphicsItemFunc_inputMethodHints, METH_NOARGS},
    {"inputMethodQuery", (PyCFunction)SbkQGraphicsItemFunc_inputMethodQuery, METH_O},
    {"installSceneEventFilter", (PyCFunction)SbkQGraphicsItemFunc_installSceneEventFilter, METH_O},
    {"isActive", (PyCFunction)SbkQGraphicsItemFunc_isActive, METH_NOARGS},
    {"isAncestorOf", (PyCFunction)SbkQGraphicsItemFunc_isAncestorOf, METH_O},
    {"isBlockedByModalPanel", (PyCFunction)SbkQGraphicsItemFunc_isBlockedByModalPanel, METH_NOARGS},
    {"isClipped", (PyCFunction)SbkQGraphicsItemFunc_isClipped, METH_NOARGS},
    {"isEnabled", (PyCFunction)SbkQGraphicsItemFunc_isEnabled, METH_NOARGS},
    {"isObscured", (PyCFunction)SbkQGraphicsItemFunc_isObscured, METH_VARARGS},
    {"isObscuredBy", (PyCFunction)SbkQGraphicsItemFunc_isObscuredBy, METH_O},
    {"isPanel", (PyCFunction)SbkQGraphicsItemFunc_isPanel, METH_NOARGS},
    {"isSelected", (PyCFunction)SbkQGraphicsItemFunc_isSelected, METH_NOARGS},
    {"isUnderMouse", (PyCFunction)SbkQGraphicsItemFunc_isUnderMouse, METH_NOARGS},
    {"isVisible", (PyCFunction)SbkQGraphicsItemFunc_isVisible, METH_NOARGS},
    {"isVisibleTo", (PyCFunction)SbkQGraphicsItemFunc_isVisibleTo, METH_O},
    {"isWidget", (PyCFunction)SbkQGraphicsItemFunc_isWidget, METH_NOARGS},
    {"isWindow", (PyCFunction)SbkQGraphicsItemFunc_isWindow, METH_NOARGS},
    {"itemChange", (PyCFunction)SbkQGraphicsItemFunc_itemChange, METH_VARARGS},
    {"itemTransform", (PyCFunction)SbkQGraphicsItemFunc_itemTransform, METH_VARARGS|METH_KEYWORDS},
    {"keyPressEvent", (PyCFunction)SbkQGraphicsItemFunc_keyPressEvent, METH_O},
    {"keyReleaseEvent", (PyCFunction)SbkQGraphicsItemFunc_keyReleaseEvent, METH_O},
    {"mapFromItem", (PyCFunction)SbkQGraphicsItemFunc_mapFromItem, METH_VARARGS},
    {"mapFromParent", (PyCFunction)SbkQGraphicsItemFunc_mapFromParent, METH_VARARGS},
    {"mapFromScene", (PyCFunction)SbkQGraphicsItemFunc_mapFromScene, METH_VARARGS},
    {"mapRectFromItem", (PyCFunction)SbkQGraphicsItemFunc_mapRectFromItem, METH_VARARGS},
    {"mapRectFromParent", (PyCFunction)SbkQGraphicsItemFunc_mapRectFromParent, METH_VARARGS},
    {"mapRectFromScene", (PyCFunction)SbkQGraphicsItemFunc_mapRectFromScene, METH_VARARGS},
    {"mapRectToItem", (PyCFunction)SbkQGraphicsItemFunc_mapRectToItem, METH_VARARGS},
    {"mapRectToParent", (PyCFunction)SbkQGraphicsItemFunc_mapRectToParent, METH_VARARGS},
    {"mapRectToScene", (PyCFunction)SbkQGraphicsItemFunc_mapRectToScene, METH_VARARGS},
    {"mapToItem", (PyCFunction)SbkQGraphicsItemFunc_mapToItem, METH_VARARGS},
    {"mapToParent", (PyCFunction)SbkQGraphicsItemFunc_mapToParent, METH_VARARGS},
    {"mapToScene", (PyCFunction)SbkQGraphicsItemFunc_mapToScene, METH_VARARGS},
    {"mouseDoubleClickEvent", (PyCFunction)SbkQGraphicsItemFunc_mouseDoubleClickEvent, METH_O},
    {"mouseMoveEvent", (PyCFunction)SbkQGraphicsItemFunc_mouseMoveEvent, METH_O},
    {"mousePressEvent", (PyCFunction)SbkQGraphicsItemFunc_mousePressEvent, METH_O},
    {"mouseReleaseEvent", (PyCFunction)SbkQGraphicsItemFunc_mouseReleaseEvent, METH_O},
    {"moveBy", (PyCFunction)SbkQGraphicsItemFunc_moveBy, METH_VARARGS},
    {"opacity", (PyCFunction)SbkQGraphicsItemFunc_opacity, METH_NOARGS},
    {"opaqueArea", (PyCFunction)SbkQGraphicsItemFunc_opaqueArea, METH_NOARGS},
    {"paint", (PyCFunction)SbkQGraphicsItemFunc_paint, METH_VARARGS|METH_KEYWORDS},
    {"panel", (PyCFunction)SbkQGraphicsItemFunc_panel, METH_NOARGS},
    {"panelModality", (PyCFunction)SbkQGraphicsItemFunc_panelModality, METH_NOARGS},
    {"parentItem", (PyCFunction)SbkQGraphicsItemFunc_parentItem, METH_NOARGS},
    {"parentObject", (PyCFunction)SbkQGraphicsItemFunc_parentObject, METH_NOARGS},
    {"parentWidget", (PyCFunction)SbkQGraphicsItemFunc_parentWidget, METH_NOARGS},
    {"pos", (PyCFunction)SbkQGraphicsItemFunc_pos, METH_NOARGS},
    {"prepareGeometryChange", (PyCFunction)SbkQGraphicsItemFunc_prepareGeometryChange, METH_NOARGS},
    {"removeFromIndex", (PyCFunction)SbkQGraphicsItemFunc_removeFromIndex, METH_NOARGS},
    {"removeSceneEventFilter", (PyCFunction)SbkQGraphicsItemFunc_removeSceneEventFilter, METH_O},
    {"resetTransform", (PyCFunction)SbkQGraphicsItemFunc_resetTransform, METH_NOARGS},
    {"rotate", (PyCFunction)SbkQGraphicsItemFunc_rotate, METH_O},
    {"rotation", (PyCFunction)SbkQGraphicsItemFunc_rotation, METH_NOARGS},
    {"scale", (PyCFunction)SbkQGraphicsItemFunc_scale, METH_VARARGS},
    {"scene", (PyCFunction)SbkQGraphicsItemFunc_scene, METH_NOARGS},
    {"sceneBoundingRect", (PyCFunction)SbkQGraphicsItemFunc_sceneBoundingRect, METH_NOARGS},
    {"sceneEvent", (PyCFunction)SbkQGraphicsItemFunc_sceneEvent, METH_O},
    {"sceneEventFilter", (PyCFunction)SbkQGraphicsItemFunc_sceneEventFilter, METH_VARARGS},
    {"scenePos", (PyCFunction)SbkQGraphicsItemFunc_scenePos, METH_NOARGS},
    {"sceneTransform", (PyCFunction)SbkQGraphicsItemFunc_sceneTransform, METH_NOARGS},
    {"scroll", (PyCFunction)SbkQGraphicsItemFunc_scroll, METH_VARARGS|METH_KEYWORDS},
    {"setAcceptDrops", (PyCFunction)SbkQGraphicsItemFunc_setAcceptDrops, METH_O},
    {"setAcceptHoverEvents", (PyCFunction)SbkQGraphicsItemFunc_setAcceptHoverEvents, METH_O},
    {"setAcceptTouchEvents", (PyCFunction)SbkQGraphicsItemFunc_setAcceptTouchEvents, METH_O},
    {"setAcceptedMouseButtons", (PyCFunction)SbkQGraphicsItemFunc_setAcceptedMouseButtons, METH_O},
    {"setAcceptsHoverEvents", (PyCFunction)SbkQGraphicsItemFunc_setAcceptsHoverEvents, METH_O},
    {"setActive", (PyCFunction)SbkQGraphicsItemFunc_setActive, METH_O},
    {"setBoundingRegionGranularity", (PyCFunction)SbkQGraphicsItemFunc_setBoundingRegionGranularity, METH_O},
    {"setCacheMode", (PyCFunction)SbkQGraphicsItemFunc_setCacheMode, METH_VARARGS|METH_KEYWORDS},
    {"setCursor", (PyCFunction)SbkQGraphicsItemFunc_setCursor, METH_O},
    {"setData", (PyCFunction)SbkQGraphicsItemFunc_setData, METH_VARARGS},
    {"setEnabled", (PyCFunction)SbkQGraphicsItemFunc_setEnabled, METH_O},
    {"setFiltersChildEvents", (PyCFunction)SbkQGraphicsItemFunc_setFiltersChildEvents, METH_O},
    {"setFlag", (PyCFunction)SbkQGraphicsItemFunc_setFlag, METH_VARARGS|METH_KEYWORDS},
    {"setFlags", (PyCFunction)SbkQGraphicsItemFunc_setFlags, METH_O},
    {"setFocus", (PyCFunction)SbkQGraphicsItemFunc_setFocus, METH_VARARGS|METH_KEYWORDS},
    {"setFocusProxy", (PyCFunction)SbkQGraphicsItemFunc_setFocusProxy, METH_O},
    {"setGraphicsEffect", (PyCFunction)SbkQGraphicsItemFunc_setGraphicsEffect, METH_O},
    {"setGroup", (PyCFunction)SbkQGraphicsItemFunc_setGroup, METH_O},
    {"setHandlesChildEvents", (PyCFunction)SbkQGraphicsItemFunc_setHandlesChildEvents, METH_O},
    {"setInputMethodHints", (PyCFunction)SbkQGraphicsItemFunc_setInputMethodHints, METH_O},
    {"setOpacity", (PyCFunction)SbkQGraphicsItemFunc_setOpacity, METH_O},
    {"setPanelModality", (PyCFunction)SbkQGraphicsItemFunc_setPanelModality, METH_O},
    {"setParentItem", (PyCFunction)SbkQGraphicsItemFunc_setParentItem, METH_O},
    {"setPos", (PyCFunction)SbkQGraphicsItemFunc_setPos, METH_VARARGS},
    {"setRotation", (PyCFunction)SbkQGraphicsItemFunc_setRotation, METH_O},
    {"setScale", (PyCFunction)SbkQGraphicsItemFunc_setScale, METH_O},
    {"setSelected", (PyCFunction)SbkQGraphicsItemFunc_setSelected, METH_O},
    {"setToolTip", (PyCFunction)SbkQGraphicsItemFunc_setToolTip, METH_O},
    {"setTransform", (PyCFunction)SbkQGraphicsItemFunc_setTransform, METH_VARARGS|METH_KEYWORDS},
    {"setTransformOriginPoint", (PyCFunction)SbkQGraphicsItemFunc_setTransformOriginPoint, METH_VARARGS},
    {"setTransformations", (PyCFunction)SbkQGraphicsItemFunc_setTransformations, METH_O},
    {"setVisible", (PyCFunction)SbkQGraphicsItemFunc_setVisible, METH_O},
    {"setX", (PyCFunction)SbkQGraphicsItemFunc_setX, METH_O},
    {"setY", (PyCFunction)SbkQGraphicsItemFunc_setY, METH_O},
    {"setZValue", (PyCFunction)SbkQGraphicsItemFunc_setZValue, METH_O},
    {"shape", (PyCFunction)SbkQGraphicsItemFunc_shape, METH_NOARGS},
    {"shear", (PyCFunction)SbkQGraphicsItemFunc_shear, METH_VARARGS},
    {"show", (PyCFunction)SbkQGraphicsItemFunc_show, METH_NOARGS},
    {"stackBefore", (PyCFunction)SbkQGraphicsItemFunc_stackBefore, METH_O},
    {"toGraphicsObject", (PyCFunction)SbkQGraphicsItemFunc_toGraphicsObject, METH_NOARGS},
    {"toolTip", (PyCFunction)SbkQGraphicsItemFunc_toolTip, METH_NOARGS},
    {"topLevelItem", (PyCFunction)SbkQGraphicsItemFunc_topLevelItem, METH_NOARGS},
    {"topLevelWidget", (PyCFunction)SbkQGraphicsItemFunc_topLevelWidget, METH_NOARGS},
    {"transform", (PyCFunction)SbkQGraphicsItemFunc_transform, METH_NOARGS},
    {"transformOriginPoint", (PyCFunction)SbkQGraphicsItemFunc_transformOriginPoint, METH_NOARGS},
    {"transformations", (PyCFunction)SbkQGraphicsItemFunc_transformations, METH_NOARGS},
    {"translate", (PyCFunction)SbkQGraphicsItemFunc_translate, METH_VARARGS},
    {"type", (PyCFunction)SbkQGraphicsItemFunc_type, METH_NOARGS},
    {"ungrabKeyboard", (PyCFunction)SbkQGraphicsItemFunc_ungrabKeyboard, METH_NOARGS},
    {"ungrabMouse", (PyCFunction)SbkQGraphicsItemFunc_ungrabMouse, METH_NOARGS},
    {"unsetCursor", (PyCFunction)SbkQGraphicsItemFunc_unsetCursor, METH_NOARGS},
    {"update", (PyCFunction)SbkQGraphicsItemFunc_update, METH_VARARGS|METH_KEYWORDS},
    {"updateMicroFocus", (PyCFunction)SbkQGraphicsItemFunc_updateMicroFocus, METH_NOARGS},
    {"wheelEvent", (PyCFunction)SbkQGraphicsItemFunc_wheelEvent, METH_O},
    {"window", (PyCFunction)SbkQGraphicsItemFunc_window, METH_NOARGS},
    {"x", (PyCFunction)SbkQGraphicsItemFunc_x, METH_NOARGS},
    {"y", (PyCFunction)SbkQGraphicsItemFunc_y, METH_NOARGS},
    {"zValue", (PyCFunction)SbkQGraphicsItemFunc_zValue, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGraphicsItem_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsItem",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGraphicsItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGraphicsItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGraphicsItem >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGraphicsItem*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QGraphicsItem_CacheMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QGraphicsItem_CacheMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QGraphicsItem_CacheMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "CacheMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QGraphicsItem_CacheMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QGraphicsItem_CacheMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QGraphicsItem_CacheMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QGraphicsItem_PanelModality_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QGraphicsItem_PanelModality_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QGraphicsItem_PanelModality_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PanelModality",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QGraphicsItem_PanelModality_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QGraphicsItem_PanelModality_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QGraphicsItem_PanelModality_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGraphicsItem::GraphicsItemFlags >::checkType(self) && Shiboken::Converter<QGraphicsItem::GraphicsItemFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGraphicsItem::GraphicsItemFlags >::toPython(
        Shiboken::Converter<QGraphicsItem::GraphicsItemFlags>::toCpp(self)
        & Shiboken::Converter< QGraphicsItem::GraphicsItemFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGraphicsItem::GraphicsItemFlags >::checkType(self) && Shiboken::Converter<QGraphicsItem::GraphicsItemFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGraphicsItem::GraphicsItemFlags >::toPython(
        Shiboken::Converter<QGraphicsItem::GraphicsItemFlags>::toCpp(self)
        | Shiboken::Converter< QGraphicsItem::GraphicsItemFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGraphicsItem::GraphicsItemFlags >::checkType(self) && Shiboken::Converter<QGraphicsItem::GraphicsItemFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGraphicsItem::GraphicsItemFlags >::toPython(
        Shiboken::Converter<QGraphicsItem::GraphicsItemFlags>::toCpp(self)
        ^ Shiboken::Converter< QGraphicsItem::GraphicsItemFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsItem::GraphicsItemFlags >::toPython(
        ~Shiboken::Converter<QGraphicsItem::GraphicsItemFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "GraphicsItemFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "GraphicsItemFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


static PyGetSetDef SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "GraphicsItemChange",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QGraphicsItem_Extension_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QGraphicsItem_Extension_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QGraphicsItem_Extension_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Extension",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QGraphicsItem_Extension_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QGraphicsItem_Extension_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QGraphicsItem_Extension_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QGraphicsItem(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSITEM_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGraphicsItem_Type);


    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQGraphicsItem_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGraphicsItem_Type));
    PyModule_AddObject(module, "QGraphicsItem",
        ((PyObject*)&SbkQGraphicsItem_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: CacheMode
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSITEM_CACHEMODE_IDX] = &SbkPySide_QtGui_QGraphicsItem_CacheMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsItem_CacheMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsItem_CacheMode_Type);
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
            "CacheMode",((PyObject*)&SbkPySide_QtGui_QGraphicsItem_CacheMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_CacheMode_Type,
        (long) QGraphicsItem::NoCache, "NoCache");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "NoCache", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_CacheMode_Type.tp_dict,
        "NoCache", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_CacheMode_Type,
        (long) QGraphicsItem::ItemCoordinateCache, "ItemCoordinateCache");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemCoordinateCache", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_CacheMode_Type.tp_dict,
        "ItemCoordinateCache", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_CacheMode_Type,
        (long) QGraphicsItem::DeviceCoordinateCache, "DeviceCoordinateCache");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "DeviceCoordinateCache", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_CacheMode_Type.tp_dict,
        "DeviceCoordinateCache", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsItem::CacheMode");

    // init enum class: PanelModality
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSITEM_PANELMODALITY_IDX] = &SbkPySide_QtGui_QGraphicsItem_PanelModality_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsItem_PanelModality_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsItem_PanelModality_Type);
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
            "PanelModality",((PyObject*)&SbkPySide_QtGui_QGraphicsItem_PanelModality_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_PanelModality_Type,
        (long) QGraphicsItem::NonModal, "NonModal");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "NonModal", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_PanelModality_Type.tp_dict,
        "NonModal", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_PanelModality_Type,
        (long) QGraphicsItem::PanelModal, "PanelModal");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "PanelModal", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_PanelModality_Type.tp_dict,
        "PanelModal", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_PanelModality_Type,
        (long) QGraphicsItem::SceneModal, "SceneModal");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "SceneModal", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_PanelModality_Type.tp_dict,
        "SceneModal", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsItem::PanelModality");

    // init enum class: GraphicsItemFlag
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSITEM_GRAPHICSITEMFLAG_IDX] = &SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type);
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
            "GraphicsItemFlag",((PyObject*)&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type));

    // init flags class: QFlags<QGraphicsItem::GraphicsItemFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QGRAPHICSITEM_GRAPHICSITEMFLAG__IDX] = &SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlags_Type);
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
            "GraphicsItemFlags",((PyObject*)&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemIsMovable, "ItemIsMovable");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemIsMovable", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemIsMovable", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemIsSelectable, "ItemIsSelectable");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemIsSelectable", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemIsSelectable", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemIsFocusable, "ItemIsFocusable");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemIsFocusable", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemIsFocusable", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemClipsToShape, "ItemClipsToShape");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemClipsToShape", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemClipsToShape", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemClipsChildrenToShape, "ItemClipsChildrenToShape");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemClipsChildrenToShape", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemClipsChildrenToShape", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemIgnoresTransformations, "ItemIgnoresTransformations");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemIgnoresTransformations", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemIgnoresTransformations", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemIgnoresParentOpacity, "ItemIgnoresParentOpacity");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemIgnoresParentOpacity", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemIgnoresParentOpacity", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemDoesntPropagateOpacityToChildren, "ItemDoesntPropagateOpacityToChildren");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemDoesntPropagateOpacityToChildren", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemDoesntPropagateOpacityToChildren", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemStacksBehindParent, "ItemStacksBehindParent");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemStacksBehindParent", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemStacksBehindParent", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemUsesExtendedStyleOption, "ItemUsesExtendedStyleOption");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemUsesExtendedStyleOption", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemUsesExtendedStyleOption", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemHasNoContents, "ItemHasNoContents");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemHasNoContents", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemHasNoContents", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemSendsGeometryChanges, "ItemSendsGeometryChanges");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemSendsGeometryChanges", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemSendsGeometryChanges", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemAcceptsInputMethod, "ItemAcceptsInputMethod");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemAcceptsInputMethod", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemAcceptsInputMethod", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemNegativeZStacksBehindParent, "ItemNegativeZStacksBehindParent");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemNegativeZStacksBehindParent", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemNegativeZStacksBehindParent", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemIsPanel, "ItemIsPanel");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemIsPanel", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemIsPanel", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemIsFocusScope, "ItemIsFocusScope");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemIsFocusScope", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemIsFocusScope", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemSendsScenePositionChanges, "ItemSendsScenePositionChanges");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemSendsScenePositionChanges", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemSendsScenePositionChanges", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type,
        (long) QGraphicsItem::ItemStopsClickFocusPropagation, "ItemStopsClickFocusPropagation");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemStopsClickFocusPropagation", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemFlag_Type.tp_dict,
        "ItemStopsClickFocusPropagation", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsItem::GraphicsItemFlag");

    // init enum class: GraphicsItemChange
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSITEM_GRAPHICSITEMCHANGE_IDX] = &SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type);
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
            "GraphicsItemChange",((PyObject*)&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemPositionChange, "ItemPositionChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemPositionChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemPositionChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemMatrixChange, "ItemMatrixChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemMatrixChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemMatrixChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemVisibleChange, "ItemVisibleChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemVisibleChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemVisibleChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemEnabledChange, "ItemEnabledChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemEnabledChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemEnabledChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemSelectedChange, "ItemSelectedChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemSelectedChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemSelectedChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemParentChange, "ItemParentChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemParentChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemParentChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemChildAddedChange, "ItemChildAddedChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemChildAddedChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemChildAddedChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemChildRemovedChange, "ItemChildRemovedChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemChildRemovedChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemChildRemovedChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemTransformChange, "ItemTransformChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemTransformChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemTransformChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemPositionHasChanged, "ItemPositionHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemPositionHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemPositionHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemTransformHasChanged, "ItemTransformHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemTransformHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemTransformHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemSceneChange, "ItemSceneChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemSceneChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemSceneChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemVisibleHasChanged, "ItemVisibleHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemVisibleHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemVisibleHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemEnabledHasChanged, "ItemEnabledHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemEnabledHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemEnabledHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemSelectedHasChanged, "ItemSelectedHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemSelectedHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemSelectedHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemParentHasChanged, "ItemParentHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemParentHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemParentHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemSceneHasChanged, "ItemSceneHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemSceneHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemSceneHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemCursorChange, "ItemCursorChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemCursorChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemCursorChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemCursorHasChanged, "ItemCursorHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemCursorHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemCursorHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemToolTipChange, "ItemToolTipChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemToolTipChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemToolTipChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemToolTipHasChanged, "ItemToolTipHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemToolTipHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemToolTipHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemFlagsChange, "ItemFlagsChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemFlagsChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemFlagsChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemFlagsHaveChanged, "ItemFlagsHaveChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemFlagsHaveChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemFlagsHaveChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemZValueChange, "ItemZValueChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemZValueChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemZValueChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemZValueHasChanged, "ItemZValueHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemZValueHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemZValueHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemOpacityChange, "ItemOpacityChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemOpacityChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemOpacityChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemOpacityHasChanged, "ItemOpacityHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemOpacityHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemOpacityHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemScenePositionHasChanged, "ItemScenePositionHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemScenePositionHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemScenePositionHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemRotationChange, "ItemRotationChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemRotationChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemRotationChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemRotationHasChanged, "ItemRotationHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemRotationHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemRotationHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemScaleChange, "ItemScaleChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemScaleChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemScaleChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemScaleHasChanged, "ItemScaleHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemScaleHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemScaleHasChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemTransformOriginPointChange, "ItemTransformOriginPointChange");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemTransformOriginPointChange", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemTransformOriginPointChange", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type,
        (long) QGraphicsItem::ItemTransformOriginPointHasChanged, "ItemTransformOriginPointHasChanged");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "ItemTransformOriginPointHasChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_GraphicsItemChange_Type.tp_dict,
        "ItemTransformOriginPointHasChanged", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsItem::GraphicsItemChange");

    // init enum class: Extension
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSITEM_EXTENSION_IDX] = &SbkPySide_QtGui_QGraphicsItem_Extension_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsItem_Extension_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsItem_Extension_Type);
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
            "Extension",((PyObject*)&SbkPySide_QtGui_QGraphicsItem_Extension_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsItem_Extension_Type,
        (long) QGraphicsItem::UserExtension, "UserExtension");
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict,
        "UserExtension", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsItem_Extension_Type.tp_dict,
        "UserExtension", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsItem::Extension");



    // Begin code injection
    
    PyObject* userTypeConstant =  PyInt_FromLong(QGraphicsItem::UserType);
    PyDict_SetItemString(SbkQGraphicsItem_Type.super.ht_type.tp_dict, "UserType", userTypeConstant);
    
    // End of code injection
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsItem >("QGraphicsItem*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsItem >(typeid(QGraphicsItem).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsItem >(typeid(QGraphicsItemWrapper).name());
    PySide::initQtMetaType<QGraphicsItem* >();
}


